{
 "cells": [
  {
   "cell_type": "markdown",
   "metadata": {
    "hideCode": true,
    "hidePrompt": true,
    "slideshow": {
     "slide_type": "slide"
    }
   },
   "source": [
    "# LFP example with stim strength"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 1,
   "metadata": {},
   "outputs": [],
   "source": [
    "import numpy as np\n",
    "import pandas as pd\n",
    "from bayes_window import BayesWindow, BayesRegression\n",
    "from bayes_window.generative_models import generate_fake_lfp"
   ]
  },
  {
   "cell_type": "markdown",
   "metadata": {},
   "source": [
    "## ISI"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 2,
   "metadata": {},
   "outputs": [
    {
     "data": {
      "text/html": "\n<div id=\"altair-viz-ce9cf152a4dc415c896e34531ebbd1a5\"></div>\n<script type=\"text/javascript\">\n  (function(spec, embedOpt){\n    let outputDiv = document.currentScript.previousElementSibling;\n    if (outputDiv.id !== \"altair-viz-ce9cf152a4dc415c896e34531ebbd1a5\") {\n      outputDiv = document.getElementById(\"altair-viz-ce9cf152a4dc415c896e34531ebbd1a5\");\n    }\n    const paths = {\n      \"vega\": \"https://cdn.jsdelivr.net/npm//vega@5?noext\",\n      \"vega-lib\": \"https://cdn.jsdelivr.net/npm//vega-lib?noext\",\n      \"vega-lite\": \"https://cdn.jsdelivr.net/npm//vega-lite@4.8.1?noext\",\n      \"vega-embed\": \"https://cdn.jsdelivr.net/npm//vega-embed@6?noext\",\n    };\n\n    function loadScript(lib) {\n      return new Promise(function(resolve, reject) {\n        var s = document.createElement('script');\n        s.src = paths[lib];\n        s.async = true;\n        s.onload = () => resolve(paths[lib]);\n        s.onerror = () => reject(`Error loading script: ${paths[lib]}`);\n        document.getElementsByTagName(\"head\")[0].appendChild(s);\n      });\n    }\n\n    function showError(err) {\n      outputDiv.innerHTML = `<div class=\"error\" style=\"color:red;\">${err}</div>`;\n      throw err;\n    }\n\n    function displayChart(vegaEmbed) {\n      vegaEmbed(outputDiv, spec, embedOpt)\n        .catch(err => showError(`Javascript Error: ${err.message}<br>This usually means there's a typo in your chart specification. See the javascript console for the full traceback.`));\n    }\n\n    if(typeof define === \"function\" && define.amd) {\n      requirejs.config({paths});\n      require([\"vega-embed\"], displayChart, err => showError(`Error loading script: ${err.message}`));\n    } else if (typeof vegaEmbed === \"function\") {\n      displayChart(vegaEmbed);\n    } else {\n      loadScript(\"vega\")\n        .then(() => loadScript(\"vega-lite\"))\n        .then(() => loadScript(\"vega-embed\"))\n        .catch(showError)\n        .then(() => displayChart(vegaEmbed));\n    }\n  })({\"config\": {\"view\": {\"continuousWidth\": 400, \"continuousHeight\": 300}}, \"layer\": [{\"layer\": [{\"mark\": {\"type\": \"line\", \"clip\": true, \"fill\": null, \"opacity\": 0.8}, \"encoding\": {\"color\": {\"type\": \"nominal\", \"field\": \"\"}, \"detail\": {\"type\": \"ordinal\", \"field\": \"\"}, \"size\": {\"value\": 1.0}, \"x\": {\"type\": \"ordinal\", \"field\": \"stim_strength\"}, \"y\": {\"type\": \"quantitative\", \"aggregate\": \"mean\", \"axis\": {\"orient\": \"right\"}, \"field\": \"isi\", \"scale\": {\"domain\": [0.02834845765621748, 0.08226705672974756], \"zero\": false}, \"title\": \"isi\"}}}, {\"mark\": {\"type\": \"circle\", \"clip\": true, \"filled\": true, \"opacity\": 0}, \"encoding\": {\"color\": {\"type\": \"nominal\", \"field\": \"\"}, \"detail\": {\"type\": \"ordinal\", \"field\": \"\"}, \"x\": {\"type\": \"ordinal\", \"field\": \"stim_strength\"}, \"y\": {\"type\": \"quantitative\", \"aggregate\": \"mean\", \"axis\": {\"orient\": \"right\", \"title\": \"\"}, \"field\": \"isi\", \"scale\": {\"domain\": [0.02834845765621748, 0.08226705672974756], \"zero\": false}}}}, {\"mark\": {\"type\": \"boxplot\", \"clip\": true, \"color\": \"black\", \"median\": {\"color\": \"red\", \"strokeWidth\": 20}, \"opacity\": 0.3, \"size\": 9}, \"encoding\": {\"x\": {\"type\": \"ordinal\", \"field\": \"stim_strength\"}, \"y\": {\"type\": \"quantitative\", \"axis\": {\"orient\": \"right\", \"title\": \"\"}, \"field\": \"isi\", \"scale\": {\"domain\": [0.02834845765621748, 0.08226705672974756], \"zero\": false}}}}], \"width\": 60}, {\"mark\": {\"type\": \"line\", \"fill\": null}, \"encoding\": {\"color\": {\"type\": \"nominal\", \"field\": \"\"}, \"detail\": {\"type\": \"quantitative\", \"field\": \"i_trial\"}, \"opacity\": {\"value\": 0.5}, \"size\": {\"value\": 0.9}, \"x\": {\"type\": \"ordinal\", \"field\": \"stim_strength\"}, \"y\": {\"type\": \"quantitative\", \"field\": \"isi\", \"scale\": {\"clamp\": true, \"domain\": [0.02834845765621748, 0.08226705672974756], \"zero\": false}}}}], \"data\": {\"name\": \"data-6559982f12898f6144bbf7141f437388\"}, \"$schema\": \"https://vega.github.io/schema/vega-lite/v4.8.1.json\", \"datasets\": {\"data-6559982f12898f6144bbf7141f437388\": [{\"mouse\": 0, \"neuron_x_mouse\": \"m1bayes0\", \"i_trial\": 0, \"stim\": 0, \"Log power\": 1.6864048420051554, \"Firing rate\": 48.574108884767185, \"Power\": 48.574108884767185, \"i_spike\": 47.5, \"isi\": 0.07372136849711032, \"stim_strength\": 0, \"combined_condition\": 1.0}, {\"mouse\": 0, \"neuron_x_mouse\": \"m1bayes0\", \"i_trial\": 0, \"stim\": 1, \"Log power\": 1.9569439309585728, \"Firing rate\": 90.56156749808656, \"Power\": 90.56156749808656, \"i_spike\": 42.0, \"isi\": 0.08205451326968892, \"stim_strength\": 0, \"combined_condition\": 1.0}, {\"mouse\": 0, \"neuron_x_mouse\": \"m1bayes0\", \"i_trial\": 1, \"stim\": 0, \"Log power\": 1.5967864115723784, \"Firing rate\": 39.517222438456095, \"Power\": 39.517222438456095, \"i_spike\": 37.5, \"isi\": 0.09267813528995457, \"stim_strength\": 0, \"combined_condition\": 1.0}, {\"mouse\": 0, \"neuron_x_mouse\": \"m1bayes0\", \"i_trial\": 1, \"stim\": 1, \"Log power\": 1.5371512701910637, \"Firing rate\": 34.44698930350749, \"Power\": 34.44698930350749, \"i_spike\": 42.5, \"isi\": 0.0822468692651202, \"stim_strength\": 0, \"combined_condition\": 1.0}, {\"mouse\": 0, \"neuron_x_mouse\": \"m1bayes0\", \"i_trial\": 2, \"stim\": 0, \"Log power\": 2.089612379771504, \"Firing rate\": 122.9171210672866, \"Power\": 122.9171210672866, \"i_spike\": 49.0, \"isi\": 0.07142197285592612, \"stim_strength\": 0, \"combined_condition\": 1.0}, {\"mouse\": 0, \"neuron_x_mouse\": \"m1bayes0\", \"i_trial\": 2, \"stim\": 1, \"Log power\": 2.9454371519793257, \"Firing rate\": 881.9361653477592, \"Power\": 881.9361653477592, \"i_spike\": 45.5, \"isi\": 0.07666128225334826, \"stim_strength\": 0, \"combined_condition\": 1.0}, {\"mouse\": 0, \"neuron_x_mouse\": \"m1bayes0\", \"i_trial\": 3, \"stim\": 0, \"Log power\": 1.5540752549722723, \"Firing rate\": 35.81584937796998, \"Power\": 35.81584937796998, \"i_spike\": 37.5, \"isi\": 0.08997728435667128, \"stim_strength\": 0, \"combined_condition\": 1.0}, {\"mouse\": 0, \"neuron_x_mouse\": \"m1bayes0\", \"i_trial\": 3, \"stim\": 1, \"Log power\": 1.8836677701713689, \"Firing rate\": 76.50111590732261, \"Power\": 76.50111590732261, \"i_spike\": 47.0, \"isi\": 0.07292570933732853, \"stim_strength\": 0, \"combined_condition\": 1.0}, {\"mouse\": 0, \"neuron_x_mouse\": \"m1bayes0\", \"i_trial\": 4, \"stim\": 0, \"Log power\": 1.6909773777131925, \"Firing rate\": 49.08823055547738, \"Power\": 49.08823055547738, \"i_spike\": 34.0, \"isi\": 0.10235171374755002, \"stim_strength\": 0, \"combined_condition\": 1.0}, {\"mouse\": 0, \"neuron_x_mouse\": \"m1bayes0\", \"i_trial\": 4, \"stim\": 1, \"Log power\": 1.7920762034293807, \"Firing rate\": 61.95497747672174, \"Power\": 61.95497747672174, \"i_spike\": 63.5, \"isi\": 0.055343606634689145, \"stim_strength\": 0, \"combined_condition\": 1.0}, {\"mouse\": 0, \"neuron_x_mouse\": \"m1bayes0\", \"i_trial\": 5, \"stim\": 0, \"Log power\": 1.532781951512292, \"Firing rate\": 34.10216501201676, \"Power\": 34.10216501201676, \"i_spike\": 31.0, \"isi\": 0.11323726050408439, \"stim_strength\": 0, \"combined_condition\": 1.0}, {\"mouse\": 0, \"neuron_x_mouse\": \"m1bayes0\", \"i_trial\": 5, \"stim\": 1, \"Log power\": 1.6408188754188506, \"Firing rate\": 43.733967252630094, \"Power\": 43.733967252630094, \"i_spike\": 57.0, \"isi\": 0.0598225277491555, \"stim_strength\": 0, \"combined_condition\": 1.0}, {\"mouse\": 0, \"neuron_x_mouse\": \"m1bayes0\", \"i_trial\": 6, \"stim\": 0, \"Log power\": 1.982988565787311, \"Firing rate\": 96.15869611507068, \"Power\": 96.15869611507068, \"i_spike\": 46.5, \"isi\": 0.07536894174173202, \"stim_strength\": 0, \"combined_condition\": 1.0}, {\"mouse\": 0, \"neuron_x_mouse\": \"m1bayes0\", \"i_trial\": 6, \"stim\": 1, \"Log power\": 1.8086390962922767, \"Firing rate\": 64.36341758128972, \"Power\": 64.36341758128972, \"i_spike\": 45.5, \"isi\": 0.0766571299398319, \"stim_strength\": 0, \"combined_condition\": 1.0}, {\"mouse\": 0, \"neuron_x_mouse\": \"m1bayes0\", \"i_trial\": 7, \"stim\": 0, \"Log power\": 1.5680476666028798, \"Firing rate\": 36.9868773020953, \"Power\": 36.9868773020953, \"i_spike\": 41.0, \"isi\": 0.08536663967720004, \"stim_strength\": 0, \"combined_condition\": 1.0}, {\"mouse\": 0, \"neuron_x_mouse\": \"m1bayes0\", \"i_trial\": 7, \"stim\": 1, \"Log power\": 1.831615817956193, \"Firing rate\": 67.86030667102288, \"Power\": 67.86030667102288, \"i_spike\": 48.5, \"isi\": 0.07273470296585786, \"stim_strength\": 0, \"combined_condition\": 1.0}, {\"mouse\": 0, \"neuron_x_mouse\": \"m1bayes0\", \"i_trial\": 8, \"stim\": 0, \"Log power\": 1.9108474065501857, \"Firing rate\": 81.44180802932536, \"Power\": 81.44180802932536, \"i_spike\": 42.5, \"isi\": 0.08168808674492659, \"stim_strength\": 0, \"combined_condition\": 1.0}, {\"mouse\": 0, \"neuron_x_mouse\": \"m1bayes0\", \"i_trial\": 8, \"stim\": 1, \"Log power\": 2.2101281484467283, \"Firing rate\": 162.22887198590752, \"Power\": 162.22887198590752, \"i_spike\": 50.5, \"isi\": 0.06730656423147362, \"stim_strength\": 0, \"combined_condition\": 1.0}, {\"mouse\": 0, \"neuron_x_mouse\": \"m1bayes0\", \"i_trial\": 9, \"stim\": 0, \"Log power\": 1.6003453932147342, \"Firing rate\": 39.84239100327249, \"Power\": 39.84239100327249, \"i_spike\": 44.0, \"isi\": 0.08023094947076682, \"stim_strength\": 0, \"combined_condition\": 1.0}, {\"mouse\": 0, \"neuron_x_mouse\": \"m1bayes0\", \"i_trial\": 9, \"stim\": 1, \"Log power\": 1.8846794244187794, \"Firing rate\": 76.67952685226197, \"Power\": 76.67952685226197, \"i_spike\": 66.5, \"isi\": 0.05207100622242981, \"stim_strength\": 0, \"combined_condition\": 1.0}, {\"mouse\": 1, \"neuron_x_mouse\": \"m1bayes1\", \"i_trial\": 0, \"stim\": 0, \"Log power\": 2.62256270893102, \"Firing rate\": 419.33654142775833, \"Power\": 419.33654142775833, \"i_spike\": 56.0, \"isi\": 0.06135587025253226, \"stim_strength\": 0, \"combined_condition\": 1.0}, {\"mouse\": 1, \"neuron_x_mouse\": \"m1bayes1\", \"i_trial\": 0, \"stim\": 1, \"Log power\": 1.9074497303000084, \"Firing rate\": 80.8071389224126, \"Power\": 80.8071389224126, \"i_spike\": 50.5, \"isi\": 0.06907708048590899, \"stim_strength\": 0, \"combined_condition\": 1.0}, {\"mouse\": 1, \"neuron_x_mouse\": \"m1bayes1\", \"i_trial\": 1, \"stim\": 0, \"Log power\": 2.4370751953872225, \"Firing rate\": 273.5742362069313, \"Power\": 273.5742362069313, \"i_spike\": 47.0, \"isi\": 0.07477653959442904, \"stim_strength\": 0, \"combined_condition\": 1.0}, {\"mouse\": 1, \"neuron_x_mouse\": \"m1bayes1\", \"i_trial\": 1, \"stim\": 1, \"Log power\": 2.0309860936229427, \"Firing rate\": 107.3955023088723, \"Power\": 107.3955023088723, \"i_spike\": 55.5, \"isi\": 0.06246725930556797, \"stim_strength\": 0, \"combined_condition\": 1.0}, {\"mouse\": 1, \"neuron_x_mouse\": \"m1bayes1\", \"i_trial\": 2, \"stim\": 0, \"Log power\": 2.371963761216021, \"Firing rate\": 235.48527799908427, \"Power\": 235.48527799908427, \"i_spike\": 51.5, \"isi\": 0.06713410798074274, \"stim_strength\": 0, \"combined_condition\": 1.0}, {\"mouse\": 1, \"neuron_x_mouse\": \"m1bayes1\", \"i_trial\": 2, \"stim\": 1, \"Log power\": 1.548266252314118, \"Firing rate\": 35.33997616928085, \"Power\": 35.33997616928085, \"i_spike\": 43.5, \"isi\": 0.0792500170293713, \"stim_strength\": 0, \"combined_condition\": 1.0}, {\"mouse\": 1, \"neuron_x_mouse\": \"m1bayes1\", \"i_trial\": 3, \"stim\": 0, \"Log power\": 1.969409348319507, \"Firing rate\": 93.19859136273777, \"Power\": 93.19859136273777, \"i_spike\": 41.5, \"isi\": 0.08446624001070896, \"stim_strength\": 0, \"combined_condition\": 1.0}, {\"mouse\": 1, \"neuron_x_mouse\": \"m1bayes1\", \"i_trial\": 3, \"stim\": 1, \"Log power\": 1.970381111118592, \"Firing rate\": 93.40736289488143, \"Power\": 93.40736289488143, \"i_spike\": 56.0, \"isi\": 0.06248167044676111, \"stim_strength\": 0, \"combined_condition\": 1.0}, {\"mouse\": 1, \"neuron_x_mouse\": \"m1bayes1\", \"i_trial\": 4, \"stim\": 0, \"Log power\": 2.5114976920237684, \"Firing rate\": 324.71151654501864, \"Power\": 324.71151654501864, \"i_spike\": 38.5, \"isi\": 0.09010267779881131, \"stim_strength\": 0, \"combined_condition\": 1.0}, {\"mouse\": 1, \"neuron_x_mouse\": \"m1bayes1\", \"i_trial\": 4, \"stim\": 1, \"Log power\": 1.844954487929357, \"Firing rate\": 69.97686596123025, \"Power\": 69.97686596123025, \"i_spike\": 56.5, \"isi\": 0.06223743221316064, \"stim_strength\": 0, \"combined_condition\": 1.0}, {\"mouse\": 1, \"neuron_x_mouse\": \"m1bayes1\", \"i_trial\": 5, \"stim\": 0, \"Log power\": 1.8567526883350929, \"Firing rate\": 71.90393999858837, \"Power\": 71.90393999858837, \"i_spike\": 49.0, \"isi\": 0.07073003651911514, \"stim_strength\": 0, \"combined_condition\": 1.0}, {\"mouse\": 1, \"neuron_x_mouse\": \"m1bayes1\", \"i_trial\": 5, \"stim\": 1, \"Log power\": 2.091235817234347, \"Firing rate\": 123.37745777111606, \"Power\": 123.37745777111606, \"i_spike\": 49.5, \"isi\": 0.07077465476631925, \"stim_strength\": 0, \"combined_condition\": 1.0}, {\"mouse\": 1, \"neuron_x_mouse\": \"m1bayes1\", \"i_trial\": 6, \"stim\": 0, \"Log power\": 2.5692955583941686, \"Firing rate\": 370.93307379622945, \"Power\": 370.93307379622945, \"i_spike\": 55.5, \"isi\": 0.06269016996561622, \"stim_strength\": 0, \"combined_condition\": 1.0}, {\"mouse\": 1, \"neuron_x_mouse\": \"m1bayes1\", \"i_trial\": 6, \"stim\": 1, \"Log power\": 1.7509138427672821, \"Firing rate\": 56.352585002112114, \"Power\": 56.352585002112114, \"i_spike\": 59.5, \"isi\": 0.058472611639739915, \"stim_strength\": 0, \"combined_condition\": 1.0}, {\"mouse\": 1, \"neuron_x_mouse\": \"m1bayes1\", \"i_trial\": 7, \"stim\": 0, \"Log power\": 2.0417361809833285, \"Firing rate\": 110.08703653559841, \"Power\": 110.08703653559841, \"i_spike\": 44.5, \"isi\": 0.0775769438382383, \"stim_strength\": 0, \"combined_condition\": 1.0}, {\"mouse\": 1, \"neuron_x_mouse\": \"m1bayes1\", \"i_trial\": 7, \"stim\": 1, \"Log power\": 2.271091110818418, \"Firing rate\": 186.6771280473962, \"Power\": 186.6771280473962, \"i_spike\": 48.5, \"isi\": 0.07180336131271388, \"stim_strength\": 0, \"combined_condition\": 1.0}, {\"mouse\": 1, \"neuron_x_mouse\": \"m1bayes1\", \"i_trial\": 8, \"stim\": 0, \"Log power\": 1.8146260031340944, \"Firing rate\": 65.25683451065679, \"Power\": 65.25683451065679, \"i_spike\": 43.5, \"isi\": 0.07946176552979312, \"stim_strength\": 0, \"combined_condition\": 1.0}, {\"mouse\": 1, \"neuron_x_mouse\": \"m1bayes1\", \"i_trial\": 8, \"stim\": 1, \"Log power\": 2.0807361487621345, \"Firing rate\": 120.43040552716833, \"Power\": 120.43040552716833, \"i_spike\": 50.0, \"isi\": 0.07025277742800912, \"stim_strength\": 0, \"combined_condition\": 1.0}, {\"mouse\": 1, \"neuron_x_mouse\": \"m1bayes1\", \"i_trial\": 9, \"stim\": 0, \"Log power\": 2.0538509136301313, \"Firing rate\": 113.20116949650759, \"Power\": 113.20116949650759, \"i_spike\": 45.0, \"isi\": 0.07773669143567664, \"stim_strength\": 0, \"combined_condition\": 1.0}, {\"mouse\": 1, \"neuron_x_mouse\": \"m1bayes1\", \"i_trial\": 9, \"stim\": 1, \"Log power\": 1.9091730216123042, \"Firing rate\": 81.12842066609318, \"Power\": 81.12842066609318, \"i_spike\": 56.0, \"isi\": 0.05894729801645676, \"stim_strength\": 0, \"combined_condition\": 1.0}, {\"mouse\": 2, \"neuron_x_mouse\": \"m1bayes2\", \"i_trial\": 0, \"stim\": 0, \"Log power\": 1.8887021726562525, \"Firing rate\": 77.39308750324041, \"Power\": 77.39308750324041, \"i_spike\": 50.0, \"isi\": 0.06780714298095476, \"stim_strength\": 0, \"combined_condition\": 1.0}, {\"mouse\": 2, \"neuron_x_mouse\": \"m1bayes2\", \"i_trial\": 0, \"stim\": 1, \"Log power\": 2.0214403729353365, \"Firing rate\": 105.06072003868086, \"Power\": 105.06072003868086, \"i_spike\": 60.0, \"isi\": 0.05798648262480545, \"stim_strength\": 0, \"combined_condition\": 1.0}, {\"mouse\": 2, \"neuron_x_mouse\": \"m1bayes2\", \"i_trial\": 1, \"stim\": 0, \"Log power\": 1.7291393318477248, \"Firing rate\": 53.59685812148622, \"Power\": 53.59685812148622, \"i_spike\": 50.5, \"isi\": 0.06936587616139098, \"stim_strength\": 0, \"combined_condition\": 1.0}, {\"mouse\": 2, \"neuron_x_mouse\": \"m1bayes2\", \"i_trial\": 1, \"stim\": 1, \"Log power\": 2.0314995680933143, \"Firing rate\": 107.52255310783569, \"Power\": 107.52255310783569, \"i_spike\": 48.5, \"isi\": 0.06861831213637369, \"stim_strength\": 0, \"combined_condition\": 1.0}, {\"mouse\": 2, \"neuron_x_mouse\": \"m1bayes2\", \"i_trial\": 2, \"stim\": 0, \"Log power\": 1.9201653068498405, \"Firing rate\": 83.20804281767958, \"Power\": 83.20804281767958, \"i_spike\": 62.0, \"isi\": 0.05554146921111516, \"stim_strength\": 0, \"combined_condition\": 1.0}, {\"mouse\": 2, \"neuron_x_mouse\": \"m1bayes2\", \"i_trial\": 2, \"stim\": 1, \"Log power\": 2.2763955287629245, \"Firing rate\": 188.97115989874976, \"Power\": 188.97115989874976, \"i_spike\": 59.5, \"isi\": 0.059080625564345096, \"stim_strength\": 0, \"combined_condition\": 1.0}, {\"mouse\": 2, \"neuron_x_mouse\": \"m1bayes2\", \"i_trial\": 3, \"stim\": 0, \"Log power\": 1.7899148810719774, \"Firing rate\": 61.647416504486735, \"Power\": 61.647416504486735, \"i_spike\": 53.0, \"isi\": 0.0659473629021974, \"stim_strength\": 0, \"combined_condition\": 1.0}, {\"mouse\": 2, \"neuron_x_mouse\": \"m1bayes2\", \"i_trial\": 3, \"stim\": 1, \"Log power\": 2.0103008144034225, \"Firing rate\": 102.40020224774705, \"Power\": 102.40020224774705, \"i_spike\": 66.5, \"isi\": 0.05260825641645607, \"stim_strength\": 0, \"combined_condition\": 1.0}, {\"mouse\": 2, \"neuron_x_mouse\": \"m1bayes2\", \"i_trial\": 4, \"stim\": 0, \"Log power\": 1.7432542389547079, \"Firing rate\": 55.36741389828541, \"Power\": 55.36741389828541, \"i_spike\": 44.0, \"isi\": 0.07857820081236815, \"stim_strength\": 0, \"combined_condition\": 1.0}, {\"mouse\": 2, \"neuron_x_mouse\": \"m1bayes2\", \"i_trial\": 4, \"stim\": 1, \"Log power\": 1.9131356815427392, \"Firing rate\": 81.87205314579893, \"Power\": 81.87205314579893, \"i_spike\": 67.5, \"isi\": 0.05105537373833938, \"stim_strength\": 0, \"combined_condition\": 1.0}, {\"mouse\": 2, \"neuron_x_mouse\": \"m1bayes2\", \"i_trial\": 5, \"stim\": 0, \"Log power\": 1.7330892005691652, \"Firing rate\": 54.086540091072486, \"Power\": 54.086540091072486, \"i_spike\": 45.0, \"isi\": 0.0770670375927146, \"stim_strength\": 0, \"combined_condition\": 1.0}, {\"mouse\": 2, \"neuron_x_mouse\": \"m1bayes2\", \"i_trial\": 5, \"stim\": 1, \"Log power\": 1.9354037320845863, \"Firing rate\": 86.17945277901761, \"Power\": 86.17945277901761, \"i_spike\": 62.0, \"isi\": 0.05547600290656003, \"stim_strength\": 0, \"combined_condition\": 1.0}, {\"mouse\": 2, \"neuron_x_mouse\": \"m1bayes2\", \"i_trial\": 6, \"stim\": 0, \"Log power\": 1.97761962038831, \"Firing rate\": 94.9772564851168, \"Power\": 94.9772564851168, \"i_spike\": 61.5, \"isi\": 0.056649700864614023, \"stim_strength\": 0, \"combined_condition\": 1.0}, {\"mouse\": 2, \"neuron_x_mouse\": \"m1bayes2\", \"i_trial\": 6, \"stim\": 1, \"Log power\": 2.201704250694412, \"Firing rate\": 159.11248212117096, \"Power\": 159.11248212117096, \"i_spike\": 57.0, \"isi\": 0.0617551739393036, \"stim_strength\": 0, \"combined_condition\": 1.0}, {\"mouse\": 2, \"neuron_x_mouse\": \"m1bayes2\", \"i_trial\": 7, \"stim\": 0, \"Log power\": 1.9856740334546066, \"Firing rate\": 96.75513727771863, \"Power\": 96.75513727771863, \"i_spike\": 54.0, \"isi\": 0.06314219098534574, \"stim_strength\": 0, \"combined_condition\": 1.0}, {\"mouse\": 2, \"neuron_x_mouse\": \"m1bayes2\", \"i_trial\": 7, \"stim\": 1, \"Log power\": 1.7384633896527355, \"Firing rate\": 54.759993719577935, \"Power\": 54.759993719577935, \"i_spike\": 57.0, \"isi\": 0.0599958008444421, \"stim_strength\": 0, \"combined_condition\": 1.0}, {\"mouse\": 2, \"neuron_x_mouse\": \"m1bayes2\", \"i_trial\": 8, \"stim\": 0, \"Log power\": 1.776835066795343, \"Firing rate\": 59.818437779837645, \"Power\": 59.818437779837645, \"i_spike\": 48.5, \"isi\": 0.07131445877566607, \"stim_strength\": 0, \"combined_condition\": 1.0}, {\"mouse\": 2, \"neuron_x_mouse\": \"m1bayes2\", \"i_trial\": 8, \"stim\": 1, \"Log power\": 1.8092086924760131, \"Firing rate\": 64.44788839642547, \"Power\": 64.44788839642547, \"i_spike\": 64.0, \"isi\": 0.053323380266190365, \"stim_strength\": 0, \"combined_condition\": 1.0}, {\"mouse\": 2, \"neuron_x_mouse\": \"m1bayes2\", \"i_trial\": 9, \"stim\": 0, \"Log power\": 1.961184710467782, \"Firing rate\": 91.45021070964576, \"Power\": 91.45021070964576, \"i_spike\": 53.5, \"isi\": 0.06385723105973999, \"stim_strength\": 0, \"combined_condition\": 1.0}, {\"mouse\": 2, \"neuron_x_mouse\": \"m1bayes2\", \"i_trial\": 9, \"stim\": 1, \"Log power\": 1.7971425819069777, \"Firing rate\": 62.68196201474591, \"Power\": 62.68196201474591, \"i_spike\": 51.0, \"isi\": 0.06827024084278634, \"stim_strength\": 0, \"combined_condition\": 1.0}, {\"mouse\": 3, \"neuron_x_mouse\": \"m1bayes3\", \"i_trial\": 0, \"stim\": 0, \"Log power\": 1.9779979166755193, \"Firing rate\": 95.06002335857022, \"Power\": 95.06002335857022, \"i_spike\": 69.0, \"isi\": 0.04990315230706309, \"stim_strength\": 0, \"combined_condition\": 1.0}, {\"mouse\": 3, \"neuron_x_mouse\": \"m1bayes3\", \"i_trial\": 0, \"stim\": 1, \"Log power\": 1.7085596979517488, \"Firing rate\": 51.11633385234467, \"Power\": 51.11633385234467, \"i_spike\": 68.5, \"isi\": 0.0502387441243349, \"stim_strength\": 0, \"combined_condition\": 1.0}, {\"mouse\": 3, \"neuron_x_mouse\": \"m1bayes3\", \"i_trial\": 1, \"stim\": 0, \"Log power\": 2.401482778198322, \"Firing rate\": 252.04772289801596, \"Power\": 252.04772289801596, \"i_spike\": 56.0, \"isi\": 0.06294893152731665, \"stim_strength\": 0, \"combined_condition\": 1.0}, {\"mouse\": 3, \"neuron_x_mouse\": \"m1bayes3\", \"i_trial\": 1, \"stim\": 1, \"Log power\": 2.313770149917087, \"Firing rate\": 205.95396147226086, \"Power\": 205.95396147226086, \"i_spike\": 69.5, \"isi\": 0.05003938581182429, \"stim_strength\": 0, \"combined_condition\": 1.0}, {\"mouse\": 3, \"neuron_x_mouse\": \"m1bayes3\", \"i_trial\": 2, \"stim\": 0, \"Log power\": 2.4814175826887164, \"Firing rate\": 302.98252645839887, \"Power\": 302.98252645839887, \"i_spike\": 66.0, \"isi\": 0.05271232737968904, \"stim_strength\": 0, \"combined_condition\": 1.0}, {\"mouse\": 3, \"neuron_x_mouse\": \"m1bayes3\", \"i_trial\": 2, \"stim\": 1, \"Log power\": 2.264299294091876, \"Firing rate\": 183.78044301695658, \"Power\": 183.78044301695658, \"i_spike\": 64.5, \"isi\": 0.05336936046438036, \"stim_strength\": 0, \"combined_condition\": 1.0}, {\"mouse\": 3, \"neuron_x_mouse\": \"m1bayes3\", \"i_trial\": 3, \"stim\": 0, \"Log power\": 1.909160455474934, \"Firing rate\": 81.12607328160615, \"Power\": 81.12607328160615, \"i_spike\": 61.5, \"isi\": 0.05530397314462499, \"stim_strength\": 0, \"combined_condition\": 1.0}, {\"mouse\": 3, \"neuron_x_mouse\": \"m1bayes3\", \"i_trial\": 3, \"stim\": 1, \"Log power\": 2.101642456027753, \"Firing rate\": 126.36955496131888, \"Power\": 126.36955496131888, \"i_spike\": 72.0, \"isi\": 0.048867083351027046, \"stim_strength\": 0, \"combined_condition\": 1.0}, {\"mouse\": 3, \"neuron_x_mouse\": \"m1bayes3\", \"i_trial\": 4, \"stim\": 0, \"Log power\": 2.158515734802001, \"Firing rate\": 144.05081999509642, \"Power\": 144.05081999509642, \"i_spike\": 65.0, \"isi\": 0.05377607276032252, \"stim_strength\": 0, \"combined_condition\": 1.0}, {\"mouse\": 3, \"neuron_x_mouse\": \"m1bayes3\", \"i_trial\": 4, \"stim\": 1, \"Log power\": 2.386530935202751, \"Firing rate\": 243.5179253873566, \"Power\": 243.5179253873566, \"i_spike\": 67.0, \"isi\": 0.05088305449140372, \"stim_strength\": 0, \"combined_condition\": 1.0}, {\"mouse\": 3, \"neuron_x_mouse\": \"m1bayes3\", \"i_trial\": 5, \"stim\": 0, \"Log power\": 2.087408952629181, \"Firing rate\": 122.29507075052616, \"Power\": 122.29507075052616, \"i_spike\": 69.0, \"isi\": 0.050666263902571694, \"stim_strength\": 0, \"combined_condition\": 1.0}, {\"mouse\": 3, \"neuron_x_mouse\": \"m1bayes3\", \"i_trial\": 5, \"stim\": 1, \"Log power\": 1.950514644964778, \"Firing rate\": 89.23077088364336, \"Power\": 89.23077088364336, \"i_spike\": 65.5, \"isi\": 0.05290639306357811, \"stim_strength\": 0, \"combined_condition\": 1.0}, {\"mouse\": 3, \"neuron_x_mouse\": \"m1bayes3\", \"i_trial\": 6, \"stim\": 0, \"Log power\": 1.921984752718237, \"Firing rate\": 83.55736822586746, \"Power\": 83.55736822586746, \"i_spike\": 64.0, \"isi\": 0.05409873366637733, \"stim_strength\": 0, \"combined_condition\": 1.0}, {\"mouse\": 3, \"neuron_x_mouse\": \"m1bayes3\", \"i_trial\": 6, \"stim\": 1, \"Log power\": 2.1560267959643, \"Firing rate\": 143.2276267975834, \"Power\": 143.2276267975834, \"i_spike\": 75.0, \"isi\": 0.0464837056039156, \"stim_strength\": 0, \"combined_condition\": 1.0}, {\"mouse\": 3, \"neuron_x_mouse\": \"m1bayes3\", \"i_trial\": 7, \"stim\": 0, \"Log power\": 2.526591497828235, \"Firing rate\": 336.1951917054392, \"Power\": 336.1951917054392, \"i_spike\": 63.0, \"isi\": 0.054670206247651794, \"stim_strength\": 0, \"combined_condition\": 1.0}, {\"mouse\": 3, \"neuron_x_mouse\": \"m1bayes3\", \"i_trial\": 7, \"stim\": 1, \"Log power\": 2.1573745249473517, \"Firing rate\": 143.67278982928437, \"Power\": 143.67278982928437, \"i_spike\": 59.5, \"isi\": 0.056877911233150474, \"stim_strength\": 0, \"combined_condition\": 1.0}, {\"mouse\": 3, \"neuron_x_mouse\": \"m1bayes3\", \"i_trial\": 8, \"stim\": 0, \"Log power\": 3.1666519809160674, \"Firing rate\": 1467.7496345495083, \"Power\": 1467.7496345495083, \"i_spike\": 65.0, \"isi\": 0.05359212758836269, \"stim_strength\": 0, \"combined_condition\": 1.0}, {\"mouse\": 3, \"neuron_x_mouse\": \"m1bayes3\", \"i_trial\": 8, \"stim\": 1, \"Log power\": 2.006130708291892, \"Firing rate\": 101.42165854938816, \"Power\": 101.42165854938816, \"i_spike\": 68.5, \"isi\": 0.050411688350006145, \"stim_strength\": 0, \"combined_condition\": 1.0}, {\"mouse\": 3, \"neuron_x_mouse\": \"m1bayes3\", \"i_trial\": 9, \"stim\": 0, \"Log power\": 1.91119964876796, \"Firing rate\": 81.50788964230681, \"Power\": 81.50788964230681, \"i_spike\": 57.5, \"isi\": 0.05980469747164108, \"stim_strength\": 0, \"combined_condition\": 1.0}, {\"mouse\": 3, \"neuron_x_mouse\": \"m1bayes3\", \"i_trial\": 9, \"stim\": 1, \"Log power\": 2.0575510713524845, \"Firing rate\": 114.16975559447745, \"Power\": 114.16975559447745, \"i_spike\": 60.5, \"isi\": 0.05817076423478697, \"stim_strength\": 0, \"combined_condition\": 1.0}, {\"mouse\": 4, \"neuron_x_mouse\": \"m1bayes4\", \"i_trial\": 0, \"stim\": 0, \"Log power\": 1.9878749974748675, \"Firing rate\": 97.24672792539951, \"Power\": 97.24672792539951, \"i_spike\": 53.0, \"isi\": 0.06615187083527549, \"stim_strength\": 0, \"combined_condition\": 1.0}, {\"mouse\": 4, \"neuron_x_mouse\": \"m1bayes4\", \"i_trial\": 0, \"stim\": 1, \"Log power\": 2.059088793298447, \"Firing rate\": 114.57471702357758, \"Power\": 114.57471702357758, \"i_spike\": 79.5, \"isi\": 0.04388552136851831, \"stim_strength\": 0, \"combined_condition\": 1.0}, {\"mouse\": 4, \"neuron_x_mouse\": \"m1bayes4\", \"i_trial\": 1, \"stim\": 0, \"Log power\": 1.8063287817250837, \"Firing rate\": 64.02193287649514, \"Power\": 64.02193287649514, \"i_spike\": 63.5, \"isi\": 0.05511222154988579, \"stim_strength\": 0, \"combined_condition\": 1.0}, {\"mouse\": 4, \"neuron_x_mouse\": \"m1bayes4\", \"i_trial\": 1, \"stim\": 1, \"Log power\": 1.927096696402765, \"Firing rate\": 84.54670688817598, \"Power\": 84.54670688817598, \"i_spike\": 64.0, \"isi\": 0.05363511001626813, \"stim_strength\": 0, \"combined_condition\": 1.0}, {\"mouse\": 4, \"neuron_x_mouse\": \"m1bayes4\", \"i_trial\": 2, \"stim\": 0, \"Log power\": 2.1442160771948346, \"Firing rate\": 139.3850121247563, \"Power\": 139.3850121247563, \"i_spike\": 76.5, \"isi\": 0.04542184847298307, \"stim_strength\": 0, \"combined_condition\": 1.0}, {\"mouse\": 4, \"neuron_x_mouse\": \"m1bayes4\", \"i_trial\": 2, \"stim\": 1, \"Log power\": 2.060898124224898, \"Firing rate\": 115.05304685637066, \"Power\": 115.05304685637066, \"i_spike\": 70.0, \"isi\": 0.05011158091609195, \"stim_strength\": 0, \"combined_condition\": 1.0}, {\"mouse\": 4, \"neuron_x_mouse\": \"m1bayes4\", \"i_trial\": 3, \"stim\": 0, \"Log power\": 2.506644476325146, \"Firing rate\": 321.10308370722504, \"Power\": 321.10308370722504, \"i_spike\": 62.5, \"isi\": 0.0555641557296402, \"stim_strength\": 0, \"combined_condition\": 1.0}, {\"mouse\": 4, \"neuron_x_mouse\": \"m1bayes4\", \"i_trial\": 3, \"stim\": 1, \"Log power\": 2.0645417976468186, \"Firing rate\": 116.02238737816842, \"Power\": 116.02238737816842, \"i_spike\": 70.0, \"isi\": 0.05008430702576105, \"stim_strength\": 0, \"combined_condition\": 1.0}, {\"mouse\": 4, \"neuron_x_mouse\": \"m1bayes4\", \"i_trial\": 4, \"stim\": 0, \"Log power\": 1.9682723233076216, \"Firing rate\": 92.95490755803802, \"Power\": 92.95490755803802, \"i_spike\": 65.5, \"isi\": 0.05304475347280013, \"stim_strength\": 0, \"combined_condition\": 1.0}, {\"mouse\": 4, \"neuron_x_mouse\": \"m1bayes4\", \"i_trial\": 4, \"stim\": 1, \"Log power\": 1.9392293502968152, \"Firing rate\": 86.9419447243029, \"Power\": 86.9419447243029, \"i_spike\": 68.0, \"isi\": 0.05095394881533538, \"stim_strength\": 0, \"combined_condition\": 1.0}, {\"mouse\": 4, \"neuron_x_mouse\": \"m1bayes4\", \"i_trial\": 5, \"stim\": 0, \"Log power\": 2.0480691037921015, \"Firing rate\": 111.70409742530803, \"Power\": 111.70409742530803, \"i_spike\": 83.5, \"isi\": 0.04155966126644191, \"stim_strength\": 0, \"combined_condition\": 1.0}, {\"mouse\": 4, \"neuron_x_mouse\": \"m1bayes4\", \"i_trial\": 5, \"stim\": 1, \"Log power\": 2.2224725899582682, \"Firing rate\": 166.906246275608, \"Power\": 166.906246275608, \"i_spike\": 78.5, \"isi\": 0.0438955836977032, \"stim_strength\": 0, \"combined_condition\": 1.0}, {\"mouse\": 4, \"neuron_x_mouse\": \"m1bayes4\", \"i_trial\": 6, \"stim\": 0, \"Log power\": 2.0482489367727212, \"Firing rate\": 111.75036151854918, \"Power\": 111.75036151854918, \"i_spike\": 74.5, \"isi\": 0.04610804184211899, \"stim_strength\": 0, \"combined_condition\": 1.0}, {\"mouse\": 4, \"neuron_x_mouse\": \"m1bayes4\", \"i_trial\": 6, \"stim\": 1, \"Log power\": 1.966912828229967, \"Firing rate\": 92.66438083787273, \"Power\": 92.66438083787273, \"i_spike\": 67.5, \"isi\": 0.05162234481555981, \"stim_strength\": 0, \"combined_condition\": 1.0}, {\"mouse\": 4, \"neuron_x_mouse\": \"m1bayes4\", \"i_trial\": 7, \"stim\": 0, \"Log power\": 2.8156319405063024, \"Firing rate\": 654.0816125920497, \"Power\": 654.0816125920497, \"i_spike\": 69.5, \"isi\": 0.04999510454301548, \"stim_strength\": 0, \"combined_condition\": 1.0}, {\"mouse\": 4, \"neuron_x_mouse\": \"m1bayes4\", \"i_trial\": 7, \"stim\": 1, \"Log power\": 2.416272251079987, \"Firing rate\": 260.77878110581446, \"Power\": 260.77878110581446, \"i_spike\": 81.5, \"isi\": 0.042376105378286524, \"stim_strength\": 0, \"combined_condition\": 1.0}, {\"mouse\": 4, \"neuron_x_mouse\": \"m1bayes4\", \"i_trial\": 8, \"stim\": 0, \"Log power\": 1.94625296426983, \"Firing rate\": 88.35944193513508, \"Power\": 88.35944193513508, \"i_spike\": 66.5, \"isi\": 0.05220154815302335, \"stim_strength\": 0, \"combined_condition\": 1.0}, {\"mouse\": 4, \"neuron_x_mouse\": \"m1bayes4\", \"i_trial\": 8, \"stim\": 1, \"Log power\": 2.133512348114147, \"Firing rate\": 135.99168286836954, \"Power\": 135.99168286836954, \"i_spike\": 63.0, \"isi\": 0.05506028461456602, \"stim_strength\": 0, \"combined_condition\": 1.0}, {\"mouse\": 4, \"neuron_x_mouse\": \"m1bayes4\", \"i_trial\": 9, \"stim\": 0, \"Log power\": 2.3402647985903915, \"Firing rate\": 218.90959555261, \"Power\": 218.90959555261, \"i_spike\": 74.0, \"isi\": 0.046754893230424865, \"stim_strength\": 0, \"combined_condition\": 1.0}, {\"mouse\": 4, \"neuron_x_mouse\": \"m1bayes4\", \"i_trial\": 9, \"stim\": 1, \"Log power\": 1.7634231568210117, \"Firing rate\": 57.9993540570258, \"Power\": 57.9993540570258, \"i_spike\": 67.0, \"isi\": 0.05182980460312368, \"stim_strength\": 0, \"combined_condition\": 1.0}, {\"mouse\": 5, \"neuron_x_mouse\": \"m1bayes5\", \"i_trial\": 0, \"stim\": 0, \"Log power\": 2.0607641187270356, \"Firing rate\": 115.01755167264241, \"Power\": 115.01755167264241, \"i_spike\": 87.0, \"isi\": 0.039890436228248, \"stim_strength\": 0, \"combined_condition\": 1.0}, {\"mouse\": 5, \"neuron_x_mouse\": \"m1bayes5\", \"i_trial\": 0, \"stim\": 1, \"Log power\": 1.9774190015635287, \"Firing rate\": 94.93339264139787, \"Power\": 94.93339264139787, \"i_spike\": 91.5, \"isi\": 0.037037904257795594, \"stim_strength\": 0, \"combined_condition\": 1.0}, {\"mouse\": 5, \"neuron_x_mouse\": \"m1bayes5\", \"i_trial\": 1, \"stim\": 0, \"Log power\": 2.0404033131280643, \"Firing rate\": 109.74969276068843, \"Power\": 109.74969276068843, \"i_spike\": 86.5, \"isi\": 0.040305606185453376, \"stim_strength\": 0, \"combined_condition\": 1.0}, {\"mouse\": 5, \"neuron_x_mouse\": \"m1bayes5\", \"i_trial\": 1, \"stim\": 1, \"Log power\": 1.8965319924246902, \"Firing rate\": 78.80104783259652, \"Power\": 78.80104783259652, \"i_spike\": 77.0, \"isi\": 0.04540517838773304, \"stim_strength\": 0, \"combined_condition\": 1.0}, {\"mouse\": 5, \"neuron_x_mouse\": \"m1bayes5\", \"i_trial\": 2, \"stim\": 0, \"Log power\": 2.0221812990633743, \"Firing rate\": 105.24011138424022, \"Power\": 105.24011138424022, \"i_spike\": 84.0, \"isi\": 0.04173811360997767, \"stim_strength\": 0, \"combined_condition\": 1.0}, {\"mouse\": 5, \"neuron_x_mouse\": \"m1bayes5\", \"i_trial\": 2, \"stim\": 1, \"Log power\": 2.221643435662302, \"Firing rate\": 166.58789314667206, \"Power\": 166.58789314667206, \"i_spike\": 93.0, \"isi\": 0.037709660294907854, \"stim_strength\": 0, \"combined_condition\": 1.0}, {\"mouse\": 5, \"neuron_x_mouse\": \"m1bayes5\", \"i_trial\": 3, \"stim\": 0, \"Log power\": 2.0992407167113174, \"Firing rate\": 125.67263372879592, \"Power\": 125.67263372879592, \"i_spike\": 73.0, \"isi\": 0.048161854497385026, \"stim_strength\": 0, \"combined_condition\": 1.0}, {\"mouse\": 5, \"neuron_x_mouse\": \"m1bayes5\", \"i_trial\": 3, \"stim\": 1, \"Log power\": 2.290223036238085, \"Firing rate\": 195.08462189625695, \"Power\": 195.08462189625695, \"i_spike\": 86.5, \"isi\": 0.039421386637522454, \"stim_strength\": 0, \"combined_condition\": 1.0}, {\"mouse\": 5, \"neuron_x_mouse\": \"m1bayes5\", \"i_trial\": 4, \"stim\": 0, \"Log power\": 2.4428274300978496, \"Firing rate\": 277.22183257304005, \"Power\": 277.22183257304005, \"i_spike\": 78.5, \"isi\": 0.04416451605036737, \"stim_strength\": 0, \"combined_condition\": 1.0}, {\"mouse\": 5, \"neuron_x_mouse\": \"m1bayes5\", \"i_trial\": 4, \"stim\": 1, \"Log power\": 2.2312327391739077, \"Firing rate\": 170.30709425882011, \"Power\": 170.30709425882011, \"i_spike\": 94.5, \"isi\": 0.037199298391511135, \"stim_strength\": 0, \"combined_condition\": 1.0}, {\"mouse\": 5, \"neuron_x_mouse\": \"m1bayes5\", \"i_trial\": 5, \"stim\": 0, \"Log power\": 2.3091260710651076, \"Firing rate\": 203.76334951738593, \"Power\": 203.76334951738593, \"i_spike\": 79.5, \"isi\": 0.04289752459013066, \"stim_strength\": 0, \"combined_condition\": 1.0}, {\"mouse\": 5, \"neuron_x_mouse\": \"m1bayes5\", \"i_trial\": 5, \"stim\": 1, \"Log power\": 2.110106704688957, \"Firing rate\": 128.85661091485824, \"Power\": 128.85661091485824, \"i_spike\": 78.5, \"isi\": 0.044340356180662406, \"stim_strength\": 0, \"combined_condition\": 1.0}, {\"mouse\": 5, \"neuron_x_mouse\": \"m1bayes5\", \"i_trial\": 6, \"stim\": 0, \"Log power\": 2.0982831337370675, \"Firing rate\": 125.39584135665099, \"Power\": 125.39584135665099, \"i_spike\": 81.0, \"isi\": 0.04288718709783768, \"stim_strength\": 0, \"combined_condition\": 1.0}, {\"mouse\": 5, \"neuron_x_mouse\": \"m1bayes5\", \"i_trial\": 6, \"stim\": 1, \"Log power\": 2.5068887652512895, \"Firing rate\": 321.2837537284727, \"Power\": 321.2837537284727, \"i_spike\": 100.0, \"isi\": 0.03479803936494099, \"stim_strength\": 0, \"combined_condition\": 1.0}, {\"mouse\": 5, \"neuron_x_mouse\": \"m1bayes5\", \"i_trial\": 7, \"stim\": 0, \"Log power\": 2.387693132268623, \"Firing rate\": 244.170466120712, \"Power\": 244.170466120712, \"i_spike\": 97.0, \"isi\": 0.036008751811580066, \"stim_strength\": 0, \"combined_condition\": 1.0}, {\"mouse\": 5, \"neuron_x_mouse\": \"m1bayes5\", \"i_trial\": 7, \"stim\": 1, \"Log power\": 2.196862154318468, \"Firing rate\": 157.3483359359497, \"Power\": 157.3483359359497, \"i_spike\": 91.0, \"isi\": 0.038451869705820756, \"stim_strength\": 0, \"combined_condition\": 1.0}, {\"mouse\": 5, \"neuron_x_mouse\": \"m1bayes5\", \"i_trial\": 8, \"stim\": 0, \"Log power\": 2.0161682871187154, \"Firing rate\": 103.79305312217139, \"Power\": 103.79305312217139, \"i_spike\": 75.5, \"isi\": 0.04537530152178335, \"stim_strength\": 0, \"combined_condition\": 1.0}, {\"mouse\": 5, \"neuron_x_mouse\": \"m1bayes5\", \"i_trial\": 8, \"stim\": 1, \"Log power\": 2.018962628157209, \"Firing rate\": 104.4630322983104, \"Power\": 104.4630322983104, \"i_spike\": 80.5, \"isi\": 0.0432104171751574, \"stim_strength\": 0, \"combined_condition\": 1.0}, {\"mouse\": 5, \"neuron_x_mouse\": \"m1bayes5\", \"i_trial\": 9, \"stim\": 0, \"Log power\": 2.0659953701540377, \"Firing rate\": 116.41136191780386, \"Power\": 116.41136191780386, \"i_spike\": 85.0, \"isi\": 0.04097628877269652, \"stim_strength\": 0, \"combined_condition\": 1.0}, {\"mouse\": 5, \"neuron_x_mouse\": \"m1bayes5\", \"i_trial\": 9, \"stim\": 1, \"Log power\": 2.0882669964478326, \"Firing rate\": 122.53693027846059, \"Power\": 122.53693027846059, \"i_spike\": 76.5, \"isi\": 0.04553849939939315, \"stim_strength\": 0, \"combined_condition\": 1.0}, {\"mouse\": 6, \"neuron_x_mouse\": \"m1bayes6\", \"i_trial\": 0, \"stim\": 0, \"Log power\": 2.136119384165171, \"Firing rate\": 136.81048552618924, \"Power\": 136.81048552618924, \"i_spike\": 91.5, \"isi\": 0.0377041870826555, \"stim_strength\": 0, \"combined_condition\": 1.0}, {\"mouse\": 6, \"neuron_x_mouse\": \"m1bayes6\", \"i_trial\": 0, \"stim\": 1, \"Log power\": 2.3879849669046354, \"Firing rate\": 244.33459748548938, \"Power\": 244.33459748548938, \"i_spike\": 88.5, \"isi\": 0.038786311097675434, \"stim_strength\": 0, \"combined_condition\": 1.0}, {\"mouse\": 6, \"neuron_x_mouse\": \"m1bayes6\", \"i_trial\": 1, \"stim\": 0, \"Log power\": 2.3601524820425523, \"Firing rate\": 229.1672124211903, \"Power\": 229.1672124211903, \"i_spike\": 97.5, \"isi\": 0.035897299760971495, \"stim_strength\": 0, \"combined_condition\": 1.0}, {\"mouse\": 6, \"neuron_x_mouse\": \"m1bayes6\", \"i_trial\": 1, \"stim\": 1, \"Log power\": 2.210127725153314, \"Firing rate\": 162.22871386651315, \"Power\": 162.22871386651315, \"i_spike\": 103.5, \"isi\": 0.03380025921757642, \"stim_strength\": 0, \"combined_condition\": 1.0}, {\"mouse\": 6, \"neuron_x_mouse\": \"m1bayes6\", \"i_trial\": 2, \"stim\": 0, \"Log power\": 2.220409380977405, \"Firing rate\": 166.11520289248048, \"Power\": 166.11520289248048, \"i_spike\": 86.0, \"isi\": 0.0400840574430319, \"stim_strength\": 0, \"combined_condition\": 1.0}, {\"mouse\": 6, \"neuron_x_mouse\": \"m1bayes6\", \"i_trial\": 2, \"stim\": 1, \"Log power\": 2.236922294755517, \"Firing rate\": 172.55291276281133, \"Power\": 172.55291276281133, \"i_spike\": 95.0, \"isi\": 0.036687928665086696, \"stim_strength\": 0, \"combined_condition\": 1.0}, {\"mouse\": 6, \"neuron_x_mouse\": \"m1bayes6\", \"i_trial\": 3, \"stim\": 0, \"Log power\": 2.30672906354839, \"Firing rate\": 202.6418135569258, \"Power\": 202.6418135569258, \"i_spike\": 92.0, \"isi\": 0.037636653856218644, \"stim_strength\": 0, \"combined_condition\": 1.0}, {\"mouse\": 6, \"neuron_x_mouse\": \"m1bayes6\", \"i_trial\": 3, \"stim\": 1, \"Log power\": 2.233689084841117, \"Firing rate\": 171.2730709833116, \"Power\": 171.2730709833116, \"i_spike\": 116.5, \"isi\": 0.03004958662684281, \"stim_strength\": 0, \"combined_condition\": 1.0}, {\"mouse\": 6, \"neuron_x_mouse\": \"m1bayes6\", \"i_trial\": 4, \"stim\": 0, \"Log power\": 2.346658916940514, \"Firing rate\": 222.1564449108824, \"Power\": 222.1564449108824, \"i_spike\": 100.0, \"isi\": 0.034050784156541405, \"stim_strength\": 0, \"combined_condition\": 1.0}, {\"mouse\": 6, \"neuron_x_mouse\": \"m1bayes6\", \"i_trial\": 4, \"stim\": 1, \"Log power\": 2.2368706823893256, \"Firing rate\": 172.53240747130917, \"Power\": 172.53240747130917, \"i_spike\": 110.0, \"isi\": 0.03166991727870939, \"stim_strength\": 0, \"combined_condition\": 1.0}, {\"mouse\": 6, \"neuron_x_mouse\": \"m1bayes6\", \"i_trial\": 5, \"stim\": 0, \"Log power\": 2.1877134363147657, \"Firing rate\": 154.06835170748025, \"Power\": 154.06835170748025, \"i_spike\": 93.0, \"isi\": 0.037671055094809086, \"stim_strength\": 0, \"combined_condition\": 1.0}, {\"mouse\": 6, \"neuron_x_mouse\": \"m1bayes6\", \"i_trial\": 5, \"stim\": 1, \"Log power\": 2.1390390954368423, \"Firing rate\": 137.73334516558782, \"Power\": 137.73334516558782, \"i_spike\": 101.0, \"isi\": 0.03476984577883134, \"stim_strength\": 0, \"combined_condition\": 1.0}, {\"mouse\": 6, \"neuron_x_mouse\": \"m1bayes6\", \"i_trial\": 6, \"stim\": 0, \"Log power\": 2.555751673980236, \"Firing rate\": 359.5436922370336, \"Power\": 359.5436922370336, \"i_spike\": 93.5, \"isi\": 0.03743722496243034, \"stim_strength\": 0, \"combined_condition\": 1.0}, {\"mouse\": 6, \"neuron_x_mouse\": \"m1bayes6\", \"i_trial\": 6, \"stim\": 1, \"Log power\": 2.0786241841721553, \"Firing rate\": 119.84617678980906, \"Power\": 119.84617678980906, \"i_spike\": 90.0, \"isi\": 0.03850193431003449, \"stim_strength\": 0, \"combined_condition\": 1.0}, {\"mouse\": 6, \"neuron_x_mouse\": \"m1bayes6\", \"i_trial\": 7, \"stim\": 0, \"Log power\": 2.1897758508181546, \"Firing rate\": 154.80174459602128, \"Power\": 154.80174459602128, \"i_spike\": 94.0, \"isi\": 0.03703708717677838, \"stim_strength\": 0, \"combined_condition\": 1.0}, {\"mouse\": 6, \"neuron_x_mouse\": \"m1bayes6\", \"i_trial\": 7, \"stim\": 1, \"Log power\": 2.0595213644281203, \"Firing rate\": 114.68889394168251, \"Power\": 114.68889394168251, \"i_spike\": 101.5, \"isi\": 0.034467760694125195, \"stim_strength\": 0, \"combined_condition\": 1.0}, {\"mouse\": 6, \"neuron_x_mouse\": \"m1bayes6\", \"i_trial\": 8, \"stim\": 0, \"Log power\": 2.0584109640193873, \"Firing rate\": 114.39603291254487, \"Power\": 114.39603291254487, \"i_spike\": 100.0, \"isi\": 0.034792046942135335, \"stim_strength\": 0, \"combined_condition\": 1.0}, {\"mouse\": 6, \"neuron_x_mouse\": \"m1bayes6\", \"i_trial\": 8, \"stim\": 1, \"Log power\": 2.212762543609866, \"Firing rate\": 163.21592986797546, \"Power\": 163.21592986797546, \"i_spike\": 90.5, \"isi\": 0.03756594825528133, \"stim_strength\": 0, \"combined_condition\": 1.0}, {\"mouse\": 6, \"neuron_x_mouse\": \"m1bayes6\", \"i_trial\": 9, \"stim\": 0, \"Log power\": 2.037980996170363, \"Firing rate\": 109.13925783185549, \"Power\": 109.13925783185549, \"i_spike\": 90.0, \"isi\": 0.03894540516981944, \"stim_strength\": 0, \"combined_condition\": 1.0}, {\"mouse\": 6, \"neuron_x_mouse\": \"m1bayes6\", \"i_trial\": 9, \"stim\": 1, \"Log power\": 2.569609012238856, \"Firing rate\": 371.20089291981077, \"Power\": 371.20089291981077, \"i_spike\": 94.5, \"isi\": 0.03669851908072518, \"stim_strength\": 0, \"combined_condition\": 1.0}, {\"mouse\": 7, \"neuron_x_mouse\": \"m1bayes7\", \"i_trial\": 0, \"stim\": 0, \"Log power\": 2.4685442819085206, \"Firing rate\": 294.13335852498903, \"Power\": 294.13335852498903, \"i_spike\": 111.0, \"isi\": 0.03135159595985396, \"stim_strength\": 0, \"combined_condition\": 1.0}, {\"mouse\": 7, \"neuron_x_mouse\": \"m1bayes7\", \"i_trial\": 0, \"stim\": 1, \"Log power\": 2.2557481412640494, \"Firing rate\": 180.1972426816719, \"Power\": 180.1972426816719, \"i_spike\": 116.0, \"isi\": 0.030090794770230862, \"stim_strength\": 0, \"combined_condition\": 1.0}, {\"mouse\": 7, \"neuron_x_mouse\": \"m1bayes7\", \"i_trial\": 1, \"stim\": 0, \"Log power\": 2.1956159234639028, \"Firing rate\": 156.89746382133035, \"Power\": 156.89746382133035, \"i_spike\": 104.5, \"isi\": 0.033136066447555394, \"stim_strength\": 0, \"combined_condition\": 1.0}, {\"mouse\": 7, \"neuron_x_mouse\": \"m1bayes7\", \"i_trial\": 1, \"stim\": 1, \"Log power\": 2.2439708056310086, \"Firing rate\": 175.37626055393335, \"Power\": 175.37626055393335, \"i_spike\": 113.0, \"isi\": 0.030900419514015114, \"stim_strength\": 0, \"combined_condition\": 1.0}, {\"mouse\": 7, \"neuron_x_mouse\": \"m1bayes7\", \"i_trial\": 2, \"stim\": 0, \"Log power\": 2.4851150283774333, \"Firing rate\": 305.5730354811457, \"Power\": 305.5730354811457, \"i_spike\": 106.0, \"isi\": 0.032763503721089854, \"stim_strength\": 0, \"combined_condition\": 1.0}, {\"mouse\": 7, \"neuron_x_mouse\": \"m1bayes7\", \"i_trial\": 2, \"stim\": 1, \"Log power\": 2.3489249986304226, \"Firing rate\": 223.31865248343817, \"Power\": 223.31865248343817, \"i_spike\": 121.5, \"isi\": 0.02888069097933466, \"stim_strength\": 0, \"combined_condition\": 1.0}, {\"mouse\": 7, \"neuron_x_mouse\": \"m1bayes7\", \"i_trial\": 3, \"stim\": 0, \"Log power\": 2.1548626811714366, \"Firing rate\": 142.844223039647, \"Power\": 142.844223039647, \"i_spike\": 103.5, \"isi\": 0.03365044538047108, \"stim_strength\": 0, \"combined_condition\": 1.0}, {\"mouse\": 7, \"neuron_x_mouse\": \"m1bayes7\", \"i_trial\": 3, \"stim\": 1, \"Log power\": 2.3421586116044306, \"Firing rate\": 219.86627145463908, \"Power\": 219.86627145463908, \"i_spike\": 117.5, \"isi\": 0.02969901550472233, \"stim_strength\": 0, \"combined_condition\": 1.0}, {\"mouse\": 7, \"neuron_x_mouse\": \"m1bayes7\", \"i_trial\": 4, \"stim\": 0, \"Log power\": 2.5527450768520445, \"Firing rate\": 357.0631868777906, \"Power\": 357.0631868777906, \"i_spike\": 100.0, \"isi\": 0.034808851885537534, \"stim_strength\": 0, \"combined_condition\": 1.0}, {\"mouse\": 7, \"neuron_x_mouse\": \"m1bayes7\", \"i_trial\": 4, \"stim\": 1, \"Log power\": 2.228048437550175, \"Firing rate\": 169.0629479707277, \"Power\": 169.0629479707277, \"i_spike\": 109.0, \"isi\": 0.03182827885285394, \"stim_strength\": 0, \"combined_condition\": 1.0}, {\"mouse\": 7, \"neuron_x_mouse\": \"m1bayes7\", \"i_trial\": 5, \"stim\": 0, \"Log power\": 2.995629033713281, \"Firing rate\": 989.9859559989704, \"Power\": 989.9859559989704, \"i_spike\": 114.5, \"isi\": 0.030452296534285623, \"stim_strength\": 0, \"combined_condition\": 1.0}, {\"mouse\": 7, \"neuron_x_mouse\": \"m1bayes7\", \"i_trial\": 5, \"stim\": 1, \"Log power\": 2.318175634115493, \"Firing rate\": 208.05379125217138, \"Power\": 208.05379125217138, \"i_spike\": 101.5, \"isi\": 0.03425858755725605, \"stim_strength\": 0, \"combined_condition\": 1.0}, {\"mouse\": 7, \"neuron_x_mouse\": \"m1bayes7\", \"i_trial\": 6, \"stim\": 0, \"Log power\": 2.143983537538121, \"Firing rate\": 139.3103994638867, \"Power\": 139.3103994638867, \"i_spike\": 104.5, \"isi\": 0.03319373018422869, \"stim_strength\": 0, \"combined_condition\": 1.0}, {\"mouse\": 7, \"neuron_x_mouse\": \"m1bayes7\", \"i_trial\": 6, \"stim\": 1, \"Log power\": 2.5723482287735484, \"Firing rate\": 373.54955963778787, \"Power\": 373.54955963778787, \"i_spike\": 108.0, \"isi\": 0.032304315925450654, \"stim_strength\": 0, \"combined_condition\": 1.0}, {\"mouse\": 7, \"neuron_x_mouse\": \"m1bayes7\", \"i_trial\": 7, \"stim\": 0, \"Log power\": 2.331966421819981, \"Firing rate\": 214.76644175644657, \"Power\": 214.76644175644657, \"i_spike\": 112.5, \"isi\": 0.030805378018066213, \"stim_strength\": 0, \"combined_condition\": 1.0}, {\"mouse\": 7, \"neuron_x_mouse\": \"m1bayes7\", \"i_trial\": 7, \"stim\": 1, \"Log power\": 2.962549762419186, \"Firing rate\": 917.381044910437, \"Power\": 917.381044910437, \"i_spike\": 116.5, \"isi\": 0.030113147333831795, \"stim_strength\": 0, \"combined_condition\": 1.0}, {\"mouse\": 7, \"neuron_x_mouse\": \"m1bayes7\", \"i_trial\": 8, \"stim\": 0, \"Log power\": 2.3422113349460583, \"Firing rate\": 219.89296483595533, \"Power\": 219.89296483595533, \"i_spike\": 109.5, \"isi\": 0.03141880606153138, \"stim_strength\": 0, \"combined_condition\": 1.0}, {\"mouse\": 7, \"neuron_x_mouse\": \"m1bayes7\", \"i_trial\": 8, \"stim\": 1, \"Log power\": 2.435647716183211, \"Firing rate\": 272.6765033305787, \"Power\": 272.6765033305787, \"i_spike\": 110.5, \"isi\": 0.03136782050414742, \"stim_strength\": 0, \"combined_condition\": 1.0}, {\"mouse\": 7, \"neuron_x_mouse\": \"m1bayes7\", \"i_trial\": 9, \"stim\": 0, \"Log power\": 3.0275031585775776, \"Firing rate\": 1065.3766120101502, \"Power\": 1065.3766120101502, \"i_spike\": 113.0, \"isi\": 0.030783021041679702, \"stim_strength\": 0, \"combined_condition\": 1.0}, {\"mouse\": 7, \"neuron_x_mouse\": \"m1bayes7\", \"i_trial\": 9, \"stim\": 1, \"Log power\": 2.2605400028893943, \"Firing rate\": 182.19648866522763, \"Power\": 182.19648866522763, \"i_spike\": 123.5, \"isi\": 0.02812715069260961, \"stim_strength\": 0, \"combined_condition\": 1.0}, {\"mouse\": 0, \"neuron_x_mouse\": \"m1bayes0\", \"i_trial\": 0, \"stim\": 0, \"Log power\": 2.0018619132582023, \"Firing rate\": 100.42964169608798, \"Power\": 100.42964169608798, \"i_spike\": 55.0, \"isi\": 0.06369238469639807, \"stim_strength\": 1, \"combined_condition\": 1.0}, {\"mouse\": 0, \"neuron_x_mouse\": \"m1bayes0\", \"i_trial\": 0, \"stim\": 1, \"Log power\": 3.103034660576555, \"Firing rate\": 1267.7530398301808, \"Power\": 1267.7530398301808, \"i_spike\": 81.5, \"isi\": 0.04249433706743292, \"stim_strength\": 1, \"combined_condition\": 1.0}, {\"mouse\": 0, \"neuron_x_mouse\": \"m1bayes0\", \"i_trial\": 1, \"stim\": 0, \"Log power\": 2.020500163683681, \"Firing rate\": 104.8335188693854, \"Power\": 104.8335188693854, \"i_spike\": 38.0, \"isi\": 0.09212341476727073, \"stim_strength\": 1, \"combined_condition\": 1.0}, {\"mouse\": 0, \"neuron_x_mouse\": \"m1bayes0\", \"i_trial\": 1, \"stim\": 1, \"Log power\": 1.889872945496533, \"Firing rate\": 77.60200557959439, \"Power\": 77.60200557959439, \"i_spike\": 55.0, \"isi\": 0.06354471114226784, \"stim_strength\": 1, \"combined_condition\": 1.0}, {\"mouse\": 0, \"neuron_x_mouse\": \"m1bayes0\", \"i_trial\": 2, \"stim\": 0, \"Log power\": 1.6718924915565323, \"Firing rate\": 46.97778019651732, \"Power\": 46.97778019651732, \"i_spike\": 43.5, \"isi\": 0.07967313163461082, \"stim_strength\": 1, \"combined_condition\": 1.0}, {\"mouse\": 0, \"neuron_x_mouse\": \"m1bayes0\", \"i_trial\": 2, \"stim\": 1, \"Log power\": 2.318485294839149, \"Firing rate\": 208.202190700598, \"Power\": 208.202190700598, \"i_spike\": 66.0, \"isi\": 0.05305968751407003, \"stim_strength\": 1, \"combined_condition\": 1.0}, {\"mouse\": 0, \"neuron_x_mouse\": \"m1bayes0\", \"i_trial\": 3, \"stim\": 0, \"Log power\": 1.7099286335583286, \"Firing rate\": 51.2777113786572, \"Power\": 51.2777113786572, \"i_spike\": 51.0, \"isi\": 0.06893508499967295, \"stim_strength\": 1, \"combined_condition\": 1.0}, {\"mouse\": 0, \"neuron_x_mouse\": \"m1bayes0\", \"i_trial\": 3, \"stim\": 1, \"Log power\": 3.3748522511411956, \"Firing rate\": 2370.5670912978176, \"Power\": 2370.5670912978176, \"i_spike\": 63.5, \"isi\": 0.05502669517219422, \"stim_strength\": 1, \"combined_condition\": 1.0}, {\"mouse\": 0, \"neuron_x_mouse\": \"m1bayes0\", \"i_trial\": 4, \"stim\": 0, \"Log power\": 1.9424003080237064, \"Firing rate\": 87.57906574613642, \"Power\": 87.57906574613642, \"i_spike\": 45.0, \"isi\": 0.07855422034767068, \"stim_strength\": 1, \"combined_condition\": 1.0}, {\"mouse\": 0, \"neuron_x_mouse\": \"m1bayes0\", \"i_trial\": 4, \"stim\": 1, \"Log power\": 1.9830052599870995, \"Firing rate\": 96.16239250865743, \"Power\": 96.16239250865743, \"i_spike\": 75.5, \"isi\": 0.04552056853003494, \"stim_strength\": 1, \"combined_condition\": 1.0}, {\"mouse\": 0, \"neuron_x_mouse\": \"m1bayes0\", \"i_trial\": 5, \"stim\": 0, \"Log power\": 1.8331116871964257, \"Firing rate\": 68.09444541688006, \"Power\": 68.09444541688006, \"i_spike\": 52.5, \"isi\": 0.06603268783029724, \"stim_strength\": 1, \"combined_condition\": 1.0}, {\"mouse\": 0, \"neuron_x_mouse\": \"m1bayes0\", \"i_trial\": 5, \"stim\": 1, \"Log power\": 1.9368396121585987, \"Firing rate\": 86.46485393470175, \"Power\": 86.46485393470175, \"i_spike\": 64.5, \"isi\": 0.05370211769905006, \"stim_strength\": 1, \"combined_condition\": 1.0}, {\"mouse\": 0, \"neuron_x_mouse\": \"m1bayes0\", \"i_trial\": 6, \"stim\": 0, \"Log power\": 1.8159337328614136, \"Firing rate\": 65.45362935521047, \"Power\": 65.45362935521047, \"i_spike\": 37.5, \"isi\": 0.08836118540897872, \"stim_strength\": 1, \"combined_condition\": 1.0}, {\"mouse\": 0, \"neuron_x_mouse\": \"m1bayes0\", \"i_trial\": 6, \"stim\": 1, \"Log power\": 1.9514647795047961, \"Firing rate\": 89.42620059641571, \"Power\": 89.42620059641571, \"i_spike\": 64.0, \"isi\": 0.054665918888860576, \"stim_strength\": 1, \"combined_condition\": 1.0}, {\"mouse\": 0, \"neuron_x_mouse\": \"m1bayes0\", \"i_trial\": 7, \"stim\": 0, \"Log power\": 2.1818293811982135, \"Firing rate\": 151.9950278204137, \"Power\": 151.9950278204137, \"i_spike\": 41.0, \"isi\": 0.08603295050656826, \"stim_strength\": 1, \"combined_condition\": 1.0}, {\"mouse\": 0, \"neuron_x_mouse\": \"m1bayes0\", \"i_trial\": 7, \"stim\": 1, \"Log power\": 2.269698897170053, \"Firing rate\": 186.07965713646018, \"Power\": 186.07965713646018, \"i_spike\": 68.0, \"isi\": 0.050411195418788836, \"stim_strength\": 1, \"combined_condition\": 1.0}, {\"mouse\": 0, \"neuron_x_mouse\": \"m1bayes0\", \"i_trial\": 8, \"stim\": 0, \"Log power\": 1.9009297532817888, \"Firing rate\": 79.60305828160828, \"Power\": 79.60305828160828, \"i_spike\": 48.0, \"isi\": 0.07061590460528315, \"stim_strength\": 1, \"combined_condition\": 1.0}, {\"mouse\": 0, \"neuron_x_mouse\": \"m1bayes0\", \"i_trial\": 8, \"stim\": 1, \"Log power\": 2.047770987143736, \"Firing rate\": 111.62744569328252, \"Power\": 111.62744569328252, \"i_spike\": 67.5, \"isi\": 0.051487587633790875, \"stim_strength\": 1, \"combined_condition\": 1.0}, {\"mouse\": 0, \"neuron_x_mouse\": \"m1bayes0\", \"i_trial\": 9, \"stim\": 0, \"Log power\": 1.9862795869420333, \"Firing rate\": 96.89014078264694, \"Power\": 96.89014078264694, \"i_spike\": 36.0, \"isi\": 0.09563929392824909, \"stim_strength\": 1, \"combined_condition\": 1.0}, {\"mouse\": 0, \"neuron_x_mouse\": \"m1bayes0\", \"i_trial\": 9, \"stim\": 1, \"Log power\": 2.1105606341488157, \"Firing rate\": 128.9913636990435, \"Power\": 128.9913636990435, \"i_spike\": 71.5, \"isi\": 0.048794123562204285, \"stim_strength\": 1, \"combined_condition\": 1.0}, {\"mouse\": 1, \"neuron_x_mouse\": \"m1bayes1\", \"i_trial\": 0, \"stim\": 0, \"Log power\": 1.7948076101506085, \"Firing rate\": 62.34585858861493, \"Power\": 62.34585858861493, \"i_spike\": 41.0, \"isi\": 0.08613425753385899, \"stim_strength\": 1, \"combined_condition\": 1.0}, {\"mouse\": 1, \"neuron_x_mouse\": \"m1bayes1\", \"i_trial\": 0, \"stim\": 1, \"Log power\": 2.5552733923952964, \"Firing rate\": 359.14795045637436, \"Power\": 359.14795045637436, \"i_spike\": 91.0, \"isi\": 0.038580414362883786, \"stim_strength\": 1, \"combined_condition\": 1.0}, {\"mouse\": 1, \"neuron_x_mouse\": \"m1bayes1\", \"i_trial\": 1, \"stim\": 0, \"Log power\": 4.592268281437253, \"Firing rate\": 39108.240876347794, \"Power\": 39108.240876347794, \"i_spike\": 42.5, \"isi\": 0.08265061855766768, \"stim_strength\": 1, \"combined_condition\": 1.0}, {\"mouse\": 1, \"neuron_x_mouse\": \"m1bayes1\", \"i_trial\": 1, \"stim\": 1, \"Log power\": 1.9107434208321252, \"Firing rate\": 81.4223102658125, \"Power\": 81.4223102658125, \"i_spike\": 63.0, \"isi\": 0.055131044689596904, \"stim_strength\": 1, \"combined_condition\": 1.0}, {\"mouse\": 1, \"neuron_x_mouse\": \"m1bayes1\", \"i_trial\": 2, \"stim\": 0, \"Log power\": 2.3085162019509657, \"Firing rate\": 203.47741044717483, \"Power\": 203.47741044717483, \"i_spike\": 50.5, \"isi\": 0.06902853513022615, \"stim_strength\": 1, \"combined_condition\": 1.0}, {\"mouse\": 1, \"neuron_x_mouse\": \"m1bayes1\", \"i_trial\": 2, \"stim\": 1, \"Log power\": 2.131111522464779, \"Firing rate\": 135.2419806442773, \"Power\": 135.2419806442773, \"i_spike\": 77.5, \"isi\": 0.04448458724085465, \"stim_strength\": 1, \"combined_condition\": 1.0}, {\"mouse\": 1, \"neuron_x_mouse\": \"m1bayes1\", \"i_trial\": 3, \"stim\": 0, \"Log power\": 1.811711614876714, \"Firing rate\": 64.82038629632281, \"Power\": 64.82038629632281, \"i_spike\": 49.5, \"isi\": 0.06730376886830405, \"stim_strength\": 1, \"combined_condition\": 1.0}, {\"mouse\": 1, \"neuron_x_mouse\": \"m1bayes1\", \"i_trial\": 3, \"stim\": 1, \"Log power\": 2.0465579277186525, \"Firing rate\": 111.31608601932216, \"Power\": 111.31608601932216, \"i_spike\": 67.5, \"isi\": 0.04920565521297111, \"stim_strength\": 1, \"combined_condition\": 1.0}, {\"mouse\": 1, \"neuron_x_mouse\": \"m1bayes1\", \"i_trial\": 4, \"stim\": 0, \"Log power\": 1.835917328255278, \"Firing rate\": 68.53577502055394, \"Power\": 68.53577502055394, \"i_spike\": 47.5, \"isi\": 0.07281168571251755, \"stim_strength\": 1, \"combined_condition\": 1.0}, {\"mouse\": 1, \"neuron_x_mouse\": \"m1bayes1\", \"i_trial\": 4, \"stim\": 1, \"Log power\": 2.294066135407849, \"Firing rate\": 196.81859869810327, \"Power\": 196.81859869810327, \"i_spike\": 71.5, \"isi\": 0.04723562817950004, \"stim_strength\": 1, \"combined_condition\": 1.0}, {\"mouse\": 1, \"neuron_x_mouse\": \"m1bayes1\", \"i_trial\": 5, \"stim\": 0, \"Log power\": 2.06407207931907, \"Firing rate\": 115.8969692963056, \"Power\": 115.8969692963056, \"i_spike\": 49.5, \"isi\": 0.06977439408084736, \"stim_strength\": 1, \"combined_condition\": 1.0}, {\"mouse\": 1, \"neuron_x_mouse\": \"m1bayes1\", \"i_trial\": 5, \"stim\": 1, \"Log power\": 2.060069493602582, \"Firing rate\": 114.83373579220084, \"Power\": 114.83373579220084, \"i_spike\": 64.5, \"isi\": 0.05239984888586632, \"stim_strength\": 1, \"combined_condition\": 1.0}, {\"mouse\": 1, \"neuron_x_mouse\": \"m1bayes1\", \"i_trial\": 6, \"stim\": 0, \"Log power\": 1.9040267903450487, \"Firing rate\": 80.17275180671096, \"Power\": 80.17275180671096, \"i_spike\": 56.0, \"isi\": 0.06189321325498069, \"stim_strength\": 1, \"combined_condition\": 1.0}, {\"mouse\": 1, \"neuron_x_mouse\": \"m1bayes1\", \"i_trial\": 6, \"stim\": 1, \"Log power\": 2.1138406704612245, \"Firing rate\": 129.96926725395645, \"Power\": 129.96926725395645, \"i_spike\": 72.5, \"isi\": 0.04769116878664881, \"stim_strength\": 1, \"combined_condition\": 1.0}, {\"mouse\": 1, \"neuron_x_mouse\": \"m1bayes1\", \"i_trial\": 7, \"stim\": 0, \"Log power\": 1.8264647382543708, \"Firing rate\": 67.060183620302, \"Power\": 67.060183620302, \"i_spike\": 50.0, \"isi\": 0.06964939632835838, \"stim_strength\": 1, \"combined_condition\": 1.0}, {\"mouse\": 1, \"neuron_x_mouse\": \"m1bayes1\", \"i_trial\": 7, \"stim\": 1, \"Log power\": 2.0567604758673714, \"Firing rate\": 113.96210850307581, \"Power\": 113.96210850307581, \"i_spike\": 63.5, \"isi\": 0.05364947287362414, \"stim_strength\": 1, \"combined_condition\": 1.0}, {\"mouse\": 1, \"neuron_x_mouse\": \"m1bayes1\", \"i_trial\": 8, \"stim\": 0, \"Log power\": 2.4394608728029232, \"Firing rate\": 275.08117630143045, \"Power\": 275.08117630143045, \"i_spike\": 36.0, \"isi\": 0.09760108987686118, \"stim_strength\": 1, \"combined_condition\": 1.0}, {\"mouse\": 1, \"neuron_x_mouse\": \"m1bayes1\", \"i_trial\": 8, \"stim\": 1, \"Log power\": 2.1698125754264437, \"Firing rate\": 147.84702003484054, \"Power\": 147.84702003484054, \"i_spike\": 65.5, \"isi\": 0.05287564552989061, \"stim_strength\": 1, \"combined_condition\": 1.0}, {\"mouse\": 1, \"neuron_x_mouse\": \"m1bayes1\", \"i_trial\": 9, \"stim\": 0, \"Log power\": 1.9374330391535353, \"Firing rate\": 86.58308166346957, \"Power\": 86.58308166346957, \"i_spike\": 42.0, \"isi\": 0.08104250356051754, \"stim_strength\": 1, \"combined_condition\": 1.0}, {\"mouse\": 1, \"neuron_x_mouse\": \"m1bayes1\", \"i_trial\": 9, \"stim\": 1, \"Log power\": 2.9259188145239605, \"Firing rate\": 843.1771224785876, \"Power\": 843.1771224785876, \"i_spike\": 58.0, \"isi\": 0.05837444614622307, \"stim_strength\": 1, \"combined_condition\": 1.0}, {\"mouse\": 2, \"neuron_x_mouse\": \"m1bayes2\", \"i_trial\": 0, \"stim\": 0, \"Log power\": 1.8791320244390024, \"Firing rate\": 75.7063005307589, \"Power\": 75.7063005307589, \"i_spike\": 48.5, \"isi\": 0.07168274803568589, \"stim_strength\": 1, \"combined_condition\": 1.0}, {\"mouse\": 2, \"neuron_x_mouse\": \"m1bayes2\", \"i_trial\": 0, \"stim\": 1, \"Log power\": 1.9413145877095062, \"Firing rate\": 87.36039473488522, \"Power\": 87.36039473488522, \"i_spike\": 83.0, \"isi\": 0.04212898211778962, \"stim_strength\": 1, \"combined_condition\": 1.0}, {\"mouse\": 2, \"neuron_x_mouse\": \"m1bayes2\", \"i_trial\": 1, \"stim\": 0, \"Log power\": 2.8678872620136735, \"Firing rate\": 737.7127033107098, \"Power\": 737.7127033107098, \"i_spike\": 59.0, \"isi\": 0.05920175414607926, \"stim_strength\": 1, \"combined_condition\": 1.0}, {\"mouse\": 2, \"neuron_x_mouse\": \"m1bayes2\", \"i_trial\": 1, \"stim\": 1, \"Log power\": 2.1246754050985754, \"Firing rate\": 133.25251207734618, \"Power\": 133.25251207734618, \"i_spike\": 88.0, \"isi\": 0.03903717452282527, \"stim_strength\": 1, \"combined_condition\": 1.0}, {\"mouse\": 2, \"neuron_x_mouse\": \"m1bayes2\", \"i_trial\": 2, \"stim\": 0, \"Log power\": 2.0358753073721223, \"Firing rate\": 108.61137388802008, \"Power\": 108.61137388802008, \"i_spike\": 43.0, \"isi\": 0.08155593200499159, \"stim_strength\": 1, \"combined_condition\": 1.0}, {\"mouse\": 2, \"neuron_x_mouse\": \"m1bayes2\", \"i_trial\": 2, \"stim\": 1, \"Log power\": 3.0036079728273575, \"Firing rate\": 1008.3422688533926, \"Power\": 1008.3422688533926, \"i_spike\": 71.0, \"isi\": 0.04839697072239333, \"stim_strength\": 1, \"combined_condition\": 1.0}, {\"mouse\": 2, \"neuron_x_mouse\": \"m1bayes2\", \"i_trial\": 3, \"stim\": 0, \"Log power\": 1.6578381725090017, \"Firing rate\": 45.48185533683682, \"Power\": 45.48185533683682, \"i_spike\": 49.5, \"isi\": 0.06736252502010297, \"stim_strength\": 1, \"combined_condition\": 1.0}, {\"mouse\": 2, \"neuron_x_mouse\": \"m1bayes2\", \"i_trial\": 3, \"stim\": 1, \"Log power\": 2.106163598996885, \"Firing rate\": 127.69197346679384, \"Power\": 127.69197346679384, \"i_spike\": 82.5, \"isi\": 0.041293330119213476, \"stim_strength\": 1, \"combined_condition\": 1.0}, {\"mouse\": 2, \"neuron_x_mouse\": \"m1bayes2\", \"i_trial\": 4, \"stim\": 0, \"Log power\": 2.4246478109390917, \"Firing rate\": 265.85682320188766, \"Power\": 265.85682320188766, \"i_spike\": 47.5, \"isi\": 0.07279591388589922, \"stim_strength\": 1, \"combined_condition\": 1.0}, {\"mouse\": 2, \"neuron_x_mouse\": \"m1bayes2\", \"i_trial\": 4, \"stim\": 1, \"Log power\": 2.693966209823101, \"Firing rate\": 494.27222875978634, \"Power\": 494.27222875978634, \"i_spike\": 79.5, \"isi\": 0.0439306055930975, \"stim_strength\": 1, \"combined_condition\": 1.0}, {\"mouse\": 2, \"neuron_x_mouse\": \"m1bayes2\", \"i_trial\": 5, \"stim\": 0, \"Log power\": 2.324278555479303, \"Firing rate\": 210.99810529946623, \"Power\": 210.99810529946623, \"i_spike\": 51.0, \"isi\": 0.0684268655141675, \"stim_strength\": 1, \"combined_condition\": 1.0}, {\"mouse\": 2, \"neuron_x_mouse\": \"m1bayes2\", \"i_trial\": 5, \"stim\": 1, \"Log power\": 2.232321514483141, \"Firing rate\": 170.73458940967353, \"Power\": 170.73458940967353, \"i_spike\": 77.5, \"isi\": 0.04495167663442248, \"stim_strength\": 1, \"combined_condition\": 1.0}, {\"mouse\": 2, \"neuron_x_mouse\": \"m1bayes2\", \"i_trial\": 6, \"stim\": 0, \"Log power\": 2.014194505614833, \"Firing rate\": 103.32240477945219, \"Power\": 103.32240477945219, \"i_spike\": 44.5, \"isi\": 0.078111269566641, \"stim_strength\": 1, \"combined_condition\": 1.0}, {\"mouse\": 2, \"neuron_x_mouse\": \"m1bayes2\", \"i_trial\": 6, \"stim\": 1, \"Log power\": 2.1117170859814043, \"Firing rate\": 129.33530333380816, \"Power\": 129.33530333380816, \"i_spike\": 65.0, \"isi\": 0.052396764476603644, \"stim_strength\": 1, \"combined_condition\": 1.0}, {\"mouse\": 2, \"neuron_x_mouse\": \"m1bayes2\", \"i_trial\": 7, \"stim\": 0, \"Log power\": 1.895235677579651, \"Firing rate\": 78.5661872253704, \"Power\": 78.5661872253704, \"i_spike\": 50.0, \"isi\": 0.06997584001998876, \"stim_strength\": 1, \"combined_condition\": 1.0}, {\"mouse\": 2, \"neuron_x_mouse\": \"m1bayes2\", \"i_trial\": 7, \"stim\": 1, \"Log power\": 2.1657250781447024, \"Firing rate\": 146.46203973720182, \"Power\": 146.46203973720182, \"i_spike\": 78.5, \"isi\": 0.044148275685639025, \"stim_strength\": 1, \"combined_condition\": 1.0}, {\"mouse\": 2, \"neuron_x_mouse\": \"m1bayes2\", \"i_trial\": 8, \"stim\": 0, \"Log power\": 1.7683748043480418, \"Firing rate\": 58.6644231171841, \"Power\": 58.6644231171841, \"i_spike\": 50.5, \"isi\": 0.0682910111205317, \"stim_strength\": 1, \"combined_condition\": 1.0}, {\"mouse\": 2, \"neuron_x_mouse\": \"m1bayes2\", \"i_trial\": 8, \"stim\": 1, \"Log power\": 2.421581106359022, \"Firing rate\": 263.9861281761035, \"Power\": 263.9861281761035, \"i_spike\": 73.0, \"isi\": 0.04757220629506525, \"stim_strength\": 1, \"combined_condition\": 1.0}, {\"mouse\": 2, \"neuron_x_mouse\": \"m1bayes2\", \"i_trial\": 9, \"stim\": 0, \"Log power\": 2.2149294645972475, \"Firing rate\": 164.0323340471282, \"Power\": 164.0323340471282, \"i_spike\": 54.0, \"isi\": 0.06478913641856986, \"stim_strength\": 1, \"combined_condition\": 1.0}, {\"mouse\": 2, \"neuron_x_mouse\": \"m1bayes2\", \"i_trial\": 9, \"stim\": 1, \"Log power\": 2.4726325554995454, \"Firing rate\": 296.91528509501, \"Power\": 296.91528509501, \"i_spike\": 88.5, \"isi\": 0.03905234741345108, \"stim_strength\": 1, \"combined_condition\": 1.0}, {\"mouse\": 3, \"neuron_x_mouse\": \"m1bayes3\", \"i_trial\": 0, \"stim\": 0, \"Log power\": 2.106781796213733, \"Firing rate\": 127.87386625008, \"Power\": 127.87386625008, \"i_spike\": 63.0, \"isi\": 0.055477904459541726, \"stim_strength\": 1, \"combined_condition\": 1.0}, {\"mouse\": 3, \"neuron_x_mouse\": \"m1bayes3\", \"i_trial\": 0, \"stim\": 1, \"Log power\": 1.9849094941167944, \"Firing rate\": 96.58495773802814, \"Power\": 96.58495773802814, \"i_spike\": 82.0, \"isi\": 0.042705837533902336, \"stim_strength\": 1, \"combined_condition\": 1.0}, {\"mouse\": 3, \"neuron_x_mouse\": \"m1bayes3\", \"i_trial\": 1, \"stim\": 0, \"Log power\": 2.3149335549614207, \"Firing rate\": 206.50641864112546, \"Power\": 206.50641864112546, \"i_spike\": 56.0, \"isi\": 0.06281721142984406, \"stim_strength\": 1, \"combined_condition\": 1.0}, {\"mouse\": 3, \"neuron_x_mouse\": \"m1bayes3\", \"i_trial\": 1, \"stim\": 1, \"Log power\": 2.394758696664956, \"Firing rate\": 248.1753806468403, \"Power\": 248.1753806468403, \"i_spike\": 73.5, \"isi\": 0.047066199465950545, \"stim_strength\": 1, \"combined_condition\": 1.0}, {\"mouse\": 3, \"neuron_x_mouse\": \"m1bayes3\", \"i_trial\": 2, \"stim\": 0, \"Log power\": 2.2066981562252046, \"Firing rate\": 160.9526591600929, \"Power\": 160.9526591600929, \"i_spike\": 66.0, \"isi\": 0.05297472427989326, \"stim_strength\": 1, \"combined_condition\": 1.0}, {\"mouse\": 3, \"neuron_x_mouse\": \"m1bayes3\", \"i_trial\": 2, \"stim\": 1, \"Log power\": 2.844146126540519, \"Firing rate\": 698.4673770203228, \"Power\": 698.4673770203228, \"i_spike\": 94.0, \"isi\": 0.03578941076187081, \"stim_strength\": 1, \"combined_condition\": 1.0}, {\"mouse\": 3, \"neuron_x_mouse\": \"m1bayes3\", \"i_trial\": 3, \"stim\": 0, \"Log power\": 1.8316034033744024, \"Firing rate\": 67.85836686906435, \"Power\": 67.85836686906435, \"i_spike\": 48.0, \"isi\": 0.07086168983730814, \"stim_strength\": 1, \"combined_condition\": 1.0}, {\"mouse\": 3, \"neuron_x_mouse\": \"m1bayes3\", \"i_trial\": 3, \"stim\": 1, \"Log power\": 2.442724687239048, \"Firing rate\": 277.1562568037572, \"Power\": 277.1562568037572, \"i_spike\": 89.5, \"isi\": 0.038102786074911986, \"stim_strength\": 1, \"combined_condition\": 1.0}, {\"mouse\": 3, \"neuron_x_mouse\": \"m1bayes3\", \"i_trial\": 4, \"stim\": 0, \"Log power\": 1.8631453712883395, \"Firing rate\": 72.97017222632165, \"Power\": 72.97017222632165, \"i_spike\": 61.5, \"isi\": 0.056736364738056516, \"stim_strength\": 1, \"combined_condition\": 1.0}, {\"mouse\": 3, \"neuron_x_mouse\": \"m1bayes3\", \"i_trial\": 4, \"stim\": 1, \"Log power\": 2.292987073402953, \"Firing rate\": 196.33018390927177, \"Power\": 196.33018390927177, \"i_spike\": 80.5, \"isi\": 0.04262422257874704, \"stim_strength\": 1, \"combined_condition\": 1.0}, {\"mouse\": 3, \"neuron_x_mouse\": \"m1bayes3\", \"i_trial\": 5, \"stim\": 0, \"Log power\": 1.9399538588684557, \"Firing rate\": 87.0871060318939, \"Power\": 87.0871060318939, \"i_spike\": 58.5, \"isi\": 0.059523957800914004, \"stim_strength\": 1, \"combined_condition\": 1.0}, {\"mouse\": 3, \"neuron_x_mouse\": \"m1bayes3\", \"i_trial\": 5, \"stim\": 1, \"Log power\": 2.0784290226883964, \"Firing rate\": 119.79233290244886, \"Power\": 119.79233290244886, \"i_spike\": 80.5, \"isi\": 0.04350548808397096, \"stim_strength\": 1, \"combined_condition\": 1.0}, {\"mouse\": 3, \"neuron_x_mouse\": \"m1bayes3\", \"i_trial\": 6, \"stim\": 0, \"Log power\": 1.8785410056384824, \"Firing rate\": 75.603344086924, \"Power\": 75.603344086924, \"i_spike\": 66.0, \"isi\": 0.053090245108361044, \"stim_strength\": 1, \"combined_condition\": 1.0}, {\"mouse\": 3, \"neuron_x_mouse\": \"m1bayes3\", \"i_trial\": 6, \"stim\": 1, \"Log power\": 2.4955337810026936, \"Firing rate\": 312.9923918949626, \"Power\": 312.9923918949626, \"i_spike\": 86.5, \"isi\": 0.04025312553969407, \"stim_strength\": 1, \"combined_condition\": 1.0}, {\"mouse\": 3, \"neuron_x_mouse\": \"m1bayes3\", \"i_trial\": 7, \"stim\": 0, \"Log power\": 2.0746303082109985, \"Firing rate\": 118.74909492010592, \"Power\": 118.74909492010592, \"i_spike\": 72.0, \"isi\": 0.048033024487303656, \"stim_strength\": 1, \"combined_condition\": 1.0}, {\"mouse\": 3, \"neuron_x_mouse\": \"m1bayes3\", \"i_trial\": 7, \"stim\": 1, \"Log power\": 2.2225790239954217, \"Firing rate\": 166.94715557411453, \"Power\": 166.94715557411453, \"i_spike\": 92.0, \"isi\": 0.037726561692618406, \"stim_strength\": 1, \"combined_condition\": 1.0}, {\"mouse\": 3, \"neuron_x_mouse\": \"m1bayes3\", \"i_trial\": 8, \"stim\": 0, \"Log power\": 2.6080842192343936, \"Firing rate\": 405.5871800810127, \"Power\": 405.5871800810127, \"i_spike\": 59.0, \"isi\": 0.05923222896162077, \"stim_strength\": 1, \"combined_condition\": 1.0}, {\"mouse\": 3, \"neuron_x_mouse\": \"m1bayes3\", \"i_trial\": 8, \"stim\": 1, \"Log power\": 2.0890101697914005, \"Firing rate\": 122.74679742063014, \"Power\": 122.74679742063014, \"i_spike\": 76.5, \"isi\": 0.045275146956503434, \"stim_strength\": 1, \"combined_condition\": 1.0}, {\"mouse\": 3, \"neuron_x_mouse\": \"m1bayes3\", \"i_trial\": 9, \"stim\": 0, \"Log power\": 1.8505586835559884, \"Firing rate\": 70.88570835005078, \"Power\": 70.88570835005078, \"i_spike\": 62.0, \"isi\": 0.056137864419993855, \"stim_strength\": 1, \"combined_condition\": 1.0}, {\"mouse\": 3, \"neuron_x_mouse\": \"m1bayes3\", \"i_trial\": 9, \"stim\": 1, \"Log power\": 2.142944482058454, \"Firing rate\": 138.9774958274784, \"Power\": 138.9774958274784, \"i_spike\": 92.5, \"isi\": 0.036836545061461855, \"stim_strength\": 1, \"combined_condition\": 1.0}, {\"mouse\": 4, \"neuron_x_mouse\": \"m1bayes4\", \"i_trial\": 0, \"stim\": 0, \"Log power\": 2.078284465097118, \"Firing rate\": 119.7524659225041, \"Power\": 119.7524659225041, \"i_spike\": 71.5, \"isi\": 0.04913041544051911, \"stim_strength\": 1, \"combined_condition\": 1.0}, {\"mouse\": 4, \"neuron_x_mouse\": \"m1bayes4\", \"i_trial\": 0, \"stim\": 1, \"Log power\": 2.421793627596909, \"Firing rate\": 264.11534093424433, \"Power\": 264.11534093424433, \"i_spike\": 90.0, \"isi\": 0.03857433760881643, \"stim_strength\": 1, \"combined_condition\": 1.0}, {\"mouse\": 4, \"neuron_x_mouse\": \"m1bayes4\", \"i_trial\": 1, \"stim\": 0, \"Log power\": 2.316182090768357, \"Firing rate\": 207.1009498583483, \"Power\": 207.1009498583483, \"i_spike\": 73.5, \"isi\": 0.047086372923413444, \"stim_strength\": 1, \"combined_condition\": 1.0}, {\"mouse\": 4, \"neuron_x_mouse\": \"m1bayes4\", \"i_trial\": 1, \"stim\": 1, \"Log power\": 2.226370444090893, \"Firing rate\": 168.41099590866273, \"Power\": 168.41099590866273, \"i_spike\": 98.5, \"isi\": 0.03542282536838226, \"stim_strength\": 1, \"combined_condition\": 1.0}, {\"mouse\": 4, \"neuron_x_mouse\": \"m1bayes4\", \"i_trial\": 2, \"stim\": 0, \"Log power\": 1.8484326401012656, \"Firing rate\": 70.53954273953954, \"Power\": 70.53954273953954, \"i_spike\": 69.0, \"isi\": 0.050584016194700175, \"stim_strength\": 1, \"combined_condition\": 1.0}, {\"mouse\": 4, \"neuron_x_mouse\": \"m1bayes4\", \"i_trial\": 2, \"stim\": 1, \"Log power\": 2.204037591202337, \"Firing rate\": 159.96964874585973, \"Power\": 159.96964874585973, \"i_spike\": 96.0, \"isi\": 0.036186308343125355, \"stim_strength\": 1, \"combined_condition\": 1.0}, {\"mouse\": 4, \"neuron_x_mouse\": \"m1bayes4\", \"i_trial\": 3, \"stim\": 0, \"Log power\": 2.3534358243533315, \"Firing rate\": 225.65025277352905, \"Power\": 225.65025277352905, \"i_spike\": 78.5, \"isi\": 0.0436453099039065, \"stim_strength\": 1, \"combined_condition\": 1.0}, {\"mouse\": 4, \"neuron_x_mouse\": \"m1bayes4\", \"i_trial\": 3, \"stim\": 1, \"Log power\": 2.1166126305811863, \"Firing rate\": 130.80147174320263, \"Power\": 130.80147174320263, \"i_spike\": 87.0, \"isi\": 0.040295703739998565, \"stim_strength\": 1, \"combined_condition\": 1.0}, {\"mouse\": 4, \"neuron_x_mouse\": \"m1bayes4\", \"i_trial\": 4, \"stim\": 0, \"Log power\": 1.9998073820109155, \"Firing rate\": 99.95565790298451, \"Power\": 99.95565790298451, \"i_spike\": 66.5, \"isi\": 0.051857335599791235, \"stim_strength\": 1, \"combined_condition\": 1.0}, {\"mouse\": 4, \"neuron_x_mouse\": \"m1bayes4\", \"i_trial\": 4, \"stim\": 1, \"Log power\": 2.8367916750651014, \"Firing rate\": 686.7389420124421, \"Power\": 686.7389420124421, \"i_spike\": 90.0, \"isi\": 0.038783025322376374, \"stim_strength\": 1, \"combined_condition\": 1.0}, {\"mouse\": 4, \"neuron_x_mouse\": \"m1bayes4\", \"i_trial\": 5, \"stim\": 0, \"Log power\": 2.218614883110927, \"Firing rate\": 165.43023364142306, \"Power\": 165.43023364142306, \"i_spike\": 75.0, \"isi\": 0.04666979436115639, \"stim_strength\": 1, \"combined_condition\": 1.0}, {\"mouse\": 4, \"neuron_x_mouse\": \"m1bayes4\", \"i_trial\": 5, \"stim\": 1, \"Log power\": 2.0509597715453602, \"Firing rate\": 112.45008072625197, \"Power\": 112.45008072625197, \"i_spike\": 79.5, \"isi\": 0.043858575711766594, \"stim_strength\": 1, \"combined_condition\": 1.0}, {\"mouse\": 4, \"neuron_x_mouse\": \"m1bayes4\", \"i_trial\": 6, \"stim\": 0, \"Log power\": 2.1136297951563785, \"Firing rate\": 129.90617491189758, \"Power\": 129.90617491189758, \"i_spike\": 69.0, \"isi\": 0.0505271444698216, \"stim_strength\": 1, \"combined_condition\": 1.0}, {\"mouse\": 4, \"neuron_x_mouse\": \"m1bayes4\", \"i_trial\": 6, \"stim\": 1, \"Log power\": 2.077453993509209, \"Firing rate\": 119.5236902908414, \"Power\": 119.5236902908414, \"i_spike\": 90.0, \"isi\": 0.03857602693267524, \"stim_strength\": 1, \"combined_condition\": 1.0}, {\"mouse\": 4, \"neuron_x_mouse\": \"m1bayes4\", \"i_trial\": 7, \"stim\": 0, \"Log power\": 1.8503374384312896, \"Firing rate\": 70.84960583448812, \"Power\": 70.84960583448812, \"i_spike\": 70.0, \"isi\": 0.04950497640060252, \"stim_strength\": 1, \"combined_condition\": 1.0}, {\"mouse\": 4, \"neuron_x_mouse\": \"m1bayes4\", \"i_trial\": 7, \"stim\": 1, \"Log power\": 2.1722774403478984, \"Firing rate\": 148.68852058396897, \"Power\": 148.68852058396897, \"i_spike\": 84.0, \"isi\": 0.0403752834200546, \"stim_strength\": 1, \"combined_condition\": 1.0}, {\"mouse\": 4, \"neuron_x_mouse\": \"m1bayes4\", \"i_trial\": 8, \"stim\": 0, \"Log power\": 2.07642715289067, \"Firing rate\": 119.24142374891706, \"Power\": 119.24142374891706, \"i_spike\": 77.5, \"isi\": 0.04481010781860927, \"stim_strength\": 1, \"combined_condition\": 1.0}, {\"mouse\": 4, \"neuron_x_mouse\": \"m1bayes4\", \"i_trial\": 8, \"stim\": 1, \"Log power\": 2.2632943769784406, \"Firing rate\": 183.3556837493314, \"Power\": 183.3556837493314, \"i_spike\": 80.5, \"isi\": 0.043217476496940896, \"stim_strength\": 1, \"combined_condition\": 1.0}, {\"mouse\": 4, \"neuron_x_mouse\": \"m1bayes4\", \"i_trial\": 9, \"stim\": 0, \"Log power\": 1.9209075532046707, \"Firing rate\": 83.35037406163117, \"Power\": 83.35037406163117, \"i_spike\": 64.0, \"isi\": 0.054346742252283683, \"stim_strength\": 1, \"combined_condition\": 1.0}, {\"mouse\": 4, \"neuron_x_mouse\": \"m1bayes4\", \"i_trial\": 9, \"stim\": 1, \"Log power\": 2.7777415815140793, \"Firing rate\": 599.4342883998322, \"Power\": 599.4342883998322, \"i_spike\": 89.0, \"isi\": 0.03892204004416507, \"stim_strength\": 1, \"combined_condition\": 1.0}, {\"mouse\": 5, \"neuron_x_mouse\": \"m1bayes5\", \"i_trial\": 0, \"stim\": 0, \"Log power\": 2.195495101368505, \"Firing rate\": 156.8538205228955, \"Power\": 156.8538205228955, \"i_spike\": 74.5, \"isi\": 0.046542738596387453, \"stim_strength\": 1, \"combined_condition\": 1.0}, {\"mouse\": 5, \"neuron_x_mouse\": \"m1bayes5\", \"i_trial\": 0, \"stim\": 1, \"Log power\": 3.536290617368642, \"Firing rate\": 3437.879239293706, \"Power\": 3437.879239293706, \"i_spike\": 108.0, \"isi\": 0.032403246016512656, \"stim_strength\": 1, \"combined_condition\": 1.0}, {\"mouse\": 5, \"neuron_x_mouse\": \"m1bayes5\", \"i_trial\": 1, \"stim\": 0, \"Log power\": 2.8104213468870394, \"Firing rate\": 646.2809383770804, \"Power\": 646.2809383770804, \"i_spike\": 73.5, \"isi\": 0.04704387850506653, \"stim_strength\": 1, \"combined_condition\": 1.0}, {\"mouse\": 5, \"neuron_x_mouse\": \"m1bayes5\", \"i_trial\": 1, \"stim\": 1, \"Log power\": 2.2925332130524825, \"Firing rate\": 196.12511581482912, \"Power\": 196.12511581482912, \"i_spike\": 94.5, \"isi\": 0.036890127406291696, \"stim_strength\": 1, \"combined_condition\": 1.0}, {\"mouse\": 5, \"neuron_x_mouse\": \"m1bayes5\", \"i_trial\": 2, \"stim\": 0, \"Log power\": 2.0778220277071746, \"Firing rate\": 119.62502118799236, \"Power\": 119.62502118799236, \"i_spike\": 80.0, \"isi\": 0.043497355032945696, \"stim_strength\": 1, \"combined_condition\": 1.0}, {\"mouse\": 5, \"neuron_x_mouse\": \"m1bayes5\", \"i_trial\": 2, \"stim\": 1, \"Log power\": 2.254577659984747, \"Firing rate\": 179.71224105775514, \"Power\": 179.71224105775514, \"i_spike\": 107.0, \"isi\": 0.03182892742829042, \"stim_strength\": 1, \"combined_condition\": 1.0}, {\"mouse\": 5, \"neuron_x_mouse\": \"m1bayes5\", \"i_trial\": 3, \"stim\": 0, \"Log power\": 2.51898541385257, \"Firing rate\": 330.35844548272865, \"Power\": 330.35844548272865, \"i_spike\": 70.5, \"isi\": 0.04928079667884992, \"stim_strength\": 1, \"combined_condition\": 1.0}, {\"mouse\": 5, \"neuron_x_mouse\": \"m1bayes5\", \"i_trial\": 3, \"stim\": 1, \"Log power\": 2.3816194186453994, \"Firing rate\": 240.779450312201, \"Power\": 240.779450312201, \"i_spike\": 99.0, \"isi\": 0.03502357673651477, \"stim_strength\": 1, \"combined_condition\": 1.0}, {\"mouse\": 5, \"neuron_x_mouse\": \"m1bayes5\", \"i_trial\": 4, \"stim\": 0, \"Log power\": 2.126985228259878, \"Firing rate\": 133.96311215250182, \"Power\": 133.96311215250182, \"i_spike\": 69.0, \"isi\": 0.05007612857375813, \"stim_strength\": 1, \"combined_condition\": 1.0}, {\"mouse\": 5, \"neuron_x_mouse\": \"m1bayes5\", \"i_trial\": 4, \"stim\": 1, \"Log power\": 2.890575465975743, \"Firing rate\": 777.2763719112264, \"Power\": 777.2763719112264, \"i_spike\": 84.5, \"isi\": 0.04147110931263313, \"stim_strength\": 1, \"combined_condition\": 1.0}, {\"mouse\": 5, \"neuron_x_mouse\": \"m1bayes5\", \"i_trial\": 5, \"stim\": 0, \"Log power\": 2.0508031016407817, \"Firing rate\": 112.4095221495133, \"Power\": 112.4095221495133, \"i_spike\": 82.5, \"isi\": 0.0420099731541536, \"stim_strength\": 1, \"combined_condition\": 1.0}, {\"mouse\": 5, \"neuron_x_mouse\": \"m1bayes5\", \"i_trial\": 5, \"stim\": 1, \"Log power\": 2.4900333044460776, \"Firing rate\": 309.0532424988242, \"Power\": 309.0532424988242, \"i_spike\": 126.5, \"isi\": 0.02752583566365659, \"stim_strength\": 1, \"combined_condition\": 1.0}, {\"mouse\": 5, \"neuron_x_mouse\": \"m1bayes5\", \"i_trial\": 6, \"stim\": 0, \"Log power\": 1.9875114037513986, \"Firing rate\": 97.16534650237377, \"Power\": 97.16534650237377, \"i_spike\": 68.5, \"isi\": 0.05075234769166972, \"stim_strength\": 1, \"combined_condition\": 1.0}, {\"mouse\": 5, \"neuron_x_mouse\": \"m1bayes5\", \"i_trial\": 6, \"stim\": 1, \"Log power\": 2.6265137203135542, \"Firing rate\": 423.16887833683137, \"Power\": 423.16887833683137, \"i_spike\": 94.5, \"isi\": 0.03674772716470961, \"stim_strength\": 1, \"combined_condition\": 1.0}, {\"mouse\": 5, \"neuron_x_mouse\": \"m1bayes5\", \"i_trial\": 7, \"stim\": 0, \"Log power\": 2.1985712334234795, \"Firing rate\": 157.9687688475036, \"Power\": 157.9687688475036, \"i_spike\": 74.0, \"isi\": 0.046392337679683836, \"stim_strength\": 1, \"combined_condition\": 1.0}, {\"mouse\": 5, \"neuron_x_mouse\": \"m1bayes5\", \"i_trial\": 7, \"stim\": 1, \"Log power\": 2.4169384987679376, \"Firing rate\": 261.1791467666121, \"Power\": 261.1791467666121, \"i_spike\": 98.0, \"isi\": 0.03487618655658861, \"stim_strength\": 1, \"combined_condition\": 1.0}, {\"mouse\": 5, \"neuron_x_mouse\": \"m1bayes5\", \"i_trial\": 8, \"stim\": 0, \"Log power\": 2.1300604504666008, \"Firing rate\": 134.91506609645973, \"Power\": 134.91506609645973, \"i_spike\": 86.0, \"isi\": 0.04018068410973603, \"stim_strength\": 1, \"combined_condition\": 1.0}, {\"mouse\": 5, \"neuron_x_mouse\": \"m1bayes5\", \"i_trial\": 8, \"stim\": 1, \"Log power\": 2.28051192318486, \"Firing rate\": 190.77080977710287, \"Power\": 190.77080977710287, \"i_spike\": 87.5, \"isi\": 0.03961040347056356, \"stim_strength\": 1, \"combined_condition\": 1.0}, {\"mouse\": 5, \"neuron_x_mouse\": \"m1bayes5\", \"i_trial\": 9, \"stim\": 0, \"Log power\": 2.2112882471851494, \"Firing rate\": 162.66280128027907, \"Power\": 162.66280128027907, \"i_spike\": 74.0, \"isi\": 0.04739584583113276, \"stim_strength\": 1, \"combined_condition\": 1.0}, {\"mouse\": 5, \"neuron_x_mouse\": \"m1bayes5\", \"i_trial\": 9, \"stim\": 1, \"Log power\": 2.3025625324869567, \"Firing rate\": 200.70700599507174, \"Power\": 200.70700599507174, \"i_spike\": 107.0, \"isi\": 0.03268429804122226, \"stim_strength\": 1, \"combined_condition\": 1.0}, {\"mouse\": 6, \"neuron_x_mouse\": \"m1bayes6\", \"i_trial\": 0, \"stim\": 0, \"Log power\": 2.3714865829240748, \"Firing rate\": 235.22668214315712, \"Power\": 235.22668214315712, \"i_spike\": 87.5, \"isi\": 0.0396891891770976, \"stim_strength\": 1, \"combined_condition\": 1.0}, {\"mouse\": 6, \"neuron_x_mouse\": \"m1bayes6\", \"i_trial\": 0, \"stim\": 1, \"Log power\": 2.366690101842781, \"Firing rate\": 232.64306014216754, \"Power\": 232.64306014216754, \"i_spike\": 115.0, \"isi\": 0.030405520042590013, \"stim_strength\": 1, \"combined_condition\": 1.0}, {\"mouse\": 6, \"neuron_x_mouse\": \"m1bayes6\", \"i_trial\": 1, \"stim\": 0, \"Log power\": 2.6968852490251187, \"Firing rate\": 497.60558832610093, \"Power\": 497.60558832610093, \"i_spike\": 94.5, \"isi\": 0.036977107199545625, \"stim_strength\": 1, \"combined_condition\": 1.0}, {\"mouse\": 6, \"neuron_x_mouse\": \"m1bayes6\", \"i_trial\": 1, \"stim\": 1, \"Log power\": 2.401947355152673, \"Firing rate\": 252.31748965968467, \"Power\": 252.31748965968467, \"i_spike\": 129.5, \"isi\": 0.026824614125603642, \"stim_strength\": 1, \"combined_condition\": 1.0}, {\"mouse\": 6, \"neuron_x_mouse\": \"m1bayes6\", \"i_trial\": 2, \"stim\": 0, \"Log power\": 2.431020458762135, \"Firing rate\": 269.7866520657392, \"Power\": 269.7866520657392, \"i_spike\": 104.0, \"isi\": 0.033686742147128725, \"stim_strength\": 1, \"combined_condition\": 1.0}, {\"mouse\": 6, \"neuron_x_mouse\": \"m1bayes6\", \"i_trial\": 2, \"stim\": 1, \"Log power\": 2.0678191366617384, \"Firing rate\": 116.90124506260067, \"Power\": 116.90124506260067, \"i_spike\": 98.5, \"isi\": 0.034580128878044486, \"stim_strength\": 1, \"combined_condition\": 1.0}, {\"mouse\": 6, \"neuron_x_mouse\": \"m1bayes6\", \"i_trial\": 3, \"stim\": 0, \"Log power\": 1.8829936180866533, \"Firing rate\": 76.38245591708242, \"Power\": 76.38245591708242, \"i_spike\": 78.0, \"isi\": 0.044496403167798654, \"stim_strength\": 1, \"combined_condition\": 1.0}, {\"mouse\": 6, \"neuron_x_mouse\": \"m1bayes6\", \"i_trial\": 3, \"stim\": 1, \"Log power\": 2.2605750674616596, \"Firing rate\": 182.2111996507956, \"Power\": 182.2111996507956, \"i_spike\": 112.5, \"isi\": 0.0293768428564157, \"stim_strength\": 1, \"combined_condition\": 1.0}, {\"mouse\": 6, \"neuron_x_mouse\": \"m1bayes6\", \"i_trial\": 4, \"stim\": 0, \"Log power\": 2.068159727941217, \"Firing rate\": 116.9929597005928, \"Power\": 116.9929597005928, \"i_spike\": 92.5, \"isi\": 0.03756101434620676, \"stim_strength\": 1, \"combined_condition\": 1.0}, {\"mouse\": 6, \"neuron_x_mouse\": \"m1bayes6\", \"i_trial\": 4, \"stim\": 1, \"Log power\": 2.3681955773475294, \"Firing rate\": 233.4509133230671, \"Power\": 233.4509133230671, \"i_spike\": 120.5, \"isi\": 0.028736224123799874, \"stim_strength\": 1, \"combined_condition\": 1.0}, {\"mouse\": 6, \"neuron_x_mouse\": \"m1bayes6\", \"i_trial\": 5, \"stim\": 0, \"Log power\": 2.2556709014715897, \"Firing rate\": 180.16519723652513, \"Power\": 180.16519723652513, \"i_spike\": 94.5, \"isi\": 0.036735804263412955, \"stim_strength\": 1, \"combined_condition\": 1.0}, {\"mouse\": 6, \"neuron_x_mouse\": \"m1bayes6\", \"i_trial\": 5, \"stim\": 1, \"Log power\": 4.584664753117325, \"Firing rate\": 38429.501694654056, \"Power\": 38429.501694654056, \"i_spike\": 104.0, \"isi\": 0.032817987363718375, \"stim_strength\": 1, \"combined_condition\": 1.0}, {\"mouse\": 6, \"neuron_x_mouse\": \"m1bayes6\", \"i_trial\": 6, \"stim\": 0, \"Log power\": 2.218609437883244, \"Firing rate\": 165.42815947360134, \"Power\": 165.42815947360134, \"i_spike\": 93.5, \"isi\": 0.037214022428128594, \"stim_strength\": 1, \"combined_condition\": 1.0}, {\"mouse\": 6, \"neuron_x_mouse\": \"m1bayes6\", \"i_trial\": 6, \"stim\": 1, \"Log power\": 2.3364579417420104, \"Firing rate\": 216.99910455616916, \"Power\": 216.99910455616916, \"i_spike\": 114.5, \"isi\": 0.030231750903382017, \"stim_strength\": 1, \"combined_condition\": 1.0}, {\"mouse\": 6, \"neuron_x_mouse\": \"m1bayes6\", \"i_trial\": 7, \"stim\": 0, \"Log power\": 2.1814208683148837, \"Firing rate\": 151.8521230959297, \"Power\": 151.8521230959297, \"i_spike\": 101.0, \"isi\": 0.034628285946703675, \"stim_strength\": 1, \"combined_condition\": 1.0}, {\"mouse\": 6, \"neuron_x_mouse\": \"m1bayes6\", \"i_trial\": 7, \"stim\": 1, \"Log power\": 2.4478293506595143, \"Firing rate\": 280.43315024779395, \"Power\": 280.43315024779395, \"i_spike\": 102.5, \"isi\": 0.03390113723803605, \"stim_strength\": 1, \"combined_condition\": 1.0}, {\"mouse\": 6, \"neuron_x_mouse\": \"m1bayes6\", \"i_trial\": 8, \"stim\": 0, \"Log power\": 2.3113088395747345, \"Firing rate\": 204.7900441244514, \"Power\": 204.7900441244514, \"i_spike\": 100.0, \"isi\": 0.03446796413928074, \"stim_strength\": 1, \"combined_condition\": 1.0}, {\"mouse\": 6, \"neuron_x_mouse\": \"m1bayes6\", \"i_trial\": 8, \"stim\": 1, \"Log power\": 2.0958422999705175, \"Firing rate\": 124.6930649390644, \"Power\": 124.6930649390644, \"i_spike\": 112.0, \"isi\": 0.030800506086220526, \"stim_strength\": 1, \"combined_condition\": 1.0}, {\"mouse\": 6, \"neuron_x_mouse\": \"m1bayes6\", \"i_trial\": 9, \"stim\": 0, \"Log power\": 2.524117746452066, \"Firing rate\": 334.28565967874067, \"Power\": 334.28565967874067, \"i_spike\": 101.0, \"isi\": 0.034559032568746005, \"stim_strength\": 1, \"combined_condition\": 1.0}, {\"mouse\": 6, \"neuron_x_mouse\": \"m1bayes6\", \"i_trial\": 9, \"stim\": 1, \"Log power\": 2.261503991272252, \"Firing rate\": 182.60135305077057, \"Power\": 182.60135305077057, \"i_spike\": 104.5, \"isi\": 0.0332839503701086, \"stim_strength\": 1, \"combined_condition\": 1.0}, {\"mouse\": 7, \"neuron_x_mouse\": \"m1bayes7\", \"i_trial\": 0, \"stim\": 0, \"Log power\": 2.133321177025395, \"Firing rate\": 135.9318341756805, \"Power\": 135.9318341756805, \"i_spike\": 109.0, \"isi\": 0.03191544361619484, \"stim_strength\": 1, \"combined_condition\": 1.0}, {\"mouse\": 7, \"neuron_x_mouse\": \"m1bayes7\", \"i_trial\": 0, \"stim\": 1, \"Log power\": 2.419317473262253, \"Firing rate\": 262.6137572613826, \"Power\": 262.6137572613826, \"i_spike\": 116.0, \"isi\": 0.030243456863319085, \"stim_strength\": 1, \"combined_condition\": 1.0}, {\"mouse\": 7, \"neuron_x_mouse\": \"m1bayes7\", \"i_trial\": 1, \"stim\": 0, \"Log power\": 2.1211449647223044, \"Firing rate\": 132.17367478406865, \"Power\": 132.17367478406865, \"i_spike\": 90.5, \"isi\": 0.03826954171949034, \"stim_strength\": 1, \"combined_condition\": 1.0}, {\"mouse\": 7, \"neuron_x_mouse\": \"m1bayes7\", \"i_trial\": 1, \"stim\": 1, \"Log power\": 2.7690844222230018, \"Firing rate\": 587.6035653049483, \"Power\": 587.6035653049483, \"i_spike\": 114.0, \"isi\": 0.03068509420718441, \"stim_strength\": 1, \"combined_condition\": 1.0}, {\"mouse\": 7, \"neuron_x_mouse\": \"m1bayes7\", \"i_trial\": 2, \"stim\": 0, \"Log power\": 2.3749905333580856, \"Firing rate\": 237.1322015617334, \"Power\": 237.1322015617334, \"i_spike\": 121.5, \"isi\": 0.028711882952461368, \"stim_strength\": 1, \"combined_condition\": 1.0}, {\"mouse\": 7, \"neuron_x_mouse\": \"m1bayes7\", \"i_trial\": 2, \"stim\": 1, \"Log power\": 2.5130154119506214, \"Firing rate\": 325.8482642809919, \"Power\": 325.8482642809919, \"i_spike\": 119.5, \"isi\": 0.029158245032704647, \"stim_strength\": 1, \"combined_condition\": 1.0}, {\"mouse\": 7, \"neuron_x_mouse\": \"m1bayes7\", \"i_trial\": 3, \"stim\": 0, \"Log power\": 2.3339516671040994, \"Firing rate\": 215.750428583264, \"Power\": 215.750428583264, \"i_spike\": 106.5, \"isi\": 0.03238969456467746, \"stim_strength\": 1, \"combined_condition\": 1.0}, {\"mouse\": 7, \"neuron_x_mouse\": \"m1bayes7\", \"i_trial\": 3, \"stim\": 1, \"Log power\": 2.145575057844711, \"Firing rate\": 139.8218544462471, \"Power\": 139.8218544462471, \"i_spike\": 100.5, \"isi\": 0.03448634022339306, \"stim_strength\": 1, \"combined_condition\": 1.0}, {\"mouse\": 7, \"neuron_x_mouse\": \"m1bayes7\", \"i_trial\": 4, \"stim\": 0, \"Log power\": 2.7952071109799186, \"Firing rate\": 624.0323597342657, \"Power\": 624.0323597342657, \"i_spike\": 99.0, \"isi\": 0.03543445608998932, \"stim_strength\": 1, \"combined_condition\": 1.0}, {\"mouse\": 7, \"neuron_x_mouse\": \"m1bayes7\", \"i_trial\": 4, \"stim\": 1, \"Log power\": 2.4862125713113565, \"Firing rate\": 306.34625199740805, \"Power\": 306.34625199740805, \"i_spike\": 134.0, \"isi\": 0.02578989865302196, \"stim_strength\": 1, \"combined_condition\": 1.0}, {\"mouse\": 7, \"neuron_x_mouse\": \"m1bayes7\", \"i_trial\": 5, \"stim\": 0, \"Log power\": 2.172657623981426, \"Firing rate\": 148.81874027236697, \"Power\": 148.81874027236697, \"i_spike\": 107.0, \"isi\": 0.03282855879929693, \"stim_strength\": 1, \"combined_condition\": 1.0}, {\"mouse\": 7, \"neuron_x_mouse\": \"m1bayes7\", \"i_trial\": 5, \"stim\": 1, \"Log power\": 2.347070624983367, \"Firing rate\": 222.36714747807852, \"Power\": 222.36714747807852, \"i_spike\": 123.0, \"isi\": 0.028368891419844427, \"stim_strength\": 1, \"combined_condition\": 1.0}, {\"mouse\": 7, \"neuron_x_mouse\": \"m1bayes7\", \"i_trial\": 6, \"stim\": 0, \"Log power\": 2.3660153596819202, \"Firing rate\": 232.28189459831626, \"Power\": 232.28189459831626, \"i_spike\": 118.0, \"isi\": 0.029728637031476927, \"stim_strength\": 1, \"combined_condition\": 1.0}, {\"mouse\": 7, \"neuron_x_mouse\": \"m1bayes7\", \"i_trial\": 6, \"stim\": 1, \"Log power\": 2.43447594808572, \"Firing rate\": 271.94178762717775, \"Power\": 271.94178762717775, \"i_spike\": 124.5, \"isi\": 0.028132379790843737, \"stim_strength\": 1, \"combined_condition\": 1.0}, {\"mouse\": 7, \"neuron_x_mouse\": \"m1bayes7\", \"i_trial\": 7, \"stim\": 0, \"Log power\": 2.5904230994647155, \"Firing rate\": 389.4243462191472, \"Power\": 389.4243462191472, \"i_spike\": 104.0, \"isi\": 0.0332319827647596, \"stim_strength\": 1, \"combined_condition\": 1.0}, {\"mouse\": 7, \"neuron_x_mouse\": \"m1bayes7\", \"i_trial\": 7, \"stim\": 1, \"Log power\": 2.3824605912285617, \"Firing rate\": 241.24626108571275, \"Power\": 241.24626108571275, \"i_spike\": 133.0, \"isi\": 0.02625682576231553, \"stim_strength\": 1, \"combined_condition\": 1.0}, {\"mouse\": 7, \"neuron_x_mouse\": \"m1bayes7\", \"i_trial\": 8, \"stim\": 0, \"Log power\": 2.280374153639161, \"Firing rate\": 190.71030189454973, \"Power\": 190.71030189454973, \"i_spike\": 114.5, \"isi\": 0.030446011170726536, \"stim_strength\": 1, \"combined_condition\": 1.0}, {\"mouse\": 7, \"neuron_x_mouse\": \"m1bayes7\", \"i_trial\": 8, \"stim\": 1, \"Log power\": 2.624771574199338, \"Firing rate\": 421.4747621044228, \"Power\": 421.4747621044228, \"i_spike\": 126.5, \"isi\": 0.027596074343590633, \"stim_strength\": 1, \"combined_condition\": 1.0}, {\"mouse\": 7, \"neuron_x_mouse\": \"m1bayes7\", \"i_trial\": 9, \"stim\": 0, \"Log power\": 2.1349861554291425, \"Firing rate\": 136.45396366882753, \"Power\": 136.45396366882753, \"i_spike\": 111.0, \"isi\": 0.031554792145922834, \"stim_strength\": 1, \"combined_condition\": 1.0}, {\"mouse\": 7, \"neuron_x_mouse\": \"m1bayes7\", \"i_trial\": 9, \"stim\": 1, \"Log power\": 2.9020592598142563, \"Firing rate\": 798.1035816826546, \"Power\": 798.1035816826546, \"i_spike\": 117.0, \"isi\": 0.029645706172566053, \"stim_strength\": 1, \"combined_condition\": 1.0}, {\"mouse\": 0, \"neuron_x_mouse\": \"m1bayes0\", \"i_trial\": 0, \"stim\": 0, \"Log power\": 1.9031108915303598, \"Firing rate\": 80.00385085096066, \"Power\": 80.00385085096066, \"i_spike\": 43.0, \"isi\": 0.07967752475425702, \"stim_strength\": 2, \"combined_condition\": 1.0}, {\"mouse\": 0, \"neuron_x_mouse\": \"m1bayes0\", \"i_trial\": 0, \"stim\": 1, \"Log power\": 2.3411794665299035, \"Firing rate\": 219.37112706407126, \"Power\": 219.37112706407126, \"i_spike\": 77.0, \"isi\": 0.04508959328510743, \"stim_strength\": 2, \"combined_condition\": 1.0}, {\"mouse\": 0, \"neuron_x_mouse\": \"m1bayes0\", \"i_trial\": 1, \"stim\": 0, \"Log power\": 1.923290347123119, \"Firing rate\": 83.80893986671143, \"Power\": 83.80893986671143, \"i_spike\": 43.0, \"isi\": 0.08108380937194858, \"stim_strength\": 2, \"combined_condition\": 1.0}, {\"mouse\": 0, \"neuron_x_mouse\": \"m1bayes0\", \"i_trial\": 1, \"stim\": 1, \"Log power\": 2.1819765807530103, \"Firing rate\": 152.04655367080952, \"Power\": 152.04655367080952, \"i_spike\": 83.0, \"isi\": 0.04168314899839224, \"stim_strength\": 2, \"combined_condition\": 1.0}, {\"mouse\": 0, \"neuron_x_mouse\": \"m1bayes0\", \"i_trial\": 2, \"stim\": 0, \"Log power\": 1.5199472074181661, \"Firing rate\": 33.10908718245945, \"Power\": 33.10908718245945, \"i_spike\": 42.0, \"isi\": 0.08187716056993995, \"stim_strength\": 2, \"combined_condition\": 1.0}, {\"mouse\": 0, \"neuron_x_mouse\": \"m1bayes0\", \"i_trial\": 2, \"stim\": 1, \"Log power\": 2.0127904787127635, \"Firing rate\": 102.9889140242372, \"Power\": 102.9889140242372, \"i_spike\": 86.0, \"isi\": 0.04049375600335422, \"stim_strength\": 2, \"combined_condition\": 1.0}, {\"mouse\": 0, \"neuron_x_mouse\": \"m1bayes0\", \"i_trial\": 3, \"stim\": 0, \"Log power\": 1.9292239354059568, \"Firing rate\": 84.96184511499816, \"Power\": 84.96184511499816, \"i_spike\": 49.5, \"isi\": 0.07043115034087123, \"stim_strength\": 2, \"combined_condition\": 1.0}, {\"mouse\": 0, \"neuron_x_mouse\": \"m1bayes0\", \"i_trial\": 3, \"stim\": 1, \"Log power\": 3.507489228053904, \"Firing rate\": 3217.2827324047657, \"Power\": 3217.2827324047657, \"i_spike\": 88.0, \"isi\": 0.039296543654600585, \"stim_strength\": 2, \"combined_condition\": 1.0}, {\"mouse\": 0, \"neuron_x_mouse\": \"m1bayes0\", \"i_trial\": 4, \"stim\": 0, \"Log power\": 1.9229454673836957, \"Firing rate\": 83.7424123536239, \"Power\": 83.7424123536239, \"i_spike\": 39.0, \"isi\": 0.08935298189284988, \"stim_strength\": 2, \"combined_condition\": 1.0}, {\"mouse\": 0, \"neuron_x_mouse\": \"m1bayes0\", \"i_trial\": 4, \"stim\": 1, \"Log power\": 2.0621882868861863, \"Firing rate\": 115.39534419518658, \"Power\": 115.39534419518658, \"i_spike\": 78.5, \"isi\": 0.0445712211674458, \"stim_strength\": 2, \"combined_condition\": 1.0}, {\"mouse\": 0, \"neuron_x_mouse\": \"m1bayes0\", \"i_trial\": 5, \"stim\": 0, \"Log power\": 4.115817811163288, \"Firing rate\": 13056.23057439158, \"Power\": 13056.23057439158, \"i_spike\": 38.0, \"isi\": 0.08886320327497499, \"stim_strength\": 2, \"combined_condition\": 1.0}, {\"mouse\": 0, \"neuron_x_mouse\": \"m1bayes0\", \"i_trial\": 5, \"stim\": 1, \"Log power\": 2.5267990838231262, \"Firing rate\": 336.3559261794946, \"Power\": 336.3559261794946, \"i_spike\": 75.5, \"isi\": 0.04457124955366038, \"stim_strength\": 2, \"combined_condition\": 1.0}, {\"mouse\": 0, \"neuron_x_mouse\": \"m1bayes0\", \"i_trial\": 6, \"stim\": 0, \"Log power\": 1.5430247279536646, \"Firing rate\": 34.91601954717634, \"Power\": 34.91601954717634, \"i_spike\": 37.0, \"isi\": 0.09441351083121195, \"stim_strength\": 2, \"combined_condition\": 1.0}, {\"mouse\": 0, \"neuron_x_mouse\": \"m1bayes0\", \"i_trial\": 6, \"stim\": 1, \"Log power\": 2.9160416720250164, \"Firing rate\": 824.2171976477447, \"Power\": 824.2171976477447, \"i_spike\": 86.5, \"isi\": 0.0402441484456935, \"stim_strength\": 2, \"combined_condition\": 1.0}, {\"mouse\": 0, \"neuron_x_mouse\": \"m1bayes0\", \"i_trial\": 7, \"stim\": 0, \"Log power\": 1.564525463224499, \"Firing rate\": 36.68812045111309, \"Power\": 36.68812045111309, \"i_spike\": 35.5, \"isi\": 0.09541531838641083, \"stim_strength\": 2, \"combined_condition\": 1.0}, {\"mouse\": 0, \"neuron_x_mouse\": \"m1bayes0\", \"i_trial\": 7, \"stim\": 1, \"Log power\": 2.624669688389798, \"Firing rate\": 421.37589540825854, \"Power\": 421.37589540825854, \"i_spike\": 79.0, \"isi\": 0.043282754426904636, \"stim_strength\": 2, \"combined_condition\": 1.0}, {\"mouse\": 0, \"neuron_x_mouse\": \"m1bayes0\", \"i_trial\": 8, \"stim\": 0, \"Log power\": 1.4599702774494907, \"Firing rate\": 28.83834130508832, \"Power\": 28.83834130508832, \"i_spike\": 31.5, \"isi\": 0.10819083163912775, \"stim_strength\": 2, \"combined_condition\": 1.0}, {\"mouse\": 0, \"neuron_x_mouse\": \"m1bayes0\", \"i_trial\": 8, \"stim\": 1, \"Log power\": 2.3023689638719147, \"Firing rate\": 200.61756916804796, \"Power\": 200.61756916804796, \"i_spike\": 101.0, \"isi\": 0.03305025507971565, \"stim_strength\": 2, \"combined_condition\": 1.0}, {\"mouse\": 0, \"neuron_x_mouse\": \"m1bayes0\", \"i_trial\": 9, \"stim\": 0, \"Log power\": 1.9621350525852077, \"Firing rate\": 91.65054515763978, \"Power\": 91.65054515763978, \"i_spike\": 36.0, \"isi\": 0.09703584189311386, \"stim_strength\": 2, \"combined_condition\": 1.0}, {\"mouse\": 0, \"neuron_x_mouse\": \"m1bayes0\", \"i_trial\": 9, \"stim\": 1, \"Log power\": 2.0610302620641505, \"Firing rate\": 115.08805806346722, \"Power\": 115.08805806346722, \"i_spike\": 82.0, \"isi\": 0.04156664025057236, \"stim_strength\": 2, \"combined_condition\": 1.0}, {\"mouse\": 1, \"neuron_x_mouse\": \"m1bayes1\", \"i_trial\": 0, \"stim\": 0, \"Log power\": 1.764819789721827, \"Firing rate\": 58.18617244388706, \"Power\": 58.18617244388706, \"i_spike\": 56.0, \"isi\": 0.0610050162450065, \"stim_strength\": 2, \"combined_condition\": 1.0}, {\"mouse\": 1, \"neuron_x_mouse\": \"m1bayes1\", \"i_trial\": 0, \"stim\": 1, \"Log power\": 2.539085460155039, \"Firing rate\": 346.0074582256712, \"Power\": 346.0074582256712, \"i_spike\": 90.5, \"isi\": 0.03836727267148073, \"stim_strength\": 2, \"combined_condition\": 1.0}, {\"mouse\": 1, \"neuron_x_mouse\": \"m1bayes1\", \"i_trial\": 1, \"stim\": 0, \"Log power\": 2.3438822389701386, \"Firing rate\": 220.74061031193688, \"Power\": 220.74061031193688, \"i_spike\": 40.5, \"isi\": 0.08646672607577048, \"stim_strength\": 2, \"combined_condition\": 1.0}, {\"mouse\": 1, \"neuron_x_mouse\": \"m1bayes1\", \"i_trial\": 1, \"stim\": 1, \"Log power\": 2.1377934432163475, \"Firing rate\": 137.33886160140048, \"Power\": 137.33886160140048, \"i_spike\": 85.5, \"isi\": 0.03898573747587349, \"stim_strength\": 2, \"combined_condition\": 1.0}, {\"mouse\": 1, \"neuron_x_mouse\": \"m1bayes1\", \"i_trial\": 2, \"stim\": 0, \"Log power\": 1.6695922999158168, \"Firing rate\": 46.72962543491792, \"Power\": 46.72962543491792, \"i_spike\": 47.0, \"isi\": 0.07482494636053347, \"stim_strength\": 2, \"combined_condition\": 1.0}, {\"mouse\": 1, \"neuron_x_mouse\": \"m1bayes1\", \"i_trial\": 2, \"stim\": 1, \"Log power\": 2.3065061359516794, \"Firing rate\": 202.5378222282081, \"Power\": 202.5378222282081, \"i_spike\": 80.5, \"isi\": 0.043510864090225, \"stim_strength\": 2, \"combined_condition\": 1.0}, {\"mouse\": 1, \"neuron_x_mouse\": \"m1bayes1\", \"i_trial\": 3, \"stim\": 0, \"Log power\": 1.5495725947614292, \"Firing rate\": 35.446437604017305, \"Power\": 35.446437604017305, \"i_spike\": 37.0, \"isi\": 0.09393678737162706, \"stim_strength\": 2, \"combined_condition\": 1.0}, {\"mouse\": 1, \"neuron_x_mouse\": \"m1bayes1\", \"i_trial\": 3, \"stim\": 1, \"Log power\": 2.411054946017089, \"Firing rate\": 257.66471283133984, \"Power\": 257.66471283133984, \"i_spike\": 101.0, \"isi\": 0.03399047339804805, \"stim_strength\": 2, \"combined_condition\": 1.0}, {\"mouse\": 1, \"neuron_x_mouse\": \"m1bayes1\", \"i_trial\": 4, \"stim\": 0, \"Log power\": 1.842991782206745, \"Firing rate\": 69.66133325513718, \"Power\": 69.66133325513718, \"i_spike\": 52.5, \"isi\": 0.06426178798174789, \"stim_strength\": 2, \"combined_condition\": 1.0}, {\"mouse\": 1, \"neuron_x_mouse\": \"m1bayes1\", \"i_trial\": 4, \"stim\": 1, \"Log power\": 2.419394801436396, \"Firing rate\": 262.6605210385583, \"Power\": 262.6605210385583, \"i_spike\": 97.0, \"isi\": 0.03580139228551206, \"stim_strength\": 2, \"combined_condition\": 1.0}, {\"mouse\": 1, \"neuron_x_mouse\": \"m1bayes1\", \"i_trial\": 5, \"stim\": 0, \"Log power\": 1.6839281999407636, \"Firing rate\": 48.297894658418954, \"Power\": 48.297894658418954, \"i_spike\": 47.5, \"isi\": 0.07262913621471045, \"stim_strength\": 2, \"combined_condition\": 1.0}, {\"mouse\": 1, \"neuron_x_mouse\": \"m1bayes1\", \"i_trial\": 5, \"stim\": 1, \"Log power\": 2.656915435711839, \"Firing rate\": 453.85323534626644, \"Power\": 453.85323534626644, \"i_spike\": 85.0, \"isi\": 0.04117990693347628, \"stim_strength\": 2, \"combined_condition\": 1.0}, {\"mouse\": 1, \"neuron_x_mouse\": \"m1bayes1\", \"i_trial\": 6, \"stim\": 0, \"Log power\": 1.9595595875322547, \"Firing rate\": 91.10864496380664, \"Power\": 91.10864496380664, \"i_spike\": 51.5, \"isi\": 0.06757153508556478, \"stim_strength\": 2, \"combined_condition\": 1.0}, {\"mouse\": 1, \"neuron_x_mouse\": \"m1bayes1\", \"i_trial\": 6, \"stim\": 1, \"Log power\": 2.048980189345912, \"Firing rate\": 111.93868206703466, \"Power\": 111.93868206703466, \"i_spike\": 83.5, \"isi\": 0.04102841339346923, \"stim_strength\": 2, \"combined_condition\": 1.0}, {\"mouse\": 1, \"neuron_x_mouse\": \"m1bayes1\", \"i_trial\": 7, \"stim\": 0, \"Log power\": 2.4090837494582344, \"Firing rate\": 256.497861995718, \"Power\": 256.497861995718, \"i_spike\": 47.5, \"isi\": 0.06912962351236623, \"stim_strength\": 2, \"combined_condition\": 1.0}, {\"mouse\": 1, \"neuron_x_mouse\": \"m1bayes1\", \"i_trial\": 7, \"stim\": 1, \"Log power\": 2.4516623957597847, \"Firing rate\": 282.9191833137684, \"Power\": 282.9191833137684, \"i_spike\": 89.0, \"isi\": 0.039420491070159845, \"stim_strength\": 2, \"combined_condition\": 1.0}, {\"mouse\": 1, \"neuron_x_mouse\": \"m1bayes1\", \"i_trial\": 8, \"stim\": 0, \"Log power\": 2.997650591486115, \"Firing rate\": 994.6048931258268, \"Power\": 994.6048931258268, \"i_spike\": 42.5, \"isi\": 0.08101343749595986, \"stim_strength\": 2, \"combined_condition\": 1.0}, {\"mouse\": 1, \"neuron_x_mouse\": \"m1bayes1\", \"i_trial\": 8, \"stim\": 1, \"Log power\": 2.1849791800154894, \"Firing rate\": 153.1014063436186, \"Power\": 153.1014063436186, \"i_spike\": 95.0, \"isi\": 0.03660144525468065, \"stim_strength\": 2, \"combined_condition\": 1.0}, {\"mouse\": 1, \"neuron_x_mouse\": \"m1bayes1\", \"i_trial\": 9, \"stim\": 0, \"Log power\": 1.855876315849105, \"Firing rate\": 71.75898973856631, \"Power\": 71.75898973856631, \"i_spike\": 44.0, \"isi\": 0.07772464245910278, \"stim_strength\": 2, \"combined_condition\": 1.0}, {\"mouse\": 1, \"neuron_x_mouse\": \"m1bayes1\", \"i_trial\": 9, \"stim\": 1, \"Log power\": 3.2044512918568513, \"Firing rate\": 1601.2210538955705, \"Power\": 1601.2210538955705, \"i_spike\": 83.0, \"isi\": 0.041581683169655194, \"stim_strength\": 2, \"combined_condition\": 1.0}, {\"mouse\": 2, \"neuron_x_mouse\": \"m1bayes2\", \"i_trial\": 0, \"stim\": 0, \"Log power\": 2.007416222900846, \"Firing rate\": 101.72231209461445, \"Power\": 101.72231209461445, \"i_spike\": 48.0, \"isi\": 0.07279216319447737, \"stim_strength\": 2, \"combined_condition\": 1.0}, {\"mouse\": 2, \"neuron_x_mouse\": \"m1bayes2\", \"i_trial\": 0, \"stim\": 1, \"Log power\": 2.651505056829884, \"Firing rate\": 448.2342691079536, \"Power\": 448.2342691079536, \"i_spike\": 106.5, \"isi\": 0.03265759342331206, \"stim_strength\": 2, \"combined_condition\": 1.0}, {\"mouse\": 2, \"neuron_x_mouse\": \"m1bayes2\", \"i_trial\": 1, \"stim\": 0, \"Log power\": 1.868918922208024, \"Firing rate\": 73.94672121353966, \"Power\": 73.94672121353966, \"i_spike\": 54.5, \"isi\": 0.06418561759113935, \"stim_strength\": 2, \"combined_condition\": 1.0}, {\"mouse\": 2, \"neuron_x_mouse\": \"m1bayes2\", \"i_trial\": 1, \"stim\": 1, \"Log power\": 2.132785072075929, \"Firing rate\": 135.7641397379857, \"Power\": 135.7641397379857, \"i_spike\": 100.0, \"isi\": 0.0338076173534773, \"stim_strength\": 2, \"combined_condition\": 1.0}, {\"mouse\": 2, \"neuron_x_mouse\": \"m1bayes2\", \"i_trial\": 2, \"stim\": 0, \"Log power\": 1.9543930756723737, \"Firing rate\": 90.03120765013684, \"Power\": 90.03120765013684, \"i_spike\": 40.0, \"isi\": 0.08776891124494675, \"stim_strength\": 2, \"combined_condition\": 1.0}, {\"mouse\": 2, \"neuron_x_mouse\": \"m1bayes2\", \"i_trial\": 2, \"stim\": 1, \"Log power\": 2.2927475878580177, \"Firing rate\": 196.2219502529633, \"Power\": 196.2219502529633, \"i_spike\": 80.5, \"isi\": 0.0431533165396246, \"stim_strength\": 2, \"combined_condition\": 1.0}, {\"mouse\": 2, \"neuron_x_mouse\": \"m1bayes2\", \"i_trial\": 3, \"stim\": 0, \"Log power\": 1.860356689773824, \"Firing rate\": 72.50311899275246, \"Power\": 72.50311899275246, \"i_spike\": 48.0, \"isi\": 0.07089262402416663, \"stim_strength\": 2, \"combined_condition\": 1.0}, {\"mouse\": 2, \"neuron_x_mouse\": \"m1bayes2\", \"i_trial\": 3, \"stim\": 1, \"Log power\": 2.0679618405926745, \"Firing rate\": 116.93966371398604, \"Power\": 116.93966371398604, \"i_spike\": 90.5, \"isi\": 0.03863287002049611, \"stim_strength\": 2, \"combined_condition\": 1.0}, {\"mouse\": 2, \"neuron_x_mouse\": \"m1bayes2\", \"i_trial\": 4, \"stim\": 0, \"Log power\": 1.979978152339546, \"Firing rate\": 95.49445452798744, \"Power\": 95.49445452798744, \"i_spike\": 51.0, \"isi\": 0.0684292347794948, \"stim_strength\": 2, \"combined_condition\": 1.0}, {\"mouse\": 2, \"neuron_x_mouse\": \"m1bayes2\", \"i_trial\": 4, \"stim\": 1, \"Log power\": 2.0474599663209148, \"Firing rate\": 111.5475321033651, \"Power\": 111.5475321033651, \"i_spike\": 97.5, \"isi\": 0.035773376807609586, \"stim_strength\": 2, \"combined_condition\": 1.0}, {\"mouse\": 2, \"neuron_x_mouse\": \"m1bayes2\", \"i_trial\": 5, \"stim\": 0, \"Log power\": 2.1016231537267918, \"Firing rate\": 126.36393856719273, \"Power\": 126.36393856719273, \"i_spike\": 56.0, \"isi\": 0.06261965849597441, \"stim_strength\": 2, \"combined_condition\": 1.0}, {\"mouse\": 2, \"neuron_x_mouse\": \"m1bayes2\", \"i_trial\": 5, \"stim\": 1, \"Log power\": 2.2011920552633346, \"Firing rate\": 158.9249396790438, \"Power\": 158.9249396790438, \"i_spike\": 80.0, \"isi\": 0.041907978883942675, \"stim_strength\": 2, \"combined_condition\": 1.0}, {\"mouse\": 2, \"neuron_x_mouse\": \"m1bayes2\", \"i_trial\": 6, \"stim\": 0, \"Log power\": 2.1424126175699945, \"Firing rate\": 138.80739937348335, \"Power\": 138.80739937348335, \"i_spike\": 55.0, \"isi\": 0.061472807329319874, \"stim_strength\": 2, \"combined_condition\": 1.0}, {\"mouse\": 2, \"neuron_x_mouse\": \"m1bayes2\", \"i_trial\": 6, \"stim\": 1, \"Log power\": 3.2763723823277355, \"Firing rate\": 1889.6108863989145, \"Power\": 1889.6108863989145, \"i_spike\": 94.0, \"isi\": 0.03734183142290452, \"stim_strength\": 2, \"combined_condition\": 1.0}, {\"mouse\": 2, \"neuron_x_mouse\": \"m1bayes2\", \"i_trial\": 7, \"stim\": 0, \"Log power\": 2.1856074144941915, \"Firing rate\": 153.32303748928464, \"Power\": 153.32303748928464, \"i_spike\": 50.5, \"isi\": 0.0697791645430835, \"stim_strength\": 2, \"combined_condition\": 1.0}, {\"mouse\": 2, \"neuron_x_mouse\": \"m1bayes2\", \"i_trial\": 7, \"stim\": 1, \"Log power\": 2.5388474056852592, \"Firing rate\": 345.817849435391, \"Power\": 345.817849435391, \"i_spike\": 91.5, \"isi\": 0.03812731274434116, \"stim_strength\": 2, \"combined_condition\": 1.0}, {\"mouse\": 2, \"neuron_x_mouse\": \"m1bayes2\", \"i_trial\": 8, \"stim\": 0, \"Log power\": 1.9003880128167272, \"Firing rate\": 79.50382305262814, \"Power\": 79.50382305262814, \"i_spike\": 57.5, \"isi\": 0.06120397893216919, \"stim_strength\": 2, \"combined_condition\": 1.0}, {\"mouse\": 2, \"neuron_x_mouse\": \"m1bayes2\", \"i_trial\": 8, \"stim\": 1, \"Log power\": 2.3161000954323767, \"Firing rate\": 207.06185263347606, \"Power\": 207.06185263347606, \"i_spike\": 91.0, \"isi\": 0.036949637701766694, \"stim_strength\": 2, \"combined_condition\": 1.0}, {\"mouse\": 2, \"neuron_x_mouse\": \"m1bayes2\", \"i_trial\": 9, \"stim\": 0, \"Log power\": 1.9132868821979536, \"Firing rate\": 81.90056205796348, \"Power\": 81.90056205796348, \"i_spike\": 52.0, \"isi\": 0.06669759791489047, \"stim_strength\": 2, \"combined_condition\": 1.0}, {\"mouse\": 2, \"neuron_x_mouse\": \"m1bayes2\", \"i_trial\": 9, \"stim\": 1, \"Log power\": 2.177991070647107, \"Firing rate\": 150.65760897676674, \"Power\": 150.65760897676674, \"i_spike\": 91.0, \"isi\": 0.037854558501559984, \"stim_strength\": 2, \"combined_condition\": 1.0}, {\"mouse\": 3, \"neuron_x_mouse\": \"m1bayes3\", \"i_trial\": 0, \"stim\": 0, \"Log power\": 2.1715472610207467, \"Firing rate\": 148.43874060564892, \"Power\": 148.43874060564892, \"i_spike\": 59.0, \"isi\": 0.059048734202419705, \"stim_strength\": 2, \"combined_condition\": 1.0}, {\"mouse\": 3, \"neuron_x_mouse\": \"m1bayes3\", \"i_trial\": 0, \"stim\": 1, \"Log power\": 2.3017216891178, \"Firing rate\": 200.31879040578056, \"Power\": 200.31879040578056, \"i_spike\": 103.5, \"isi\": 0.03375155576273928, \"stim_strength\": 2, \"combined_condition\": 1.0}, {\"mouse\": 3, \"neuron_x_mouse\": \"m1bayes3\", \"i_trial\": 1, \"stim\": 0, \"Log power\": 2.1716447589864947, \"Firing rate\": 148.47206845227996, \"Power\": 148.47206845227996, \"i_spike\": 63.5, \"isi\": 0.055351172975889484, \"stim_strength\": 2, \"combined_condition\": 1.0}, {\"mouse\": 3, \"neuron_x_mouse\": \"m1bayes3\", \"i_trial\": 1, \"stim\": 1, \"Log power\": 2.347232022957301, \"Firing rate\": 222.44980170986653, \"Power\": 222.44980170986653, \"i_spike\": 95.0, \"isi\": 0.03701522495159678, \"stim_strength\": 2, \"combined_condition\": 1.0}, {\"mouse\": 3, \"neuron_x_mouse\": \"m1bayes3\", \"i_trial\": 2, \"stim\": 0, \"Log power\": 1.9702549376684215, \"Firing rate\": 93.38022965255915, \"Power\": 93.38022965255915, \"i_spike\": 66.5, \"isi\": 0.05260775985827791, \"stim_strength\": 2, \"combined_condition\": 1.0}, {\"mouse\": 3, \"neuron_x_mouse\": \"m1bayes3\", \"i_trial\": 2, \"stim\": 1, \"Log power\": 2.368081447491137, \"Firing rate\": 233.38957195280105, \"Power\": 233.38957195280105, \"i_spike\": 102.5, \"isi\": 0.03399477011986479, \"stim_strength\": 2, \"combined_condition\": 1.0}, {\"mouse\": 3, \"neuron_x_mouse\": \"m1bayes3\", \"i_trial\": 3, \"stim\": 0, \"Log power\": 1.7969105884959249, \"Firing rate\": 62.64848721947691, \"Power\": 62.64848721947691, \"i_spike\": 60.0, \"isi\": 0.05632461876741066, \"stim_strength\": 2, \"combined_condition\": 1.0}, {\"mouse\": 3, \"neuron_x_mouse\": \"m1bayes3\", \"i_trial\": 3, \"stim\": 1, \"Log power\": 2.3201792072672487, \"Firing rate\": 209.01584358706887, \"Power\": 209.01584358706887, \"i_spike\": 97.0, \"isi\": 0.035280028933717233, \"stim_strength\": 2, \"combined_condition\": 1.0}, {\"mouse\": 3, \"neuron_x_mouse\": \"m1bayes3\", \"i_trial\": 4, \"stim\": 0, \"Log power\": 1.957074270334467, \"Firing rate\": 90.58875068855197, \"Power\": 90.58875068855197, \"i_spike\": 59.0, \"isi\": 0.05817671751680787, \"stim_strength\": 2, \"combined_condition\": 1.0}, {\"mouse\": 3, \"neuron_x_mouse\": \"m1bayes3\", \"i_trial\": 4, \"stim\": 1, \"Log power\": 2.3248708966009954, \"Firing rate\": 211.2860853024131, \"Power\": 211.2860853024131, \"i_spike\": 96.5, \"isi\": 0.035844260435144625, \"stim_strength\": 2, \"combined_condition\": 1.0}, {\"mouse\": 3, \"neuron_x_mouse\": \"m1bayes3\", \"i_trial\": 5, \"stim\": 0, \"Log power\": 1.9456876637901153, \"Firing rate\": 88.24450347157841, \"Power\": 88.24450347157841, \"i_spike\": 48.0, \"isi\": 0.07165285524177976, \"stim_strength\": 2, \"combined_condition\": 1.0}, {\"mouse\": 3, \"neuron_x_mouse\": \"m1bayes3\", \"i_trial\": 5, \"stim\": 1, \"Log power\": 2.4069825684577615, \"Firing rate\": 255.25988453899237, \"Power\": 255.25988453899237, \"i_spike\": 96.0, \"isi\": 0.03616559726624802, \"stim_strength\": 2, \"combined_condition\": 1.0}, {\"mouse\": 3, \"neuron_x_mouse\": \"m1bayes3\", \"i_trial\": 6, \"stim\": 0, \"Log power\": 2.173262947691997, \"Firing rate\": 149.02630984697137, \"Power\": 149.02630984697137, \"i_spike\": 55.0, \"isi\": 0.06351966603499487, \"stim_strength\": 2, \"combined_condition\": 1.0}, {\"mouse\": 3, \"neuron_x_mouse\": \"m1bayes3\", \"i_trial\": 6, \"stim\": 1, \"Log power\": 2.267173931310095, \"Firing rate\": 185.00093839286927, \"Power\": 185.00093839286927, \"i_spike\": 104.0, \"isi\": 0.03318270473467403, \"stim_strength\": 2, \"combined_condition\": 1.0}, {\"mouse\": 3, \"neuron_x_mouse\": \"m1bayes3\", \"i_trial\": 7, \"stim\": 0, \"Log power\": 1.7929831673026129, \"Firing rate\": 62.08449706085405, \"Power\": 62.08449706085405, \"i_spike\": 50.0, \"isi\": 0.06969302645985749, \"stim_strength\": 2, \"combined_condition\": 1.0}, {\"mouse\": 3, \"neuron_x_mouse\": \"m1bayes3\", \"i_trial\": 7, \"stim\": 1, \"Log power\": 2.247865595360321, \"Firing rate\": 176.95612330840595, \"Power\": 176.95612330840595, \"i_spike\": 94.5, \"isi\": 0.036552335566298604, \"stim_strength\": 2, \"combined_condition\": 1.0}, {\"mouse\": 3, \"neuron_x_mouse\": \"m1bayes3\", \"i_trial\": 8, \"stim\": 0, \"Log power\": 2.078892989967017, \"Firing rate\": 119.92037832823408, \"Power\": 119.92037832823408, \"i_spike\": 68.0, \"isi\": 0.051455428653007916, \"stim_strength\": 2, \"combined_condition\": 1.0}, {\"mouse\": 3, \"neuron_x_mouse\": \"m1bayes3\", \"i_trial\": 8, \"stim\": 1, \"Log power\": 2.3057022982487747, \"Firing rate\": 202.16329073668098, \"Power\": 202.16329073668098, \"i_spike\": 96.0, \"isi\": 0.036128370147185514, \"stim_strength\": 2, \"combined_condition\": 1.0}, {\"mouse\": 3, \"neuron_x_mouse\": \"m1bayes3\", \"i_trial\": 9, \"stim\": 0, \"Log power\": 2.011096674285602, \"Firing rate\": 102.58802625718035, \"Power\": 102.58802625718035, \"i_spike\": 63.5, \"isi\": 0.05457495660451529, \"stim_strength\": 2, \"combined_condition\": 1.0}, {\"mouse\": 3, \"neuron_x_mouse\": \"m1bayes3\", \"i_trial\": 9, \"stim\": 1, \"Log power\": 3.739180862465525, \"Firing rate\": 5485.05343081022, \"Power\": 5485.05343081022, \"i_spike\": 90.5, \"isi\": 0.03800660807111689, \"stim_strength\": 2, \"combined_condition\": 1.0}, {\"mouse\": 4, \"neuron_x_mouse\": \"m1bayes4\", \"i_trial\": 0, \"stim\": 0, \"Log power\": 2.5892856098436363, \"Firing rate\": 388.40571352751243, \"Power\": 388.40571352751243, \"i_spike\": 62.5, \"isi\": 0.05577033764143675, \"stim_strength\": 2, \"combined_condition\": 1.0}, {\"mouse\": 4, \"neuron_x_mouse\": \"m1bayes4\", \"i_trial\": 0, \"stim\": 1, \"Log power\": 3.217960946841189, \"Firing rate\": 1651.8132551814765, \"Power\": 1651.8132551814765, \"i_spike\": 89.0, \"isi\": 0.03846192886556358, \"stim_strength\": 2, \"combined_condition\": 1.0}, {\"mouse\": 4, \"neuron_x_mouse\": \"m1bayes4\", \"i_trial\": 1, \"stim\": 0, \"Log power\": 2.7630687753007854, \"Firing rate\": 579.5204625903615, \"Power\": 579.5204625903615, \"i_spike\": 70.5, \"isi\": 0.049200783389714335, \"stim_strength\": 2, \"combined_condition\": 1.0}, {\"mouse\": 4, \"neuron_x_mouse\": \"m1bayes4\", \"i_trial\": 1, \"stim\": 1, \"Log power\": 2.2531451363934125, \"Firing rate\": 179.1204354629226, \"Power\": 179.1204354629226, \"i_spike\": 93.0, \"isi\": 0.03725579858322115, \"stim_strength\": 2, \"combined_condition\": 1.0}, {\"mouse\": 4, \"neuron_x_mouse\": \"m1bayes4\", \"i_trial\": 2, \"stim\": 0, \"Log power\": 2.0881595230293666, \"Firing rate\": 122.50661022152383, \"Power\": 122.50661022152383, \"i_spike\": 76.0, \"isi\": 0.04529213795247639, \"stim_strength\": 2, \"combined_condition\": 1.0}, {\"mouse\": 4, \"neuron_x_mouse\": \"m1bayes4\", \"i_trial\": 2, \"stim\": 1, \"Log power\": 2.6419377582702617, \"Firing rate\": 438.46785342744255, \"Power\": 438.46785342744255, \"i_spike\": 87.0, \"isi\": 0.03816640334446935, \"stim_strength\": 2, \"combined_condition\": 1.0}, {\"mouse\": 4, \"neuron_x_mouse\": \"m1bayes4\", \"i_trial\": 3, \"stim\": 0, \"Log power\": 2.0521783870852364, \"Firing rate\": 112.76605492590356, \"Power\": 112.76605492590356, \"i_spike\": 64.0, \"isi\": 0.054693622678460896, \"stim_strength\": 2, \"combined_condition\": 1.0}, {\"mouse\": 4, \"neuron_x_mouse\": \"m1bayes4\", \"i_trial\": 3, \"stim\": 1, \"Log power\": 2.41158397629528, \"Firing rate\": 257.97877505810374, \"Power\": 257.97877505810374, \"i_spike\": 95.5, \"isi\": 0.036450780429693866, \"stim_strength\": 2, \"combined_condition\": 1.0}, {\"mouse\": 4, \"neuron_x_mouse\": \"m1bayes4\", \"i_trial\": 4, \"stim\": 0, \"Log power\": 3.355063871070907, \"Firing rate\": 2264.977390098273, \"Power\": 2264.977390098273, \"i_spike\": 75.0, \"isi\": 0.046463681968345986, \"stim_strength\": 2, \"combined_condition\": 1.0}, {\"mouse\": 4, \"neuron_x_mouse\": \"m1bayes4\", \"i_trial\": 4, \"stim\": 1, \"Log power\": 2.125403816242339, \"Firing rate\": 133.47619453799044, \"Power\": 133.47619453799044, \"i_spike\": 101.0, \"isi\": 0.03325915817226928, \"stim_strength\": 2, \"combined_condition\": 1.0}, {\"mouse\": 4, \"neuron_x_mouse\": \"m1bayes4\", \"i_trial\": 5, \"stim\": 0, \"Log power\": 2.0360676278203305, \"Firing rate\": 108.65948136960829, \"Power\": 108.65948136960829, \"i_spike\": 70.5, \"isi\": 0.048509853230740495, \"stim_strength\": 2, \"combined_condition\": 1.0}, {\"mouse\": 4, \"neuron_x_mouse\": \"m1bayes4\", \"i_trial\": 5, \"stim\": 1, \"Log power\": 2.099625529963021, \"Firing rate\": 125.78403723139101, \"Power\": 125.78403723139101, \"i_spike\": 95.5, \"isi\": 0.03619259754062236, \"stim_strength\": 2, \"combined_condition\": 1.0}, {\"mouse\": 4, \"neuron_x_mouse\": \"m1bayes4\", \"i_trial\": 6, \"stim\": 0, \"Log power\": 1.8173066553260941, \"Firing rate\": 65.66087340720338, \"Power\": 65.66087340720338, \"i_spike\": 70.5, \"isi\": 0.04937282550014416, \"stim_strength\": 2, \"combined_condition\": 1.0}, {\"mouse\": 4, \"neuron_x_mouse\": \"m1bayes4\", \"i_trial\": 6, \"stim\": 1, \"Log power\": 2.4142987435994248, \"Firing rate\": 259.5964466756846, \"Power\": 259.5964466756846, \"i_spike\": 118.0, \"isi\": 0.029548516753408752, \"stim_strength\": 2, \"combined_condition\": 1.0}, {\"mouse\": 4, \"neuron_x_mouse\": \"m1bayes4\", \"i_trial\": 7, \"stim\": 0, \"Log power\": 1.8515178796395673, \"Firing rate\": 71.04244171418868, \"Power\": 71.04244171418868, \"i_spike\": 70.0, \"isi\": 0.05013971506804336, \"stim_strength\": 2, \"combined_condition\": 1.0}, {\"mouse\": 4, \"neuron_x_mouse\": \"m1bayes4\", \"i_trial\": 7, \"stim\": 1, \"Log power\": 2.2150921941021657, \"Firing rate\": 164.09380823835355, \"Power\": 164.09380823835355, \"i_spike\": 112.0, \"isi\": 0.031113237756063093, \"stim_strength\": 2, \"combined_condition\": 1.0}, {\"mouse\": 4, \"neuron_x_mouse\": \"m1bayes4\", \"i_trial\": 8, \"stim\": 0, \"Log power\": 2.333982826851163, \"Firing rate\": 215.76590879367447, \"Power\": 215.76590879367447, \"i_spike\": 60.5, \"isi\": 0.05769775565061573, \"stim_strength\": 2, \"combined_condition\": 1.0}, {\"mouse\": 4, \"neuron_x_mouse\": \"m1bayes4\", \"i_trial\": 8, \"stim\": 1, \"Log power\": 2.0955940765764054, \"Firing rate\": 124.62181629681939, \"Power\": 124.62181629681939, \"i_spike\": 85.5, \"isi\": 0.041046700807221635, \"stim_strength\": 2, \"combined_condition\": 1.0}, {\"mouse\": 4, \"neuron_x_mouse\": \"m1bayes4\", \"i_trial\": 9, \"stim\": 0, \"Log power\": 2.1825553002560194, \"Firing rate\": 152.24929849674876, \"Power\": 152.24929849674876, \"i_spike\": 62.5, \"isi\": 0.055442245015391335, \"stim_strength\": 2, \"combined_condition\": 1.0}, {\"mouse\": 4, \"neuron_x_mouse\": \"m1bayes4\", \"i_trial\": 9, \"stim\": 1, \"Log power\": 2.2033463779313207, \"Firing rate\": 159.71524717599115, \"Power\": 159.71524717599115, \"i_spike\": 91.0, \"isi\": 0.038451626262391396, \"stim_strength\": 2, \"combined_condition\": 1.0}, {\"mouse\": 5, \"neuron_x_mouse\": \"m1bayes5\", \"i_trial\": 0, \"stim\": 0, \"Log power\": 1.9653684764980979, \"Firing rate\": 92.33545136478475, \"Power\": 92.33545136478475, \"i_spike\": 69.5, \"isi\": 0.05053763078698731, \"stim_strength\": 2, \"combined_condition\": 1.0}, {\"mouse\": 5, \"neuron_x_mouse\": \"m1bayes5\", \"i_trial\": 0, \"stim\": 1, \"Log power\": 2.279082733441729, \"Firing rate\": 190.14404713345482, \"Power\": 190.14404713345482, \"i_spike\": 105.5, \"isi\": 0.03307268802694135, \"stim_strength\": 2, \"combined_condition\": 1.0}, {\"mouse\": 5, \"neuron_x_mouse\": \"m1bayes5\", \"i_trial\": 1, \"stim\": 0, \"Log power\": 2.037457798721162, \"Firing rate\": 109.00785620856722, \"Power\": 109.00785620856722, \"i_spike\": 71.5, \"isi\": 0.04916267184997751, \"stim_strength\": 2, \"combined_condition\": 1.0}, {\"mouse\": 5, \"neuron_x_mouse\": \"m1bayes5\", \"i_trial\": 1, \"stim\": 1, \"Log power\": 2.399703526966226, \"Firing rate\": 251.01722663726107, \"Power\": 251.01722663726107, \"i_spike\": 111.5, \"isi\": 0.031141358358682966, \"stim_strength\": 2, \"combined_condition\": 1.0}, {\"mouse\": 5, \"neuron_x_mouse\": \"m1bayes5\", \"i_trial\": 2, \"stim\": 0, \"Log power\": 2.1282123309770995, \"Firing rate\": 134.34216130553733, \"Power\": 134.34216130553733, \"i_spike\": 74.5, \"isi\": 0.04705242203458722, \"stim_strength\": 2, \"combined_condition\": 1.0}, {\"mouse\": 5, \"neuron_x_mouse\": \"m1bayes5\", \"i_trial\": 2, \"stim\": 1, \"Log power\": 2.3497750658838155, \"Firing rate\": 223.75619380752318, \"Power\": 223.75619380752318, \"i_spike\": 113.0, \"isi\": 0.03039586325126567, \"stim_strength\": 2, \"combined_condition\": 1.0}, {\"mouse\": 5, \"neuron_x_mouse\": \"m1bayes5\", \"i_trial\": 3, \"stim\": 0, \"Log power\": 2.253176219395694, \"Firing rate\": 179.13325579654608, \"Power\": 179.13325579654608, \"i_spike\": 83.0, \"isi\": 0.041413608348585026, \"stim_strength\": 2, \"combined_condition\": 1.0}, {\"mouse\": 5, \"neuron_x_mouse\": \"m1bayes5\", \"i_trial\": 3, \"stim\": 1, \"Log power\": 2.2053804937668366, \"Firing rate\": 160.4650640373485, \"Power\": 160.4650640373485, \"i_spike\": 114.0, \"isi\": 0.03002008431298395, \"stim_strength\": 2, \"combined_condition\": 1.0}, {\"mouse\": 5, \"neuron_x_mouse\": \"m1bayes5\", \"i_trial\": 4, \"stim\": 0, \"Log power\": 2.337543320422256, \"Firing rate\": 217.5421019178322, \"Power\": 217.5421019178322, \"i_spike\": 87.5, \"isi\": 0.0398847528445992, \"stim_strength\": 2, \"combined_condition\": 1.0}, {\"mouse\": 5, \"neuron_x_mouse\": \"m1bayes5\", \"i_trial\": 4, \"stim\": 1, \"Log power\": 2.239533201402256, \"Firing rate\": 173.59339683083107, \"Power\": 173.59339683083107, \"i_spike\": 115.5, \"isi\": 0.029623965882070082, \"stim_strength\": 2, \"combined_condition\": 1.0}, {\"mouse\": 5, \"neuron_x_mouse\": \"m1bayes5\", \"i_trial\": 5, \"stim\": 0, \"Log power\": 1.8481964030515114, \"Firing rate\": 70.50118277244658, \"Power\": 70.50118277244658, \"i_spike\": 79.0, \"isi\": 0.0443092872644805, \"stim_strength\": 2, \"combined_condition\": 1.0}, {\"mouse\": 5, \"neuron_x_mouse\": \"m1bayes5\", \"i_trial\": 5, \"stim\": 1, \"Log power\": 2.477984382563663, \"Firing rate\": 300.5968204636888, \"Power\": 300.5968204636888, \"i_spike\": 91.0, \"isi\": 0.03828323201835051, \"stim_strength\": 2, \"combined_condition\": 1.0}, {\"mouse\": 5, \"neuron_x_mouse\": \"m1bayes5\", \"i_trial\": 6, \"stim\": 0, \"Log power\": 2.3308292685947922, \"Firing rate\": 214.20483458431403, \"Power\": 214.20483458431403, \"i_spike\": 77.0, \"isi\": 0.04463309460679133, \"stim_strength\": 2, \"combined_condition\": 1.0}, {\"mouse\": 5, \"neuron_x_mouse\": \"m1bayes5\", \"i_trial\": 6, \"stim\": 1, \"Log power\": 2.296380365607195, \"Firing rate\": 197.87018763763558, \"Power\": 197.87018763763558, \"i_spike\": 108.5, \"isi\": 0.03187981222059265, \"stim_strength\": 2, \"combined_condition\": 1.0}, {\"mouse\": 5, \"neuron_x_mouse\": \"m1bayes5\", \"i_trial\": 7, \"stim\": 0, \"Log power\": 2.249250440644325, \"Firing rate\": 177.5212881632097, \"Power\": 177.5212881632097, \"i_spike\": 76.0, \"isi\": 0.04511938468079429, \"stim_strength\": 2, \"combined_condition\": 1.0}, {\"mouse\": 5, \"neuron_x_mouse\": \"m1bayes5\", \"i_trial\": 7, \"stim\": 1, \"Log power\": 2.3498910410071545, \"Firing rate\": 223.81595422002297, \"Power\": 223.81595422002297, \"i_spike\": 107.5, \"isi\": 0.032158109715479964, \"stim_strength\": 2, \"combined_condition\": 1.0}, {\"mouse\": 5, \"neuron_x_mouse\": \"m1bayes5\", \"i_trial\": 8, \"stim\": 0, \"Log power\": 2.096980574597847, \"Firing rate\": 125.02031090805056, \"Power\": 125.02031090805056, \"i_spike\": 91.0, \"isi\": 0.03835609669652595, \"stim_strength\": 2, \"combined_condition\": 1.0}, {\"mouse\": 5, \"neuron_x_mouse\": \"m1bayes5\", \"i_trial\": 8, \"stim\": 1, \"Log power\": 2.4356944906296465, \"Firing rate\": 272.7058727559052, \"Power\": 272.7058727559052, \"i_spike\": 106.0, \"isi\": 0.03285929226242781, \"stim_strength\": 2, \"combined_condition\": 1.0}, {\"mouse\": 5, \"neuron_x_mouse\": \"m1bayes5\", \"i_trial\": 9, \"stim\": 0, \"Log power\": 2.015208303574719, \"Firing rate\": 103.56387779453509, \"Power\": 103.56387779453509, \"i_spike\": 74.5, \"isi\": 0.04693900485254317, \"stim_strength\": 2, \"combined_condition\": 1.0}, {\"mouse\": 5, \"neuron_x_mouse\": \"m1bayes5\", \"i_trial\": 9, \"stim\": 1, \"Log power\": 2.7344748968305312, \"Firing rate\": 542.5938873109551, \"Power\": 542.5938873109551, \"i_spike\": 114.5, \"isi\": 0.030282217798543988, \"stim_strength\": 2, \"combined_condition\": 1.0}, {\"mouse\": 6, \"neuron_x_mouse\": \"m1bayes6\", \"i_trial\": 0, \"stim\": 0, \"Log power\": 2.130395167501416, \"Firing rate\": 135.01908716818411, \"Power\": 135.01908716818411, \"i_spike\": 93.0, \"isi\": 0.037640450834565756, \"stim_strength\": 2, \"combined_condition\": 1.0}, {\"mouse\": 6, \"neuron_x_mouse\": \"m1bayes6\", \"i_trial\": 0, \"stim\": 1, \"Log power\": 2.1180004296294443, \"Firing rate\": 131.22011971245692, \"Power\": 131.22011971245692, \"i_spike\": 115.5, \"isi\": 0.030108043744767134, \"stim_strength\": 2, \"combined_condition\": 1.0}, {\"mouse\": 6, \"neuron_x_mouse\": \"m1bayes6\", \"i_trial\": 1, \"stim\": 0, \"Log power\": 2.209843281093584, \"Firing rate\": 162.12249587915338, \"Power\": 162.12249587915338, \"i_spike\": 90.0, \"isi\": 0.03838149054105179, \"stim_strength\": 2, \"combined_condition\": 1.0}, {\"mouse\": 6, \"neuron_x_mouse\": \"m1bayes6\", \"i_trial\": 1, \"stim\": 1, \"Log power\": 2.900070865996258, \"Firing rate\": 794.45785979882, \"Power\": 794.45785979882, \"i_spike\": 105.0, \"isi\": 0.03322658379964364, \"stim_strength\": 2, \"combined_condition\": 1.0}, {\"mouse\": 6, \"neuron_x_mouse\": \"m1bayes6\", \"i_trial\": 2, \"stim\": 0, \"Log power\": 2.500151446184771, \"Firing rate\": 316.3380594742849, \"Power\": 316.3380594742849, \"i_spike\": 94.0, \"isi\": 0.03706708238558928, \"stim_strength\": 2, \"combined_condition\": 1.0}, {\"mouse\": 6, \"neuron_x_mouse\": \"m1bayes6\", \"i_trial\": 2, \"stim\": 1, \"Log power\": 2.393368298317737, \"Firing rate\": 247.38211505957423, \"Power\": 247.38211505957423, \"i_spike\": 110.0, \"isi\": 0.031549687572966244, \"stim_strength\": 2, \"combined_condition\": 1.0}, {\"mouse\": 6, \"neuron_x_mouse\": \"m1bayes6\", \"i_trial\": 3, \"stim\": 0, \"Log power\": 3.898210271418747, \"Firing rate\": 7910.615418485594, \"Power\": 7910.615418485594, \"i_spike\": 101.0, \"isi\": 0.03475773479680377, \"stim_strength\": 2, \"combined_condition\": 1.0}, {\"mouse\": 6, \"neuron_x_mouse\": \"m1bayes6\", \"i_trial\": 3, \"stim\": 1, \"Log power\": 2.305437508834914, \"Firing rate\": 202.0400693144304, \"Power\": 202.0400693144304, \"i_spike\": 118.0, \"isi\": 0.029341816216704925, \"stim_strength\": 2, \"combined_condition\": 1.0}, {\"mouse\": 6, \"neuron_x_mouse\": \"m1bayes6\", \"i_trial\": 4, \"stim\": 0, \"Log power\": 2.1849570801437617, \"Firing rate\": 153.0936156958089, \"Power\": 153.0936156958089, \"i_spike\": 106.0, \"isi\": 0.033045122131388986, \"stim_strength\": 2, \"combined_condition\": 1.0}, {\"mouse\": 6, \"neuron_x_mouse\": \"m1bayes6\", \"i_trial\": 4, \"stim\": 1, \"Log power\": 2.5259448085743093, \"Firing rate\": 335.6949504261295, \"Power\": 335.6949504261295, \"i_spike\": 120.0, \"isi\": 0.02882191831079986, \"stim_strength\": 2, \"combined_condition\": 1.0}, {\"mouse\": 6, \"neuron_x_mouse\": \"m1bayes6\", \"i_trial\": 5, \"stim\": 0, \"Log power\": 2.4545770245912726, \"Firing rate\": 284.8242907425812, \"Power\": 284.8242907425812, \"i_spike\": 96.0, \"isi\": 0.03627653255826617, \"stim_strength\": 2, \"combined_condition\": 1.0}, {\"mouse\": 6, \"neuron_x_mouse\": \"m1bayes6\", \"i_trial\": 5, \"stim\": 1, \"Log power\": 2.2777220899866992, \"Firing rate\": 189.54925856227328, \"Power\": 189.54925856227328, \"i_spike\": 113.5, \"isi\": 0.030846249188454404, \"stim_strength\": 2, \"combined_condition\": 1.0}, {\"mouse\": 6, \"neuron_x_mouse\": \"m1bayes6\", \"i_trial\": 6, \"stim\": 0, \"Log power\": 2.1940626729341823, \"Firing rate\": 156.33732363856248, \"Power\": 156.33732363856248, \"i_spike\": 106.5, \"isi\": 0.032148725201900076, \"stim_strength\": 2, \"combined_condition\": 1.0}, {\"mouse\": 6, \"neuron_x_mouse\": \"m1bayes6\", \"i_trial\": 6, \"stim\": 1, \"Log power\": 2.32630831120093, \"Firing rate\": 211.98655208091031, \"Power\": 211.98655208091031, \"i_spike\": 121.0, \"isi\": 0.028729880279328997, \"stim_strength\": 2, \"combined_condition\": 1.0}, {\"mouse\": 6, \"neuron_x_mouse\": \"m1bayes6\", \"i_trial\": 7, \"stim\": 0, \"Log power\": 2.3630130450061295, \"Firing rate\": 230.68164780718712, \"Power\": 230.68164780718712, \"i_spike\": 96.0, \"isi\": 0.03622208352009055, \"stim_strength\": 2, \"combined_condition\": 1.0}, {\"mouse\": 6, \"neuron_x_mouse\": \"m1bayes6\", \"i_trial\": 7, \"stim\": 1, \"Log power\": 2.2260973399586876, \"Firing rate\": 168.30512470291907, \"Power\": 168.30512470291907, \"i_spike\": 112.5, \"isi\": 0.031045658701783156, \"stim_strength\": 2, \"combined_condition\": 1.0}, {\"mouse\": 6, \"neuron_x_mouse\": \"m1bayes6\", \"i_trial\": 8, \"stim\": 0, \"Log power\": 1.9736851206628934, \"Firing rate\": 94.12069397222524, \"Power\": 94.12069397222524, \"i_spike\": 100.5, \"isi\": 0.03454785922939486, \"stim_strength\": 2, \"combined_condition\": 1.0}, {\"mouse\": 6, \"neuron_x_mouse\": \"m1bayes6\", \"i_trial\": 8, \"stim\": 1, \"Log power\": 2.9130786163960947, \"Firing rate\": 818.6129608122858, \"Power\": 818.6129608122858, \"i_spike\": 111.5, \"isi\": 0.03150648117289594, \"stim_strength\": 2, \"combined_condition\": 1.0}, {\"mouse\": 6, \"neuron_x_mouse\": \"m1bayes6\", \"i_trial\": 9, \"stim\": 0, \"Log power\": 2.3411552079469398, \"Firing rate\": 219.35887389419807, \"Power\": 219.35887389419807, \"i_spike\": 95.5, \"isi\": 0.03658677106457599, \"stim_strength\": 2, \"combined_condition\": 1.0}, {\"mouse\": 6, \"neuron_x_mouse\": \"m1bayes6\", \"i_trial\": 9, \"stim\": 1, \"Log power\": 2.521252599496434, \"Firing rate\": 332.0875540850842, \"Power\": 332.0875540850842, \"i_spike\": 134.0, \"isi\": 0.025556538214864373, \"stim_strength\": 2, \"combined_condition\": 1.0}, {\"mouse\": 7, \"neuron_x_mouse\": \"m1bayes7\", \"i_trial\": 0, \"stim\": 0, \"Log power\": 2.1104216165988947, \"Firing rate\": 128.95008020507265, \"Power\": 128.95008020507265, \"i_spike\": 105.5, \"isi\": 0.032838387745475414, \"stim_strength\": 2, \"combined_condition\": 1.0}, {\"mouse\": 7, \"neuron_x_mouse\": \"m1bayes7\", \"i_trial\": 0, \"stim\": 1, \"Log power\": 2.524798620769959, \"Firing rate\": 334.8101540961159, \"Power\": 334.8101540961159, \"i_spike\": 126.5, \"isi\": 0.027250757168287284, \"stim_strength\": 2, \"combined_condition\": 1.0}, {\"mouse\": 7, \"neuron_x_mouse\": \"m1bayes7\", \"i_trial\": 1, \"stim\": 0, \"Log power\": 2.2888839393846077, \"Firing rate\": 194.48402741378436, \"Power\": 194.48402741378436, \"i_spike\": 112.5, \"isi\": 0.03119702628448289, \"stim_strength\": 2, \"combined_condition\": 1.0}, {\"mouse\": 7, \"neuron_x_mouse\": \"m1bayes7\", \"i_trial\": 1, \"stim\": 1, \"Log power\": 2.807466219843152, \"Firing rate\": 641.8982916351522, \"Power\": 641.8982916351522, \"i_spike\": 133.5, \"isi\": 0.025920913299341087, \"stim_strength\": 2, \"combined_condition\": 1.0}, {\"mouse\": 7, \"neuron_x_mouse\": \"m1bayes7\", \"i_trial\": 2, \"stim\": 0, \"Log power\": 2.3046098229145886, \"Firing rate\": 201.655384548622, \"Power\": 201.655384548622, \"i_spike\": 100.5, \"isi\": 0.034723680189908256, \"stim_strength\": 2, \"combined_condition\": 1.0}, {\"mouse\": 7, \"neuron_x_mouse\": \"m1bayes7\", \"i_trial\": 2, \"stim\": 1, \"Log power\": 2.163621548054324, \"Firing rate\": 145.75435772779292, \"Power\": 145.75435772779292, \"i_spike\": 120.5, \"isi\": 0.028863189411867992, \"stim_strength\": 2, \"combined_condition\": 1.0}, {\"mouse\": 7, \"neuron_x_mouse\": \"m1bayes7\", \"i_trial\": 3, \"stim\": 0, \"Log power\": 2.4923470661031435, \"Firing rate\": 310.7041586160697, \"Power\": 310.7041586160697, \"i_spike\": 110.0, \"isi\": 0.031859555967369016, \"stim_strength\": 2, \"combined_condition\": 1.0}, {\"mouse\": 7, \"neuron_x_mouse\": \"m1bayes7\", \"i_trial\": 3, \"stim\": 1, \"Log power\": 2.1371165432075716, \"Firing rate\": 137.1249692545643, \"Power\": 137.1249692545643, \"i_spike\": 118.5, \"isi\": 0.029455395478515865, \"stim_strength\": 2, \"combined_condition\": 1.0}, {\"mouse\": 7, \"neuron_x_mouse\": \"m1bayes7\", \"i_trial\": 4, \"stim\": 0, \"Log power\": 2.434280702832438, \"Firing rate\": 271.81955855865084, \"Power\": 271.81955855865084, \"i_spike\": 111.5, \"isi\": 0.0314687055940785, \"stim_strength\": 2, \"combined_condition\": 1.0}, {\"mouse\": 7, \"neuron_x_mouse\": \"m1bayes7\", \"i_trial\": 4, \"stim\": 1, \"Log power\": 2.3772612916110982, \"Firing rate\": 238.37532140001193, \"Power\": 238.37532140001193, \"i_spike\": 120.5, \"isi\": 0.02869932669813439, \"stim_strength\": 2, \"combined_condition\": 1.0}, {\"mouse\": 7, \"neuron_x_mouse\": \"m1bayes7\", \"i_trial\": 5, \"stim\": 0, \"Log power\": 2.2953754431621864, \"Firing rate\": 197.41286127580398, \"Power\": 197.41286127580398, \"i_spike\": 106.0, \"isi\": 0.0329305873166075, \"stim_strength\": 2, \"combined_condition\": 1.0}, {\"mouse\": 7, \"neuron_x_mouse\": \"m1bayes7\", \"i_trial\": 5, \"stim\": 1, \"Log power\": 2.3052730722464503, \"Firing rate\": 201.9635855174877, \"Power\": 201.9635855174877, \"i_spike\": 115.5, \"isi\": 0.0299251088347565, \"stim_strength\": 2, \"combined_condition\": 1.0}, {\"mouse\": 7, \"neuron_x_mouse\": \"m1bayes7\", \"i_trial\": 6, \"stim\": 0, \"Log power\": 2.0792511914603042, \"Firing rate\": 120.01932818816174, \"Power\": 120.01932818816174, \"i_spike\": 100.0, \"isi\": 0.034907201362944826, \"stim_strength\": 2, \"combined_condition\": 1.0}, {\"mouse\": 7, \"neuron_x_mouse\": \"m1bayes7\", \"i_trial\": 6, \"stim\": 1, \"Log power\": 2.6859828722161136, \"Firing rate\": 485.26936164437524, \"Power\": 485.26936164437524, \"i_spike\": 127.0, \"isi\": 0.027321650059897427, \"stim_strength\": 2, \"combined_condition\": 1.0}, {\"mouse\": 7, \"neuron_x_mouse\": \"m1bayes7\", \"i_trial\": 7, \"stim\": 0, \"Log power\": 2.38153546252045, \"Firing rate\": 240.73290826148207, \"Power\": 240.73290826148207, \"i_spike\": 111.0, \"isi\": 0.031628736706996986, \"stim_strength\": 2, \"combined_condition\": 1.0}, {\"mouse\": 7, \"neuron_x_mouse\": \"m1bayes7\", \"i_trial\": 7, \"stim\": 1, \"Log power\": 2.200131643882898, \"Firing rate\": 158.53736800738724, \"Power\": 158.53736800738724, \"i_spike\": 116.5, \"isi\": 0.03001894370582933, \"stim_strength\": 2, \"combined_condition\": 1.0}, {\"mouse\": 7, \"neuron_x_mouse\": \"m1bayes7\", \"i_trial\": 8, \"stim\": 0, \"Log power\": 2.2815838329307647, \"Firing rate\": 191.242244858035, \"Power\": 191.242244858035, \"i_spike\": 114.0, \"isi\": 0.030649903718396695, \"stim_strength\": 2, \"combined_condition\": 1.0}, {\"mouse\": 7, \"neuron_x_mouse\": \"m1bayes7\", \"i_trial\": 8, \"stim\": 1, \"Log power\": 2.168599839260011, \"Firing rate\": 147.43474373794402, \"Power\": 147.43474373794402, \"i_spike\": 113.5, \"isi\": 0.030854116218231246, \"stim_strength\": 2, \"combined_condition\": 1.0}, {\"mouse\": 7, \"neuron_x_mouse\": \"m1bayes7\", \"i_trial\": 9, \"stim\": 0, \"Log power\": 2.1323384121130156, \"Firing rate\": 135.62458182201863, \"Power\": 135.62458182201863, \"i_spike\": 97.5, \"isi\": 0.03564373574394183, \"stim_strength\": 2, \"combined_condition\": 1.0}, {\"mouse\": 7, \"neuron_x_mouse\": \"m1bayes7\", \"i_trial\": 9, \"stim\": 1, \"Log power\": 2.2193693912362984, \"Firing rate\": 165.71788855815754, \"Power\": 165.71788855815754, \"i_spike\": 122.5, \"isi\": 0.028452861962688144, \"stim_strength\": 2, \"combined_condition\": 1.0}, {\"mouse\": 0, \"neuron_x_mouse\": \"m1bayes0\", \"i_trial\": 0, \"stim\": 0, \"Log power\": 3.3590010021809973, \"Firing rate\": 2285.604077645344, \"Power\": 2285.604077645344, \"i_spike\": 46.0, \"isi\": 0.075256800020243, \"stim_strength\": 3, \"combined_condition\": 1.0}, {\"mouse\": 0, \"neuron_x_mouse\": \"m1bayes0\", \"i_trial\": 0, \"stim\": 1, \"Log power\": 2.430211605642057, \"Firing rate\": 269.2846546877548, \"Power\": 269.2846546877548, \"i_spike\": 98.5, \"isi\": 0.03493351462326414, \"stim_strength\": 3, \"combined_condition\": 1.0}, {\"mouse\": 0, \"neuron_x_mouse\": \"m1bayes0\", \"i_trial\": 1, \"stim\": 0, \"Log power\": 1.8180834446693552, \"Firing rate\": 65.7784210854285, \"Power\": 65.7784210854285, \"i_spike\": 43.5, \"isi\": 0.08012322789515498, \"stim_strength\": 3, \"combined_condition\": 1.0}, {\"mouse\": 0, \"neuron_x_mouse\": \"m1bayes0\", \"i_trial\": 1, \"stim\": 1, \"Log power\": 2.439689378398553, \"Firing rate\": 275.22594932971157, \"Power\": 275.22594932971157, \"i_spike\": 108.0, \"isi\": 0.031537242701076634, \"stim_strength\": 3, \"combined_condition\": 1.0}, {\"mouse\": 0, \"neuron_x_mouse\": \"m1bayes0\", \"i_trial\": 2, \"stim\": 0, \"Log power\": 1.6615555362250942, \"Firing rate\": 45.8728302793658, \"Power\": 45.8728302793658, \"i_spike\": 32.5, \"isi\": 0.10660017548733015, \"stim_strength\": 3, \"combined_condition\": 1.0}, {\"mouse\": 0, \"neuron_x_mouse\": \"m1bayes0\", \"i_trial\": 2, \"stim\": 1, \"Log power\": 2.4858673263786812, \"Firing rate\": 306.10281702956814, \"Power\": 306.10281702956814, \"i_spike\": 105.0, \"isi\": 0.03272067572028348, \"stim_strength\": 3, \"combined_condition\": 1.0}, {\"mouse\": 0, \"neuron_x_mouse\": \"m1bayes0\", \"i_trial\": 3, \"stim\": 0, \"Log power\": 1.6552371305974851, \"Firing rate\": 45.21027311341765, \"Power\": 45.21027311341765, \"i_spike\": 39.5, \"isi\": 0.08808920928467162, \"stim_strength\": 3, \"combined_condition\": 1.0}, {\"mouse\": 0, \"neuron_x_mouse\": \"m1bayes0\", \"i_trial\": 3, \"stim\": 1, \"Log power\": 2.4514876775627514, \"Firing rate\": 282.8053868234928, \"Power\": 282.8053868234928, \"i_spike\": 93.5, \"isi\": 0.036392276674685455, \"stim_strength\": 3, \"combined_condition\": 1.0}, {\"mouse\": 0, \"neuron_x_mouse\": \"m1bayes0\", \"i_trial\": 4, \"stim\": 0, \"Log power\": 1.608721736347985, \"Firing rate\": 40.61829938742297, \"Power\": 40.61829938742297, \"i_spike\": 36.5, \"isi\": 0.09297451474931505, \"stim_strength\": 3, \"combined_condition\": 1.0}, {\"mouse\": 0, \"neuron_x_mouse\": \"m1bayes0\", \"i_trial\": 4, \"stim\": 1, \"Log power\": 2.487155027633491, \"Firing rate\": 307.0117715287857, \"Power\": 307.0117715287857, \"i_spike\": 91.5, \"isi\": 0.036888410065959415, \"stim_strength\": 3, \"combined_condition\": 1.0}, {\"mouse\": 0, \"neuron_x_mouse\": \"m1bayes0\", \"i_trial\": 5, \"stim\": 0, \"Log power\": 3.5568906086253955, \"Firing rate\": 3604.8783084738543, \"Power\": 3604.8783084738543, \"i_spike\": 42.5, \"isi\": 0.08159394163178908, \"stim_strength\": 3, \"combined_condition\": 1.0}, {\"mouse\": 0, \"neuron_x_mouse\": \"m1bayes0\", \"i_trial\": 5, \"stim\": 1, \"Log power\": 2.59905978652246, \"Firing rate\": 397.2462320341289, \"Power\": 397.2462320341289, \"i_spike\": 98.0, \"isi\": 0.03501348383220072, \"stim_strength\": 3, \"combined_condition\": 1.0}, {\"mouse\": 0, \"neuron_x_mouse\": \"m1bayes0\", \"i_trial\": 6, \"stim\": 0, \"Log power\": 1.354794315955303, \"Firing rate\": 22.63572014633078, \"Power\": 22.63572014633078, \"i_spike\": 29.0, \"isi\": 0.11991686650610675, \"stim_strength\": 3, \"combined_condition\": 1.0}, {\"mouse\": 0, \"neuron_x_mouse\": \"m1bayes0\", \"i_trial\": 6, \"stim\": 1, \"Log power\": 2.478825215735923, \"Firing rate\": 301.17936668918054, \"Power\": 301.17936668918054, \"i_spike\": 123.5, \"isi\": 0.02830948658382924, \"stim_strength\": 3, \"combined_condition\": 1.0}, {\"mouse\": 0, \"neuron_x_mouse\": \"m1bayes0\", \"i_trial\": 7, \"stim\": 0, \"Log power\": 2.0510585451535714, \"Firing rate\": 112.47565867818497, \"Power\": 112.47565867818497, \"i_spike\": 39.0, \"isi\": 0.08675699447103638, \"stim_strength\": 3, \"combined_condition\": 1.0}, {\"mouse\": 0, \"neuron_x_mouse\": \"m1bayes0\", \"i_trial\": 7, \"stim\": 1, \"Log power\": 2.197865275359849, \"Firing rate\": 157.7121947002787, \"Power\": 157.7121947002787, \"i_spike\": 93.5, \"isi\": 0.03746178019570173, \"stim_strength\": 3, \"combined_condition\": 1.0}, {\"mouse\": 0, \"neuron_x_mouse\": \"m1bayes0\", \"i_trial\": 8, \"stim\": 0, \"Log power\": 2.9010262621046294, \"Firing rate\": 796.2074962106251, \"Power\": 796.2074962106251, \"i_spike\": 34.5, \"isi\": 0.10269210913026351, \"stim_strength\": 3, \"combined_condition\": 1.0}, {\"mouse\": 0, \"neuron_x_mouse\": \"m1bayes0\", \"i_trial\": 8, \"stim\": 1, \"Log power\": 2.3524637824299317, \"Firing rate\": 225.14576507728867, \"Power\": 225.14576507728867, \"i_spike\": 92.5, \"isi\": 0.03679473070473951, \"stim_strength\": 3, \"combined_condition\": 1.0}, {\"mouse\": 0, \"neuron_x_mouse\": \"m1bayes0\", \"i_trial\": 9, \"stim\": 0, \"Log power\": 1.686269935486078, \"Firing rate\": 48.55902247096358, \"Power\": 48.55902247096358, \"i_spike\": 44.5, \"isi\": 0.07732484891445918, \"stim_strength\": 3, \"combined_condition\": 1.0}, {\"mouse\": 0, \"neuron_x_mouse\": \"m1bayes0\", \"i_trial\": 9, \"stim\": 1, \"Log power\": 2.2249383884396785, \"Firing rate\": 167.85658700390667, \"Power\": 167.85658700390667, \"i_spike\": 107.0, \"isi\": 0.03214972836305398, \"stim_strength\": 3, \"combined_condition\": 1.0}, {\"mouse\": 1, \"neuron_x_mouse\": \"m1bayes1\", \"i_trial\": 0, \"stim\": 0, \"Log power\": 1.8081171383310166, \"Firing rate\": 64.28610870543102, \"Power\": 64.28610870543102, \"i_spike\": 45.5, \"isi\": 0.07693487507216426, \"stim_strength\": 3, \"combined_condition\": 1.0}, {\"mouse\": 1, \"neuron_x_mouse\": \"m1bayes1\", \"i_trial\": 0, \"stim\": 1, \"Log power\": 2.2358487120010326, \"Firing rate\": 172.12688605189754, \"Power\": 172.12688605189754, \"i_spike\": 104.0, \"isi\": 0.033520692593172065, \"stim_strength\": 3, \"combined_condition\": 1.0}, {\"mouse\": 1, \"neuron_x_mouse\": \"m1bayes1\", \"i_trial\": 1, \"stim\": 0, \"Log power\": 1.9402656945576178, \"Firing rate\": 87.14965948557807, \"Power\": 87.14965948557807, \"i_spike\": 55.0, \"isi\": 0.06330171572992789, \"stim_strength\": 3, \"combined_condition\": 1.0}, {\"mouse\": 1, \"neuron_x_mouse\": \"m1bayes1\", \"i_trial\": 1, \"stim\": 1, \"Log power\": 2.653466457644004, \"Firing rate\": 450.26320425875946, \"Power\": 450.26320425875946, \"i_spike\": 94.5, \"isi\": 0.03676455745521443, \"stim_strength\": 3, \"combined_condition\": 1.0}, {\"mouse\": 1, \"neuron_x_mouse\": \"m1bayes1\", \"i_trial\": 2, \"stim\": 0, \"Log power\": 1.865467816848963, \"Firing rate\": 73.36143483207351, \"Power\": 73.36143483207351, \"i_spike\": 35.5, \"isi\": 0.09931695810947667, \"stim_strength\": 3, \"combined_condition\": 1.0}, {\"mouse\": 1, \"neuron_x_mouse\": \"m1bayes1\", \"i_trial\": 2, \"stim\": 1, \"Log power\": 2.4805794579381852, \"Firing rate\": 302.3983783935254, \"Power\": 302.3983783935254, \"i_spike\": 114.5, \"isi\": 0.030171299904970424, \"stim_strength\": 3, \"combined_condition\": 1.0}, {\"mouse\": 1, \"neuron_x_mouse\": \"m1bayes1\", \"i_trial\": 3, \"stim\": 0, \"Log power\": 1.7796237136702673, \"Firing rate\": 60.203773569915114, \"Power\": 60.203773569915114, \"i_spike\": 49.5, \"isi\": 0.06884237371082096, \"stim_strength\": 3, \"combined_condition\": 1.0}, {\"mouse\": 1, \"neuron_x_mouse\": \"m1bayes1\", \"i_trial\": 3, \"stim\": 1, \"Log power\": 2.3500744328394654, \"Firing rate\": 223.91048612690565, \"Power\": 223.91048612690565, \"i_spike\": 88.0, \"isi\": 0.039227324624559905, \"stim_strength\": 3, \"combined_condition\": 1.0}, {\"mouse\": 1, \"neuron_x_mouse\": \"m1bayes1\", \"i_trial\": 4, \"stim\": 0, \"Log power\": 2.0846814185358014, \"Firing rate\": 121.52941812541526, \"Power\": 121.52941812541526, \"i_spike\": 50.0, \"isi\": 0.0656691631249596, \"stim_strength\": 3, \"combined_condition\": 1.0}, {\"mouse\": 1, \"neuron_x_mouse\": \"m1bayes1\", \"i_trial\": 4, \"stim\": 1, \"Log power\": 2.386055241817133, \"Firing rate\": 243.25134026310792, \"Power\": 243.25134026310792, \"i_spike\": 101.5, \"isi\": 0.03354434259416973, \"stim_strength\": 3, \"combined_condition\": 1.0}, {\"mouse\": 1, \"neuron_x_mouse\": \"m1bayes1\", \"i_trial\": 5, \"stim\": 0, \"Log power\": 1.7471164736176923, \"Firing rate\": 55.86199911766682, \"Power\": 55.86199911766682, \"i_spike\": 45.5, \"isi\": 0.07588611630808012, \"stim_strength\": 3, \"combined_condition\": 1.0}, {\"mouse\": 1, \"neuron_x_mouse\": \"m1bayes1\", \"i_trial\": 5, \"stim\": 1, \"Log power\": 2.3312539940034327, \"Firing rate\": 214.41442218220345, \"Power\": 214.41442218220345, \"i_spike\": 101.0, \"isi\": 0.034388324143630807, \"stim_strength\": 3, \"combined_condition\": 1.0}, {\"mouse\": 1, \"neuron_x_mouse\": \"m1bayes1\", \"i_trial\": 6, \"stim\": 0, \"Log power\": 1.8284666948349322, \"Firing rate\": 67.37002287821247, \"Power\": 67.37002287821247, \"i_spike\": 55.0, \"isi\": 0.06353252267717178, \"stim_strength\": 3, \"combined_condition\": 1.0}, {\"mouse\": 1, \"neuron_x_mouse\": \"m1bayes1\", \"i_trial\": 6, \"stim\": 1, \"Log power\": 2.391270865229599, \"Firing rate\": 246.19025900369215, \"Power\": 246.19025900369215, \"i_spike\": 117.0, \"isi\": 0.02861250128286367, \"stim_strength\": 3, \"combined_condition\": 1.0}, {\"mouse\": 1, \"neuron_x_mouse\": \"m1bayes1\", \"i_trial\": 7, \"stim\": 0, \"Log power\": 2.1336017021340017, \"Firing rate\": 136.01966538753743, \"Power\": 136.01966538753743, \"i_spike\": 53.0, \"isi\": 0.0625703317844398, \"stim_strength\": 3, \"combined_condition\": 1.0}, {\"mouse\": 1, \"neuron_x_mouse\": \"m1bayes1\", \"i_trial\": 7, \"stim\": 1, \"Log power\": 2.3344575379810655, \"Firing rate\": 216.0018834199169, \"Power\": 216.0018834199169, \"i_spike\": 113.0, \"isi\": 0.03024562458508023, \"stim_strength\": 3, \"combined_condition\": 1.0}, {\"mouse\": 1, \"neuron_x_mouse\": \"m1bayes1\", \"i_trial\": 8, \"stim\": 0, \"Log power\": 2.0095004491397286, \"Firing rate\": 102.21166176545907, \"Power\": 102.21166176545907, \"i_spike\": 51.5, \"isi\": 0.06820532311731962, \"stim_strength\": 3, \"combined_condition\": 1.0}, {\"mouse\": 1, \"neuron_x_mouse\": \"m1bayes1\", \"i_trial\": 8, \"stim\": 1, \"Log power\": 2.2974202526759737, \"Firing rate\": 198.34454132323577, \"Power\": 198.34454132323577, \"i_spike\": 106.5, \"isi\": 0.0321957079022748, \"stim_strength\": 3, \"combined_condition\": 1.0}, {\"mouse\": 1, \"neuron_x_mouse\": \"m1bayes1\", \"i_trial\": 9, \"stim\": 0, \"Log power\": 2.375162443253835, \"Firing rate\": 237.22608587994543, \"Power\": 237.22608587994543, \"i_spike\": 52.0, \"isi\": 0.06764474919608712, \"stim_strength\": 3, \"combined_condition\": 1.0}, {\"mouse\": 1, \"neuron_x_mouse\": \"m1bayes1\", \"i_trial\": 9, \"stim\": 1, \"Log power\": 2.496013800305557, \"Firing rate\": 313.33852903686045, \"Power\": 313.33852903686045, \"i_spike\": 117.5, \"isi\": 0.029629643806271, \"stim_strength\": 3, \"combined_condition\": 1.0}, {\"mouse\": 2, \"neuron_x_mouse\": \"m1bayes2\", \"i_trial\": 0, \"stim\": 0, \"Log power\": 1.7170066318221402, \"Firing rate\": 52.12026699835819, \"Power\": 52.12026699835819, \"i_spike\": 43.5, \"isi\": 0.08056218621868322, \"stim_strength\": 3, \"combined_condition\": 1.0}, {\"mouse\": 2, \"neuron_x_mouse\": \"m1bayes2\", \"i_trial\": 0, \"stim\": 1, \"Log power\": 2.2383722574492144, \"Firing rate\": 173.12997146523654, \"Power\": 173.12997146523654, \"i_spike\": 110.0, \"isi\": 0.03089638797959528, \"stim_strength\": 3, \"combined_condition\": 1.0}, {\"mouse\": 2, \"neuron_x_mouse\": \"m1bayes2\", \"i_trial\": 1, \"stim\": 0, \"Log power\": 1.8275417168642598, \"Firing rate\": 67.22668817011643, \"Power\": 67.22668817011643, \"i_spike\": 50.0, \"isi\": 0.07025292503132499, \"stim_strength\": 3, \"combined_condition\": 1.0}, {\"mouse\": 2, \"neuron_x_mouse\": \"m1bayes2\", \"i_trial\": 1, \"stim\": 1, \"Log power\": 2.485997308256816, \"Firing rate\": 306.1944455798953, \"Power\": 306.1944455798953, \"i_spike\": 116.5, \"isi\": 0.030103458749781695, \"stim_strength\": 3, \"combined_condition\": 1.0}, {\"mouse\": 2, \"neuron_x_mouse\": \"m1bayes2\", \"i_trial\": 2, \"stim\": 0, \"Log power\": 1.918781915694465, \"Firing rate\": 82.94341561968113, \"Power\": 82.94341561968113, \"i_spike\": 54.5, \"isi\": 0.06425546060148886, \"stim_strength\": 3, \"combined_condition\": 1.0}, {\"mouse\": 2, \"neuron_x_mouse\": \"m1bayes2\", \"i_trial\": 2, \"stim\": 1, \"Log power\": 2.649711865935889, \"Firing rate\": 446.3873367786585, \"Power\": 446.3873367786585, \"i_spike\": 112.0, \"isi\": 0.031196975189417636, \"stim_strength\": 3, \"combined_condition\": 1.0}, {\"mouse\": 2, \"neuron_x_mouse\": \"m1bayes2\", \"i_trial\": 3, \"stim\": 0, \"Log power\": 1.857216388445607, \"Firing rate\": 71.98075347965734, \"Power\": 71.98075347965734, \"i_spike\": 52.0, \"isi\": 0.0673745017526595, \"stim_strength\": 3, \"combined_condition\": 1.0}, {\"mouse\": 2, \"neuron_x_mouse\": \"m1bayes2\", \"i_trial\": 3, \"stim\": 1, \"Log power\": 3.0674208977986845, \"Firing rate\": 1167.9409822426112, \"Power\": 1167.9409822426112, \"i_spike\": 108.0, \"isi\": 0.031217312490794395, \"stim_strength\": 3, \"combined_condition\": 1.0}, {\"mouse\": 2, \"neuron_x_mouse\": \"m1bayes2\", \"i_trial\": 4, \"stim\": 0, \"Log power\": 1.7504230362955286, \"Firing rate\": 56.28893558482518, \"Power\": 56.28893558482518, \"i_spike\": 40.0, \"isi\": 0.08747165409151941, \"stim_strength\": 3, \"combined_condition\": 1.0}, {\"mouse\": 2, \"neuron_x_mouse\": \"m1bayes2\", \"i_trial\": 4, \"stim\": 1, \"Log power\": 2.201546278844266, \"Firing rate\": 159.05461649454807, \"Power\": 159.05461649454807, \"i_spike\": 101.5, \"isi\": 0.03449841810963805, \"stim_strength\": 3, \"combined_condition\": 1.0}, {\"mouse\": 2, \"neuron_x_mouse\": \"m1bayes2\", \"i_trial\": 5, \"stim\": 0, \"Log power\": 2.132857118348261, \"Firing rate\": 135.7866638822274, \"Power\": 135.7866638822274, \"i_spike\": 62.5, \"isi\": 0.055791987415050336, \"stim_strength\": 3, \"combined_condition\": 1.0}, {\"mouse\": 2, \"neuron_x_mouse\": \"m1bayes2\", \"i_trial\": 5, \"stim\": 1, \"Log power\": 2.3104734928898587, \"Firing rate\": 204.39651790325618, \"Power\": 204.39651790325618, \"i_spike\": 91.0, \"isi\": 0.03741702396711603, \"stim_strength\": 3, \"combined_condition\": 1.0}, {\"mouse\": 2, \"neuron_x_mouse\": \"m1bayes2\", \"i_trial\": 6, \"stim\": 0, \"Log power\": 2.5988037623175146, \"Firing rate\": 397.01211743557883, \"Power\": 397.01211743557883, \"i_spike\": 59.0, \"isi\": 0.05958146178432206, \"stim_strength\": 3, \"combined_condition\": 1.0}, {\"mouse\": 2, \"neuron_x_mouse\": \"m1bayes2\", \"i_trial\": 6, \"stim\": 1, \"Log power\": 3.259037494628047, \"Firing rate\": 1815.6724113064663, \"Power\": 1815.6724113064663, \"i_spike\": 108.0, \"isi\": 0.0319576467148028, \"stim_strength\": 3, \"combined_condition\": 1.0}, {\"mouse\": 2, \"neuron_x_mouse\": \"m1bayes2\", \"i_trial\": 7, \"stim\": 0, \"Log power\": 1.8680490838223835, \"Firing rate\": 73.79876325403495, \"Power\": 73.79876325403495, \"i_spike\": 35.0, \"isi\": 0.09964289113422747, \"stim_strength\": 3, \"combined_condition\": 1.0}, {\"mouse\": 2, \"neuron_x_mouse\": \"m1bayes2\", \"i_trial\": 7, \"stim\": 1, \"Log power\": 2.854597712832049, \"Firing rate\": 715.4803534020605, \"Power\": 715.4803534020605, \"i_spike\": 115.0, \"isi\": 0.030363714796436573, \"stim_strength\": 3, \"combined_condition\": 1.0}, {\"mouse\": 2, \"neuron_x_mouse\": \"m1bayes2\", \"i_trial\": 8, \"stim\": 0, \"Log power\": 1.8325191112268746, \"Firing rate\": 68.0015968601381, \"Power\": 68.0015968601381, \"i_spike\": 50.0, \"isi\": 0.06901535915088362, \"stim_strength\": 3, \"combined_condition\": 1.0}, {\"mouse\": 2, \"neuron_x_mouse\": \"m1bayes2\", \"i_trial\": 8, \"stim\": 1, \"Log power\": 3.19334823827792, \"Firing rate\": 1560.8035287989576, \"Power\": 1560.8035287989576, \"i_spike\": 101.0, \"isi\": 0.03264436535939718, \"stim_strength\": 3, \"combined_condition\": 1.0}, {\"mouse\": 2, \"neuron_x_mouse\": \"m1bayes2\", \"i_trial\": 9, \"stim\": 0, \"Log power\": 1.5978570096796902, \"Firing rate\": 39.61475822275894, \"Power\": 39.61475822275894, \"i_spike\": 44.5, \"isi\": 0.07844180149958611, \"stim_strength\": 3, \"combined_condition\": 1.0}, {\"mouse\": 2, \"neuron_x_mouse\": \"m1bayes2\", \"i_trial\": 9, \"stim\": 1, \"Log power\": 3.2754090965602174, \"Firing rate\": 1885.4242845506656, \"Power\": 1885.4242845506656, \"i_spike\": 118.0, \"isi\": 0.028937268026960956, \"stim_strength\": 3, \"combined_condition\": 1.0}, {\"mouse\": 3, \"neuron_x_mouse\": \"m1bayes3\", \"i_trial\": 0, \"stim\": 0, \"Log power\": 2.2038426060110714, \"Firing rate\": 159.8978432939508, \"Power\": 159.8978432939508, \"i_spike\": 63.5, \"isi\": 0.055085370836237046, \"stim_strength\": 3, \"combined_condition\": 1.0}, {\"mouse\": 3, \"neuron_x_mouse\": \"m1bayes3\", \"i_trial\": 0, \"stim\": 1, \"Log power\": 2.6979938107607175, \"Firing rate\": 498.8773777830649, \"Power\": 498.8773777830649, \"i_spike\": 129.0, \"isi\": 0.026081228125579895, \"stim_strength\": 3, \"combined_condition\": 1.0}, {\"mouse\": 3, \"neuron_x_mouse\": \"m1bayes3\", \"i_trial\": 1, \"stim\": 0, \"Log power\": 2.6787021118001344, \"Firing rate\": 477.2018424626872, \"Power\": 477.2018424626872, \"i_spike\": 65.5, \"isi\": 0.05342460782602973, \"stim_strength\": 3, \"combined_condition\": 1.0}, {\"mouse\": 3, \"neuron_x_mouse\": \"m1bayes3\", \"i_trial\": 1, \"stim\": 1, \"Log power\": 2.2646829773648878, \"Firing rate\": 183.94287805135554, \"Power\": 183.94287805135554, \"i_spike\": 109.0, \"isi\": 0.031843840730448256, \"stim_strength\": 3, \"combined_condition\": 1.0}, {\"mouse\": 3, \"neuron_x_mouse\": \"m1bayes3\", \"i_trial\": 2, \"stim\": 0, \"Log power\": 1.903329120865331, \"Firing rate\": 80.0440622171581, \"Power\": 80.0440622171581, \"i_spike\": 56.0, \"isi\": 0.06204077817108297, \"stim_strength\": 3, \"combined_condition\": 1.0}, {\"mouse\": 3, \"neuron_x_mouse\": \"m1bayes3\", \"i_trial\": 2, \"stim\": 1, \"Log power\": 2.6558484767431336, \"Firing rate\": 452.73959367722375, \"Power\": 452.73959367722375, \"i_spike\": 120.5, \"isi\": 0.028981855675657284, \"stim_strength\": 3, \"combined_condition\": 1.0}, {\"mouse\": 3, \"neuron_x_mouse\": \"m1bayes3\", \"i_trial\": 3, \"stim\": 0, \"Log power\": 2.383244353290991, \"Firing rate\": 241.68202619842776, \"Power\": 241.68202619842776, \"i_spike\": 65.0, \"isi\": 0.054025456849159145, \"stim_strength\": 3, \"combined_condition\": 1.0}, {\"mouse\": 3, \"neuron_x_mouse\": \"m1bayes3\", \"i_trial\": 3, \"stim\": 1, \"Log power\": 2.432308151382313, \"Firing rate\": 270.58776244696486, \"Power\": 270.58776244696486, \"i_spike\": 106.0, \"isi\": 0.03215660612561346, \"stim_strength\": 3, \"combined_condition\": 1.0}, {\"mouse\": 3, \"neuron_x_mouse\": \"m1bayes3\", \"i_trial\": 4, \"stim\": 0, \"Log power\": 2.5162121189013886, \"Firing rate\": 328.255581154309, \"Power\": 328.255581154309, \"i_spike\": 60.0, \"isi\": 0.0578852217770746, \"stim_strength\": 3, \"combined_condition\": 1.0}, {\"mouse\": 3, \"neuron_x_mouse\": \"m1bayes3\", \"i_trial\": 4, \"stim\": 1, \"Log power\": 2.7525777843242794, \"Firing rate\": 565.6890657710276, \"Power\": 565.6890657710276, \"i_spike\": 97.5, \"isi\": 0.03533788979470269, \"stim_strength\": 3, \"combined_condition\": 1.0}, {\"mouse\": 3, \"neuron_x_mouse\": \"m1bayes3\", \"i_trial\": 5, \"stim\": 0, \"Log power\": 1.6405816882905522, \"Firing rate\": 43.71008874981825, \"Power\": 43.71008874981825, \"i_spike\": 59.5, \"isi\": 0.05810017057272925, \"stim_strength\": 3, \"combined_condition\": 1.0}, {\"mouse\": 3, \"neuron_x_mouse\": \"m1bayes3\", \"i_trial\": 5, \"stim\": 1, \"Log power\": 2.6885554334805883, \"Firing rate\": 488.1524051936472, \"Power\": 488.1524051936472, \"i_spike\": 118.0, \"isi\": 0.027919937421068568, \"stim_strength\": 3, \"combined_condition\": 1.0}, {\"mouse\": 3, \"neuron_x_mouse\": \"m1bayes3\", \"i_trial\": 6, \"stim\": 0, \"Log power\": 1.7880535420532337, \"Firing rate\": 61.38376775601592, \"Power\": 61.38376775601592, \"i_spike\": 66.5, \"isi\": 0.05261278695680818, \"stim_strength\": 3, \"combined_condition\": 1.0}, {\"mouse\": 3, \"neuron_x_mouse\": \"m1bayes3\", \"i_trial\": 6, \"stim\": 1, \"Log power\": 2.4131177776707378, \"Firing rate\": 258.89149158447304, \"Power\": 258.89149158447304, \"i_spike\": 115.5, \"isi\": 0.029528957588625213, \"stim_strength\": 3, \"combined_condition\": 1.0}, {\"mouse\": 3, \"neuron_x_mouse\": \"m1bayes3\", \"i_trial\": 7, \"stim\": 0, \"Log power\": 1.9961327792773869, \"Firing rate\": 99.1134923790196, \"Power\": 99.1134923790196, \"i_spike\": 66.5, \"isi\": 0.052407780710282445, \"stim_strength\": 3, \"combined_condition\": 1.0}, {\"mouse\": 3, \"neuron_x_mouse\": \"m1bayes3\", \"i_trial\": 7, \"stim\": 1, \"Log power\": 2.6807334716366227, \"Firing rate\": 479.43912451014745, \"Power\": 479.43912451014745, \"i_spike\": 112.5, \"isi\": 0.030525184618086492, \"stim_strength\": 3, \"combined_condition\": 1.0}, {\"mouse\": 3, \"neuron_x_mouse\": \"m1bayes3\", \"i_trial\": 8, \"stim\": 0, \"Log power\": 2.1244786742074844, \"Firing rate\": 133.19216374252974, \"Power\": 133.19216374252974, \"i_spike\": 73.5, \"isi\": 0.047202464282296255, \"stim_strength\": 3, \"combined_condition\": 1.0}, {\"mouse\": 3, \"neuron_x_mouse\": \"m1bayes3\", \"i_trial\": 8, \"stim\": 1, \"Log power\": 2.924583693103274, \"Firing rate\": 840.5889818085734, \"Power\": 840.5889818085734, \"i_spike\": 102.0, \"isi\": 0.03428127014158007, \"stim_strength\": 3, \"combined_condition\": 1.0}, {\"mouse\": 3, \"neuron_x_mouse\": \"m1bayes3\", \"i_trial\": 9, \"stim\": 0, \"Log power\": 1.899175132723258, \"Firing rate\": 79.28209774260726, \"Power\": 79.28209774260726, \"i_spike\": 57.5, \"isi\": 0.06107257653321148, \"stim_strength\": 3, \"combined_condition\": 1.0}, {\"mouse\": 3, \"neuron_x_mouse\": \"m1bayes3\", \"i_trial\": 9, \"stim\": 1, \"Log power\": 2.287801013849329, \"Firing rate\": 193.99968012584503, \"Power\": 193.99968012584503, \"i_spike\": 104.5, \"isi\": 0.03265733826254179, \"stim_strength\": 3, \"combined_condition\": 1.0}, {\"mouse\": 4, \"neuron_x_mouse\": \"m1bayes4\", \"i_trial\": 0, \"stim\": 0, \"Log power\": 2.07981634236709, \"Firing rate\": 120.17561197109545, \"Power\": 120.17561197109545, \"i_spike\": 67.5, \"isi\": 0.051393589604983546, \"stim_strength\": 3, \"combined_condition\": 1.0}, {\"mouse\": 4, \"neuron_x_mouse\": \"m1bayes4\", \"i_trial\": 0, \"stim\": 1, \"Log power\": 2.781801861654192, \"Firing rate\": 605.0647628337581, \"Power\": 605.0647628337581, \"i_spike\": 106.0, \"isi\": 0.031704713868690886, \"stim_strength\": 3, \"combined_condition\": 1.0}, {\"mouse\": 4, \"neuron_x_mouse\": \"m1bayes4\", \"i_trial\": 1, \"stim\": 0, \"Log power\": 1.904942723660503, \"Firing rate\": 80.34201572190568, \"Power\": 80.34201572190568, \"i_spike\": 82.0, \"isi\": 0.04207565162510332, \"stim_strength\": 3, \"combined_condition\": 1.0}, {\"mouse\": 4, \"neuron_x_mouse\": \"m1bayes4\", \"i_trial\": 1, \"stim\": 1, \"Log power\": 2.2184964610848934, \"Firing rate\": 165.38513080557007, \"Power\": 165.38513080557007, \"i_spike\": 98.5, \"isi\": 0.035371119892099324, \"stim_strength\": 3, \"combined_condition\": 1.0}, {\"mouse\": 4, \"neuron_x_mouse\": \"m1bayes4\", \"i_trial\": 2, \"stim\": 0, \"Log power\": 2.300729346473593, \"Firing rate\": 199.86159384396547, \"Power\": 199.86159384396547, \"i_spike\": 62.5, \"isi\": 0.0552626914956044, \"stim_strength\": 3, \"combined_condition\": 1.0}, {\"mouse\": 4, \"neuron_x_mouse\": \"m1bayes4\", \"i_trial\": 2, \"stim\": 1, \"Log power\": 2.3567217919776877, \"Firing rate\": 227.36404754268068, \"Power\": 227.36404754268068, \"i_spike\": 106.5, \"isi\": 0.032124949997085206, \"stim_strength\": 3, \"combined_condition\": 1.0}, {\"mouse\": 4, \"neuron_x_mouse\": \"m1bayes4\", \"i_trial\": 3, \"stim\": 0, \"Log power\": 2.0017587750086823, \"Firing rate\": 100.40579403505704, \"Power\": 100.40579403505704, \"i_spike\": 62.5, \"isi\": 0.0563068556311917, \"stim_strength\": 3, \"combined_condition\": 1.0}, {\"mouse\": 4, \"neuron_x_mouse\": \"m1bayes4\", \"i_trial\": 3, \"stim\": 1, \"Log power\": 2.3304870416603753, \"Firing rate\": 214.03610624111073, \"Power\": 214.03610624111073, \"i_spike\": 123.0, \"isi\": 0.028350508765290543, \"stim_strength\": 3, \"combined_condition\": 1.0}, {\"mouse\": 4, \"neuron_x_mouse\": \"m1bayes4\", \"i_trial\": 4, \"stim\": 0, \"Log power\": 1.9753998850487147, \"Firing rate\": 94.49305389252063, \"Power\": 94.49305389252063, \"i_spike\": 63.5, \"isi\": 0.054319754523455346, \"stim_strength\": 3, \"combined_condition\": 1.0}, {\"mouse\": 4, \"neuron_x_mouse\": \"m1bayes4\", \"i_trial\": 4, \"stim\": 1, \"Log power\": 2.3434653905614553, \"Firing rate\": 220.52883873621832, \"Power\": 220.52883873621832, \"i_spike\": 124.0, \"isi\": 0.027568684404261527, \"stim_strength\": 3, \"combined_condition\": 1.0}, {\"mouse\": 4, \"neuron_x_mouse\": \"m1bayes4\", \"i_trial\": 5, \"stim\": 0, \"Log power\": 1.9986275815901786, \"Firing rate\": 99.68448777208677, \"Power\": 99.68448777208677, \"i_spike\": 71.5, \"isi\": 0.04829373133447896, \"stim_strength\": 3, \"combined_condition\": 1.0}, {\"mouse\": 4, \"neuron_x_mouse\": \"m1bayes4\", \"i_trial\": 5, \"stim\": 1, \"Log power\": 2.9915727520192354, \"Firing rate\": 980.7825990211543, \"Power\": 980.7825990211543, \"i_spike\": 94.5, \"isi\": 0.03697013785449338, \"stim_strength\": 3, \"combined_condition\": 1.0}, {\"mouse\": 4, \"neuron_x_mouse\": \"m1bayes4\", \"i_trial\": 6, \"stim\": 0, \"Log power\": 2.047702733055676, \"Firing rate\": 111.60990360801416, \"Power\": 111.60990360801416, \"i_spike\": 68.5, \"isi\": 0.051028333903773426, \"stim_strength\": 3, \"combined_condition\": 1.0}, {\"mouse\": 4, \"neuron_x_mouse\": \"m1bayes4\", \"i_trial\": 6, \"stim\": 1, \"Log power\": 2.452069256857654, \"Firing rate\": 283.18435533412463, \"Power\": 283.18435533412463, \"i_spike\": 108.5, \"isi\": 0.0322805863318964, \"stim_strength\": 3, \"combined_condition\": 1.0}, {\"mouse\": 4, \"neuron_x_mouse\": \"m1bayes4\", \"i_trial\": 7, \"stim\": 0, \"Log power\": 2.1888847393620554, \"Firing rate\": 154.48443874023027, \"Power\": 154.48443874023027, \"i_spike\": 77.5, \"isi\": 0.04502309805403988, \"stim_strength\": 3, \"combined_condition\": 1.0}, {\"mouse\": 4, \"neuron_x_mouse\": \"m1bayes4\", \"i_trial\": 7, \"stim\": 1, \"Log power\": 2.478252480064167, \"Firing rate\": 300.7824413713331, \"Power\": 300.7824413713331, \"i_spike\": 113.0, \"isi\": 0.030550269349587357, \"stim_strength\": 3, \"combined_condition\": 1.0}, {\"mouse\": 4, \"neuron_x_mouse\": \"m1bayes4\", \"i_trial\": 8, \"stim\": 0, \"Log power\": 1.963334378854518, \"Firing rate\": 91.90399258586935, \"Power\": 91.90399258586935, \"i_spike\": 66.5, \"isi\": 0.052343981525319036, \"stim_strength\": 3, \"combined_condition\": 1.0}, {\"mouse\": 4, \"neuron_x_mouse\": \"m1bayes4\", \"i_trial\": 8, \"stim\": 1, \"Log power\": 2.060248544426596, \"Firing rate\": 114.88108917778307, \"Power\": 114.88108917778307, \"i_spike\": 100.5, \"isi\": 0.03442980762110208, \"stim_strength\": 3, \"combined_condition\": 1.0}, {\"mouse\": 4, \"neuron_x_mouse\": \"m1bayes4\", \"i_trial\": 9, \"stim\": 0, \"Log power\": 1.9561733138067083, \"Firing rate\": 90.40101648916473, \"Power\": 90.40101648916473, \"i_spike\": 69.5, \"isi\": 0.0502860359654448, \"stim_strength\": 3, \"combined_condition\": 1.0}, {\"mouse\": 4, \"neuron_x_mouse\": \"m1bayes4\", \"i_trial\": 9, \"stim\": 1, \"Log power\": 2.421294466333962, \"Firing rate\": 263.81195137262654, \"Power\": 263.81195137262654, \"i_spike\": 108.5, \"isi\": 0.03200879799413577, \"stim_strength\": 3, \"combined_condition\": 1.0}, {\"mouse\": 5, \"neuron_x_mouse\": \"m1bayes5\", \"i_trial\": 0, \"stim\": 0, \"Log power\": 2.028243682580431, \"Firing rate\": 106.71947561140772, \"Power\": 106.71947561140772, \"i_spike\": 64.0, \"isi\": 0.054762306317153744, \"stim_strength\": 3, \"combined_condition\": 1.0}, {\"mouse\": 5, \"neuron_x_mouse\": \"m1bayes5\", \"i_trial\": 0, \"stim\": 1, \"Log power\": 2.348788825747423, \"Firing rate\": 223.24864197447408, \"Power\": 223.24864197447408, \"i_spike\": 102.0, \"isi\": 0.03376288932871532, \"stim_strength\": 3, \"combined_condition\": 1.0}, {\"mouse\": 5, \"neuron_x_mouse\": \"m1bayes5\", \"i_trial\": 1, \"stim\": 0, \"Log power\": 2.3280051011973333, \"Firing rate\": 212.81640431250395, \"Power\": 212.81640431250395, \"i_spike\": 84.0, \"isi\": 0.040999779012910055, \"stim_strength\": 3, \"combined_condition\": 1.0}, {\"mouse\": 5, \"neuron_x_mouse\": \"m1bayes5\", \"i_trial\": 1, \"stim\": 1, \"Log power\": 2.492282041688771, \"Firing rate\": 310.6576421522172, \"Power\": 310.6576421522172, \"i_spike\": 132.5, \"isi\": 0.026284571137499914, \"stim_strength\": 3, \"combined_condition\": 1.0}, {\"mouse\": 5, \"neuron_x_mouse\": \"m1bayes5\", \"i_trial\": 2, \"stim\": 0, \"Log power\": 2.2896221771445635, \"Firing rate\": 194.8149032518387, \"Power\": 194.8149032518387, \"i_spike\": 73.0, \"isi\": 0.04791370488556751, \"stim_strength\": 3, \"combined_condition\": 1.0}, {\"mouse\": 5, \"neuron_x_mouse\": \"m1bayes5\", \"i_trial\": 2, \"stim\": 1, \"Log power\": 2.463467219710654, \"Firing rate\": 290.71485213205034, \"Power\": 290.71485213205034, \"i_spike\": 126.0, \"isi\": 0.02738853002223826, \"stim_strength\": 3, \"combined_condition\": 1.0}, {\"mouse\": 5, \"neuron_x_mouse\": \"m1bayes5\", \"i_trial\": 3, \"stim\": 0, \"Log power\": 2.103857741017728, \"Firing rate\": 127.0157979776984, \"Power\": 127.0157979776984, \"i_spike\": 81.5, \"isi\": 0.04248074075994935, \"stim_strength\": 3, \"combined_condition\": 1.0}, {\"mouse\": 5, \"neuron_x_mouse\": \"m1bayes5\", \"i_trial\": 3, \"stim\": 1, \"Log power\": 2.2575544599113613, \"Firing rate\": 180.94828026015904, \"Power\": 180.94828026015904, \"i_spike\": 109.5, \"isi\": 0.0318354134041138, \"stim_strength\": 3, \"combined_condition\": 1.0}, {\"mouse\": 5, \"neuron_x_mouse\": \"m1bayes5\", \"i_trial\": 4, \"stim\": 0, \"Log power\": 1.9881041916643416, \"Firing rate\": 97.29806237282162, \"Power\": 97.29806237282162, \"i_spike\": 67.0, \"isi\": 0.0515688344981395, \"stim_strength\": 3, \"combined_condition\": 1.0}, {\"mouse\": 5, \"neuron_x_mouse\": \"m1bayes5\", \"i_trial\": 4, \"stim\": 1, \"Log power\": 2.380334499567155, \"Firing rate\": 240.0681244749963, \"Power\": 240.0681244749963, \"i_spike\": 102.5, \"isi\": 0.032777925934523416, \"stim_strength\": 3, \"combined_condition\": 1.0}, {\"mouse\": 5, \"neuron_x_mouse\": \"m1bayes5\", \"i_trial\": 5, \"stim\": 0, \"Log power\": 2.006547706098183, \"Firing rate\": 101.5190876476095, \"Power\": 101.5190876476095, \"i_spike\": 67.5, \"isi\": 0.051973471236898855, \"stim_strength\": 3, \"combined_condition\": 1.0}, {\"mouse\": 5, \"neuron_x_mouse\": \"m1bayes5\", \"i_trial\": 5, \"stim\": 1, \"Log power\": 2.3709169815157973, \"Firing rate\": 234.91837147217092, \"Power\": 234.91837147217092, \"i_spike\": 120.5, \"isi\": 0.028776041770205246, \"stim_strength\": 3, \"combined_condition\": 1.0}, {\"mouse\": 5, \"neuron_x_mouse\": \"m1bayes5\", \"i_trial\": 6, \"stim\": 0, \"Log power\": 2.2375084659605635, \"Firing rate\": 172.7859662375374, \"Power\": 172.7859662375374, \"i_spike\": 86.0, \"isi\": 0.04032528706854343, \"stim_strength\": 3, \"combined_condition\": 1.0}, {\"mouse\": 5, \"neuron_x_mouse\": \"m1bayes5\", \"i_trial\": 6, \"stim\": 1, \"Log power\": 2.71534196945728, \"Firing rate\": 519.2087101014176, \"Power\": 519.2087101014176, \"i_spike\": 121.0, \"isi\": 0.02870680828350152, \"stim_strength\": 3, \"combined_condition\": 1.0}, {\"mouse\": 5, \"neuron_x_mouse\": \"m1bayes5\", \"i_trial\": 7, \"stim\": 0, \"Log power\": 1.9080483471738021, \"Firing rate\": 80.91859755646011, \"Power\": 80.91859755646011, \"i_spike\": 80.0, \"isi\": 0.04240388394455635, \"stim_strength\": 3, \"combined_condition\": 1.0}, {\"mouse\": 5, \"neuron_x_mouse\": \"m1bayes5\", \"i_trial\": 7, \"stim\": 1, \"Log power\": 2.327451873108153, \"Firing rate\": 212.5454797206673, \"Power\": 212.5454797206673, \"i_spike\": 126.0, \"isi\": 0.02768661251274311, \"stim_strength\": 3, \"combined_condition\": 1.0}, {\"mouse\": 5, \"neuron_x_mouse\": \"m1bayes5\", \"i_trial\": 8, \"stim\": 0, \"Log power\": 2.4903714437309685, \"Firing rate\": 309.29396334625943, \"Power\": 309.29396334625943, \"i_spike\": 76.0, \"isi\": 0.045768173110695455, \"stim_strength\": 3, \"combined_condition\": 1.0}, {\"mouse\": 5, \"neuron_x_mouse\": \"m1bayes5\", \"i_trial\": 8, \"stim\": 1, \"Log power\": 2.4276728569254713, \"Firing rate\": 267.7150934844047, \"Power\": 267.7150934844047, \"i_spike\": 110.5, \"isi\": 0.031790844084826235, \"stim_strength\": 3, \"combined_condition\": 1.0}, {\"mouse\": 5, \"neuron_x_mouse\": \"m1bayes5\", \"i_trial\": 9, \"stim\": 0, \"Log power\": 1.9026229727166102, \"Firing rate\": 79.9140190289904, \"Power\": 79.9140190289904, \"i_spike\": 73.0, \"isi\": 0.0477981858108589, \"stim_strength\": 3, \"combined_condition\": 1.0}, {\"mouse\": 5, \"neuron_x_mouse\": \"m1bayes5\", \"i_trial\": 9, \"stim\": 1, \"Log power\": 2.2016735856282716, \"Firing rate\": 159.101247756614, \"Power\": 159.101247756614, \"i_spike\": 118.0, \"isi\": 0.029465493602227, \"stim_strength\": 3, \"combined_condition\": 1.0}, {\"mouse\": 6, \"neuron_x_mouse\": \"m1bayes6\", \"i_trial\": 0, \"stim\": 0, \"Log power\": 2.270643792986862, \"Firing rate\": 186.48495194956465, \"Power\": 186.48495194956465, \"i_spike\": 91.0, \"isi\": 0.03785731209666221, \"stim_strength\": 3, \"combined_condition\": 1.0}, {\"mouse\": 6, \"neuron_x_mouse\": \"m1bayes6\", \"i_trial\": 0, \"stim\": 1, \"Log power\": 2.2798667059012256, \"Firing rate\": 190.48759817835762, \"Power\": 190.48759817835762, \"i_spike\": 125.5, \"isi\": 0.02791042719076936, \"stim_strength\": 3, \"combined_condition\": 1.0}, {\"mouse\": 6, \"neuron_x_mouse\": \"m1bayes6\", \"i_trial\": 1, \"stim\": 0, \"Log power\": 2.061827607299408, \"Firing rate\": 115.29954867242989, \"Power\": 115.29954867242989, \"i_spike\": 89.0, \"isi\": 0.039320764444231, \"stim_strength\": 3, \"combined_condition\": 1.0}, {\"mouse\": 6, \"neuron_x_mouse\": \"m1bayes6\", \"i_trial\": 1, \"stim\": 1, \"Log power\": 2.2878721378394733, \"Firing rate\": 194.031453868818, \"Power\": 194.031453868818, \"i_spike\": 130.0, \"isi\": 0.026910971220722345, \"stim_strength\": 3, \"combined_condition\": 1.0}, {\"mouse\": 6, \"neuron_x_mouse\": \"m1bayes6\", \"i_trial\": 2, \"stim\": 0, \"Log power\": 2.1371586035029217, \"Firing rate\": 137.13825009565434, \"Power\": 137.13825009565434, \"i_spike\": 89.5, \"isi\": 0.038994625952493256, \"stim_strength\": 3, \"combined_condition\": 1.0}, {\"mouse\": 6, \"neuron_x_mouse\": \"m1bayes6\", \"i_trial\": 2, \"stim\": 1, \"Log power\": 2.1856799982919712, \"Firing rate\": 153.34866456686302, \"Power\": 153.34866456686302, \"i_spike\": 118.5, \"isi\": 0.029495395485307725, \"stim_strength\": 3, \"combined_condition\": 1.0}, {\"mouse\": 6, \"neuron_x_mouse\": \"m1bayes6\", \"i_trial\": 3, \"stim\": 0, \"Log power\": 2.4027752178827195, \"Firing rate\": 252.7989221236592, \"Power\": 252.7989221236592, \"i_spike\": 89.5, \"isi\": 0.039313719065098396, \"stim_strength\": 3, \"combined_condition\": 1.0}, {\"mouse\": 6, \"neuron_x_mouse\": \"m1bayes6\", \"i_trial\": 3, \"stim\": 1, \"Log power\": 2.1779729116882853, \"Firing rate\": 150.65130972997287, \"Power\": 150.65130972997287, \"i_spike\": 129.5, \"isi\": 0.027069238839220904, \"stim_strength\": 3, \"combined_condition\": 1.0}, {\"mouse\": 6, \"neuron_x_mouse\": \"m1bayes6\", \"i_trial\": 4, \"stim\": 0, \"Log power\": 2.3517931608444242, \"Firing rate\": 224.7983715426038, \"Power\": 224.7983715426038, \"i_spike\": 94.0, \"isi\": 0.03669944953946361, \"stim_strength\": 3, \"combined_condition\": 1.0}, {\"mouse\": 6, \"neuron_x_mouse\": \"m1bayes6\", \"i_trial\": 4, \"stim\": 1, \"Log power\": 2.328236511190991, \"Firing rate\": 212.9298318778887, \"Power\": 212.9298318778887, \"i_spike\": 129.5, \"isi\": 0.027080725050809898, \"stim_strength\": 3, \"combined_condition\": 1.0}, {\"mouse\": 6, \"neuron_x_mouse\": \"m1bayes6\", \"i_trial\": 5, \"stim\": 0, \"Log power\": 2.3344528642215194, \"Firing rate\": 215.99955887867404, \"Power\": 215.99955887867404, \"i_spike\": 91.5, \"isi\": 0.03809412496895485, \"stim_strength\": 3, \"combined_condition\": 1.0}, {\"mouse\": 6, \"neuron_x_mouse\": \"m1bayes6\", \"i_trial\": 5, \"stim\": 1, \"Log power\": 2.1302961963183957, \"Firing rate\": 134.98832123213208, \"Power\": 134.98832123213208, \"i_spike\": 124.5, \"isi\": 0.028051428101516698, \"stim_strength\": 3, \"combined_condition\": 1.0}, {\"mouse\": 6, \"neuron_x_mouse\": \"m1bayes6\", \"i_trial\": 6, \"stim\": 0, \"Log power\": 2.8610064123015495, \"Firing rate\": 726.11667837434, \"Power\": 726.11667837434, \"i_spike\": 96.0, \"isi\": 0.03639079927695875, \"stim_strength\": 3, \"combined_condition\": 1.0}, {\"mouse\": 6, \"neuron_x_mouse\": \"m1bayes6\", \"i_trial\": 6, \"stim\": 1, \"Log power\": 2.491768835886696, \"Firing rate\": 310.29075482540645, \"Power\": 310.29075482540645, \"i_spike\": 126.0, \"isi\": 0.027555297193539, \"stim_strength\": 3, \"combined_condition\": 1.0}, {\"mouse\": 6, \"neuron_x_mouse\": \"m1bayes6\", \"i_trial\": 7, \"stim\": 0, \"Log power\": 2.158850068787784, \"Firing rate\": 144.16175768726416, \"Power\": 144.16175768726416, \"i_spike\": 97.0, \"isi\": 0.03541622073054031, \"stim_strength\": 3, \"combined_condition\": 1.0}, {\"mouse\": 6, \"neuron_x_mouse\": \"m1bayes6\", \"i_trial\": 7, \"stim\": 1, \"Log power\": 2.1747965054699296, \"Firing rate\": 149.5534738946192, \"Power\": 149.5534738946192, \"i_spike\": 111.0, \"isi\": 0.03162047157229646, \"stim_strength\": 3, \"combined_condition\": 1.0}, {\"mouse\": 6, \"neuron_x_mouse\": \"m1bayes6\", \"i_trial\": 8, \"stim\": 0, \"Log power\": 2.151387562487989, \"Firing rate\": 141.70577920228976, \"Power\": 141.70577920228976, \"i_spike\": 81.0, \"isi\": 0.04129730043536564, \"stim_strength\": 3, \"combined_condition\": 1.0}, {\"mouse\": 6, \"neuron_x_mouse\": \"m1bayes6\", \"i_trial\": 8, \"stim\": 1, \"Log power\": 2.536216585946814, \"Firing rate\": 343.7293255801925, \"Power\": 343.7293255801925, \"i_spike\": 118.5, \"isi\": 0.029523790876636827, \"stim_strength\": 3, \"combined_condition\": 1.0}, {\"mouse\": 6, \"neuron_x_mouse\": \"m1bayes6\", \"i_trial\": 9, \"stim\": 0, \"Log power\": 2.211568180421453, \"Firing rate\": 162.7676826559356, \"Power\": 162.7676826559356, \"i_spike\": 96.0, \"isi\": 0.036537165574491604, \"stim_strength\": 3, \"combined_condition\": 1.0}, {\"mouse\": 6, \"neuron_x_mouse\": \"m1bayes6\", \"i_trial\": 9, \"stim\": 1, \"Log power\": 2.748764325695675, \"Firing rate\": 560.7436002530586, \"Power\": 560.7436002530586, \"i_spike\": 116.5, \"isi\": 0.03006302762786673, \"stim_strength\": 3, \"combined_condition\": 1.0}, {\"mouse\": 7, \"neuron_x_mouse\": \"m1bayes7\", \"i_trial\": 0, \"stim\": 0, \"Log power\": 2.1126433119381596, \"Firing rate\": 129.61143290442143, \"Power\": 129.61143290442143, \"i_spike\": 103.0, \"isi\": 0.03389375449561134, \"stim_strength\": 3, \"combined_condition\": 1.0}, {\"mouse\": 7, \"neuron_x_mouse\": \"m1bayes7\", \"i_trial\": 0, \"stim\": 1, \"Log power\": 2.3524385085321446, \"Firing rate\": 225.1326630331262, \"Power\": 225.1326630331262, \"i_spike\": 120.5, \"isi\": 0.029121679602638215, \"stim_strength\": 3, \"combined_condition\": 1.0}, {\"mouse\": 7, \"neuron_x_mouse\": \"m1bayes7\", \"i_trial\": 1, \"stim\": 0, \"Log power\": 2.3000384590979595, \"Firing rate\": 199.54390139365833, \"Power\": 199.54390139365833, \"i_spike\": 112.0, \"isi\": 0.0312691435668891, \"stim_strength\": 3, \"combined_condition\": 1.0}, {\"mouse\": 7, \"neuron_x_mouse\": \"m1bayes7\", \"i_trial\": 1, \"stim\": 1, \"Log power\": 2.2041176789187045, \"Firing rate\": 159.99915127409886, \"Power\": 159.99915127409886, \"i_spike\": 133.0, \"isi\": 0.026119269991901263, \"stim_strength\": 3, \"combined_condition\": 1.0}, {\"mouse\": 7, \"neuron_x_mouse\": \"m1bayes7\", \"i_trial\": 2, \"stim\": 0, \"Log power\": 2.345931888443158, \"Firing rate\": 221.78485614439168, \"Power\": 221.78485614439168, \"i_spike\": 110.0, \"isi\": 0.03172174869195594, \"stim_strength\": 3, \"combined_condition\": 1.0}, {\"mouse\": 7, \"neuron_x_mouse\": \"m1bayes7\", \"i_trial\": 2, \"stim\": 1, \"Log power\": 2.56588905115972, \"Firing rate\": 368.03494005996725, \"Power\": 368.03494005996725, \"i_spike\": 117.5, \"isi\": 0.02927404436250054, \"stim_strength\": 3, \"combined_condition\": 1.0}, {\"mouse\": 7, \"neuron_x_mouse\": \"m1bayes7\", \"i_trial\": 3, \"stim\": 0, \"Log power\": 2.2684252188382135, \"Firing rate\": 185.53473096953263, \"Power\": 185.53473096953263, \"i_spike\": 98.5, \"isi\": 0.03507659958273043, \"stim_strength\": 3, \"combined_condition\": 1.0}, {\"mouse\": 7, \"neuron_x_mouse\": \"m1bayes7\", \"i_trial\": 3, \"stim\": 1, \"Log power\": 2.371883325424631, \"Firing rate\": 235.44166774955363, \"Power\": 235.44166774955363, \"i_spike\": 127.5, \"isi\": 0.027360575999437017, \"stim_strength\": 3, \"combined_condition\": 1.0}, {\"mouse\": 7, \"neuron_x_mouse\": \"m1bayes7\", \"i_trial\": 4, \"stim\": 0, \"Log power\": 2.202073444085854, \"Firing rate\": 159.24780102396105, \"Power\": 159.24780102396105, \"i_spike\": 101.0, \"isi\": 0.03439015264572739, \"stim_strength\": 3, \"combined_condition\": 1.0}, {\"mouse\": 7, \"neuron_x_mouse\": \"m1bayes7\", \"i_trial\": 4, \"stim\": 1, \"Log power\": 2.362665517640082, \"Firing rate\": 230.49712757586354, \"Power\": 230.49712757586354, \"i_spike\": 141.0, \"isi\": 0.02472699517277539, \"stim_strength\": 3, \"combined_condition\": 1.0}, {\"mouse\": 7, \"neuron_x_mouse\": \"m1bayes7\", \"i_trial\": 5, \"stim\": 0, \"Log power\": 2.1058436968615024, \"Firing rate\": 127.5979499512423, \"Power\": 127.5979499512423, \"i_spike\": 97.0, \"isi\": 0.035852651201314555, \"stim_strength\": 3, \"combined_condition\": 1.0}, {\"mouse\": 7, \"neuron_x_mouse\": \"m1bayes7\", \"i_trial\": 5, \"stim\": 1, \"Log power\": 2.5062174024666315, \"Firing rate\": 320.787474521772, \"Power\": 320.787474521772, \"i_spike\": 123.0, \"isi\": 0.0284798831616425, \"stim_strength\": 3, \"combined_condition\": 1.0}, {\"mouse\": 7, \"neuron_x_mouse\": \"m1bayes7\", \"i_trial\": 6, \"stim\": 0, \"Log power\": 2.1574765491637877, \"Firing rate\": 143.70654532535343, \"Power\": 143.70654532535343, \"i_spike\": 102.0, \"isi\": 0.03395955522712172, \"stim_strength\": 3, \"combined_condition\": 1.0}, {\"mouse\": 7, \"neuron_x_mouse\": \"m1bayes7\", \"i_trial\": 6, \"stim\": 1, \"Log power\": 2.28291002846784, \"Firing rate\": 191.82712967847345, \"Power\": 191.82712967847345, \"i_spike\": 121.5, \"isi\": 0.028080937180524613, \"stim_strength\": 3, \"combined_condition\": 1.0}, {\"mouse\": 7, \"neuron_x_mouse\": \"m1bayes7\", \"i_trial\": 7, \"stim\": 0, \"Log power\": 2.2004343823152923, \"Firing rate\": 158.6479199220055, \"Power\": 158.6479199220055, \"i_spike\": 126.5, \"isi\": 0.027605471914003313, \"stim_strength\": 3, \"combined_condition\": 1.0}, {\"mouse\": 7, \"neuron_x_mouse\": \"m1bayes7\", \"i_trial\": 7, \"stim\": 1, \"Log power\": 2.2598555797497486, \"Firing rate\": 181.90958360431299, \"Power\": 181.90958360431299, \"i_spike\": 131.5, \"isi\": 0.02628592053144239, \"stim_strength\": 3, \"combined_condition\": 1.0}, {\"mouse\": 7, \"neuron_x_mouse\": \"m1bayes7\", \"i_trial\": 8, \"stim\": 0, \"Log power\": 2.1669497170120327, \"Firing rate\": 146.87562139436002, \"Power\": 146.87562139436002, \"i_spike\": 100.0, \"isi\": 0.03503442147176353, \"stim_strength\": 3, \"combined_condition\": 1.0}, {\"mouse\": 7, \"neuron_x_mouse\": \"m1bayes7\", \"i_trial\": 8, \"stim\": 1, \"Log power\": 2.5899597974802213, \"Firing rate\": 389.009132859922, \"Power\": 389.009132859922, \"i_spike\": 140.5, \"isi\": 0.024644531849746344, \"stim_strength\": 3, \"combined_condition\": 1.0}, {\"mouse\": 7, \"neuron_x_mouse\": \"m1bayes7\", \"i_trial\": 9, \"stim\": 0, \"Log power\": 2.364478920408704, \"Firing rate\": 231.4615837500512, \"Power\": 231.4615837500512, \"i_spike\": 119.0, \"isi\": 0.029324847977515438, \"stim_strength\": 3, \"combined_condition\": 1.0}, {\"mouse\": 7, \"neuron_x_mouse\": \"m1bayes7\", \"i_trial\": 9, \"stim\": 1, \"Log power\": 2.939181639448521, \"Firing rate\": 869.3239395571892, \"Power\": 869.3239395571892, \"i_spike\": 136.5, \"isi\": 0.025548367657862434, \"stim_strength\": 3, \"combined_condition\": 1.0}]}}, {\"mode\": \"vega-lite\"});\n</script>",
      "text/plain": "alt.LayerChart(...)"
     },
     "execution_count": 2,
     "metadata": {},
     "output_type": "execute_result"
    }
   ],
   "source": [
    "df = []\n",
    "for slope in np.linspace(4, 40, 4):\n",
    "    df1 = generate_fake_lfp(mouse_response_slope=slope)[0]\n",
    "    df1['stim_strength'] = slope\n",
    "    df.append(df1)\n",
    "df = pd.concat(df)\n",
    "\n",
    "BayesWindow(df=df, y='isi', treatment='stim_strength', group='mouse', detail='i_trial').data_box_detail()\n"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 3,
   "metadata": {},
   "outputs": [
    {
     "data": {
      "text/html": "\n<div id=\"altair-viz-cfdb4fa2f2dd46fab820ffe77fb2b8fc\"></div>\n<script type=\"text/javascript\">\n  (function(spec, embedOpt){\n    let outputDiv = document.currentScript.previousElementSibling;\n    if (outputDiv.id !== \"altair-viz-cfdb4fa2f2dd46fab820ffe77fb2b8fc\") {\n      outputDiv = document.getElementById(\"altair-viz-cfdb4fa2f2dd46fab820ffe77fb2b8fc\");\n    }\n    const paths = {\n      \"vega\": \"https://cdn.jsdelivr.net/npm//vega@5?noext\",\n      \"vega-lib\": \"https://cdn.jsdelivr.net/npm//vega-lib?noext\",\n      \"vega-lite\": \"https://cdn.jsdelivr.net/npm//vega-lite@4.8.1?noext\",\n      \"vega-embed\": \"https://cdn.jsdelivr.net/npm//vega-embed@6?noext\",\n    };\n\n    function loadScript(lib) {\n      return new Promise(function(resolve, reject) {\n        var s = document.createElement('script');\n        s.src = paths[lib];\n        s.async = true;\n        s.onload = () => resolve(paths[lib]);\n        s.onerror = () => reject(`Error loading script: ${paths[lib]}`);\n        document.getElementsByTagName(\"head\")[0].appendChild(s);\n      });\n    }\n\n    function showError(err) {\n      outputDiv.innerHTML = `<div class=\"error\" style=\"color:red;\">${err}</div>`;\n      throw err;\n    }\n\n    function displayChart(vegaEmbed) {\n      vegaEmbed(outputDiv, spec, embedOpt)\n        .catch(err => showError(`Javascript Error: ${err.message}<br>This usually means there's a typo in your chart specification. See the javascript console for the full traceback.`));\n    }\n\n    if(typeof define === \"function\" && define.amd) {\n      requirejs.config({paths});\n      require([\"vega-embed\"], displayChart, err => showError(`Error loading script: ${err.message}`));\n    } else if (typeof vegaEmbed === \"function\") {\n      displayChart(vegaEmbed);\n    } else {\n      loadScript(\"vega\")\n        .then(() => loadScript(\"vega-lite\"))\n        .then(() => loadScript(\"vega-embed\"))\n        .catch(showError)\n        .then(() => displayChart(vegaEmbed));\n    }\n  })({\"config\": {\"view\": {\"continuousWidth\": 400, \"continuousHeight\": 300}}, \"layer\": [{\"data\": {\"name\": \"data-d025de49ec0b6d6f7d58aed3a2f5c6c3\"}, \"mark\": {\"type\": \"rule\", \"clip\": true, \"opacity\": 0.4, \"size\": 0.8}, \"encoding\": {\"x\": {\"type\": \"quantitative\", \"field\": \"\"}, \"y\": {\"type\": \"quantitative\", \"axis\": {\"orient\": \"left\", \"title\": \"\"}, \"field\": \"lower interval\", \"scale\": {\"domain\": [-0.0909029170870781, 0], \"zero\": true}}, \"y2\": {\"field\": \"higher interval\"}}}, {\"data\": {\"name\": \"data-d025de49ec0b6d6f7d58aed3a2f5c6c3\"}, \"mark\": {\"type\": \"line\", \"clip\": true, \"color\": \"black\", \"fill\": null, \"point\": false, \"size\": 1}, \"encoding\": {\"x\": {\"type\": \"quantitative\", \"field\": \"\"}, \"y\": {\"type\": \"quantitative\", \"aggregate\": \"mean\", \"axis\": {\"orient\": \"left\"}, \"field\": \"center interval\", \"scale\": {\"domain\": [-0.0909029170870781, 0], \"zero\": true}, \"title\": \"\\u0394 isi\"}}}, {\"data\": {\"name\": \"data-d025de49ec0b6d6f7d58aed3a2f5c6c3\"}, \"mark\": {\"type\": \"line\", \"color\": \"black\", \"opacity\": 1, \"size\": 0.5}, \"encoding\": {\"x\": {\"type\": \"quantitative\", \"field\": \"\"}, \"y\": {\"type\": \"quantitative\", \"axis\": {\"orient\": \"left\", \"title\": \"\"}, \"field\": \"zero\", \"scale\": {\"domain\": [-0.0909029170870781, 0], \"zero\": true}}}}, {\"data\": {\"name\": \"data-f6cb2c7f022597bac5511786b2a4732e\"}, \"mark\": {\"type\": \"area\", \"clip\": false, \"color\": \"black\", \"fillOpacity\": 0.06, \"orient\": \"horizontal\", \"stroke\": \"black\", \"strokeOpacity\": 0.7}, \"encoding\": {\"x\": {\"type\": \"quantitative\", \"axis\": {\"labels\": false, \"tickCount\": 0, \"title\": \"\", \"values\": [0]}, \"field\": \"density\", \"stack\": \"center\", \"title\": \"\"}, \"y\": {\"type\": \"quantitative\", \"axis\": {\"orient\": \"left\", \"title\": \"\"}, \"field\": \"slope\", \"scale\": {\"domain\": [-0.0909029170870781, 0], \"zero\": true}, \"title\": \"\"}}, \"transform\": [{\"density\": \"slope\", \"counts\": true, \"extent\": [-0.0909029170870781, -0.04679596796631813], \"as\": [\"slope\", \"density\"]}], \"width\": 30}, {\"data\": {\"name\": \"data-d025de49ec0b6d6f7d58aed3a2f5c6c3\"}, \"mark\": {\"type\": \"line\", \"clip\": true, \"fill\": null, \"opacity\": 0.8}, \"encoding\": {\"color\": {\"type\": \"nominal\", \"field\": \"\"}, \"detail\": {\"type\": \"nominal\", \"field\": \"\"}, \"size\": {\"value\": 1.0}, \"x\": {\"type\": \"quantitative\", \"field\": \"\"}, \"y\": {\"type\": \"quantitative\", \"aggregate\": \"mean\", \"axis\": {\"orient\": \"right\"}, \"field\": \"isi diff\", \"scale\": {\"domain\": [-0.016943282802706742, 0.004916638573073128], \"zero\": false}, \"title\": \"isi diff\"}}}, {\"data\": {\"name\": \"data-d025de49ec0b6d6f7d58aed3a2f5c6c3\"}, \"mark\": {\"type\": \"circle\", \"clip\": true, \"filled\": true, \"opacity\": 0}, \"encoding\": {\"color\": {\"type\": \"nominal\", \"field\": \"\"}, \"detail\": {\"type\": \"nominal\", \"field\": \"\"}, \"x\": {\"type\": \"quantitative\", \"field\": \"\"}, \"y\": {\"type\": \"quantitative\", \"aggregate\": \"mean\", \"axis\": {\"orient\": \"right\", \"title\": \"\"}, \"field\": \"isi diff\", \"scale\": {\"domain\": [-0.016943282802706742, 0.004916638573073128], \"zero\": false}}}}, {\"data\": {\"name\": \"data-d025de49ec0b6d6f7d58aed3a2f5c6c3\"}, \"mark\": {\"type\": \"boxplot\", \"clip\": true, \"color\": \"black\", \"median\": {\"color\": \"red\", \"strokeWidth\": 20}, \"opacity\": 0.3, \"size\": 9}, \"encoding\": {\"x\": {\"type\": \"quantitative\", \"field\": \"\"}, \"y\": {\"type\": \"quantitative\", \"axis\": {\"orient\": \"right\", \"title\": \"\"}, \"field\": \"isi diff\", \"scale\": {\"domain\": [-0.016943282802706742, 0.004916638573073128], \"zero\": false}}}}], \"resolve\": {\"scale\": {\"y\": \"independent\"}}, \"$schema\": \"https://vega.github.io/schema/vega-lite/v4.8.1.json\", \"datasets\": {\"data-d025de49ec0b6d6f7d58aed3a2f5c6c3\": [{\"mouse\": 0, \"i_trial\": 0, \"combined_condition\": 1.0, \"isi diff\": -0.02479458000148413, \"mu_intercept_per_group higher interval\": 16.18404769897461, \"mu_intercept_per_group lower interval\": 6.218565464019775, \"mu_intercept_per_group center interval\": 8.992014878196642, \"mu_intercept_per_group higher interval75\": 13.148079872131348, \"mu_intercept_per_group lower interval75\": 7.265211582183838, \"sigma_intercept_per_group higher interval\": 0.38656166195869446, \"sigma_intercept_per_group lower interval\": 0.14417333900928497, \"sigma_intercept_per_group center interval\": 0.252084344625473, \"sigma_obs higher interval\": 177.4834442138672, \"sigma_obs lower interval\": 142.7471466064453, \"sigma_obs center interval\": 160.30035400390625, \"higher interval\": -0.04679596796631813, \"lower interval\": -0.0909029170870781, \"center interval\": -0.0717964768409729, \"zero\": 0}, {\"mouse\": 0, \"i_trial\": 1, \"combined_condition\": 1.0, \"isi diff\": -0.009628439322768093, \"mu_intercept_per_group higher interval\": 16.18404769897461, \"mu_intercept_per_group lower interval\": 6.218565464019775, \"mu_intercept_per_group center interval\": 8.992014878196642, \"mu_intercept_per_group higher interval75\": 13.148079872131348, \"mu_intercept_per_group lower interval75\": 7.265211582183838, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null, \"zero\": 0}, {\"mouse\": 0, \"i_trial\": 2, \"combined_condition\": 1.0, \"isi diff\": -0.007675217980296772, \"mu_intercept_per_group higher interval\": 16.18404769897461, \"mu_intercept_per_group lower interval\": 6.218565464019775, \"mu_intercept_per_group center interval\": 8.992014878196642, \"mu_intercept_per_group higher interval75\": 13.148079872131348, \"mu_intercept_per_group lower interval75\": 7.265211582183838, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null, \"zero\": 0}, {\"mouse\": 0, \"i_trial\": 3, \"combined_condition\": 1.0, \"isi diff\": -0.019470606761066316, \"mu_intercept_per_group higher interval\": 16.18404769897461, \"mu_intercept_per_group lower interval\": 6.218565464019775, \"mu_intercept_per_group center interval\": 8.992014878196642, \"mu_intercept_per_group higher interval75\": 13.148079872131348, \"mu_intercept_per_group lower interval75\": 7.265211582183838, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null, \"zero\": 0}, {\"mouse\": 0, \"i_trial\": 4, \"combined_condition\": 1.0, \"isi diff\": -0.016810265752266768, \"mu_intercept_per_group higher interval\": 16.18404769897461, \"mu_intercept_per_group lower interval\": 6.218565464019775, \"mu_intercept_per_group center interval\": 8.992014878196642, \"mu_intercept_per_group higher interval75\": 13.148079872131348, \"mu_intercept_per_group lower interval75\": 7.265211582183838, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null, \"zero\": 0}, {\"mouse\": 0, \"i_trial\": 5, \"combined_condition\": 1.0, \"isi diff\": -0.026662491361946296, \"mu_intercept_per_group higher interval\": 16.18404769897461, \"mu_intercept_per_group lower interval\": 6.218565464019775, \"mu_intercept_per_group center interval\": 8.992014878196642, \"mu_intercept_per_group higher interval75\": 13.148079872131348, \"mu_intercept_per_group lower interval75\": 7.265211582183838, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null, \"zero\": 0}, {\"mouse\": 0, \"i_trial\": 6, \"combined_condition\": 1.0, \"isi diff\": -0.004499483691862302, \"mu_intercept_per_group higher interval\": 16.18404769897461, \"mu_intercept_per_group lower interval\": 6.218565464019775, \"mu_intercept_per_group center interval\": 8.992014878196642, \"mu_intercept_per_group higher interval75\": 13.148079872131348, \"mu_intercept_per_group lower interval75\": 7.265211582183838, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null, \"zero\": 0}, {\"mouse\": 0, \"i_trial\": 7, \"combined_condition\": 1.0, \"isi diff\": -0.010828598358850416, \"mu_intercept_per_group higher interval\": 16.18404769897461, \"mu_intercept_per_group lower interval\": 6.218565464019775, \"mu_intercept_per_group center interval\": 8.992014878196642, \"mu_intercept_per_group higher interval75\": 13.148079872131348, \"mu_intercept_per_group lower interval75\": 7.265211582183838, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null, \"zero\": 0}, {\"mouse\": 0, \"i_trial\": 8, \"combined_condition\": 1.0, \"isi diff\": -0.013445579368663085, \"mu_intercept_per_group higher interval\": 16.18404769897461, \"mu_intercept_per_group lower interval\": 6.218565464019775, \"mu_intercept_per_group center interval\": 8.992014878196642, \"mu_intercept_per_group higher interval75\": 13.148079872131348, \"mu_intercept_per_group lower interval75\": 7.265211582183838, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null, \"zero\": 0}, {\"mouse\": 0, \"i_trial\": 9, \"combined_condition\": 1.0, \"isi diff\": 0.0060657308986283714, \"mu_intercept_per_group higher interval\": 16.18404769897461, \"mu_intercept_per_group lower interval\": 6.218565464019775, \"mu_intercept_per_group center interval\": 8.992014878196642, \"mu_intercept_per_group higher interval75\": 13.148079872131348, \"mu_intercept_per_group lower interval75\": 7.265211582183838, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null, \"zero\": 0}, {\"mouse\": 1, \"i_trial\": 0, \"combined_condition\": 1.0, \"isi diff\": -0.002859139420849234, \"mu_intercept_per_group higher interval\": 14.839642524719238, \"mu_intercept_per_group lower interval\": 5.237331867218018, \"mu_intercept_per_group center interval\": 8.732004769612104, \"mu_intercept_per_group higher interval75\": 12.590448379516602, \"mu_intercept_per_group lower interval75\": 6.972328186035156, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null, \"zero\": 0}, {\"mouse\": 1, \"i_trial\": 1, \"combined_condition\": 1.0, \"isi diff\": 0.0002689321736338013, \"mu_intercept_per_group higher interval\": 14.839642524719238, \"mu_intercept_per_group lower interval\": 5.237331867218018, \"mu_intercept_per_group center interval\": 8.732004769612104, \"mu_intercept_per_group higher interval75\": 12.590448379516602, \"mu_intercept_per_group lower interval75\": 6.972328186035156, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null, \"zero\": 0}, {\"mouse\": 1, \"i_trial\": 2, \"combined_condition\": 1.0, \"isi diff\": -0.016435501319516627, \"mu_intercept_per_group higher interval\": 14.839642524719238, \"mu_intercept_per_group lower interval\": 5.237331867218018, \"mu_intercept_per_group center interval\": 8.732004769612104, \"mu_intercept_per_group higher interval75\": 12.590448379516602, \"mu_intercept_per_group lower interval75\": 6.972328186035156, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null, \"zero\": 0}, {\"mouse\": 1, \"i_trial\": 3, \"combined_condition\": 1.0, \"isi diff\": -0.015219243188097462, \"mu_intercept_per_group higher interval\": 14.839642524719238, \"mu_intercept_per_group lower interval\": 5.237331867218018, \"mu_intercept_per_group center interval\": 8.732004769612104, \"mu_intercept_per_group higher interval75\": 12.590448379516602, \"mu_intercept_per_group lower interval75\": 6.972328186035156, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null, \"zero\": 0}, {\"mouse\": 1, \"i_trial\": 4, \"combined_condition\": 1.0, \"isi diff\": -0.016146398059977182, \"mu_intercept_per_group higher interval\": 14.839642524719238, \"mu_intercept_per_group lower interval\": 5.237331867218018, \"mu_intercept_per_group center interval\": 8.732004769612104, \"mu_intercept_per_group higher interval75\": 12.590448379516602, \"mu_intercept_per_group lower interval75\": 6.972328186035156, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null, \"zero\": 0}, {\"mouse\": 1, \"i_trial\": 5, \"combined_condition\": 1.0, \"isi diff\": -0.009665224159360358, \"mu_intercept_per_group higher interval\": 14.839642524719238, \"mu_intercept_per_group lower interval\": 5.237331867218018, \"mu_intercept_per_group center interval\": 8.732004769612104, \"mu_intercept_per_group higher interval75\": 12.590448379516602, \"mu_intercept_per_group lower interval75\": 6.972328186035156, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null, \"zero\": 0}, {\"mouse\": 1, \"i_trial\": 6, \"combined_condition\": 1.0, \"isi diff\": -0.005789199781863312, \"mu_intercept_per_group higher interval\": 14.839642524719238, \"mu_intercept_per_group lower interval\": 5.237331867218018, \"mu_intercept_per_group center interval\": 8.732004769612104, \"mu_intercept_per_group higher interval75\": 12.590448379516602, \"mu_intercept_per_group lower interval75\": 6.972328186035156, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null, \"zero\": 0}, {\"mouse\": 1, \"i_trial\": 7, \"combined_condition\": 1.0, \"isi diff\": -0.013040717974484833, \"mu_intercept_per_group higher interval\": 14.839642524719238, \"mu_intercept_per_group lower interval\": 5.237331867218018, \"mu_intercept_per_group center interval\": 8.732004769612104, \"mu_intercept_per_group higher interval75\": 12.590448379516602, \"mu_intercept_per_group lower interval75\": 6.972328186035156, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null, \"zero\": 0}, {\"mouse\": 1, \"i_trial\": 8, \"combined_condition\": 1.0, \"isi diff\": 0.0003810962244747834, \"mu_intercept_per_group higher interval\": 14.839642524719238, \"mu_intercept_per_group lower interval\": 5.237331867218018, \"mu_intercept_per_group center interval\": 8.732004769612104, \"mu_intercept_per_group higher interval75\": 12.590448379516602, \"mu_intercept_per_group lower interval75\": 6.972328186035156, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null, \"zero\": 0}, {\"mouse\": 1, \"i_trial\": 9, \"combined_condition\": 1.0, \"isi diff\": 0.0013664801273036153, \"mu_intercept_per_group higher interval\": 14.839642524719238, \"mu_intercept_per_group lower interval\": 5.237331867218018, \"mu_intercept_per_group center interval\": 8.732004769612104, \"mu_intercept_per_group higher interval75\": 12.590448379516602, \"mu_intercept_per_group lower interval75\": 6.972328186035156, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null, \"zero\": 0}, {\"mouse\": 2, \"i_trial\": 0, \"combined_condition\": 1.0, \"isi diff\": -0.005990947726142351, \"mu_intercept_per_group higher interval\": 15.1626615524292, \"mu_intercept_per_group lower interval\": 5.877790451049805, \"mu_intercept_per_group center interval\": 8.344816340599209, \"mu_intercept_per_group higher interval75\": 12.200968742370605, \"mu_intercept_per_group lower interval75\": 6.757171630859375, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null, \"zero\": 0}, {\"mouse\": 2, \"i_trial\": 1, \"combined_condition\": 1.0, \"isi diff\": -0.01987262981443006, \"mu_intercept_per_group higher interval\": 15.1626615524292, \"mu_intercept_per_group lower interval\": 5.877790451049805, \"mu_intercept_per_group center interval\": 8.344816340599209, \"mu_intercept_per_group higher interval75\": 12.200968742370605, \"mu_intercept_per_group lower interval75\": 6.757171630859375, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null, \"zero\": 0}, {\"mouse\": 2, \"i_trial\": 2, \"combined_condition\": 1.0, \"isi diff\": 0.007665403975962326, \"mu_intercept_per_group higher interval\": 15.1626615524292, \"mu_intercept_per_group lower interval\": 5.877790451049805, \"mu_intercept_per_group center interval\": 8.344816340599209, \"mu_intercept_per_group higher interval75\": 12.200968742370605, \"mu_intercept_per_group lower interval75\": 6.757171630859375, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null, \"zero\": 0}, {\"mouse\": 2, \"i_trial\": 3, \"combined_condition\": 1.0, \"isi diff\": -0.004949882089668511, \"mu_intercept_per_group higher interval\": 15.1626615524292, \"mu_intercept_per_group lower interval\": 5.877790451049805, \"mu_intercept_per_group center interval\": 8.344816340599209, \"mu_intercept_per_group higher interval75\": 12.200968742370605, \"mu_intercept_per_group lower interval75\": 6.757171630859375, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null, \"zero\": 0}, {\"mouse\": 2, \"i_trial\": 4, \"combined_condition\": 1.0, \"isi diff\": -0.006453527535855395, \"mu_intercept_per_group higher interval\": 15.1626615524292, \"mu_intercept_per_group lower interval\": 5.877790451049805, \"mu_intercept_per_group center interval\": 8.344816340599209, \"mu_intercept_per_group higher interval75\": 12.200968742370605, \"mu_intercept_per_group lower interval75\": 6.757171630859375, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null, \"zero\": 0}, {\"mouse\": 2, \"i_trial\": 5, \"combined_condition\": 1.0, \"isi diff\": -0.009582249175342318, \"mu_intercept_per_group higher interval\": 15.1626615524292, \"mu_intercept_per_group lower interval\": 5.877790451049805, \"mu_intercept_per_group center interval\": 8.344816340599209, \"mu_intercept_per_group higher interval75\": 12.200968742370605, \"mu_intercept_per_group lower interval75\": 6.757171630859375, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null, \"zero\": 0}, {\"mouse\": 2, \"i_trial\": 6, \"combined_condition\": 1.0, \"isi diff\": 0.0060515796196635024, \"mu_intercept_per_group higher interval\": 15.1626615524292, \"mu_intercept_per_group lower interval\": 5.877790451049805, \"mu_intercept_per_group center interval\": 8.344816340599209, \"mu_intercept_per_group higher interval75\": 12.200968742370605, \"mu_intercept_per_group lower interval75\": 6.757171630859375, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null, \"zero\": 0}, {\"mouse\": 2, \"i_trial\": 7, \"combined_condition\": 1.0, \"isi diff\": -0.004506938062080031, \"mu_intercept_per_group higher interval\": 15.1626615524292, \"mu_intercept_per_group lower interval\": 5.877790451049805, \"mu_intercept_per_group center interval\": 8.344816340599209, \"mu_intercept_per_group higher interval75\": 12.200968742370605, \"mu_intercept_per_group lower interval75\": 6.757171630859375, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null, \"zero\": 0}, {\"mouse\": 2, \"i_trial\": 8, \"combined_condition\": 1.0, \"isi diff\": -0.0043873108131297495, \"mu_intercept_per_group higher interval\": 15.1626615524292, \"mu_intercept_per_group lower interval\": 5.877790451049805, \"mu_intercept_per_group center interval\": 8.344816340599209, \"mu_intercept_per_group higher interval75\": 12.200968742370605, \"mu_intercept_per_group lower interval75\": 6.757171630859375, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null, \"zero\": 0}, {\"mouse\": 2, \"i_trial\": 9, \"combined_condition\": 1.0, \"isi diff\": -0.014142994035252696, \"mu_intercept_per_group higher interval\": 15.1626615524292, \"mu_intercept_per_group lower interval\": 5.877790451049805, \"mu_intercept_per_group center interval\": 8.344816340599209, \"mu_intercept_per_group higher interval75\": 12.200968742370605, \"mu_intercept_per_group lower interval75\": 6.757171630859375, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null, \"zero\": 0}, {\"mouse\": 3, \"i_trial\": 0, \"combined_condition\": 1.0, \"isi diff\": -0.0009790772189769564, \"mu_intercept_per_group higher interval\": 14.177671432495117, \"mu_intercept_per_group lower interval\": 5.504540920257568, \"mu_intercept_per_group center interval\": 7.911179458722472, \"mu_intercept_per_group higher interval75\": 11.60405445098877, \"mu_intercept_per_group lower interval75\": 6.4652862548828125, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null, \"zero\": 0}, {\"mouse\": 3, \"i_trial\": 1, \"combined_condition\": 1.0, \"isi diff\": -0.0015524532216731682, \"mu_intercept_per_group higher interval\": 14.177671432495117, \"mu_intercept_per_group lower interval\": 5.504540920257568, \"mu_intercept_per_group center interval\": 7.911179458722472, \"mu_intercept_per_group higher interval75\": 11.60405445098877, \"mu_intercept_per_group lower interval75\": 6.4652862548828125, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null, \"zero\": 0}, {\"mouse\": 3, \"i_trial\": 2, \"combined_condition\": 1.0, \"isi diff\": -0.008658776401152667, \"mu_intercept_per_group higher interval\": 14.177671432495117, \"mu_intercept_per_group lower interval\": 5.504540920257568, \"mu_intercept_per_group center interval\": 7.911179458722472, \"mu_intercept_per_group higher interval75\": 11.60405445098877, \"mu_intercept_per_group lower interval75\": 6.4652862548828125, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null, \"zero\": 0}, {\"mouse\": 3, \"i_trial\": 3, \"combined_condition\": 1.0, \"isi diff\": 0.0023967097082840533, \"mu_intercept_per_group higher interval\": 14.177671432495117, \"mu_intercept_per_group lower interval\": 5.504540920257568, \"mu_intercept_per_group center interval\": 7.911179458722472, \"mu_intercept_per_group higher interval75\": 11.60405445098877, \"mu_intercept_per_group lower interval75\": 6.4652862548828125, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null, \"zero\": 0}, {\"mouse\": 3, \"i_trial\": 4, \"combined_condition\": 1.0, \"isi diff\": -0.002649269967461343, \"mu_intercept_per_group higher interval\": 14.177671432495117, \"mu_intercept_per_group lower interval\": 5.504540920257568, \"mu_intercept_per_group center interval\": 7.911179458722472, \"mu_intercept_per_group higher interval75\": 11.60405445098877, \"mu_intercept_per_group lower interval75\": 6.4652862548828125, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null, \"zero\": 0}, {\"mouse\": 3, \"i_trial\": 5, \"combined_condition\": 1.0, \"isi diff\": -0.0002716055406324219, \"mu_intercept_per_group higher interval\": 14.177671432495117, \"mu_intercept_per_group lower interval\": 5.504540920257568, \"mu_intercept_per_group center interval\": 7.911179458722472, \"mu_intercept_per_group higher interval75\": 11.60405445098877, \"mu_intercept_per_group lower interval75\": 6.4652862548828125, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null, \"zero\": 0}, {\"mouse\": 3, \"i_trial\": 6, \"combined_condition\": 1.0, \"isi diff\": -0.003619534311118902, \"mu_intercept_per_group higher interval\": 14.177671432495117, \"mu_intercept_per_group lower interval\": 5.504540920257568, \"mu_intercept_per_group center interval\": 7.911179458722472, \"mu_intercept_per_group higher interval75\": 11.60405445098877, \"mu_intercept_per_group lower interval75\": 6.4652862548828125, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null, \"zero\": 0}, {\"mouse\": 3, \"i_trial\": 7, \"combined_condition\": 1.0, \"isi diff\": -0.0128942656504401, \"mu_intercept_per_group higher interval\": 14.177671432495117, \"mu_intercept_per_group lower interval\": 5.504540920257568, \"mu_intercept_per_group center interval\": 7.911179458722472, \"mu_intercept_per_group higher interval75\": 11.60405445098877, \"mu_intercept_per_group lower interval75\": 6.4652862548828125, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null, \"zero\": 0}, {\"mouse\": 3, \"i_trial\": 8, \"combined_condition\": 1.0, \"isi diff\": 0.00025177998987768735, \"mu_intercept_per_group higher interval\": 14.177671432495117, \"mu_intercept_per_group lower interval\": 5.504540920257568, \"mu_intercept_per_group center interval\": 7.911179458722472, \"mu_intercept_per_group higher interval75\": 11.60405445098877, \"mu_intercept_per_group lower interval75\": 6.4652862548828125, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null, \"zero\": 0}, {\"mouse\": 3, \"i_trial\": 9, \"combined_condition\": 1.0, \"isi diff\": -0.012500526112486164, \"mu_intercept_per_group higher interval\": 14.177671432495117, \"mu_intercept_per_group lower interval\": 5.504540920257568, \"mu_intercept_per_group center interval\": 7.911179458722472, \"mu_intercept_per_group higher interval75\": 11.60405445098877, \"mu_intercept_per_group lower interval75\": 6.4652862548828125, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null, \"zero\": 0}, {\"mouse\": 4, \"i_trial\": 0, \"combined_condition\": 1.0, \"isi diff\": -0.011166319577229133, \"mu_intercept_per_group higher interval\": 13.148555755615234, \"mu_intercept_per_group lower interval\": 4.592223167419434, \"mu_intercept_per_group center interval\": 7.7315916726365685, \"mu_intercept_per_group higher interval75\": 11.322296142578125, \"mu_intercept_per_group lower interval75\": 6.263970851898193, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null, \"zero\": 0}, {\"mouse\": 4, \"i_trial\": 1, \"combined_condition\": 1.0, \"isi diff\": -0.013119066637179114, \"mu_intercept_per_group higher interval\": 13.148555755615234, \"mu_intercept_per_group lower interval\": 4.592223167419434, \"mu_intercept_per_group center interval\": 7.7315916726365685, \"mu_intercept_per_group higher interval75\": 11.322296142578125, \"mu_intercept_per_group lower interval75\": 6.263970851898193, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null, \"zero\": 0}, {\"mouse\": 4, \"i_trial\": 2, \"combined_condition\": 1.0, \"isi diff\": -0.004381552425624748, \"mu_intercept_per_group higher interval\": 13.148555755615234, \"mu_intercept_per_group lower interval\": 4.592223167419434, \"mu_intercept_per_group center interval\": 7.7315916726365685, \"mu_intercept_per_group higher interval75\": 11.322296142578125, \"mu_intercept_per_group lower interval75\": 6.263970851898193, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null, \"zero\": 0}, {\"mouse\": 4, \"i_trial\": 3, \"combined_condition\": 1.0, \"isi diff\": -0.010853724555748089, \"mu_intercept_per_group higher interval\": 13.148555755615234, \"mu_intercept_per_group lower interval\": 4.592223167419434, \"mu_intercept_per_group center interval\": 7.7315916726365685, \"mu_intercept_per_group higher interval75\": 11.322296142578125, \"mu_intercept_per_group lower interval75\": 6.263970851898193, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null, \"zero\": 0}, {\"mouse\": 4, \"i_trial\": 4, \"combined_condition\": 1.0, \"isi diff\": -0.006679170682983952, \"mu_intercept_per_group higher interval\": 13.148555755615234, \"mu_intercept_per_group lower interval\": 4.592223167419434, \"mu_intercept_per_group center interval\": 7.7315916726365685, \"mu_intercept_per_group higher interval75\": 11.322296142578125, \"mu_intercept_per_group lower interval75\": 6.263970851898193, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null, \"zero\": 0}, {\"mouse\": 4, \"i_trial\": 5, \"combined_condition\": 1.0, \"isi diff\": 0.0025365625543889367, \"mu_intercept_per_group higher interval\": 13.148555755615234, \"mu_intercept_per_group lower interval\": 4.592223167419434, \"mu_intercept_per_group center interval\": 7.7315916726365685, \"mu_intercept_per_group higher interval75\": 11.322296142578125, \"mu_intercept_per_group lower interval75\": 6.263970851898193, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null, \"zero\": 0}, {\"mouse\": 4, \"i_trial\": 6, \"combined_condition\": 1.0, \"isi diff\": -0.004313607627590976, \"mu_intercept_per_group higher interval\": 13.148555755615234, \"mu_intercept_per_group lower interval\": 4.592223167419434, \"mu_intercept_per_group center interval\": 7.7315916726365685, \"mu_intercept_per_group higher interval75\": 11.322296142578125, \"mu_intercept_per_group lower interval75\": 6.263970851898193, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null, \"zero\": 0}, {\"mouse\": 4, \"i_trial\": 7, \"combined_condition\": 1.0, \"isi diff\": -0.0012454750503224435, \"mu_intercept_per_group higher interval\": 13.148555755615234, \"mu_intercept_per_group lower interval\": 4.592223167419434, \"mu_intercept_per_group center interval\": 7.7315916726365685, \"mu_intercept_per_group higher interval75\": 11.322296142578125, \"mu_intercept_per_group lower interval75\": 6.263970851898193, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null, \"zero\": 0}, {\"mouse\": 4, \"i_trial\": 8, \"combined_condition\": 1.0, \"isi diff\": -0.009617124226019604, \"mu_intercept_per_group higher interval\": 13.148555755615234, \"mu_intercept_per_group lower interval\": 4.592223167419434, \"mu_intercept_per_group center interval\": 7.7315916726365685, \"mu_intercept_per_group higher interval75\": 11.322296142578125, \"mu_intercept_per_group lower interval75\": 6.263970851898193, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null, \"zero\": 0}, {\"mouse\": 4, \"i_trial\": 9, \"combined_condition\": 1.0, \"isi diff\": -0.0026579577685499, \"mu_intercept_per_group higher interval\": 13.148555755615234, \"mu_intercept_per_group lower interval\": 4.592223167419434, \"mu_intercept_per_group center interval\": 7.7315916726365685, \"mu_intercept_per_group higher interval75\": 11.322296142578125, \"mu_intercept_per_group lower interval75\": 6.263970851898193, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null, \"zero\": 0}, {\"mouse\": 5, \"i_trial\": 0, \"combined_condition\": 1.0, \"isi diff\": 0.0010088220634282621, \"mu_intercept_per_group higher interval\": 12.891270637512207, \"mu_intercept_per_group lower interval\": 4.949382305145264, \"mu_intercept_per_group center interval\": 8.652005923679098, \"mu_intercept_per_group higher interval75\": 10.720244407653809, \"mu_intercept_per_group lower interval75\": 5.91101598739624, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null, \"zero\": 0}, {\"mouse\": 5, \"i_trial\": 1, \"combined_condition\": 1.0, \"isi diff\": -0.000888389330914098, \"mu_intercept_per_group higher interval\": 12.891270637512207, \"mu_intercept_per_group lower interval\": 4.949382305145264, \"mu_intercept_per_group center interval\": 8.652005923679098, \"mu_intercept_per_group higher interval75\": 10.720244407653809, \"mu_intercept_per_group lower interval75\": 5.91101598739624, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null, \"zero\": 0}, {\"mouse\": 5, \"i_trial\": 2, \"combined_condition\": 1.0, \"isi diff\": -0.002060745721824707, \"mu_intercept_per_group higher interval\": 12.891270637512207, \"mu_intercept_per_group lower interval\": 4.949382305145264, \"mu_intercept_per_group center interval\": 8.652005923679098, \"mu_intercept_per_group higher interval75\": 10.720244407653809, \"mu_intercept_per_group lower interval75\": 5.91101598739624, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null, \"zero\": 0}, {\"mouse\": 5, \"i_trial\": 3, \"combined_condition\": 1.0, \"isi diff\": -0.0016394338597713956, \"mu_intercept_per_group higher interval\": 12.891270637512207, \"mu_intercept_per_group lower interval\": 4.949382305145264, \"mu_intercept_per_group center interval\": 8.652005923679098, \"mu_intercept_per_group higher interval75\": 10.720244407653809, \"mu_intercept_per_group lower interval75\": 5.91101598739624, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null, \"zero\": 0}, {\"mouse\": 5, \"i_trial\": 4, \"combined_condition\": 1.0, \"isi diff\": 0.0050917117222563715, \"mu_intercept_per_group higher interval\": 12.891270637512207, \"mu_intercept_per_group lower interval\": 4.949382305145264, \"mu_intercept_per_group center interval\": 8.652005923679098, \"mu_intercept_per_group higher interval75\": 10.720244407653809, \"mu_intercept_per_group lower interval75\": 5.91101598739624, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null, \"zero\": 0}, {\"mouse\": 5, \"i_trial\": 5, \"combined_condition\": 1.0, \"isi diff\": -0.008851035976491436, \"mu_intercept_per_group higher interval\": 12.891270637512207, \"mu_intercept_per_group lower interval\": 4.949382305145264, \"mu_intercept_per_group center interval\": 8.652005923679098, \"mu_intercept_per_group higher interval75\": 10.720244407653809, \"mu_intercept_per_group lower interval75\": 5.91101598739624, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null, \"zero\": 0}, {\"mouse\": 5, \"i_trial\": 6, \"combined_condition\": 1.0, \"isi diff\": 0.0049074241968003265, \"mu_intercept_per_group higher interval\": 12.891270637512207, \"mu_intercept_per_group lower interval\": 4.949382305145264, \"mu_intercept_per_group center interval\": 8.652005923679098, \"mu_intercept_per_group higher interval75\": 10.720244407653809, \"mu_intercept_per_group lower interval75\": 5.91101598739624, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null, \"zero\": 0}, {\"mouse\": 5, \"i_trial\": 7, \"combined_condition\": 1.0, \"isi diff\": 0.0034039513594358167, \"mu_intercept_per_group higher interval\": 12.891270637512207, \"mu_intercept_per_group lower interval\": 4.949382305145264, \"mu_intercept_per_group center interval\": 8.652005923679098, \"mu_intercept_per_group higher interval75\": 10.720244407653809, \"mu_intercept_per_group lower interval75\": 5.91101598739624, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null, \"zero\": 0}, {\"mouse\": 5, \"i_trial\": 8, \"combined_condition\": 1.0, \"isi diff\": -0.004397315558320583, \"mu_intercept_per_group higher interval\": 12.891270637512207, \"mu_intercept_per_group lower interval\": 4.949382305145264, \"mu_intercept_per_group center interval\": 8.652005923679098, \"mu_intercept_per_group higher interval75\": 10.720244407653809, \"mu_intercept_per_group lower interval75\": 5.91101598739624, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null, \"zero\": 0}, {\"mouse\": 5, \"i_trial\": 9, \"combined_condition\": 1.0, \"isi diff\": -0.0032173221498673216, \"mu_intercept_per_group higher interval\": 12.891270637512207, \"mu_intercept_per_group lower interval\": 4.949382305145264, \"mu_intercept_per_group center interval\": 8.652005923679098, \"mu_intercept_per_group higher interval75\": 10.720244407653809, \"mu_intercept_per_group lower interval75\": 5.91101598739624, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null, \"zero\": 0}, {\"mouse\": 6, \"i_trial\": 0, \"combined_condition\": 1.0, \"isi diff\": -0.003197894480321664, \"mu_intercept_per_group higher interval\": 11.812211990356445, \"mu_intercept_per_group lower interval\": 4.320974826812744, \"mu_intercept_per_group center interval\": 6.964838225627318, \"mu_intercept_per_group higher interval75\": 10.06528377532959, \"mu_intercept_per_group lower interval75\": 5.639249324798584, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null, \"zero\": 0}, {\"mouse\": 6, \"i_trial\": 1, \"combined_condition\": 1.0, \"isi diff\": -0.002947918826699321, \"mu_intercept_per_group higher interval\": 11.812211990356445, \"mu_intercept_per_group lower interval\": 4.320974826812744, \"mu_intercept_per_group center interval\": 6.964838225627318, \"mu_intercept_per_group higher interval75\": 10.06528377532959, \"mu_intercept_per_group lower interval75\": 5.639249324798584, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null, \"zero\": 0}, {\"mouse\": 6, \"i_trial\": 2, \"combined_condition\": 1.0, \"isi diff\": -0.004252557541472697, \"mu_intercept_per_group higher interval\": 11.812211990356445, \"mu_intercept_per_group lower interval\": 4.320974826812744, \"mu_intercept_per_group center interval\": 6.964838225627318, \"mu_intercept_per_group higher interval75\": 10.06528377532959, \"mu_intercept_per_group lower interval75\": 5.639249324798584, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null, \"zero\": 0}, {\"mouse\": 6, \"i_trial\": 3, \"combined_condition\": 1.0, \"isi diff\": 0.003093502770576448, \"mu_intercept_per_group higher interval\": 11.812211990356445, \"mu_intercept_per_group lower interval\": 4.320974826812744, \"mu_intercept_per_group center interval\": 6.964838225627318, \"mu_intercept_per_group higher interval75\": 10.06528377532959, \"mu_intercept_per_group lower interval75\": 5.639249324798584, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null, \"zero\": 0}, {\"mouse\": 6, \"i_trial\": 4, \"combined_condition\": 1.0, \"isi diff\": 0.00028826851737791953, \"mu_intercept_per_group higher interval\": 11.812211990356445, \"mu_intercept_per_group lower interval\": 4.320974826812744, \"mu_intercept_per_group center interval\": 6.964838225627318, \"mu_intercept_per_group higher interval75\": 10.06528377532959, \"mu_intercept_per_group lower interval75\": 5.639249324798584, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null, \"zero\": 0}, {\"mouse\": 6, \"i_trial\": 5, \"combined_condition\": 1.0, \"isi diff\": -0.0014435546232545518, \"mu_intercept_per_group higher interval\": 11.812211990356445, \"mu_intercept_per_group lower interval\": 4.320974826812744, \"mu_intercept_per_group center interval\": 6.964838225627318, \"mu_intercept_per_group higher interval75\": 10.06528377532959, \"mu_intercept_per_group lower interval75\": 5.639249324798584, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null, \"zero\": 0}, {\"mouse\": 6, \"i_trial\": 6, \"combined_condition\": 1.0, \"isi diff\": -0.004246692970477112, \"mu_intercept_per_group higher interval\": 11.812211990356445, \"mu_intercept_per_group lower interval\": 4.320974826812744, \"mu_intercept_per_group center interval\": 6.964838225627318, \"mu_intercept_per_group higher interval75\": 10.06528377532959, \"mu_intercept_per_group lower interval75\": 5.639249324798584, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null, \"zero\": 0}, {\"mouse\": 6, \"i_trial\": 7, \"combined_condition\": 1.0, \"isi diff\": -0.0014877123430819261, \"mu_intercept_per_group higher interval\": 11.812211990356445, \"mu_intercept_per_group lower interval\": 4.320974826812744, \"mu_intercept_per_group center interval\": 6.964838225627318, \"mu_intercept_per_group higher interval75\": 10.06528377532959, \"mu_intercept_per_group lower interval75\": 5.639249324798584, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null, \"zero\": 0}, {\"mouse\": 6, \"i_trial\": 8, \"combined_condition\": 1.0, \"isi diff\": -0.0035447624859577045, \"mu_intercept_per_group higher interval\": 11.812211990356445, \"mu_intercept_per_group lower interval\": 4.320974826812744, \"mu_intercept_per_group center interval\": 6.964838225627318, \"mu_intercept_per_group higher interval75\": 10.06528377532959, \"mu_intercept_per_group lower interval75\": 5.639249324798584, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null, \"zero\": 0}, {\"mouse\": 6, \"i_trial\": 9, \"combined_condition\": 1.0, \"isi diff\": -0.0039004706558450064, \"mu_intercept_per_group higher interval\": 11.812211990356445, \"mu_intercept_per_group lower interval\": 4.320974826812744, \"mu_intercept_per_group center interval\": 6.964838225627318, \"mu_intercept_per_group higher interval75\": 10.06528377532959, \"mu_intercept_per_group lower interval75\": 5.639249324798584, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null, \"zero\": 0}, {\"mouse\": 7, \"i_trial\": 0, \"combined_condition\": 1.0, \"isi diff\": 0.0003582548747145496, \"mu_intercept_per_group higher interval\": 11.234159469604492, \"mu_intercept_per_group lower interval\": 4.253227710723877, \"mu_intercept_per_group center interval\": 6.183072286425158, \"mu_intercept_per_group higher interval75\": 9.413721084594727, \"mu_intercept_per_group lower interval75\": 5.209953784942627, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null, \"zero\": 0}, {\"mouse\": 7, \"i_trial\": 1, \"combined_condition\": 1.0, \"isi diff\": 0.0024590749825521216, \"mu_intercept_per_group higher interval\": 11.234159469604492, \"mu_intercept_per_group lower interval\": 4.253227710723877, \"mu_intercept_per_group center interval\": 6.183072286425158, \"mu_intercept_per_group higher interval75\": 9.413721084594727, \"mu_intercept_per_group lower interval75\": 5.209953784942627, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null, \"zero\": 0}, {\"mouse\": 7, \"i_trial\": 2, \"combined_condition\": 1.0, \"isi diff\": -0.001887033357629249, \"mu_intercept_per_group higher interval\": 11.234159469604492, \"mu_intercept_per_group lower interval\": 4.253227710723877, \"mu_intercept_per_group center interval\": 6.183072286425158, \"mu_intercept_per_group higher interval75\": 9.413721084594727, \"mu_intercept_per_group lower interval75\": 5.209953784942627, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null, \"zero\": 0}, {\"mouse\": 7, \"i_trial\": 3, \"combined_condition\": 1.0, \"isi diff\": 0.0017632869514385557, \"mu_intercept_per_group higher interval\": 11.234159469604492, \"mu_intercept_per_group lower interval\": 4.253227710723877, \"mu_intercept_per_group center interval\": 6.183072286425158, \"mu_intercept_per_group higher interval75\": 9.413721084594727, \"mu_intercept_per_group lower interval75\": 5.209953784942627, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null, \"zero\": 0}, {\"mouse\": 7, \"i_trial\": 4, \"combined_condition\": 1.0, \"isi diff\": -0.0027063879976900983, \"mu_intercept_per_group higher interval\": 11.234159469604492, \"mu_intercept_per_group lower interval\": 4.253227710723877, \"mu_intercept_per_group center interval\": 6.183072286425158, \"mu_intercept_per_group higher interval75\": 9.413721084594727, \"mu_intercept_per_group lower interval75\": 5.209953784942627, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null, \"zero\": 0}, {\"mouse\": 7, \"i_trial\": 5, \"combined_condition\": 1.0, \"isi diff\": -0.0017567169362001575, \"mu_intercept_per_group higher interval\": 11.234159469604492, \"mu_intercept_per_group lower interval\": 4.253227710723877, \"mu_intercept_per_group center interval\": 6.183072286425158, \"mu_intercept_per_group higher interval75\": 9.413721084594727, \"mu_intercept_per_group lower interval75\": 5.209953784942627, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null, \"zero\": 0}, {\"mouse\": 7, \"i_trial\": 6, \"combined_condition\": 1.0, \"isi diff\": -0.0038185146436793445, \"mu_intercept_per_group higher interval\": 11.234159469604492, \"mu_intercept_per_group lower interval\": 4.253227710723877, \"mu_intercept_per_group center interval\": 6.183072286425158, \"mu_intercept_per_group higher interval75\": 9.413721084594727, \"mu_intercept_per_group lower interval75\": 5.209953784942627, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null, \"zero\": 0}, {\"mouse\": 7, \"i_trial\": 7, \"combined_condition\": 1.0, \"isi diff\": -0.0007148584124114371, \"mu_intercept_per_group higher interval\": 11.234159469604492, \"mu_intercept_per_group lower interval\": 4.253227710723877, \"mu_intercept_per_group center interval\": 6.183072286425158, \"mu_intercept_per_group higher interval75\": 9.413721084594727, \"mu_intercept_per_group lower interval75\": 5.209953784942627, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null, \"zero\": 0}, {\"mouse\": 7, \"i_trial\": 8, \"combined_condition\": 1.0, \"isi diff\": -0.002372270525680814, \"mu_intercept_per_group higher interval\": 11.234159469604492, \"mu_intercept_per_group lower interval\": 4.253227710723877, \"mu_intercept_per_group center interval\": 6.183072286425158, \"mu_intercept_per_group higher interval75\": 9.413721084594727, \"mu_intercept_per_group lower interval75\": 5.209953784942627, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null, \"zero\": 0}, {\"mouse\": 7, \"i_trial\": 9, \"combined_condition\": 1.0, \"isi diff\": 0.00114516329209979, \"mu_intercept_per_group higher interval\": 11.234159469604492, \"mu_intercept_per_group lower interval\": 4.253227710723877, \"mu_intercept_per_group center interval\": 6.183072286425158, \"mu_intercept_per_group higher interval75\": 9.413721084594727, \"mu_intercept_per_group lower interval75\": 5.209953784942627, \"sigma_intercept_per_group higher interval\": null, \"sigma_intercept_per_group lower interval\": null, \"sigma_intercept_per_group center interval\": null, \"sigma_obs higher interval\": null, \"sigma_obs lower interval\": null, \"sigma_obs center interval\": null, \"higher interval\": null, \"lower interval\": null, \"center interval\": null, \"zero\": 0}], \"data-f6cb2c7f022597bac5511786b2a4732e\": [{\"draws\": 0, \"mouse\": 0, \"mu_intercept_per_group\": 9.896717071533203, \"sigma_intercept_per_group\": 0.2629536986351013, \"sigma_obs\": 176.39389038085938, \"slope\": -0.06847206503152847, \"chain\": 0, \"draw\": 0}, {\"draws\": 0, \"mouse\": 1, \"mu_intercept_per_group\": 9.511655807495117, \"sigma_intercept_per_group\": 0.2629536986351013, \"sigma_obs\": 176.39389038085938, \"slope\": -0.06847206503152847, \"chain\": 0, \"draw\": 0}, {\"draws\": 0, \"mouse\": 2, \"mu_intercept_per_group\": 9.294678688049316, \"sigma_intercept_per_group\": 0.2629536986351013, \"sigma_obs\": 176.39389038085938, \"slope\": -0.06847206503152847, \"chain\": 0, \"draw\": 0}, {\"draws\": 0, \"mouse\": 3, \"mu_intercept_per_group\": 8.730052947998047, \"sigma_intercept_per_group\": 0.2629536986351013, \"sigma_obs\": 176.39389038085938, \"slope\": -0.06847206503152847, \"chain\": 0, \"draw\": 0}, {\"draws\": 0, \"mouse\": 4, \"mu_intercept_per_group\": 8.490371704101562, \"sigma_intercept_per_group\": 0.2629536986351013, \"sigma_obs\": 176.39389038085938, \"slope\": -0.06847206503152847, \"chain\": 0, \"draw\": 0}, {\"draws\": 0, \"mouse\": 5, \"mu_intercept_per_group\": 8.147679328918457, \"sigma_intercept_per_group\": 0.2629536986351013, \"sigma_obs\": 176.39389038085938, \"slope\": -0.06847206503152847, \"chain\": 0, \"draw\": 0}, {\"draws\": 0, \"mouse\": 6, \"mu_intercept_per_group\": 7.270181655883789, \"sigma_intercept_per_group\": 0.2629536986351013, \"sigma_obs\": 176.39389038085938, \"slope\": -0.06847206503152847, \"chain\": 0, \"draw\": 0}, {\"draws\": 0, \"mouse\": 7, \"mu_intercept_per_group\": 7.027195930480957, \"sigma_intercept_per_group\": 0.2629536986351013, \"sigma_obs\": 176.39389038085938, \"slope\": -0.06847206503152847, \"chain\": 0, \"draw\": 0}, {\"draws\": 1, \"mouse\": 0, \"mu_intercept_per_group\": 9.920831680297852, \"sigma_intercept_per_group\": 0.2607809603214264, \"sigma_obs\": 177.69735717773438, \"slope\": -0.06714983284473419, \"chain\": 0, \"draw\": 1}, {\"draws\": 1, \"mouse\": 1, \"mu_intercept_per_group\": 9.58041763305664, \"sigma_intercept_per_group\": 0.2607809603214264, \"sigma_obs\": 177.69735717773438, \"slope\": -0.06714983284473419, \"chain\": 0, \"draw\": 1}, {\"draws\": 1, \"mouse\": 2, \"mu_intercept_per_group\": 9.299703598022461, \"sigma_intercept_per_group\": 0.2607809603214264, \"sigma_obs\": 177.69735717773438, \"slope\": -0.06714983284473419, \"chain\": 0, \"draw\": 1}, {\"draws\": 1, \"mouse\": 3, \"mu_intercept_per_group\": 8.99400806427002, \"sigma_intercept_per_group\": 0.2607809603214264, \"sigma_obs\": 177.69735717773438, \"slope\": -0.06714983284473419, \"chain\": 0, \"draw\": 1}, {\"draws\": 1, \"mouse\": 4, \"mu_intercept_per_group\": 8.655484199523926, \"sigma_intercept_per_group\": 0.2607809603214264, \"sigma_obs\": 177.69735717773438, \"slope\": -0.06714983284473419, \"chain\": 0, \"draw\": 1}, {\"draws\": 1, \"mouse\": 5, \"mu_intercept_per_group\": 8.124767303466797, \"sigma_intercept_per_group\": 0.2607809603214264, \"sigma_obs\": 177.69735717773438, \"slope\": -0.06714983284473419, \"chain\": 0, \"draw\": 1}, {\"draws\": 1, \"mouse\": 6, \"mu_intercept_per_group\": 7.420387268066406, \"sigma_intercept_per_group\": 0.2607809603214264, \"sigma_obs\": 177.69735717773438, \"slope\": -0.06714983284473419, \"chain\": 0, \"draw\": 1}, {\"draws\": 1, \"mouse\": 7, \"mu_intercept_per_group\": 7.28603458404541, \"sigma_intercept_per_group\": 0.2607809603214264, \"sigma_obs\": 177.69735717773438, \"slope\": -0.06714983284473419, \"chain\": 0, \"draw\": 1}, {\"draws\": 2, \"mouse\": 0, \"mu_intercept_per_group\": 9.809643745422363, \"sigma_intercept_per_group\": 0.2624515891075134, \"sigma_obs\": 178.27464294433594, \"slope\": -0.06629011034965515, \"chain\": 0, \"draw\": 2}, {\"draws\": 2, \"mouse\": 1, \"mu_intercept_per_group\": 9.431060791015625, \"sigma_intercept_per_group\": 0.2624515891075134, \"sigma_obs\": 178.27464294433594, \"slope\": -0.06629011034965515, \"chain\": 0, \"draw\": 2}, {\"draws\": 2, \"mouse\": 2, \"mu_intercept_per_group\": 9.18285846710205, \"sigma_intercept_per_group\": 0.2624515891075134, \"sigma_obs\": 178.27464294433594, \"slope\": -0.06629011034965515, \"chain\": 0, \"draw\": 2}, {\"draws\": 2, \"mouse\": 3, \"mu_intercept_per_group\": 8.431520462036133, \"sigma_intercept_per_group\": 0.2624515891075134, \"sigma_obs\": 178.27464294433594, \"slope\": -0.06629011034965515, \"chain\": 0, \"draw\": 2}, {\"draws\": 2, \"mouse\": 4, \"mu_intercept_per_group\": 8.333537101745605, \"sigma_intercept_per_group\": 0.2624515891075134, \"sigma_obs\": 178.27464294433594, \"slope\": -0.06629011034965515, \"chain\": 0, \"draw\": 2}, {\"draws\": 2, \"mouse\": 5, \"mu_intercept_per_group\": 8.05121898651123, \"sigma_intercept_per_group\": 0.2624515891075134, \"sigma_obs\": 178.27464294433594, \"slope\": -0.06629011034965515, \"chain\": 0, \"draw\": 2}, {\"draws\": 2, \"mouse\": 6, \"mu_intercept_per_group\": 7.54262638092041, \"sigma_intercept_per_group\": 0.2624515891075134, \"sigma_obs\": 178.27464294433594, \"slope\": -0.06629011034965515, \"chain\": 0, \"draw\": 2}, {\"draws\": 2, \"mouse\": 7, \"mu_intercept_per_group\": 7.050104141235352, \"sigma_intercept_per_group\": 0.2624515891075134, \"sigma_obs\": 178.27464294433594, \"slope\": -0.06629011034965515, \"chain\": 0, \"draw\": 2}, {\"draws\": 3, \"mouse\": 0, \"mu_intercept_per_group\": 8.124536514282227, \"sigma_intercept_per_group\": 0.3109934329986572, \"sigma_obs\": 161.19970703125, \"slope\": -0.0894198790192604, \"chain\": 0, \"draw\": 3}, {\"draws\": 3, \"mouse\": 1, \"mu_intercept_per_group\": 7.780027866363525, \"sigma_intercept_per_group\": 0.3109934329986572, \"sigma_obs\": 161.19970703125, \"slope\": -0.0894198790192604, \"chain\": 0, \"draw\": 3}, {\"draws\": 3, \"mouse\": 2, \"mu_intercept_per_group\": 7.551816940307617, \"sigma_intercept_per_group\": 0.3109934329986572, \"sigma_obs\": 161.19970703125, \"slope\": -0.0894198790192604, \"chain\": 0, \"draw\": 3}, {\"draws\": 3, \"mouse\": 3, \"mu_intercept_per_group\": 6.917079448699951, \"sigma_intercept_per_group\": 0.3109934329986572, \"sigma_obs\": 161.19970703125, \"slope\": -0.0894198790192604, \"chain\": 0, \"draw\": 3}, {\"draws\": 3, \"mouse\": 4, \"mu_intercept_per_group\": 7.070374011993408, \"sigma_intercept_per_group\": 0.3109934329986572, \"sigma_obs\": 161.19970703125, \"slope\": -0.0894198790192604, \"chain\": 0, \"draw\": 3}, {\"draws\": 3, \"mouse\": 5, \"mu_intercept_per_group\": 6.418036460876465, \"sigma_intercept_per_group\": 0.3109934329986572, \"sigma_obs\": 161.19970703125, \"slope\": -0.0894198790192604, \"chain\": 0, \"draw\": 3}, {\"draws\": 3, \"mouse\": 6, \"mu_intercept_per_group\": 6.13228702545166, \"sigma_intercept_per_group\": 0.3109934329986572, \"sigma_obs\": 161.19970703125, \"slope\": -0.0894198790192604, \"chain\": 0, \"draw\": 3}, {\"draws\": 3, \"mouse\": 7, \"mu_intercept_per_group\": 6.027514934539795, \"sigma_intercept_per_group\": 0.3109934329986572, \"sigma_obs\": 161.19970703125, \"slope\": -0.0894198790192604, \"chain\": 0, \"draw\": 3}, {\"draws\": 4, \"mouse\": 0, \"mu_intercept_per_group\": 8.092611312866211, \"sigma_intercept_per_group\": 0.3104691505432129, \"sigma_obs\": 162.27122497558594, \"slope\": -0.08897320926189423, \"chain\": 0, \"draw\": 4}, {\"draws\": 4, \"mouse\": 1, \"mu_intercept_per_group\": 7.831728458404541, \"sigma_intercept_per_group\": 0.3104691505432129, \"sigma_obs\": 162.27122497558594, \"slope\": -0.08897320926189423, \"chain\": 0, \"draw\": 4}, {\"draws\": 4, \"mouse\": 2, \"mu_intercept_per_group\": 7.46779727935791, \"sigma_intercept_per_group\": 0.3104691505432129, \"sigma_obs\": 162.27122497558594, \"slope\": -0.08897320926189423, \"chain\": 0, \"draw\": 4}, {\"draws\": 4, \"mouse\": 3, \"mu_intercept_per_group\": 7.149514675140381, \"sigma_intercept_per_group\": 0.3104691505432129, \"sigma_obs\": 162.27122497558594, \"slope\": -0.08897320926189423, \"chain\": 0, \"draw\": 4}, {\"draws\": 4, \"mouse\": 4, \"mu_intercept_per_group\": 7.088554859161377, \"sigma_intercept_per_group\": 0.3104691505432129, \"sigma_obs\": 162.27122497558594, \"slope\": -0.08897320926189423, \"chain\": 0, \"draw\": 4}, {\"draws\": 4, \"mouse\": 5, \"mu_intercept_per_group\": 6.538984775543213, \"sigma_intercept_per_group\": 0.3104691505432129, \"sigma_obs\": 162.27122497558594, \"slope\": -0.08897320926189423, \"chain\": 0, \"draw\": 4}, {\"draws\": 4, \"mouse\": 6, \"mu_intercept_per_group\": 6.301905155181885, \"sigma_intercept_per_group\": 0.3104691505432129, \"sigma_obs\": 162.27122497558594, \"slope\": -0.08897320926189423, \"chain\": 0, \"draw\": 4}, {\"draws\": 4, \"mouse\": 7, \"mu_intercept_per_group\": 5.7407145500183105, \"sigma_intercept_per_group\": 0.3104691505432129, \"sigma_obs\": 162.27122497558594, \"slope\": -0.08897320926189423, \"chain\": 0, \"draw\": 4}, {\"draws\": 5, \"mouse\": 0, \"mu_intercept_per_group\": 8.711028099060059, \"sigma_intercept_per_group\": 0.28629034757614136, \"sigma_obs\": 163.0521240234375, \"slope\": -0.08870696276426315, \"chain\": 0, \"draw\": 5}, {\"draws\": 5, \"mouse\": 1, \"mu_intercept_per_group\": 8.454476356506348, \"sigma_intercept_per_group\": 0.28629034757614136, \"sigma_obs\": 163.0521240234375, \"slope\": -0.08870696276426315, \"chain\": 0, \"draw\": 5}, {\"draws\": 5, \"mouse\": 2, \"mu_intercept_per_group\": 8.353976249694824, \"sigma_intercept_per_group\": 0.28629034757614136, \"sigma_obs\": 163.0521240234375, \"slope\": -0.08870696276426315, \"chain\": 0, \"draw\": 5}, {\"draws\": 5, \"mouse\": 3, \"mu_intercept_per_group\": 7.850757598876953, \"sigma_intercept_per_group\": 0.28629034757614136, \"sigma_obs\": 163.0521240234375, \"slope\": -0.08870696276426315, \"chain\": 0, \"draw\": 5}, {\"draws\": 5, \"mouse\": 4, \"mu_intercept_per_group\": 7.398372650146484, \"sigma_intercept_per_group\": 0.28629034757614136, \"sigma_obs\": 163.0521240234375, \"slope\": -0.08870696276426315, \"chain\": 0, \"draw\": 5}, {\"draws\": 5, \"mouse\": 5, \"mu_intercept_per_group\": 6.87693452835083, \"sigma_intercept_per_group\": 0.28629034757614136, \"sigma_obs\": 163.0521240234375, \"slope\": -0.08870696276426315, \"chain\": 0, \"draw\": 5}, {\"draws\": 5, \"mouse\": 6, \"mu_intercept_per_group\": 6.7424187660217285, \"sigma_intercept_per_group\": 0.28629034757614136, \"sigma_obs\": 163.0521240234375, \"slope\": -0.08870696276426315, \"chain\": 0, \"draw\": 5}, {\"draws\": 5, \"mouse\": 7, \"mu_intercept_per_group\": 6.16069221496582, \"sigma_intercept_per_group\": 0.28629034757614136, \"sigma_obs\": 163.0521240234375, \"slope\": -0.08870696276426315, \"chain\": 0, \"draw\": 5}, {\"draws\": 6, \"mouse\": 0, \"mu_intercept_per_group\": 7.104937553405762, \"sigma_intercept_per_group\": 0.3343079388141632, \"sigma_obs\": 155.51133728027344, \"slope\": -0.05306454375386238, \"chain\": 0, \"draw\": 6}, {\"draws\": 6, \"mouse\": 1, \"mu_intercept_per_group\": 7.082496643066406, \"sigma_intercept_per_group\": 0.3343079388141632, \"sigma_obs\": 155.51133728027344, \"slope\": -0.05306454375386238, \"chain\": 0, \"draw\": 6}, {\"draws\": 6, \"mouse\": 2, \"mu_intercept_per_group\": 6.801004886627197, \"sigma_intercept_per_group\": 0.3343079388141632, \"sigma_obs\": 155.51133728027344, \"slope\": -0.05306454375386238, \"chain\": 0, \"draw\": 6}, {\"draws\": 6, \"mouse\": 3, \"mu_intercept_per_group\": 6.4002366065979, \"sigma_intercept_per_group\": 0.3343079388141632, \"sigma_obs\": 155.51133728027344, \"slope\": -0.05306454375386238, \"chain\": 0, \"draw\": 6}, {\"draws\": 6, \"mouse\": 4, \"mu_intercept_per_group\": 6.416934490203857, \"sigma_intercept_per_group\": 0.3343079388141632, \"sigma_obs\": 155.51133728027344, \"slope\": -0.05306454375386238, \"chain\": 0, \"draw\": 6}, {\"draws\": 6, \"mouse\": 5, \"mu_intercept_per_group\": 5.864434719085693, \"sigma_intercept_per_group\": 0.3343079388141632, \"sigma_obs\": 155.51133728027344, \"slope\": -0.05306454375386238, \"chain\": 0, \"draw\": 6}, {\"draws\": 6, \"mouse\": 6, \"mu_intercept_per_group\": 5.459434509277344, \"sigma_intercept_per_group\": 0.3343079388141632, \"sigma_obs\": 155.51133728027344, \"slope\": -0.05306454375386238, \"chain\": 0, \"draw\": 6}, {\"draws\": 6, \"mouse\": 7, \"mu_intercept_per_group\": 5.175588130950928, \"sigma_intercept_per_group\": 0.3343079388141632, \"sigma_obs\": 155.51133728027344, \"slope\": -0.05306454375386238, \"chain\": 0, \"draw\": 6}, {\"draws\": 7, \"mouse\": 0, \"mu_intercept_per_group\": 7.030543804168701, \"sigma_intercept_per_group\": 0.34247463941574097, \"sigma_obs\": 159.1254119873047, \"slope\": -0.05717747285962105, \"chain\": 0, \"draw\": 7}, {\"draws\": 7, \"mouse\": 1, \"mu_intercept_per_group\": 7.00830078125, \"sigma_intercept_per_group\": 0.34247463941574097, \"sigma_obs\": 159.1254119873047, \"slope\": -0.05717747285962105, \"chain\": 0, \"draw\": 7}, {\"draws\": 7, \"mouse\": 2, \"mu_intercept_per_group\": 6.757171630859375, \"sigma_intercept_per_group\": 0.34247463941574097, \"sigma_obs\": 159.1254119873047, \"slope\": -0.05717747285962105, \"chain\": 0, \"draw\": 7}, {\"draws\": 7, \"mouse\": 3, \"mu_intercept_per_group\": 6.314268589019775, \"sigma_intercept_per_group\": 0.34247463941574097, \"sigma_obs\": 159.1254119873047, \"slope\": -0.05717747285962105, \"chain\": 0, \"draw\": 7}, {\"draws\": 7, \"mouse\": 4, \"mu_intercept_per_group\": 6.4084014892578125, \"sigma_intercept_per_group\": 0.34247463941574097, \"sigma_obs\": 159.1254119873047, \"slope\": -0.05717747285962105, \"chain\": 0, \"draw\": 7}, {\"draws\": 7, \"mouse\": 5, \"mu_intercept_per_group\": 5.812320709228516, \"sigma_intercept_per_group\": 0.34247463941574097, \"sigma_obs\": 159.1254119873047, \"slope\": -0.05717747285962105, \"chain\": 0, \"draw\": 7}, {\"draws\": 7, \"mouse\": 6, \"mu_intercept_per_group\": 5.495867729187012, \"sigma_intercept_per_group\": 0.34247463941574097, \"sigma_obs\": 159.1254119873047, \"slope\": -0.05717747285962105, \"chain\": 0, \"draw\": 7}, {\"draws\": 7, \"mouse\": 7, \"mu_intercept_per_group\": 5.251749038696289, \"sigma_intercept_per_group\": 0.34247463941574097, \"sigma_obs\": 159.1254119873047, \"slope\": -0.05717747285962105, \"chain\": 0, \"draw\": 7}, {\"draws\": 8, \"mouse\": 0, \"mu_intercept_per_group\": 7.139244079589844, \"sigma_intercept_per_group\": 0.3391842544078827, \"sigma_obs\": 160.05899047851562, \"slope\": -0.05477355420589447, \"chain\": 0, \"draw\": 8}, {\"draws\": 8, \"mouse\": 1, \"mu_intercept_per_group\": 6.840939998626709, \"sigma_intercept_per_group\": 0.3391842544078827, \"sigma_obs\": 160.05899047851562, \"slope\": -0.05477355420589447, \"chain\": 0, \"draw\": 8}, {\"draws\": 8, \"mouse\": 2, \"mu_intercept_per_group\": 6.684945583343506, \"sigma_intercept_per_group\": 0.3391842544078827, \"sigma_obs\": 160.05899047851562, \"slope\": -0.05477355420589447, \"chain\": 0, \"draw\": 8}, {\"draws\": 8, \"mouse\": 3, \"mu_intercept_per_group\": 6.534210205078125, \"sigma_intercept_per_group\": 0.3391842544078827, \"sigma_obs\": 160.05899047851562, \"slope\": -0.05477355420589447, \"chain\": 0, \"draw\": 8}, {\"draws\": 8, \"mouse\": 4, \"mu_intercept_per_group\": 6.009171009063721, \"sigma_intercept_per_group\": 0.3391842544078827, \"sigma_obs\": 160.05899047851562, \"slope\": -0.05477355420589447, \"chain\": 0, \"draw\": 8}, {\"draws\": 8, \"mouse\": 5, \"mu_intercept_per_group\": 5.859035491943359, \"sigma_intercept_per_group\": 0.3391842544078827, \"sigma_obs\": 160.05899047851562, \"slope\": -0.05477355420589447, \"chain\": 0, \"draw\": 8}, {\"draws\": 8, \"mouse\": 6, \"mu_intercept_per_group\": 5.397304534912109, \"sigma_intercept_per_group\": 0.3391842544078827, \"sigma_obs\": 160.05899047851562, \"slope\": -0.05477355420589447, \"chain\": 0, \"draw\": 8}, {\"draws\": 8, \"mouse\": 7, \"mu_intercept_per_group\": 5.156144618988037, \"sigma_intercept_per_group\": 0.3391842544078827, \"sigma_obs\": 160.05899047851562, \"slope\": -0.05477355420589447, \"chain\": 0, \"draw\": 8}, {\"draws\": 9, \"mouse\": 0, \"mu_intercept_per_group\": 8.32080078125, \"sigma_intercept_per_group\": 0.29131975769996643, \"sigma_obs\": 155.7545166015625, \"slope\": -0.07080179452896118, \"chain\": 0, \"draw\": 9}, {\"draws\": 9, \"mouse\": 1, \"mu_intercept_per_group\": 8.048601150512695, \"sigma_intercept_per_group\": 0.29131975769996643, \"sigma_obs\": 155.7545166015625, \"slope\": -0.07080179452896118, \"chain\": 0, \"draw\": 9}, {\"draws\": 9, \"mouse\": 2, \"mu_intercept_per_group\": 7.700895309448242, \"sigma_intercept_per_group\": 0.29131975769996643, \"sigma_obs\": 155.7545166015625, \"slope\": -0.07080179452896118, \"chain\": 0, \"draw\": 9}, {\"draws\": 9, \"mouse\": 3, \"mu_intercept_per_group\": 7.418329238891602, \"sigma_intercept_per_group\": 0.29131975769996643, \"sigma_obs\": 155.7545166015625, \"slope\": -0.07080179452896118, \"chain\": 0, \"draw\": 9}, {\"draws\": 9, \"mouse\": 4, \"mu_intercept_per_group\": 7.163764953613281, \"sigma_intercept_per_group\": 0.29131975769996643, \"sigma_obs\": 155.7545166015625, \"slope\": -0.07080179452896118, \"chain\": 0, \"draw\": 9}, {\"draws\": 9, \"mouse\": 5, \"mu_intercept_per_group\": 6.668724536895752, \"sigma_intercept_per_group\": 0.29131975769996643, \"sigma_obs\": 155.7545166015625, \"slope\": -0.07080179452896118, \"chain\": 0, \"draw\": 9}, {\"draws\": 9, \"mouse\": 6, \"mu_intercept_per_group\": 6.4206156730651855, \"sigma_intercept_per_group\": 0.29131975769996643, \"sigma_obs\": 155.7545166015625, \"slope\": -0.07080179452896118, \"chain\": 0, \"draw\": 9}, {\"draws\": 9, \"mouse\": 7, \"mu_intercept_per_group\": 6.051604270935059, \"sigma_intercept_per_group\": 0.29131975769996643, \"sigma_obs\": 155.7545166015625, \"slope\": -0.07080179452896118, \"chain\": 0, \"draw\": 9}, {\"draws\": 10, \"mouse\": 0, \"mu_intercept_per_group\": 8.291585922241211, \"sigma_intercept_per_group\": 0.29295235872268677, \"sigma_obs\": 155.34197998046875, \"slope\": -0.07053713500499725, \"chain\": 0, \"draw\": 10}, {\"draws\": 10, \"mouse\": 1, \"mu_intercept_per_group\": 8.147513389587402, \"sigma_intercept_per_group\": 0.29295235872268677, \"sigma_obs\": 155.34197998046875, \"slope\": -0.07053713500499725, \"chain\": 0, \"draw\": 10}, {\"draws\": 10, \"mouse\": 2, \"mu_intercept_per_group\": 8.03230094909668, \"sigma_intercept_per_group\": 0.29295235872268677, \"sigma_obs\": 155.34197998046875, \"slope\": -0.07053713500499725, \"chain\": 0, \"draw\": 10}, {\"draws\": 10, \"mouse\": 3, \"mu_intercept_per_group\": 7.511723041534424, \"sigma_intercept_per_group\": 0.29295235872268677, \"sigma_obs\": 155.34197998046875, \"slope\": -0.07053713500499725, \"chain\": 0, \"draw\": 10}, {\"draws\": 10, \"mouse\": 4, \"mu_intercept_per_group\": 7.217597484588623, \"sigma_intercept_per_group\": 0.29295235872268677, \"sigma_obs\": 155.34197998046875, \"slope\": -0.07053713500499725, \"chain\": 0, \"draw\": 10}, {\"draws\": 10, \"mouse\": 5, \"mu_intercept_per_group\": 6.546268939971924, \"sigma_intercept_per_group\": 0.29295235872268677, \"sigma_obs\": 155.34197998046875, \"slope\": -0.07053713500499725, \"chain\": 0, \"draw\": 10}, {\"draws\": 10, \"mouse\": 6, \"mu_intercept_per_group\": 6.222952365875244, \"sigma_intercept_per_group\": 0.29295235872268677, \"sigma_obs\": 155.34197998046875, \"slope\": -0.07053713500499725, \"chain\": 0, \"draw\": 10}, {\"draws\": 10, \"mouse\": 7, \"mu_intercept_per_group\": 5.855202674865723, \"sigma_intercept_per_group\": 0.29295235872268677, \"sigma_obs\": 155.34197998046875, \"slope\": -0.07053713500499725, \"chain\": 0, \"draw\": 10}, {\"draws\": 11, \"mouse\": 0, \"mu_intercept_per_group\": 8.715873718261719, \"sigma_intercept_per_group\": 0.27227306365966797, \"sigma_obs\": 151.28573608398438, \"slope\": -0.07524967938661575, \"chain\": 0, \"draw\": 11}, {\"draws\": 11, \"mouse\": 1, \"mu_intercept_per_group\": 8.615053176879883, \"sigma_intercept_per_group\": 0.27227306365966797, \"sigma_obs\": 151.28573608398438, \"slope\": -0.07524967938661575, \"chain\": 0, \"draw\": 11}, {\"draws\": 11, \"mouse\": 2, \"mu_intercept_per_group\": 8.386070251464844, \"sigma_intercept_per_group\": 0.27227306365966797, \"sigma_obs\": 151.28573608398438, \"slope\": -0.07524967938661575, \"chain\": 0, \"draw\": 11}, {\"draws\": 11, \"mouse\": 3, \"mu_intercept_per_group\": 7.834465503692627, \"sigma_intercept_per_group\": 0.27227306365966797, \"sigma_obs\": 151.28573608398438, \"slope\": -0.07524967938661575, \"chain\": 0, \"draw\": 11}, {\"draws\": 11, \"mouse\": 4, \"mu_intercept_per_group\": 7.684078693389893, \"sigma_intercept_per_group\": 0.27227306365966797, \"sigma_obs\": 151.28573608398438, \"slope\": -0.07524967938661575, \"chain\": 0, \"draw\": 11}, {\"draws\": 11, \"mouse\": 5, \"mu_intercept_per_group\": 7.3641037940979, \"sigma_intercept_per_group\": 0.27227306365966797, \"sigma_obs\": 151.28573608398438, \"slope\": -0.07524967938661575, \"chain\": 0, \"draw\": 11}, {\"draws\": 11, \"mouse\": 6, \"mu_intercept_per_group\": 6.858075141906738, \"sigma_intercept_per_group\": 0.27227306365966797, \"sigma_obs\": 151.28573608398438, \"slope\": -0.07524967938661575, \"chain\": 0, \"draw\": 11}, {\"draws\": 11, \"mouse\": 7, \"mu_intercept_per_group\": 6.336408615112305, \"sigma_intercept_per_group\": 0.27227306365966797, \"sigma_obs\": 151.28573608398438, \"slope\": -0.07524967938661575, \"chain\": 0, \"draw\": 11}, {\"draws\": 12, \"mouse\": 0, \"mu_intercept_per_group\": 8.443199157714844, \"sigma_intercept_per_group\": 0.29883018136024475, \"sigma_obs\": 169.108154296875, \"slope\": -0.0900108739733696, \"chain\": 0, \"draw\": 12}, {\"draws\": 12, \"mouse\": 1, \"mu_intercept_per_group\": 8.365772247314453, \"sigma_intercept_per_group\": 0.29883018136024475, \"sigma_obs\": 169.108154296875, \"slope\": -0.0900108739733696, \"chain\": 0, \"draw\": 12}, {\"draws\": 12, \"mouse\": 2, \"mu_intercept_per_group\": 8.000913619995117, \"sigma_intercept_per_group\": 0.29883018136024475, \"sigma_obs\": 169.108154296875, \"slope\": -0.0900108739733696, \"chain\": 0, \"draw\": 12}, {\"draws\": 12, \"mouse\": 3, \"mu_intercept_per_group\": 7.588976860046387, \"sigma_intercept_per_group\": 0.29883018136024475, \"sigma_obs\": 169.108154296875, \"slope\": -0.0900108739733696, \"chain\": 0, \"draw\": 12}, {\"draws\": 12, \"mouse\": 4, \"mu_intercept_per_group\": 7.256115913391113, \"sigma_intercept_per_group\": 0.29883018136024475, \"sigma_obs\": 169.108154296875, \"slope\": -0.0900108739733696, \"chain\": 0, \"draw\": 12}, {\"draws\": 12, \"mouse\": 5, \"mu_intercept_per_group\": 7.1547956466674805, \"sigma_intercept_per_group\": 0.29883018136024475, \"sigma_obs\": 169.108154296875, \"slope\": -0.0900108739733696, \"chain\": 0, \"draw\": 12}, {\"draws\": 12, \"mouse\": 6, \"mu_intercept_per_group\": 6.646728515625, \"sigma_intercept_per_group\": 0.29883018136024475, \"sigma_obs\": 169.108154296875, \"slope\": -0.0900108739733696, \"chain\": 0, \"draw\": 12}, {\"draws\": 12, \"mouse\": 7, \"mu_intercept_per_group\": 6.1752705574035645, \"sigma_intercept_per_group\": 0.29883018136024475, \"sigma_obs\": 169.108154296875, \"slope\": -0.0900108739733696, \"chain\": 0, \"draw\": 12}, {\"draws\": 13, \"mouse\": 0, \"mu_intercept_per_group\": 11.605486869812012, \"sigma_intercept_per_group\": 0.21604713797569275, \"sigma_obs\": 168.7694091796875, \"slope\": -0.05979488417506218, \"chain\": 0, \"draw\": 13}, {\"draws\": 13, \"mouse\": 1, \"mu_intercept_per_group\": 11.145689964294434, \"sigma_intercept_per_group\": 0.21604713797569275, \"sigma_obs\": 168.7694091796875, \"slope\": -0.05979488417506218, \"chain\": 0, \"draw\": 13}, {\"draws\": 13, \"mouse\": 2, \"mu_intercept_per_group\": 10.758498191833496, \"sigma_intercept_per_group\": 0.21604713797569275, \"sigma_obs\": 168.7694091796875, \"slope\": -0.05979488417506218, \"chain\": 0, \"draw\": 13}, {\"draws\": 13, \"mouse\": 3, \"mu_intercept_per_group\": 9.929182052612305, \"sigma_intercept_per_group\": 0.21604713797569275, \"sigma_obs\": 168.7694091796875, \"slope\": -0.05979488417506218, \"chain\": 0, \"draw\": 13}, {\"draws\": 13, \"mouse\": 4, \"mu_intercept_per_group\": 10.089271545410156, \"sigma_intercept_per_group\": 0.21604713797569275, \"sigma_obs\": 168.7694091796875, \"slope\": -0.05979488417506218, \"chain\": 0, \"draw\": 13}, {\"draws\": 13, \"mouse\": 5, \"mu_intercept_per_group\": 9.149585723876953, \"sigma_intercept_per_group\": 0.21604713797569275, \"sigma_obs\": 168.7694091796875, \"slope\": -0.05979488417506218, \"chain\": 0, \"draw\": 13}, {\"draws\": 13, \"mouse\": 6, \"mu_intercept_per_group\": 9.067155838012695, \"sigma_intercept_per_group\": 0.21604713797569275, \"sigma_obs\": 168.7694091796875, \"slope\": -0.05979488417506218, \"chain\": 0, \"draw\": 13}, {\"draws\": 13, \"mouse\": 7, \"mu_intercept_per_group\": 8.597243309020996, \"sigma_intercept_per_group\": 0.21604713797569275, \"sigma_obs\": 168.7694091796875, \"slope\": -0.05979488417506218, \"chain\": 0, \"draw\": 13}, {\"draws\": 14, \"mouse\": 0, \"mu_intercept_per_group\": 11.69933032989502, \"sigma_intercept_per_group\": 0.2069685161113739, \"sigma_obs\": 160.2085723876953, \"slope\": -0.061483342200517654, \"chain\": 0, \"draw\": 14}, {\"draws\": 14, \"mouse\": 1, \"mu_intercept_per_group\": 11.427083015441895, \"sigma_intercept_per_group\": 0.2069685161113739, \"sigma_obs\": 160.2085723876953, \"slope\": -0.061483342200517654, \"chain\": 0, \"draw\": 14}, {\"draws\": 14, \"mouse\": 2, \"mu_intercept_per_group\": 11.241510391235352, \"sigma_intercept_per_group\": 0.2069685161113739, \"sigma_obs\": 160.2085723876953, \"slope\": -0.061483342200517654, \"chain\": 0, \"draw\": 14}, {\"draws\": 14, \"mouse\": 3, \"mu_intercept_per_group\": 10.307126998901367, \"sigma_intercept_per_group\": 0.2069685161113739, \"sigma_obs\": 160.2085723876953, \"slope\": -0.061483342200517654, \"chain\": 0, \"draw\": 14}, {\"draws\": 14, \"mouse\": 4, \"mu_intercept_per_group\": 10.402496337890625, \"sigma_intercept_per_group\": 0.2069685161113739, \"sigma_obs\": 160.2085723876953, \"slope\": -0.061483342200517654, \"chain\": 0, \"draw\": 14}, {\"draws\": 14, \"mouse\": 5, \"mu_intercept_per_group\": 9.371123313903809, \"sigma_intercept_per_group\": 0.2069685161113739, \"sigma_obs\": 160.2085723876953, \"slope\": -0.061483342200517654, \"chain\": 0, \"draw\": 14}, {\"draws\": 14, \"mouse\": 6, \"mu_intercept_per_group\": 9.402511596679688, \"sigma_intercept_per_group\": 0.2069685161113739, \"sigma_obs\": 160.2085723876953, \"slope\": -0.061483342200517654, \"chain\": 0, \"draw\": 14}, {\"draws\": 14, \"mouse\": 7, \"mu_intercept_per_group\": 8.628089904785156, \"sigma_intercept_per_group\": 0.2069685161113739, \"sigma_obs\": 160.2085723876953, \"slope\": -0.061483342200517654, \"chain\": 0, \"draw\": 14}, {\"draws\": 15, \"mouse\": 0, \"mu_intercept_per_group\": 11.758278846740723, \"sigma_intercept_per_group\": 0.2083757370710373, \"sigma_obs\": 160.0570068359375, \"slope\": -0.06200779229402542, \"chain\": 0, \"draw\": 15}, {\"draws\": 15, \"mouse\": 1, \"mu_intercept_per_group\": 11.283011436462402, \"sigma_intercept_per_group\": 0.2083757370710373, \"sigma_obs\": 160.0570068359375, \"slope\": -0.06200779229402542, \"chain\": 0, \"draw\": 15}, {\"draws\": 15, \"mouse\": 2, \"mu_intercept_per_group\": 11.005096435546875, \"sigma_intercept_per_group\": 0.2083757370710373, \"sigma_obs\": 160.0570068359375, \"slope\": -0.06200779229402542, \"chain\": 0, \"draw\": 15}, {\"draws\": 15, \"mouse\": 3, \"mu_intercept_per_group\": 10.307001113891602, \"sigma_intercept_per_group\": 0.2083757370710373, \"sigma_obs\": 160.0570068359375, \"slope\": -0.06200779229402542, \"chain\": 0, \"draw\": 15}, {\"draws\": 15, \"mouse\": 4, \"mu_intercept_per_group\": 10.314988136291504, \"sigma_intercept_per_group\": 0.2083757370710373, \"sigma_obs\": 160.0570068359375, \"slope\": -0.06200779229402542, \"chain\": 0, \"draw\": 15}, {\"draws\": 15, \"mouse\": 5, \"mu_intercept_per_group\": 9.595281600952148, \"sigma_intercept_per_group\": 0.2083757370710373, \"sigma_obs\": 160.0570068359375, \"slope\": -0.06200779229402542, \"chain\": 0, \"draw\": 15}, {\"draws\": 15, \"mouse\": 6, \"mu_intercept_per_group\": 9.309115409851074, \"sigma_intercept_per_group\": 0.2083757370710373, \"sigma_obs\": 160.0570068359375, \"slope\": -0.06200779229402542, \"chain\": 0, \"draw\": 15}, {\"draws\": 15, \"mouse\": 7, \"mu_intercept_per_group\": 8.573688507080078, \"sigma_intercept_per_group\": 0.2083757370710373, \"sigma_obs\": 160.0570068359375, \"slope\": -0.06200779229402542, \"chain\": 0, \"draw\": 15}, {\"draws\": 16, \"mouse\": 0, \"mu_intercept_per_group\": 10.042061805725098, \"sigma_intercept_per_group\": 0.2360425442457199, \"sigma_obs\": 146.62164306640625, \"slope\": -0.08300012350082397, \"chain\": 0, \"draw\": 16}, {\"draws\": 16, \"mouse\": 1, \"mu_intercept_per_group\": 9.932144165039062, \"sigma_intercept_per_group\": 0.2360425442457199, \"sigma_obs\": 146.62164306640625, \"slope\": -0.08300012350082397, \"chain\": 0, \"draw\": 16}, {\"draws\": 16, \"mouse\": 2, \"mu_intercept_per_group\": 9.659598350524902, \"sigma_intercept_per_group\": 0.2360425442457199, \"sigma_obs\": 146.62164306640625, \"slope\": -0.08300012350082397, \"chain\": 0, \"draw\": 16}, {\"draws\": 16, \"mouse\": 3, \"mu_intercept_per_group\": 8.729010581970215, \"sigma_intercept_per_group\": 0.2360425442457199, \"sigma_obs\": 146.62164306640625, \"slope\": -0.08300012350082397, \"chain\": 0, \"draw\": 16}, {\"draws\": 16, \"mouse\": 4, \"mu_intercept_per_group\": 8.853452682495117, \"sigma_intercept_per_group\": 0.2360425442457199, \"sigma_obs\": 146.62164306640625, \"slope\": -0.08300012350082397, \"chain\": 0, \"draw\": 16}, {\"draws\": 16, \"mouse\": 5, \"mu_intercept_per_group\": 8.16787338256836, \"sigma_intercept_per_group\": 0.2360425442457199, \"sigma_obs\": 146.62164306640625, \"slope\": -0.08300012350082397, \"chain\": 0, \"draw\": 16}, {\"draws\": 16, \"mouse\": 6, \"mu_intercept_per_group\": 7.813772201538086, \"sigma_intercept_per_group\": 0.2360425442457199, \"sigma_obs\": 146.62164306640625, \"slope\": -0.08300012350082397, \"chain\": 0, \"draw\": 16}, {\"draws\": 16, \"mouse\": 7, \"mu_intercept_per_group\": 7.390730381011963, \"sigma_intercept_per_group\": 0.2360425442457199, \"sigma_obs\": 146.62164306640625, \"slope\": -0.08300012350082397, \"chain\": 0, \"draw\": 16}, {\"draws\": 17, \"mouse\": 0, \"mu_intercept_per_group\": 10.117932319641113, \"sigma_intercept_per_group\": 0.2343677431344986, \"sigma_obs\": 146.54840087890625, \"slope\": -0.08319734781980515, \"chain\": 0, \"draw\": 17}, {\"draws\": 17, \"mouse\": 1, \"mu_intercept_per_group\": 10.168535232543945, \"sigma_intercept_per_group\": 0.2343677431344986, \"sigma_obs\": 146.54840087890625, \"slope\": -0.08319734781980515, \"chain\": 0, \"draw\": 17}, {\"draws\": 17, \"mouse\": 2, \"mu_intercept_per_group\": 9.566691398620605, \"sigma_intercept_per_group\": 0.2343677431344986, \"sigma_obs\": 146.54840087890625, \"slope\": -0.08319734781980515, \"chain\": 0, \"draw\": 17}, {\"draws\": 17, \"mouse\": 3, \"mu_intercept_per_group\": 8.732522964477539, \"sigma_intercept_per_group\": 0.2343677431344986, \"sigma_obs\": 146.54840087890625, \"slope\": -0.08319734781980515, \"chain\": 0, \"draw\": 17}, {\"draws\": 17, \"mouse\": 4, \"mu_intercept_per_group\": 8.780411720275879, \"sigma_intercept_per_group\": 0.2343677431344986, \"sigma_obs\": 146.54840087890625, \"slope\": -0.08319734781980515, \"chain\": 0, \"draw\": 17}, {\"draws\": 17, \"mouse\": 5, \"mu_intercept_per_group\": 8.238018989562988, \"sigma_intercept_per_group\": 0.2343677431344986, \"sigma_obs\": 146.54840087890625, \"slope\": -0.08319734781980515, \"chain\": 0, \"draw\": 17}, {\"draws\": 17, \"mouse\": 6, \"mu_intercept_per_group\": 7.755667686462402, \"sigma_intercept_per_group\": 0.2343677431344986, \"sigma_obs\": 146.54840087890625, \"slope\": -0.08319734781980515, \"chain\": 0, \"draw\": 17}, {\"draws\": 17, \"mouse\": 7, \"mu_intercept_per_group\": 7.379629135131836, \"sigma_intercept_per_group\": 0.2343677431344986, \"sigma_obs\": 146.54840087890625, \"slope\": -0.08319734781980515, \"chain\": 0, \"draw\": 17}, {\"draws\": 18, \"mouse\": 0, \"mu_intercept_per_group\": 11.075590133666992, \"sigma_intercept_per_group\": 0.2175133228302002, \"sigma_obs\": 148.5099334716797, \"slope\": -0.07846583425998688, \"chain\": 0, \"draw\": 18}, {\"draws\": 18, \"mouse\": 1, \"mu_intercept_per_group\": 10.296509742736816, \"sigma_intercept_per_group\": 0.2175133228302002, \"sigma_obs\": 148.5099334716797, \"slope\": -0.07846583425998688, \"chain\": 0, \"draw\": 18}, {\"draws\": 18, \"mouse\": 2, \"mu_intercept_per_group\": 10.27122688293457, \"sigma_intercept_per_group\": 0.2175133228302002, \"sigma_obs\": 148.5099334716797, \"slope\": -0.07846583425998688, \"chain\": 0, \"draw\": 18}, {\"draws\": 18, \"mouse\": 3, \"mu_intercept_per_group\": 9.867259979248047, \"sigma_intercept_per_group\": 0.2175133228302002, \"sigma_obs\": 148.5099334716797, \"slope\": -0.07846583425998688, \"chain\": 0, \"draw\": 18}, {\"draws\": 18, \"mouse\": 4, \"mu_intercept_per_group\": 9.497895240783691, \"sigma_intercept_per_group\": 0.2175133228302002, \"sigma_obs\": 148.5099334716797, \"slope\": -0.07846583425998688, \"chain\": 0, \"draw\": 18}, {\"draws\": 18, \"mouse\": 5, \"mu_intercept_per_group\": 9.167160034179688, \"sigma_intercept_per_group\": 0.2175133228302002, \"sigma_obs\": 148.5099334716797, \"slope\": -0.07846583425998688, \"chain\": 0, \"draw\": 18}, {\"draws\": 18, \"mouse\": 6, \"mu_intercept_per_group\": 8.449894905090332, \"sigma_intercept_per_group\": 0.2175133228302002, \"sigma_obs\": 148.5099334716797, \"slope\": -0.07846583425998688, \"chain\": 0, \"draw\": 18}, {\"draws\": 18, \"mouse\": 7, \"mu_intercept_per_group\": 8.171082496643066, \"sigma_intercept_per_group\": 0.2175133228302002, \"sigma_obs\": 148.5099334716797, \"slope\": -0.07846583425998688, \"chain\": 0, \"draw\": 18}, {\"draws\": 19, \"mouse\": 0, \"mu_intercept_per_group\": 11.189204216003418, \"sigma_intercept_per_group\": 0.21977612376213074, \"sigma_obs\": 149.4051055908203, \"slope\": -0.08339197933673859, \"chain\": 0, \"draw\": 19}, {\"draws\": 19, \"mouse\": 1, \"mu_intercept_per_group\": 10.43923568725586, \"sigma_intercept_per_group\": 0.21977612376213074, \"sigma_obs\": 149.4051055908203, \"slope\": -0.08339197933673859, \"chain\": 0, \"draw\": 19}, {\"draws\": 19, \"mouse\": 2, \"mu_intercept_per_group\": 10.59594440460205, \"sigma_intercept_per_group\": 0.21977612376213074, \"sigma_obs\": 149.4051055908203, \"slope\": -0.08339197933673859, \"chain\": 0, \"draw\": 19}, {\"draws\": 19, \"mouse\": 3, \"mu_intercept_per_group\": 9.827115058898926, \"sigma_intercept_per_group\": 0.21977612376213074, \"sigma_obs\": 149.4051055908203, \"slope\": -0.08339197933673859, \"chain\": 0, \"draw\": 19}, {\"draws\": 19, \"mouse\": 4, \"mu_intercept_per_group\": 9.570516586303711, \"sigma_intercept_per_group\": 0.21977612376213074, \"sigma_obs\": 149.4051055908203, \"slope\": -0.08339197933673859, \"chain\": 0, \"draw\": 19}, {\"draws\": 19, \"mouse\": 5, \"mu_intercept_per_group\": 8.853412628173828, \"sigma_intercept_per_group\": 0.21977612376213074, \"sigma_obs\": 149.4051055908203, \"slope\": -0.08339197933673859, \"chain\": 0, \"draw\": 19}, {\"draws\": 19, \"mouse\": 6, \"mu_intercept_per_group\": 8.255148887634277, \"sigma_intercept_per_group\": 0.21977612376213074, \"sigma_obs\": 149.4051055908203, \"slope\": -0.08339197933673859, \"chain\": 0, \"draw\": 19}, {\"draws\": 19, \"mouse\": 7, \"mu_intercept_per_group\": 7.646988391876221, \"sigma_intercept_per_group\": 0.21977612376213074, \"sigma_obs\": 149.4051055908203, \"slope\": -0.08339197933673859, \"chain\": 0, \"draw\": 19}, {\"draws\": 20, \"mouse\": 0, \"mu_intercept_per_group\": 11.146636009216309, \"sigma_intercept_per_group\": 0.2209462672472, \"sigma_obs\": 151.28846740722656, \"slope\": -0.082912378013134, \"chain\": 0, \"draw\": 20}, {\"draws\": 20, \"mouse\": 1, \"mu_intercept_per_group\": 10.806010246276855, \"sigma_intercept_per_group\": 0.2209462672472, \"sigma_obs\": 151.28846740722656, \"slope\": -0.082912378013134, \"chain\": 0, \"draw\": 20}, {\"draws\": 20, \"mouse\": 2, \"mu_intercept_per_group\": 10.426708221435547, \"sigma_intercept_per_group\": 0.2209462672472, \"sigma_obs\": 151.28846740722656, \"slope\": -0.082912378013134, \"chain\": 0, \"draw\": 20}, {\"draws\": 20, \"mouse\": 3, \"mu_intercept_per_group\": 9.647171020507812, \"sigma_intercept_per_group\": 0.2209462672472, \"sigma_obs\": 151.28846740722656, \"slope\": -0.082912378013134, \"chain\": 0, \"draw\": 20}, {\"draws\": 20, \"mouse\": 4, \"mu_intercept_per_group\": 9.380632400512695, \"sigma_intercept_per_group\": 0.2209462672472, \"sigma_obs\": 151.28846740722656, \"slope\": -0.082912378013134, \"chain\": 0, \"draw\": 20}, {\"draws\": 20, \"mouse\": 5, \"mu_intercept_per_group\": 8.684196472167969, \"sigma_intercept_per_group\": 0.2209462672472, \"sigma_obs\": 151.28846740722656, \"slope\": -0.082912378013134, \"chain\": 0, \"draw\": 20}, {\"draws\": 20, \"mouse\": 6, \"mu_intercept_per_group\": 8.564373016357422, \"sigma_intercept_per_group\": 0.2209462672472, \"sigma_obs\": 151.28846740722656, \"slope\": -0.082912378013134, \"chain\": 0, \"draw\": 20}, {\"draws\": 20, \"mouse\": 7, \"mu_intercept_per_group\": 7.669000625610352, \"sigma_intercept_per_group\": 0.2209462672472, \"sigma_obs\": 151.28846740722656, \"slope\": -0.082912378013134, \"chain\": 0, \"draw\": 20}, {\"draws\": 21, \"mouse\": 0, \"mu_intercept_per_group\": 11.025046348571777, \"sigma_intercept_per_group\": 0.21912328898906708, \"sigma_obs\": 150.139404296875, \"slope\": -0.08285599201917648, \"chain\": 0, \"draw\": 21}, {\"draws\": 21, \"mouse\": 1, \"mu_intercept_per_group\": 10.588025093078613, \"sigma_intercept_per_group\": 0.21912328898906708, \"sigma_obs\": 150.139404296875, \"slope\": -0.08285599201917648, \"chain\": 0, \"draw\": 21}, {\"draws\": 21, \"mouse\": 2, \"mu_intercept_per_group\": 10.226417541503906, \"sigma_intercept_per_group\": 0.21912328898906708, \"sigma_obs\": 150.139404296875, \"slope\": -0.08285599201917648, \"chain\": 0, \"draw\": 21}, {\"draws\": 21, \"mouse\": 3, \"mu_intercept_per_group\": 9.926709175109863, \"sigma_intercept_per_group\": 0.21912328898906708, \"sigma_obs\": 150.139404296875, \"slope\": -0.08285599201917648, \"chain\": 0, \"draw\": 21}, {\"draws\": 21, \"mouse\": 4, \"mu_intercept_per_group\": 9.360440254211426, \"sigma_intercept_per_group\": 0.21912328898906708, \"sigma_obs\": 150.139404296875, \"slope\": -0.08285599201917648, \"chain\": 0, \"draw\": 21}, {\"draws\": 21, \"mouse\": 5, \"mu_intercept_per_group\": 8.909676551818848, \"sigma_intercept_per_group\": 0.21912328898906708, \"sigma_obs\": 150.139404296875, \"slope\": -0.08285599201917648, \"chain\": 0, \"draw\": 21}, {\"draws\": 21, \"mouse\": 6, \"mu_intercept_per_group\": 8.483861923217773, \"sigma_intercept_per_group\": 0.21912328898906708, \"sigma_obs\": 150.139404296875, \"slope\": -0.08285599201917648, \"chain\": 0, \"draw\": 21}, {\"draws\": 21, \"mouse\": 7, \"mu_intercept_per_group\": 7.822481632232666, \"sigma_intercept_per_group\": 0.21912328898906708, \"sigma_obs\": 150.139404296875, \"slope\": -0.08285599201917648, \"chain\": 0, \"draw\": 21}, {\"draws\": 22, \"mouse\": 0, \"mu_intercept_per_group\": 11.082486152648926, \"sigma_intercept_per_group\": 0.22130535542964935, \"sigma_obs\": 151.39382934570312, \"slope\": -0.08049512654542923, \"chain\": 0, \"draw\": 22}, {\"draws\": 22, \"mouse\": 1, \"mu_intercept_per_group\": 10.716341018676758, \"sigma_intercept_per_group\": 0.22130535542964935, \"sigma_obs\": 151.39382934570312, \"slope\": -0.08049512654542923, \"chain\": 0, \"draw\": 22}, {\"draws\": 22, \"mouse\": 2, \"mu_intercept_per_group\": 10.447774887084961, \"sigma_intercept_per_group\": 0.22130535542964935, \"sigma_obs\": 151.39382934570312, \"slope\": -0.08049512654542923, \"chain\": 0, \"draw\": 22}, {\"draws\": 22, \"mouse\": 3, \"mu_intercept_per_group\": 9.362353324890137, \"sigma_intercept_per_group\": 0.22130535542964935, \"sigma_obs\": 151.39382934570312, \"slope\": -0.08049512654542923, \"chain\": 0, \"draw\": 22}, {\"draws\": 22, \"mouse\": 4, \"mu_intercept_per_group\": 9.592169761657715, \"sigma_intercept_per_group\": 0.22130535542964935, \"sigma_obs\": 151.39382934570312, \"slope\": -0.08049512654542923, \"chain\": 0, \"draw\": 22}, {\"draws\": 22, \"mouse\": 5, \"mu_intercept_per_group\": 8.938435554504395, \"sigma_intercept_per_group\": 0.22130535542964935, \"sigma_obs\": 151.39382934570312, \"slope\": -0.08049512654542923, \"chain\": 0, \"draw\": 22}, {\"draws\": 22, \"mouse\": 6, \"mu_intercept_per_group\": 8.304634094238281, \"sigma_intercept_per_group\": 0.22130535542964935, \"sigma_obs\": 151.39382934570312, \"slope\": -0.08049512654542923, \"chain\": 0, \"draw\": 22}, {\"draws\": 22, \"mouse\": 7, \"mu_intercept_per_group\": 8.044581413269043, \"sigma_intercept_per_group\": 0.22130535542964935, \"sigma_obs\": 151.39382934570312, \"slope\": -0.08049512654542923, \"chain\": 0, \"draw\": 22}, {\"draws\": 23, \"mouse\": 0, \"mu_intercept_per_group\": 10.771306037902832, \"sigma_intercept_per_group\": 0.2222389280796051, \"sigma_obs\": 160.20880126953125, \"slope\": -0.07694512605667114, \"chain\": 0, \"draw\": 23}, {\"draws\": 23, \"mouse\": 1, \"mu_intercept_per_group\": 10.665118217468262, \"sigma_intercept_per_group\": 0.2222389280796051, \"sigma_obs\": 160.20880126953125, \"slope\": -0.07694512605667114, \"chain\": 0, \"draw\": 23}, {\"draws\": 23, \"mouse\": 2, \"mu_intercept_per_group\": 10.447829246520996, \"sigma_intercept_per_group\": 0.2222389280796051, \"sigma_obs\": 160.20880126953125, \"slope\": -0.07694512605667114, \"chain\": 0, \"draw\": 23}, {\"draws\": 23, \"mouse\": 3, \"mu_intercept_per_group\": 9.51457691192627, \"sigma_intercept_per_group\": 0.2222389280796051, \"sigma_obs\": 160.20880126953125, \"slope\": -0.07694512605667114, \"chain\": 0, \"draw\": 23}, {\"draws\": 23, \"mouse\": 4, \"mu_intercept_per_group\": 9.66688346862793, \"sigma_intercept_per_group\": 0.2222389280796051, \"sigma_obs\": 160.20880126953125, \"slope\": -0.07694512605667114, \"chain\": 0, \"draw\": 23}, {\"draws\": 23, \"mouse\": 5, \"mu_intercept_per_group\": 8.953923225402832, \"sigma_intercept_per_group\": 0.2222389280796051, \"sigma_obs\": 160.20880126953125, \"slope\": -0.07694512605667114, \"chain\": 0, \"draw\": 23}, {\"draws\": 23, \"mouse\": 6, \"mu_intercept_per_group\": 8.319893836975098, \"sigma_intercept_per_group\": 0.2222389280796051, \"sigma_obs\": 160.20880126953125, \"slope\": -0.07694512605667114, \"chain\": 0, \"draw\": 23}, {\"draws\": 23, \"mouse\": 7, \"mu_intercept_per_group\": 8.211158752441406, \"sigma_intercept_per_group\": 0.2222389280796051, \"sigma_obs\": 160.20880126953125, \"slope\": -0.07694512605667114, \"chain\": 0, \"draw\": 23}, {\"draws\": 24, \"mouse\": 0, \"mu_intercept_per_group\": 11.15735149383545, \"sigma_intercept_per_group\": 0.2292281687259674, \"sigma_obs\": 156.51564025878906, \"slope\": -0.07575742900371552, \"chain\": 0, \"draw\": 24}, {\"draws\": 24, \"mouse\": 1, \"mu_intercept_per_group\": 10.312777519226074, \"sigma_intercept_per_group\": 0.2292281687259674, \"sigma_obs\": 156.51564025878906, \"slope\": -0.07575742900371552, \"chain\": 0, \"draw\": 24}, {\"draws\": 24, \"mouse\": 2, \"mu_intercept_per_group\": 10.115178108215332, \"sigma_intercept_per_group\": 0.2292281687259674, \"sigma_obs\": 156.51564025878906, \"slope\": -0.07575742900371552, \"chain\": 0, \"draw\": 24}, {\"draws\": 24, \"mouse\": 3, \"mu_intercept_per_group\": 9.875290870666504, \"sigma_intercept_per_group\": 0.2292281687259674, \"sigma_obs\": 156.51564025878906, \"slope\": -0.07575742900371552, \"chain\": 0, \"draw\": 24}, {\"draws\": 24, \"mouse\": 4, \"mu_intercept_per_group\": 9.170598983764648, \"sigma_intercept_per_group\": 0.2292281687259674, \"sigma_obs\": 156.51564025878906, \"slope\": -0.07575742900371552, \"chain\": 0, \"draw\": 24}, {\"draws\": 24, \"mouse\": 5, \"mu_intercept_per_group\": 8.794739723205566, \"sigma_intercept_per_group\": 0.2292281687259674, \"sigma_obs\": 156.51564025878906, \"slope\": -0.07575742900371552, \"chain\": 0, \"draw\": 24}, {\"draws\": 24, \"mouse\": 6, \"mu_intercept_per_group\": 8.089756965637207, \"sigma_intercept_per_group\": 0.2292281687259674, \"sigma_obs\": 156.51564025878906, \"slope\": -0.07575742900371552, \"chain\": 0, \"draw\": 24}, {\"draws\": 24, \"mouse\": 7, \"mu_intercept_per_group\": 7.628662109375, \"sigma_intercept_per_group\": 0.2292281687259674, \"sigma_obs\": 156.51564025878906, \"slope\": -0.07575742900371552, \"chain\": 0, \"draw\": 24}, {\"draws\": 25, \"mouse\": 0, \"mu_intercept_per_group\": 10.932548522949219, \"sigma_intercept_per_group\": 0.21880634129047394, \"sigma_obs\": 158.73178100585938, \"slope\": -0.07476325333118439, \"chain\": 0, \"draw\": 25}, {\"draws\": 25, \"mouse\": 1, \"mu_intercept_per_group\": 11.059064865112305, \"sigma_intercept_per_group\": 0.21880634129047394, \"sigma_obs\": 158.73178100585938, \"slope\": -0.07476325333118439, \"chain\": 0, \"draw\": 25}, {\"draws\": 25, \"mouse\": 2, \"mu_intercept_per_group\": 10.702392578125, \"sigma_intercept_per_group\": 0.21880634129047394, \"sigma_obs\": 158.73178100585938, \"slope\": -0.07476325333118439, \"chain\": 0, \"draw\": 25}, {\"draws\": 25, \"mouse\": 3, \"mu_intercept_per_group\": 9.710400581359863, \"sigma_intercept_per_group\": 0.21880634129047394, \"sigma_obs\": 158.73178100585938, \"slope\": -0.07476325333118439, \"chain\": 0, \"draw\": 25}, {\"draws\": 25, \"mouse\": 4, \"mu_intercept_per_group\": 9.866921424865723, \"sigma_intercept_per_group\": 0.21880634129047394, \"sigma_obs\": 158.73178100585938, \"slope\": -0.07476325333118439, \"chain\": 0, \"draw\": 25}, {\"draws\": 25, \"mouse\": 5, \"mu_intercept_per_group\": 9.179789543151855, \"sigma_intercept_per_group\": 0.21880634129047394, \"sigma_obs\": 158.73178100585938, \"slope\": -0.07476325333118439, \"chain\": 0, \"draw\": 25}, {\"draws\": 25, \"mouse\": 6, \"mu_intercept_per_group\": 8.713796615600586, \"sigma_intercept_per_group\": 0.21880634129047394, \"sigma_obs\": 158.73178100585938, \"slope\": -0.07476325333118439, \"chain\": 0, \"draw\": 25}, {\"draws\": 25, \"mouse\": 7, \"mu_intercept_per_group\": 8.255118370056152, \"sigma_intercept_per_group\": 0.21880634129047394, \"sigma_obs\": 158.73178100585938, \"slope\": -0.07476325333118439, \"chain\": 0, \"draw\": 25}, {\"draws\": 26, \"mouse\": 0, \"mu_intercept_per_group\": 11.840862274169922, \"sigma_intercept_per_group\": 0.21202635765075684, \"sigma_obs\": 155.2538604736328, \"slope\": -0.08651082217693329, \"chain\": 0, \"draw\": 26}, {\"draws\": 26, \"mouse\": 1, \"mu_intercept_per_group\": 10.890693664550781, \"sigma_intercept_per_group\": 0.21202635765075684, \"sigma_obs\": 155.2538604736328, \"slope\": -0.08651082217693329, \"chain\": 0, \"draw\": 26}, {\"draws\": 26, \"mouse\": 2, \"mu_intercept_per_group\": 10.552103042602539, \"sigma_intercept_per_group\": 0.21202635765075684, \"sigma_obs\": 155.2538604736328, \"slope\": -0.08651082217693329, \"chain\": 0, \"draw\": 26}, {\"draws\": 26, \"mouse\": 3, \"mu_intercept_per_group\": 10.058425903320312, \"sigma_intercept_per_group\": 0.21202635765075684, \"sigma_obs\": 155.2538604736328, \"slope\": -0.08651082217693329, \"chain\": 0, \"draw\": 26}, {\"draws\": 26, \"mouse\": 4, \"mu_intercept_per_group\": 10.059659004211426, \"sigma_intercept_per_group\": 0.21202635765075684, \"sigma_obs\": 155.2538604736328, \"slope\": -0.08651082217693329, \"chain\": 0, \"draw\": 26}, {\"draws\": 26, \"mouse\": 5, \"mu_intercept_per_group\": 9.347898483276367, \"sigma_intercept_per_group\": 0.21202635765075684, \"sigma_obs\": 155.2538604736328, \"slope\": -0.08651082217693329, \"chain\": 0, \"draw\": 26}, {\"draws\": 26, \"mouse\": 6, \"mu_intercept_per_group\": 8.970298767089844, \"sigma_intercept_per_group\": 0.21202635765075684, \"sigma_obs\": 155.2538604736328, \"slope\": -0.08651082217693329, \"chain\": 0, \"draw\": 26}, {\"draws\": 26, \"mouse\": 7, \"mu_intercept_per_group\": 8.333586692810059, \"sigma_intercept_per_group\": 0.21202635765075684, \"sigma_obs\": 155.2538604736328, \"slope\": -0.08651082217693329, \"chain\": 0, \"draw\": 26}, {\"draws\": 27, \"mouse\": 0, \"mu_intercept_per_group\": 12.558145523071289, \"sigma_intercept_per_group\": 0.19773755967617035, \"sigma_obs\": 147.13516235351562, \"slope\": -0.07075975835323334, \"chain\": 0, \"draw\": 27}, {\"draws\": 27, \"mouse\": 1, \"mu_intercept_per_group\": 11.518120765686035, \"sigma_intercept_per_group\": 0.19773755967617035, \"sigma_obs\": 147.13516235351562, \"slope\": -0.07075975835323334, \"chain\": 0, \"draw\": 27}, {\"draws\": 27, \"mouse\": 2, \"mu_intercept_per_group\": 11.557616233825684, \"sigma_intercept_per_group\": 0.19773755967617035, \"sigma_obs\": 147.13516235351562, \"slope\": -0.07075975835323334, \"chain\": 0, \"draw\": 27}, {\"draws\": 27, \"mouse\": 3, \"mu_intercept_per_group\": 10.527048110961914, \"sigma_intercept_per_group\": 0.19773755967617035, \"sigma_obs\": 147.13516235351562, \"slope\": -0.07075975835323334, \"chain\": 0, \"draw\": 27}, {\"draws\": 27, \"mouse\": 4, \"mu_intercept_per_group\": 9.993895530700684, \"sigma_intercept_per_group\": 0.19773755967617035, \"sigma_obs\": 147.13516235351562, \"slope\": -0.07075975835323334, \"chain\": 0, \"draw\": 27}, {\"draws\": 27, \"mouse\": 5, \"mu_intercept_per_group\": 9.711431503295898, \"sigma_intercept_per_group\": 0.19773755967617035, \"sigma_obs\": 147.13516235351562, \"slope\": -0.07075975835323334, \"chain\": 0, \"draw\": 27}, {\"draws\": 27, \"mouse\": 6, \"mu_intercept_per_group\": 9.396356582641602, \"sigma_intercept_per_group\": 0.19773755967617035, \"sigma_obs\": 147.13516235351562, \"slope\": -0.07075975835323334, \"chain\": 0, \"draw\": 27}, {\"draws\": 27, \"mouse\": 7, \"mu_intercept_per_group\": 8.490592956542969, \"sigma_intercept_per_group\": 0.19773755967617035, \"sigma_obs\": 147.13516235351562, \"slope\": -0.07075975835323334, \"chain\": 0, \"draw\": 27}, {\"draws\": 28, \"mouse\": 0, \"mu_intercept_per_group\": 11.904204368591309, \"sigma_intercept_per_group\": 0.1979694366455078, \"sigma_obs\": 146.36318969726562, \"slope\": -0.06838235259056091, \"chain\": 0, \"draw\": 28}, {\"draws\": 28, \"mouse\": 1, \"mu_intercept_per_group\": 11.864253997802734, \"sigma_intercept_per_group\": 0.1979694366455078, \"sigma_obs\": 146.36318969726562, \"slope\": -0.06838235259056091, \"chain\": 0, \"draw\": 28}, {\"draws\": 28, \"mouse\": 2, \"mu_intercept_per_group\": 11.438035011291504, \"sigma_intercept_per_group\": 0.1979694366455078, \"sigma_obs\": 146.36318969726562, \"slope\": -0.06838235259056091, \"chain\": 0, \"draw\": 28}, {\"draws\": 28, \"mouse\": 3, \"mu_intercept_per_group\": 10.75274658203125, \"sigma_intercept_per_group\": 0.1979694366455078, \"sigma_obs\": 146.36318969726562, \"slope\": -0.06838235259056091, \"chain\": 0, \"draw\": 28}, {\"draws\": 28, \"mouse\": 4, \"mu_intercept_per_group\": 10.291215896606445, \"sigma_intercept_per_group\": 0.1979694366455078, \"sigma_obs\": 146.36318969726562, \"slope\": -0.06838235259056091, \"chain\": 0, \"draw\": 28}, {\"draws\": 28, \"mouse\": 5, \"mu_intercept_per_group\": 9.557138442993164, \"sigma_intercept_per_group\": 0.1979694366455078, \"sigma_obs\": 146.36318969726562, \"slope\": -0.06838235259056091, \"chain\": 0, \"draw\": 28}, {\"draws\": 28, \"mouse\": 6, \"mu_intercept_per_group\": 9.55141544342041, \"sigma_intercept_per_group\": 0.1979694366455078, \"sigma_obs\": 146.36318969726562, \"slope\": -0.06838235259056091, \"chain\": 0, \"draw\": 28}, {\"draws\": 28, \"mouse\": 7, \"mu_intercept_per_group\": 8.386634826660156, \"sigma_intercept_per_group\": 0.1979694366455078, \"sigma_obs\": 146.36318969726562, \"slope\": -0.06838235259056091, \"chain\": 0, \"draw\": 28}, {\"draws\": 29, \"mouse\": 0, \"mu_intercept_per_group\": 12.010645866394043, \"sigma_intercept_per_group\": 0.2042241245508194, \"sigma_obs\": 159.5938720703125, \"slope\": -0.054333459585905075, \"chain\": 0, \"draw\": 29}, {\"draws\": 29, \"mouse\": 1, \"mu_intercept_per_group\": 11.445419311523438, \"sigma_intercept_per_group\": 0.2042241245508194, \"sigma_obs\": 159.5938720703125, \"slope\": -0.054333459585905075, \"chain\": 0, \"draw\": 29}, {\"draws\": 29, \"mouse\": 2, \"mu_intercept_per_group\": 11.230908393859863, \"sigma_intercept_per_group\": 0.2042241245508194, \"sigma_obs\": 159.5938720703125, \"slope\": -0.054333459585905075, \"chain\": 0, \"draw\": 29}, {\"draws\": 29, \"mouse\": 3, \"mu_intercept_per_group\": 10.3355073928833, \"sigma_intercept_per_group\": 0.2042241245508194, \"sigma_obs\": 159.5938720703125, \"slope\": -0.054333459585905075, \"chain\": 0, \"draw\": 29}, {\"draws\": 29, \"mouse\": 4, \"mu_intercept_per_group\": 10.217263221740723, \"sigma_intercept_per_group\": 0.2042241245508194, \"sigma_obs\": 159.5938720703125, \"slope\": -0.054333459585905075, \"chain\": 0, \"draw\": 29}, {\"draws\": 29, \"mouse\": 5, \"mu_intercept_per_group\": 9.612892150878906, \"sigma_intercept_per_group\": 0.2042241245508194, \"sigma_obs\": 159.5938720703125, \"slope\": -0.054333459585905075, \"chain\": 0, \"draw\": 29}, {\"draws\": 29, \"mouse\": 6, \"mu_intercept_per_group\": 9.322864532470703, \"sigma_intercept_per_group\": 0.2042241245508194, \"sigma_obs\": 159.5938720703125, \"slope\": -0.054333459585905075, \"chain\": 0, \"draw\": 29}, {\"draws\": 29, \"mouse\": 7, \"mu_intercept_per_group\": 8.966534614562988, \"sigma_intercept_per_group\": 0.2042241245508194, \"sigma_obs\": 159.5938720703125, \"slope\": -0.054333459585905075, \"chain\": 0, \"draw\": 29}, {\"draws\": 30, \"mouse\": 0, \"mu_intercept_per_group\": 12.384507179260254, \"sigma_intercept_per_group\": 0.19332440197467804, \"sigma_obs\": 155.2415771484375, \"slope\": -0.04808824136853218, \"chain\": 0, \"draw\": 30}, {\"draws\": 30, \"mouse\": 1, \"mu_intercept_per_group\": 11.945274353027344, \"sigma_intercept_per_group\": 0.19332440197467804, \"sigma_obs\": 155.2415771484375, \"slope\": -0.04808824136853218, \"chain\": 0, \"draw\": 30}, {\"draws\": 30, \"mouse\": 2, \"mu_intercept_per_group\": 11.408815383911133, \"sigma_intercept_per_group\": 0.19332440197467804, \"sigma_obs\": 155.2415771484375, \"slope\": -0.04808824136853218, \"chain\": 0, \"draw\": 30}, {\"draws\": 30, \"mouse\": 3, \"mu_intercept_per_group\": 10.884806632995605, \"sigma_intercept_per_group\": 0.19332440197467804, \"sigma_obs\": 155.2415771484375, \"slope\": -0.04808824136853218, \"chain\": 0, \"draw\": 30}, {\"draws\": 30, \"mouse\": 4, \"mu_intercept_per_group\": 11.063650131225586, \"sigma_intercept_per_group\": 0.19332440197467804, \"sigma_obs\": 155.2415771484375, \"slope\": -0.04808824136853218, \"chain\": 0, \"draw\": 30}, {\"draws\": 30, \"mouse\": 5, \"mu_intercept_per_group\": 10.099976539611816, \"sigma_intercept_per_group\": 0.19332440197467804, \"sigma_obs\": 155.2415771484375, \"slope\": -0.04808824136853218, \"chain\": 0, \"draw\": 30}, {\"draws\": 30, \"mouse\": 6, \"mu_intercept_per_group\": 9.749479293823242, \"sigma_intercept_per_group\": 0.19332440197467804, \"sigma_obs\": 155.2415771484375, \"slope\": -0.04808824136853218, \"chain\": 0, \"draw\": 30}, {\"draws\": 30, \"mouse\": 7, \"mu_intercept_per_group\": 9.072016716003418, \"sigma_intercept_per_group\": 0.19332440197467804, \"sigma_obs\": 155.2415771484375, \"slope\": -0.04808824136853218, \"chain\": 0, \"draw\": 30}, {\"draws\": 31, \"mouse\": 0, \"mu_intercept_per_group\": 13.342658042907715, \"sigma_intercept_per_group\": 0.1836506575345993, \"sigma_obs\": 158.29656982421875, \"slope\": -0.04887787625193596, \"chain\": 0, \"draw\": 31}, {\"draws\": 31, \"mouse\": 1, \"mu_intercept_per_group\": 12.744285583496094, \"sigma_intercept_per_group\": 0.1836506575345993, \"sigma_obs\": 158.29656982421875, \"slope\": -0.04887787625193596, \"chain\": 0, \"draw\": 31}, {\"draws\": 31, \"mouse\": 2, \"mu_intercept_per_group\": 12.244319915771484, \"sigma_intercept_per_group\": 0.1836506575345993, \"sigma_obs\": 158.29656982421875, \"slope\": -0.04887787625193596, \"chain\": 0, \"draw\": 31}, {\"draws\": 31, \"mouse\": 3, \"mu_intercept_per_group\": 11.956873893737793, \"sigma_intercept_per_group\": 0.1836506575345993, \"sigma_obs\": 158.29656982421875, \"slope\": -0.04887787625193596, \"chain\": 0, \"draw\": 31}, {\"draws\": 31, \"mouse\": 4, \"mu_intercept_per_group\": 11.587830543518066, \"sigma_intercept_per_group\": 0.1836506575345993, \"sigma_obs\": 158.29656982421875, \"slope\": -0.04887787625193596, \"chain\": 0, \"draw\": 31}, {\"draws\": 31, \"mouse\": 5, \"mu_intercept_per_group\": 10.573416709899902, \"sigma_intercept_per_group\": 0.1836506575345993, \"sigma_obs\": 158.29656982421875, \"slope\": -0.04887787625193596, \"chain\": 0, \"draw\": 31}, {\"draws\": 31, \"mouse\": 6, \"mu_intercept_per_group\": 9.926431655883789, \"sigma_intercept_per_group\": 0.1836506575345993, \"sigma_obs\": 158.29656982421875, \"slope\": -0.04887787625193596, \"chain\": 0, \"draw\": 31}, {\"draws\": 31, \"mouse\": 7, \"mu_intercept_per_group\": 9.360418319702148, \"sigma_intercept_per_group\": 0.1836506575345993, \"sigma_obs\": 158.29656982421875, \"slope\": -0.04887787625193596, \"chain\": 0, \"draw\": 31}, {\"draws\": 32, \"mouse\": 0, \"mu_intercept_per_group\": 13.328156471252441, \"sigma_intercept_per_group\": 0.18491406738758087, \"sigma_obs\": 157.98460388183594, \"slope\": -0.05552322044968605, \"chain\": 0, \"draw\": 32}, {\"draws\": 32, \"mouse\": 1, \"mu_intercept_per_group\": 12.687556266784668, \"sigma_intercept_per_group\": 0.18491406738758087, \"sigma_obs\": 157.98460388183594, \"slope\": -0.05552322044968605, \"chain\": 0, \"draw\": 32}, {\"draws\": 32, \"mouse\": 2, \"mu_intercept_per_group\": 12.138906478881836, \"sigma_intercept_per_group\": 0.18491406738758087, \"sigma_obs\": 157.98460388183594, \"slope\": -0.05552322044968605, \"chain\": 0, \"draw\": 32}, {\"draws\": 32, \"mouse\": 3, \"mu_intercept_per_group\": 11.887624740600586, \"sigma_intercept_per_group\": 0.18491406738758087, \"sigma_obs\": 157.98460388183594, \"slope\": -0.05552322044968605, \"chain\": 0, \"draw\": 32}, {\"draws\": 32, \"mouse\": 4, \"mu_intercept_per_group\": 11.091164588928223, \"sigma_intercept_per_group\": 0.18491406738758087, \"sigma_obs\": 157.98460388183594, \"slope\": -0.05552322044968605, \"chain\": 0, \"draw\": 32}, {\"draws\": 32, \"mouse\": 5, \"mu_intercept_per_group\": 10.647419929504395, \"sigma_intercept_per_group\": 0.18491406738758087, \"sigma_obs\": 157.98460388183594, \"slope\": -0.05552322044968605, \"chain\": 0, \"draw\": 32}, {\"draws\": 32, \"mouse\": 6, \"mu_intercept_per_group\": 10.108101844787598, \"sigma_intercept_per_group\": 0.18491406738758087, \"sigma_obs\": 157.98460388183594, \"slope\": -0.05552322044968605, \"chain\": 0, \"draw\": 32}, {\"draws\": 32, \"mouse\": 7, \"mu_intercept_per_group\": 9.67364501953125, \"sigma_intercept_per_group\": 0.18491406738758087, \"sigma_obs\": 157.98460388183594, \"slope\": -0.05552322044968605, \"chain\": 0, \"draw\": 32}, {\"draws\": 33, \"mouse\": 0, \"mu_intercept_per_group\": 13.429580688476562, \"sigma_intercept_per_group\": 0.18317124247550964, \"sigma_obs\": 158.44253540039062, \"slope\": -0.0640580952167511, \"chain\": 0, \"draw\": 33}, {\"draws\": 33, \"mouse\": 1, \"mu_intercept_per_group\": 13.021409034729004, \"sigma_intercept_per_group\": 0.18317124247550964, \"sigma_obs\": 158.44253540039062, \"slope\": -0.0640580952167511, \"chain\": 0, \"draw\": 33}, {\"draws\": 33, \"mouse\": 2, \"mu_intercept_per_group\": 12.416704177856445, \"sigma_intercept_per_group\": 0.18317124247550964, \"sigma_obs\": 158.44253540039062, \"slope\": -0.0640580952167511, \"chain\": 0, \"draw\": 33}, {\"draws\": 33, \"mouse\": 3, \"mu_intercept_per_group\": 12.278907775878906, \"sigma_intercept_per_group\": 0.18317124247550964, \"sigma_obs\": 158.44253540039062, \"slope\": -0.0640580952167511, \"chain\": 0, \"draw\": 33}, {\"draws\": 33, \"mouse\": 4, \"mu_intercept_per_group\": 11.403136253356934, \"sigma_intercept_per_group\": 0.18317124247550964, \"sigma_obs\": 158.44253540039062, \"slope\": -0.0640580952167511, \"chain\": 0, \"draw\": 33}, {\"draws\": 33, \"mouse\": 5, \"mu_intercept_per_group\": 10.929350852966309, \"sigma_intercept_per_group\": 0.18317124247550964, \"sigma_obs\": 158.44253540039062, \"slope\": -0.0640580952167511, \"chain\": 0, \"draw\": 33}, {\"draws\": 33, \"mouse\": 6, \"mu_intercept_per_group\": 10.056842803955078, \"sigma_intercept_per_group\": 0.18317124247550964, \"sigma_obs\": 158.44253540039062, \"slope\": -0.0640580952167511, \"chain\": 0, \"draw\": 33}, {\"draws\": 33, \"mouse\": 7, \"mu_intercept_per_group\": 9.31959342956543, \"sigma_intercept_per_group\": 0.18317124247550964, \"sigma_obs\": 158.44253540039062, \"slope\": -0.0640580952167511, \"chain\": 0, \"draw\": 33}, {\"draws\": 34, \"mouse\": 0, \"mu_intercept_per_group\": 14.137749671936035, \"sigma_intercept_per_group\": 0.16990318894386292, \"sigma_obs\": 150.9186248779297, \"slope\": -0.06404374539852142, \"chain\": 0, \"draw\": 34}, {\"draws\": 34, \"mouse\": 1, \"mu_intercept_per_group\": 13.938375473022461, \"sigma_intercept_per_group\": 0.16990318894386292, \"sigma_obs\": 150.9186248779297, \"slope\": -0.06404374539852142, \"chain\": 0, \"draw\": 34}, {\"draws\": 34, \"mouse\": 2, \"mu_intercept_per_group\": 12.995052337646484, \"sigma_intercept_per_group\": 0.16990318894386292, \"sigma_obs\": 150.9186248779297, \"slope\": -0.06404374539852142, \"chain\": 0, \"draw\": 34}, {\"draws\": 34, \"mouse\": 3, \"mu_intercept_per_group\": 12.965303421020508, \"sigma_intercept_per_group\": 0.16990318894386292, \"sigma_obs\": 150.9186248779297, \"slope\": -0.06404374539852142, \"chain\": 0, \"draw\": 34}, {\"draws\": 34, \"mouse\": 4, \"mu_intercept_per_group\": 12.014226913452148, \"sigma_intercept_per_group\": 0.16990318894386292, \"sigma_obs\": 150.9186248779297, \"slope\": -0.06404374539852142, \"chain\": 0, \"draw\": 34}, {\"draws\": 34, \"mouse\": 5, \"mu_intercept_per_group\": 11.477396965026855, \"sigma_intercept_per_group\": 0.16990318894386292, \"sigma_obs\": 150.9186248779297, \"slope\": -0.06404374539852142, \"chain\": 0, \"draw\": 34}, {\"draws\": 34, \"mouse\": 6, \"mu_intercept_per_group\": 10.331945419311523, \"sigma_intercept_per_group\": 0.16990318894386292, \"sigma_obs\": 150.9186248779297, \"slope\": -0.06404374539852142, \"chain\": 0, \"draw\": 34}, {\"draws\": 34, \"mouse\": 7, \"mu_intercept_per_group\": 10.06444263458252, \"sigma_intercept_per_group\": 0.16990318894386292, \"sigma_obs\": 150.9186248779297, \"slope\": -0.06404374539852142, \"chain\": 0, \"draw\": 34}, {\"draws\": 35, \"mouse\": 0, \"mu_intercept_per_group\": 14.125138282775879, \"sigma_intercept_per_group\": 0.16788898408412933, \"sigma_obs\": 150.71661376953125, \"slope\": -0.06342929601669312, \"chain\": 0, \"draw\": 35}, {\"draws\": 35, \"mouse\": 1, \"mu_intercept_per_group\": 13.977765083312988, \"sigma_intercept_per_group\": 0.16788898408412933, \"sigma_obs\": 150.71661376953125, \"slope\": -0.06342929601669312, \"chain\": 0, \"draw\": 35}, {\"draws\": 35, \"mouse\": 2, \"mu_intercept_per_group\": 12.915895462036133, \"sigma_intercept_per_group\": 0.16788898408412933, \"sigma_obs\": 150.71661376953125, \"slope\": -0.06342929601669312, \"chain\": 0, \"draw\": 35}, {\"draws\": 35, \"mouse\": 3, \"mu_intercept_per_group\": 13.116469383239746, \"sigma_intercept_per_group\": 0.16788898408412933, \"sigma_obs\": 150.71661376953125, \"slope\": -0.06342929601669312, \"chain\": 0, \"draw\": 35}, {\"draws\": 35, \"mouse\": 4, \"mu_intercept_per_group\": 12.056647300720215, \"sigma_intercept_per_group\": 0.16788898408412933, \"sigma_obs\": 150.71661376953125, \"slope\": -0.06342929601669312, \"chain\": 0, \"draw\": 35}, {\"draws\": 35, \"mouse\": 5, \"mu_intercept_per_group\": 11.680296897888184, \"sigma_intercept_per_group\": 0.16788898408412933, \"sigma_obs\": 150.71661376953125, \"slope\": -0.06342929601669312, \"chain\": 0, \"draw\": 35}, {\"draws\": 35, \"mouse\": 6, \"mu_intercept_per_group\": 10.528166770935059, \"sigma_intercept_per_group\": 0.16788898408412933, \"sigma_obs\": 150.71661376953125, \"slope\": -0.06342929601669312, \"chain\": 0, \"draw\": 35}, {\"draws\": 35, \"mouse\": 7, \"mu_intercept_per_group\": 10.00087833404541, \"sigma_intercept_per_group\": 0.16788898408412933, \"sigma_obs\": 150.71661376953125, \"slope\": -0.06342929601669312, \"chain\": 0, \"draw\": 35}, {\"draws\": 36, \"mouse\": 0, \"mu_intercept_per_group\": 15.36538314819336, \"sigma_intercept_per_group\": 0.1623924821615219, \"sigma_obs\": 159.24267578125, \"slope\": -0.07376310229301453, \"chain\": 0, \"draw\": 36}, {\"draws\": 36, \"mouse\": 1, \"mu_intercept_per_group\": 14.504533767700195, \"sigma_intercept_per_group\": 0.1623924821615219, \"sigma_obs\": 159.24267578125, \"slope\": -0.07376310229301453, \"chain\": 0, \"draw\": 36}, {\"draws\": 36, \"mouse\": 2, \"mu_intercept_per_group\": 14.515727996826172, \"sigma_intercept_per_group\": 0.1623924821615219, \"sigma_obs\": 159.24267578125, \"slope\": -0.07376310229301453, \"chain\": 0, \"draw\": 36}, {\"draws\": 36, \"mouse\": 3, \"mu_intercept_per_group\": 13.303773880004883, \"sigma_intercept_per_group\": 0.1623924821615219, \"sigma_obs\": 159.24267578125, \"slope\": -0.07376310229301453, \"chain\": 0, \"draw\": 36}, {\"draws\": 36, \"mouse\": 4, \"mu_intercept_per_group\": 12.768081665039062, \"sigma_intercept_per_group\": 0.1623924821615219, \"sigma_obs\": 159.24267578125, \"slope\": -0.07376310229301453, \"chain\": 0, \"draw\": 36}, {\"draws\": 36, \"mouse\": 5, \"mu_intercept_per_group\": 12.298502922058105, \"sigma_intercept_per_group\": 0.1623924821615219, \"sigma_obs\": 159.24267578125, \"slope\": -0.07376310229301453, \"chain\": 0, \"draw\": 36}, {\"draws\": 36, \"mouse\": 6, \"mu_intercept_per_group\": 11.395381927490234, \"sigma_intercept_per_group\": 0.1623924821615219, \"sigma_obs\": 159.24267578125, \"slope\": -0.07376310229301453, \"chain\": 0, \"draw\": 36}, {\"draws\": 36, \"mouse\": 7, \"mu_intercept_per_group\": 10.77302360534668, \"sigma_intercept_per_group\": 0.1623924821615219, \"sigma_obs\": 159.24267578125, \"slope\": -0.07376310229301453, \"chain\": 0, \"draw\": 36}, {\"draws\": 37, \"mouse\": 0, \"mu_intercept_per_group\": 14.888121604919434, \"sigma_intercept_per_group\": 0.16439011693000793, \"sigma_obs\": 143.52166748046875, \"slope\": -0.08125050365924835, \"chain\": 0, \"draw\": 37}, {\"draws\": 37, \"mouse\": 1, \"mu_intercept_per_group\": 14.006382942199707, \"sigma_intercept_per_group\": 0.16439011693000793, \"sigma_obs\": 143.52166748046875, \"slope\": -0.08125050365924835, \"chain\": 0, \"draw\": 37}, {\"draws\": 37, \"mouse\": 2, \"mu_intercept_per_group\": 13.13503360748291, \"sigma_intercept_per_group\": 0.16439011693000793, \"sigma_obs\": 143.52166748046875, \"slope\": -0.08125050365924835, \"chain\": 0, \"draw\": 37}, {\"draws\": 37, \"mouse\": 3, \"mu_intercept_per_group\": 12.93978214263916, \"sigma_intercept_per_group\": 0.16439011693000793, \"sigma_obs\": 143.52166748046875, \"slope\": -0.08125050365924835, \"chain\": 0, \"draw\": 37}, {\"draws\": 37, \"mouse\": 4, \"mu_intercept_per_group\": 12.318002700805664, \"sigma_intercept_per_group\": 0.16439011693000793, \"sigma_obs\": 143.52166748046875, \"slope\": -0.08125050365924835, \"chain\": 0, \"draw\": 37}, {\"draws\": 37, \"mouse\": 5, \"mu_intercept_per_group\": 11.786286354064941, \"sigma_intercept_per_group\": 0.16439011693000793, \"sigma_obs\": 143.52166748046875, \"slope\": -0.08125050365924835, \"chain\": 0, \"draw\": 37}, {\"draws\": 37, \"mouse\": 6, \"mu_intercept_per_group\": 10.790371894836426, \"sigma_intercept_per_group\": 0.16439011693000793, \"sigma_obs\": 143.52166748046875, \"slope\": -0.08125050365924835, \"chain\": 0, \"draw\": 37}, {\"draws\": 37, \"mouse\": 7, \"mu_intercept_per_group\": 10.61426067352295, \"sigma_intercept_per_group\": 0.16439011693000793, \"sigma_obs\": 143.52166748046875, \"slope\": -0.08125050365924835, \"chain\": 0, \"draw\": 37}, {\"draws\": 38, \"mouse\": 0, \"mu_intercept_per_group\": 14.653085708618164, \"sigma_intercept_per_group\": 0.16177181899547577, \"sigma_obs\": 142.9649200439453, \"slope\": -0.08242718130350113, \"chain\": 0, \"draw\": 38}, {\"draws\": 38, \"mouse\": 1, \"mu_intercept_per_group\": 14.5678129196167, \"sigma_intercept_per_group\": 0.16177181899547577, \"sigma_obs\": 142.9649200439453, \"slope\": -0.08242718130350113, \"chain\": 0, \"draw\": 38}, {\"draws\": 38, \"mouse\": 2, \"mu_intercept_per_group\": 13.380377769470215, \"sigma_intercept_per_group\": 0.16177181899547577, \"sigma_obs\": 142.9649200439453, \"slope\": -0.08242718130350113, \"chain\": 0, \"draw\": 38}, {\"draws\": 38, \"mouse\": 3, \"mu_intercept_per_group\": 12.75955581665039, \"sigma_intercept_per_group\": 0.16177181899547577, \"sigma_obs\": 142.9649200439453, \"slope\": -0.08242718130350113, \"chain\": 0, \"draw\": 38}, {\"draws\": 38, \"mouse\": 4, \"mu_intercept_per_group\": 12.729517936706543, \"sigma_intercept_per_group\": 0.16177181899547577, \"sigma_obs\": 142.9649200439453, \"slope\": -0.08242718130350113, \"chain\": 0, \"draw\": 38}, {\"draws\": 38, \"mouse\": 5, \"mu_intercept_per_group\": 12.051841735839844, \"sigma_intercept_per_group\": 0.16177181899547577, \"sigma_obs\": 142.9649200439453, \"slope\": -0.08242718130350113, \"chain\": 0, \"draw\": 38}, {\"draws\": 38, \"mouse\": 6, \"mu_intercept_per_group\": 10.388434410095215, \"sigma_intercept_per_group\": 0.16177181899547577, \"sigma_obs\": 142.9649200439453, \"slope\": -0.08242718130350113, \"chain\": 0, \"draw\": 38}, {\"draws\": 38, \"mouse\": 7, \"mu_intercept_per_group\": 10.268623352050781, \"sigma_intercept_per_group\": 0.16177181899547577, \"sigma_obs\": 142.9649200439453, \"slope\": -0.08242718130350113, \"chain\": 0, \"draw\": 38}, {\"draws\": 39, \"mouse\": 0, \"mu_intercept_per_group\": 15.18024730682373, \"sigma_intercept_per_group\": 0.15017393231391907, \"sigma_obs\": 132.3500518798828, \"slope\": -0.07693736255168915, \"chain\": 0, \"draw\": 39}, {\"draws\": 39, \"mouse\": 1, \"mu_intercept_per_group\": 15.170071601867676, \"sigma_intercept_per_group\": 0.15017393231391907, \"sigma_obs\": 132.3500518798828, \"slope\": -0.07693736255168915, \"chain\": 0, \"draw\": 39}, {\"draws\": 39, \"mouse\": 2, \"mu_intercept_per_group\": 13.935449600219727, \"sigma_intercept_per_group\": 0.15017393231391907, \"sigma_obs\": 132.3500518798828, \"slope\": -0.07693736255168915, \"chain\": 0, \"draw\": 39}, {\"draws\": 39, \"mouse\": 3, \"mu_intercept_per_group\": 13.099717140197754, \"sigma_intercept_per_group\": 0.15017393231391907, \"sigma_obs\": 132.3500518798828, \"slope\": -0.07693736255168915, \"chain\": 0, \"draw\": 39}, {\"draws\": 39, \"mouse\": 4, \"mu_intercept_per_group\": 12.908485412597656, \"sigma_intercept_per_group\": 0.15017393231391907, \"sigma_obs\": 132.3500518798828, \"slope\": -0.07693736255168915, \"chain\": 0, \"draw\": 39}, {\"draws\": 39, \"mouse\": 5, \"mu_intercept_per_group\": 12.731764793395996, \"sigma_intercept_per_group\": 0.15017393231391907, \"sigma_obs\": 132.3500518798828, \"slope\": -0.07693736255168915, \"chain\": 0, \"draw\": 39}, {\"draws\": 39, \"mouse\": 6, \"mu_intercept_per_group\": 11.688039779663086, \"sigma_intercept_per_group\": 0.15017393231391907, \"sigma_obs\": 132.3500518798828, \"slope\": -0.07693736255168915, \"chain\": 0, \"draw\": 39}, {\"draws\": 39, \"mouse\": 7, \"mu_intercept_per_group\": 10.940855026245117, \"sigma_intercept_per_group\": 0.15017393231391907, \"sigma_obs\": 132.3500518798828, \"slope\": -0.07693736255168915, \"chain\": 0, \"draw\": 39}, {\"draws\": 40, \"mouse\": 0, \"mu_intercept_per_group\": 16.009828567504883, \"sigma_intercept_per_group\": 0.14597651362419128, \"sigma_obs\": 133.90670776367188, \"slope\": -0.07750191539525986, \"chain\": 0, \"draw\": 40}, {\"draws\": 40, \"mouse\": 1, \"mu_intercept_per_group\": 14.792065620422363, \"sigma_intercept_per_group\": 0.14597651362419128, \"sigma_obs\": 133.90670776367188, \"slope\": -0.07750191539525986, \"chain\": 0, \"draw\": 40}, {\"draws\": 40, \"mouse\": 2, \"mu_intercept_per_group\": 15.1626615524292, \"sigma_intercept_per_group\": 0.14597651362419128, \"sigma_obs\": 133.90670776367188, \"slope\": -0.07750191539525986, \"chain\": 0, \"draw\": 40}, {\"draws\": 40, \"mouse\": 3, \"mu_intercept_per_group\": 14.177671432495117, \"sigma_intercept_per_group\": 0.14597651362419128, \"sigma_obs\": 133.90670776367188, \"slope\": -0.07750191539525986, \"chain\": 0, \"draw\": 40}, {\"draws\": 40, \"mouse\": 4, \"mu_intercept_per_group\": 13.400554656982422, \"sigma_intercept_per_group\": 0.14597651362419128, \"sigma_obs\": 133.90670776367188, \"slope\": -0.07750191539525986, \"chain\": 0, \"draw\": 40}, {\"draws\": 40, \"mouse\": 5, \"mu_intercept_per_group\": 12.367960929870605, \"sigma_intercept_per_group\": 0.14597651362419128, \"sigma_obs\": 133.90670776367188, \"slope\": -0.07750191539525986, \"chain\": 0, \"draw\": 40}, {\"draws\": 40, \"mouse\": 6, \"mu_intercept_per_group\": 11.441349029541016, \"sigma_intercept_per_group\": 0.14597651362419128, \"sigma_obs\": 133.90670776367188, \"slope\": -0.07750191539525986, \"chain\": 0, \"draw\": 40}, {\"draws\": 40, \"mouse\": 7, \"mu_intercept_per_group\": 10.356000900268555, \"sigma_intercept_per_group\": 0.14597651362419128, \"sigma_obs\": 133.90670776367188, \"slope\": -0.07750191539525986, \"chain\": 0, \"draw\": 40}, {\"draws\": 41, \"mouse\": 0, \"mu_intercept_per_group\": 15.943314552307129, \"sigma_intercept_per_group\": 0.14787857234477997, \"sigma_obs\": 135.8484649658203, \"slope\": -0.076487697660923, \"chain\": 0, \"draw\": 41}, {\"draws\": 41, \"mouse\": 1, \"mu_intercept_per_group\": 15.056673049926758, \"sigma_intercept_per_group\": 0.14787857234477997, \"sigma_obs\": 135.8484649658203, \"slope\": -0.076487697660923, \"chain\": 0, \"draw\": 41}, {\"draws\": 41, \"mouse\": 2, \"mu_intercept_per_group\": 14.573054313659668, \"sigma_intercept_per_group\": 0.14787857234477997, \"sigma_obs\": 135.8484649658203, \"slope\": -0.076487697660923, \"chain\": 0, \"draw\": 41}, {\"draws\": 41, \"mouse\": 3, \"mu_intercept_per_group\": 13.986356735229492, \"sigma_intercept_per_group\": 0.14787857234477997, \"sigma_obs\": 135.8484649658203, \"slope\": -0.076487697660923, \"chain\": 0, \"draw\": 41}, {\"draws\": 41, \"mouse\": 4, \"mu_intercept_per_group\": 13.148555755615234, \"sigma_intercept_per_group\": 0.14787857234477997, \"sigma_obs\": 135.8484649658203, \"slope\": -0.076487697660923, \"chain\": 0, \"draw\": 41}, {\"draws\": 41, \"mouse\": 5, \"mu_intercept_per_group\": 12.053946495056152, \"sigma_intercept_per_group\": 0.14787857234477997, \"sigma_obs\": 135.8484649658203, \"slope\": -0.076487697660923, \"chain\": 0, \"draw\": 41}, {\"draws\": 41, \"mouse\": 6, \"mu_intercept_per_group\": 11.51936149597168, \"sigma_intercept_per_group\": 0.14787857234477997, \"sigma_obs\": 135.8484649658203, \"slope\": -0.076487697660923, \"chain\": 0, \"draw\": 41}, {\"draws\": 41, \"mouse\": 7, \"mu_intercept_per_group\": 10.73415756225586, \"sigma_intercept_per_group\": 0.14787857234477997, \"sigma_obs\": 135.8484649658203, \"slope\": -0.076487697660923, \"chain\": 0, \"draw\": 41}, {\"draws\": 42, \"mouse\": 0, \"mu_intercept_per_group\": 15.058738708496094, \"sigma_intercept_per_group\": 0.15659713745117188, \"sigma_obs\": 140.39320373535156, \"slope\": -0.08681168407201767, \"chain\": 0, \"draw\": 42}, {\"draws\": 42, \"mouse\": 1, \"mu_intercept_per_group\": 14.470413208007812, \"sigma_intercept_per_group\": 0.15659713745117188, \"sigma_obs\": 140.39320373535156, \"slope\": -0.08681168407201767, \"chain\": 0, \"draw\": 42}, {\"draws\": 42, \"mouse\": 2, \"mu_intercept_per_group\": 14.179182052612305, \"sigma_intercept_per_group\": 0.15659713745117188, \"sigma_obs\": 140.39320373535156, \"slope\": -0.08681168407201767, \"chain\": 0, \"draw\": 42}, {\"draws\": 42, \"mouse\": 3, \"mu_intercept_per_group\": 13.214781761169434, \"sigma_intercept_per_group\": 0.15659713745117188, \"sigma_obs\": 140.39320373535156, \"slope\": -0.08681168407201767, \"chain\": 0, \"draw\": 42}, {\"draws\": 42, \"mouse\": 4, \"mu_intercept_per_group\": 13.1261625289917, \"sigma_intercept_per_group\": 0.15659713745117188, \"sigma_obs\": 140.39320373535156, \"slope\": -0.08681168407201767, \"chain\": 0, \"draw\": 42}, {\"draws\": 42, \"mouse\": 5, \"mu_intercept_per_group\": 11.972806930541992, \"sigma_intercept_per_group\": 0.15659713745117188, \"sigma_obs\": 140.39320373535156, \"slope\": -0.08681168407201767, \"chain\": 0, \"draw\": 42}, {\"draws\": 42, \"mouse\": 6, \"mu_intercept_per_group\": 11.284676551818848, \"sigma_intercept_per_group\": 0.15659713745117188, \"sigma_obs\": 140.39320373535156, \"slope\": -0.08681168407201767, \"chain\": 0, \"draw\": 42}, {\"draws\": 42, \"mouse\": 7, \"mu_intercept_per_group\": 10.506525039672852, \"sigma_intercept_per_group\": 0.15659713745117188, \"sigma_obs\": 140.39320373535156, \"slope\": -0.08681168407201767, \"chain\": 0, \"draw\": 42}, {\"draws\": 43, \"mouse\": 0, \"mu_intercept_per_group\": 15.768949508666992, \"sigma_intercept_per_group\": 0.1558174192905426, \"sigma_obs\": 152.50979614257812, \"slope\": -0.08733822405338287, \"chain\": 0, \"draw\": 43}, {\"draws\": 43, \"mouse\": 1, \"mu_intercept_per_group\": 15.20272159576416, \"sigma_intercept_per_group\": 0.1558174192905426, \"sigma_obs\": 152.50979614257812, \"slope\": -0.08733822405338287, \"chain\": 0, \"draw\": 43}, {\"draws\": 43, \"mouse\": 2, \"mu_intercept_per_group\": 14.632454872131348, \"sigma_intercept_per_group\": 0.1558174192905426, \"sigma_obs\": 152.50979614257812, \"slope\": -0.08733822405338287, \"chain\": 0, \"draw\": 43}, {\"draws\": 43, \"mouse\": 3, \"mu_intercept_per_group\": 13.910987854003906, \"sigma_intercept_per_group\": 0.1558174192905426, \"sigma_obs\": 152.50979614257812, \"slope\": -0.08733822405338287, \"chain\": 0, \"draw\": 43}, {\"draws\": 43, \"mouse\": 4, \"mu_intercept_per_group\": 13.551403045654297, \"sigma_intercept_per_group\": 0.1558174192905426, \"sigma_obs\": 152.50979614257812, \"slope\": -0.08733822405338287, \"chain\": 0, \"draw\": 43}, {\"draws\": 43, \"mouse\": 5, \"mu_intercept_per_group\": 12.525671005249023, \"sigma_intercept_per_group\": 0.1558174192905426, \"sigma_obs\": 152.50979614257812, \"slope\": -0.08733822405338287, \"chain\": 0, \"draw\": 43}, {\"draws\": 43, \"mouse\": 6, \"mu_intercept_per_group\": 11.594374656677246, \"sigma_intercept_per_group\": 0.1558174192905426, \"sigma_obs\": 152.50979614257812, \"slope\": -0.08733822405338287, \"chain\": 0, \"draw\": 43}, {\"draws\": 43, \"mouse\": 7, \"mu_intercept_per_group\": 11.228170394897461, \"sigma_intercept_per_group\": 0.1558174192905426, \"sigma_obs\": 152.50979614257812, \"slope\": -0.08733822405338287, \"chain\": 0, \"draw\": 43}, {\"draws\": 44, \"mouse\": 0, \"mu_intercept_per_group\": 10.678666114807129, \"sigma_intercept_per_group\": 0.23160052299499512, \"sigma_obs\": 166.13394165039062, \"slope\": -0.05903919041156769, \"chain\": 0, \"draw\": 44}, {\"draws\": 44, \"mouse\": 1, \"mu_intercept_per_group\": 10.362520217895508, \"sigma_intercept_per_group\": 0.23160052299499512, \"sigma_obs\": 166.13394165039062, \"slope\": -0.05903919041156769, \"chain\": 0, \"draw\": 44}, {\"draws\": 44, \"mouse\": 2, \"mu_intercept_per_group\": 10.048316955566406, \"sigma_intercept_per_group\": 0.23160052299499512, \"sigma_obs\": 166.13394165039062, \"slope\": -0.05903919041156769, \"chain\": 0, \"draw\": 44}, {\"draws\": 44, \"mouse\": 3, \"mu_intercept_per_group\": 9.499088287353516, \"sigma_intercept_per_group\": 0.23160052299499512, \"sigma_obs\": 166.13394165039062, \"slope\": -0.05903919041156769, \"chain\": 0, \"draw\": 44}, {\"draws\": 44, \"mouse\": 4, \"mu_intercept_per_group\": 9.45133113861084, \"sigma_intercept_per_group\": 0.23160052299499512, \"sigma_obs\": 166.13394165039062, \"slope\": -0.05903919041156769, \"chain\": 0, \"draw\": 44}, {\"draws\": 44, \"mouse\": 5, \"mu_intercept_per_group\": 9.015753746032715, \"sigma_intercept_per_group\": 0.23160052299499512, \"sigma_obs\": 166.13394165039062, \"slope\": -0.05903919041156769, \"chain\": 0, \"draw\": 44}, {\"draws\": 44, \"mouse\": 6, \"mu_intercept_per_group\": 7.746281623840332, \"sigma_intercept_per_group\": 0.23160052299499512, \"sigma_obs\": 166.13394165039062, \"slope\": -0.05903919041156769, \"chain\": 0, \"draw\": 44}, {\"draws\": 44, \"mouse\": 7, \"mu_intercept_per_group\": 7.423119068145752, \"sigma_intercept_per_group\": 0.23160052299499512, \"sigma_obs\": 166.13394165039062, \"slope\": -0.05903919041156769, \"chain\": 0, \"draw\": 44}, {\"draws\": 45, \"mouse\": 0, \"mu_intercept_per_group\": 10.908258438110352, \"sigma_intercept_per_group\": 0.2307780236005783, \"sigma_obs\": 167.02413940429688, \"slope\": -0.056187037378549576, \"chain\": 0, \"draw\": 45}, {\"draws\": 45, \"mouse\": 1, \"mu_intercept_per_group\": 10.47677993774414, \"sigma_intercept_per_group\": 0.2307780236005783, \"sigma_obs\": 167.02413940429688, \"slope\": -0.056187037378549576, \"chain\": 0, \"draw\": 45}, {\"draws\": 45, \"mouse\": 2, \"mu_intercept_per_group\": 10.356009483337402, \"sigma_intercept_per_group\": 0.2307780236005783, \"sigma_obs\": 167.02413940429688, \"slope\": -0.056187037378549576, \"chain\": 0, \"draw\": 45}, {\"draws\": 45, \"mouse\": 3, \"mu_intercept_per_group\": 9.674790382385254, \"sigma_intercept_per_group\": 0.2307780236005783, \"sigma_obs\": 167.02413940429688, \"slope\": -0.056187037378549576, \"chain\": 0, \"draw\": 45}, {\"draws\": 45, \"mouse\": 4, \"mu_intercept_per_group\": 9.18995189666748, \"sigma_intercept_per_group\": 0.2307780236005783, \"sigma_obs\": 167.02413940429688, \"slope\": -0.056187037378549576, \"chain\": 0, \"draw\": 45}, {\"draws\": 45, \"mouse\": 5, \"mu_intercept_per_group\": 8.70778751373291, \"sigma_intercept_per_group\": 0.2307780236005783, \"sigma_obs\": 167.02413940429688, \"slope\": -0.056187037378549576, \"chain\": 0, \"draw\": 45}, {\"draws\": 45, \"mouse\": 6, \"mu_intercept_per_group\": 8.536287307739258, \"sigma_intercept_per_group\": 0.2307780236005783, \"sigma_obs\": 167.02413940429688, \"slope\": -0.056187037378549576, \"chain\": 0, \"draw\": 45}, {\"draws\": 45, \"mouse\": 7, \"mu_intercept_per_group\": 8.14066219329834, \"sigma_intercept_per_group\": 0.2307780236005783, \"sigma_obs\": 167.02413940429688, \"slope\": -0.056187037378549576, \"chain\": 0, \"draw\": 45}, {\"draws\": 46, \"mouse\": 0, \"mu_intercept_per_group\": 12.051596641540527, \"sigma_intercept_per_group\": 0.19991625845432281, \"sigma_obs\": 154.44284057617188, \"slope\": -0.06749604642391205, \"chain\": 0, \"draw\": 46}, {\"draws\": 46, \"mouse\": 1, \"mu_intercept_per_group\": 11.509162902832031, \"sigma_intercept_per_group\": 0.19991625845432281, \"sigma_obs\": 154.44284057617188, \"slope\": -0.06749604642391205, \"chain\": 0, \"draw\": 46}, {\"draws\": 46, \"mouse\": 2, \"mu_intercept_per_group\": 11.299884796142578, \"sigma_intercept_per_group\": 0.19991625845432281, \"sigma_obs\": 154.44284057617188, \"slope\": -0.06749604642391205, \"chain\": 0, \"draw\": 46}, {\"draws\": 46, \"mouse\": 3, \"mu_intercept_per_group\": 10.803784370422363, \"sigma_intercept_per_group\": 0.19991625845432281, \"sigma_obs\": 154.44284057617188, \"slope\": -0.06749604642391205, \"chain\": 0, \"draw\": 46}, {\"draws\": 46, \"mouse\": 4, \"mu_intercept_per_group\": 10.249937057495117, \"sigma_intercept_per_group\": 0.19991625845432281, \"sigma_obs\": 154.44284057617188, \"slope\": -0.06749604642391205, \"chain\": 0, \"draw\": 46}, {\"draws\": 46, \"mouse\": 5, \"mu_intercept_per_group\": 9.683052062988281, \"sigma_intercept_per_group\": 0.19991625845432281, \"sigma_obs\": 154.44284057617188, \"slope\": -0.06749604642391205, \"chain\": 0, \"draw\": 46}, {\"draws\": 46, \"mouse\": 6, \"mu_intercept_per_group\": 9.535578727722168, \"sigma_intercept_per_group\": 0.19991625845432281, \"sigma_obs\": 154.44284057617188, \"slope\": -0.06749604642391205, \"chain\": 0, \"draw\": 46}, {\"draws\": 46, \"mouse\": 7, \"mu_intercept_per_group\": 8.614727020263672, \"sigma_intercept_per_group\": 0.19991625845432281, \"sigma_obs\": 154.44284057617188, \"slope\": -0.06749604642391205, \"chain\": 0, \"draw\": 46}, {\"draws\": 47, \"mouse\": 0, \"mu_intercept_per_group\": 13.532772064208984, \"sigma_intercept_per_group\": 0.17903828620910645, \"sigma_obs\": 152.53895568847656, \"slope\": -0.06651189923286438, \"chain\": 0, \"draw\": 47}, {\"draws\": 47, \"mouse\": 1, \"mu_intercept_per_group\": 13.048334121704102, \"sigma_intercept_per_group\": 0.17903828620910645, \"sigma_obs\": 152.53895568847656, \"slope\": -0.06651189923286438, \"chain\": 0, \"draw\": 47}, {\"draws\": 47, \"mouse\": 2, \"mu_intercept_per_group\": 12.61510944366455, \"sigma_intercept_per_group\": 0.17903828620910645, \"sigma_obs\": 152.53895568847656, \"slope\": -0.06651189923286438, \"chain\": 0, \"draw\": 47}, {\"draws\": 47, \"mouse\": 3, \"mu_intercept_per_group\": 11.582847595214844, \"sigma_intercept_per_group\": 0.17903828620910645, \"sigma_obs\": 152.53895568847656, \"slope\": -0.06651189923286438, \"chain\": 0, \"draw\": 47}, {\"draws\": 47, \"mouse\": 4, \"mu_intercept_per_group\": 11.574597358703613, \"sigma_intercept_per_group\": 0.17903828620910645, \"sigma_obs\": 152.53895568847656, \"slope\": -0.06651189923286438, \"chain\": 0, \"draw\": 47}, {\"draws\": 47, \"mouse\": 5, \"mu_intercept_per_group\": 10.809576988220215, \"sigma_intercept_per_group\": 0.17903828620910645, \"sigma_obs\": 152.53895568847656, \"slope\": -0.06651189923286438, \"chain\": 0, \"draw\": 47}, {\"draws\": 47, \"mouse\": 6, \"mu_intercept_per_group\": 10.479571342468262, \"sigma_intercept_per_group\": 0.17903828620910645, \"sigma_obs\": 152.53895568847656, \"slope\": -0.06651189923286438, \"chain\": 0, \"draw\": 47}, {\"draws\": 47, \"mouse\": 7, \"mu_intercept_per_group\": 9.81503677368164, \"sigma_intercept_per_group\": 0.17903828620910645, \"sigma_obs\": 152.53895568847656, \"slope\": -0.06651189923286438, \"chain\": 0, \"draw\": 47}, {\"draws\": 48, \"mouse\": 0, \"mu_intercept_per_group\": 13.615897178649902, \"sigma_intercept_per_group\": 0.17854735255241394, \"sigma_obs\": 150.40000915527344, \"slope\": -0.0694739818572998, \"chain\": 0, \"draw\": 48}, {\"draws\": 48, \"mouse\": 1, \"mu_intercept_per_group\": 12.950519561767578, \"sigma_intercept_per_group\": 0.17854735255241394, \"sigma_obs\": 150.40000915527344, \"slope\": -0.0694739818572998, \"chain\": 0, \"draw\": 48}, {\"draws\": 48, \"mouse\": 2, \"mu_intercept_per_group\": 12.577744483947754, \"sigma_intercept_per_group\": 0.17854735255241394, \"sigma_obs\": 150.40000915527344, \"slope\": -0.0694739818572998, \"chain\": 0, \"draw\": 48}, {\"draws\": 48, \"mouse\": 3, \"mu_intercept_per_group\": 12.172019958496094, \"sigma_intercept_per_group\": 0.17854735255241394, \"sigma_obs\": 150.40000915527344, \"slope\": -0.0694739818572998, \"chain\": 0, \"draw\": 48}, {\"draws\": 48, \"mouse\": 4, \"mu_intercept_per_group\": 11.554543495178223, \"sigma_intercept_per_group\": 0.17854735255241394, \"sigma_obs\": 150.40000915527344, \"slope\": -0.0694739818572998, \"chain\": 0, \"draw\": 48}, {\"draws\": 48, \"mouse\": 5, \"mu_intercept_per_group\": 10.965943336486816, \"sigma_intercept_per_group\": 0.17854735255241394, \"sigma_obs\": 150.40000915527344, \"slope\": -0.0694739818572998, \"chain\": 0, \"draw\": 48}, {\"draws\": 48, \"mouse\": 6, \"mu_intercept_per_group\": 9.964704513549805, \"sigma_intercept_per_group\": 0.17854735255241394, \"sigma_obs\": 150.40000915527344, \"slope\": -0.0694739818572998, \"chain\": 0, \"draw\": 48}, {\"draws\": 48, \"mouse\": 7, \"mu_intercept_per_group\": 9.65727424621582, \"sigma_intercept_per_group\": 0.17854735255241394, \"sigma_obs\": 150.40000915527344, \"slope\": -0.0694739818572998, \"chain\": 0, \"draw\": 48}, {\"draws\": 49, \"mouse\": 0, \"mu_intercept_per_group\": 13.411870002746582, \"sigma_intercept_per_group\": 0.17899946868419647, \"sigma_obs\": 150.43280029296875, \"slope\": -0.07012995332479477, \"chain\": 0, \"draw\": 49}, {\"draws\": 49, \"mouse\": 1, \"mu_intercept_per_group\": 12.911690711975098, \"sigma_intercept_per_group\": 0.17899946868419647, \"sigma_obs\": 150.43280029296875, \"slope\": -0.07012995332479477, \"chain\": 0, \"draw\": 49}, {\"draws\": 49, \"mouse\": 2, \"mu_intercept_per_group\": 12.469815254211426, \"sigma_intercept_per_group\": 0.17899946868419647, \"sigma_obs\": 150.43280029296875, \"slope\": -0.07012995332479477, \"chain\": 0, \"draw\": 49}, {\"draws\": 49, \"mouse\": 3, \"mu_intercept_per_group\": 12.325957298278809, \"sigma_intercept_per_group\": 0.17899946868419647, \"sigma_obs\": 150.43280029296875, \"slope\": -0.07012995332479477, \"chain\": 0, \"draw\": 49}, {\"draws\": 49, \"mouse\": 4, \"mu_intercept_per_group\": 11.548341751098633, \"sigma_intercept_per_group\": 0.17899946868419647, \"sigma_obs\": 150.43280029296875, \"slope\": -0.07012995332479477, \"chain\": 0, \"draw\": 49}, {\"draws\": 49, \"mouse\": 5, \"mu_intercept_per_group\": 10.981098175048828, \"sigma_intercept_per_group\": 0.17899946868419647, \"sigma_obs\": 150.43280029296875, \"slope\": -0.07012995332479477, \"chain\": 0, \"draw\": 49}, {\"draws\": 49, \"mouse\": 6, \"mu_intercept_per_group\": 9.938002586364746, \"sigma_intercept_per_group\": 0.17899946868419647, \"sigma_obs\": 150.43280029296875, \"slope\": -0.07012995332479477, \"chain\": 0, \"draw\": 49}, {\"draws\": 49, \"mouse\": 7, \"mu_intercept_per_group\": 9.640206336975098, \"sigma_intercept_per_group\": 0.17899946868419647, \"sigma_obs\": 150.43280029296875, \"slope\": -0.07012995332479477, \"chain\": 0, \"draw\": 49}, {\"draws\": 50, \"mouse\": 0, \"mu_intercept_per_group\": 13.959020614624023, \"sigma_intercept_per_group\": 0.17959265410900116, \"sigma_obs\": 166.35971069335938, \"slope\": -0.07664711028337479, \"chain\": 0, \"draw\": 50}, {\"draws\": 50, \"mouse\": 1, \"mu_intercept_per_group\": 13.620585441589355, \"sigma_intercept_per_group\": 0.17959265410900116, \"sigma_obs\": 166.35971069335938, \"slope\": -0.07664711028337479, \"chain\": 0, \"draw\": 50}, {\"draws\": 50, \"mouse\": 2, \"mu_intercept_per_group\": 13.238819122314453, \"sigma_intercept_per_group\": 0.17959265410900116, \"sigma_obs\": 166.35971069335938, \"slope\": -0.07664711028337479, \"chain\": 0, \"draw\": 50}, {\"draws\": 50, \"mouse\": 3, \"mu_intercept_per_group\": 12.33960247039795, \"sigma_intercept_per_group\": 0.17959265410900116, \"sigma_obs\": 166.35971069335938, \"slope\": -0.07664711028337479, \"chain\": 0, \"draw\": 50}, {\"draws\": 50, \"mouse\": 4, \"mu_intercept_per_group\": 12.376866340637207, \"sigma_intercept_per_group\": 0.17959265410900116, \"sigma_obs\": 166.35971069335938, \"slope\": -0.07664711028337479, \"chain\": 0, \"draw\": 50}, {\"draws\": 50, \"mouse\": 5, \"mu_intercept_per_group\": 11.639704704284668, \"sigma_intercept_per_group\": 0.17959265410900116, \"sigma_obs\": 166.35971069335938, \"slope\": -0.07664711028337479, \"chain\": 0, \"draw\": 50}, {\"draws\": 50, \"mouse\": 6, \"mu_intercept_per_group\": 10.619596481323242, \"sigma_intercept_per_group\": 0.17959265410900116, \"sigma_obs\": 166.35971069335938, \"slope\": -0.07664711028337479, \"chain\": 0, \"draw\": 50}, {\"draws\": 50, \"mouse\": 7, \"mu_intercept_per_group\": 9.894713401794434, \"sigma_intercept_per_group\": 0.17959265410900116, \"sigma_obs\": 166.35971069335938, \"slope\": -0.07664711028337479, \"chain\": 0, \"draw\": 50}, {\"draws\": 51, \"mouse\": 0, \"mu_intercept_per_group\": 13.658068656921387, \"sigma_intercept_per_group\": 0.17881733179092407, \"sigma_obs\": 165.62408447265625, \"slope\": -0.07742436230182648, \"chain\": 0, \"draw\": 51}, {\"draws\": 51, \"mouse\": 1, \"mu_intercept_per_group\": 13.746699333190918, \"sigma_intercept_per_group\": 0.17881733179092407, \"sigma_obs\": 165.62408447265625, \"slope\": -0.07742436230182648, \"chain\": 0, \"draw\": 51}, {\"draws\": 51, \"mouse\": 2, \"mu_intercept_per_group\": 12.88280200958252, \"sigma_intercept_per_group\": 0.17881733179092407, \"sigma_obs\": 165.62408447265625, \"slope\": -0.07742436230182648, \"chain\": 0, \"draw\": 51}, {\"draws\": 51, \"mouse\": 3, \"mu_intercept_per_group\": 12.386348724365234, \"sigma_intercept_per_group\": 0.17881733179092407, \"sigma_obs\": 165.62408447265625, \"slope\": -0.07742436230182648, \"chain\": 0, \"draw\": 51}, {\"draws\": 51, \"mouse\": 4, \"mu_intercept_per_group\": 12.553013801574707, \"sigma_intercept_per_group\": 0.17881733179092407, \"sigma_obs\": 165.62408447265625, \"slope\": -0.07742436230182648, \"chain\": 0, \"draw\": 51}, {\"draws\": 51, \"mouse\": 5, \"mu_intercept_per_group\": 11.535608291625977, \"sigma_intercept_per_group\": 0.17881733179092407, \"sigma_obs\": 165.62408447265625, \"slope\": -0.07742436230182648, \"chain\": 0, \"draw\": 51}, {\"draws\": 51, \"mouse\": 6, \"mu_intercept_per_group\": 10.440184593200684, \"sigma_intercept_per_group\": 0.17881733179092407, \"sigma_obs\": 165.62408447265625, \"slope\": -0.07742436230182648, \"chain\": 0, \"draw\": 51}, {\"draws\": 51, \"mouse\": 7, \"mu_intercept_per_group\": 10.026606559753418, \"sigma_intercept_per_group\": 0.17881733179092407, \"sigma_obs\": 165.62408447265625, \"slope\": -0.07742436230182648, \"chain\": 0, \"draw\": 51}, {\"draws\": 52, \"mouse\": 0, \"mu_intercept_per_group\": 14.060399055480957, \"sigma_intercept_per_group\": 0.1771198809146881, \"sigma_obs\": 169.0983123779297, \"slope\": -0.08501783758401871, \"chain\": 0, \"draw\": 52}, {\"draws\": 52, \"mouse\": 1, \"mu_intercept_per_group\": 14.197578430175781, \"sigma_intercept_per_group\": 0.1771198809146881, \"sigma_obs\": 169.0983123779297, \"slope\": -0.08501783758401871, \"chain\": 0, \"draw\": 52}, {\"draws\": 52, \"mouse\": 2, \"mu_intercept_per_group\": 13.276915550231934, \"sigma_intercept_per_group\": 0.1771198809146881, \"sigma_obs\": 169.0983123779297, \"slope\": -0.08501783758401871, \"chain\": 0, \"draw\": 52}, {\"draws\": 52, \"mouse\": 3, \"mu_intercept_per_group\": 12.750472068786621, \"sigma_intercept_per_group\": 0.1771198809146881, \"sigma_obs\": 169.0983123779297, \"slope\": -0.08501783758401871, \"chain\": 0, \"draw\": 52}, {\"draws\": 52, \"mouse\": 4, \"mu_intercept_per_group\": 12.301499366760254, \"sigma_intercept_per_group\": 0.1771198809146881, \"sigma_obs\": 169.0983123779297, \"slope\": -0.08501783758401871, \"chain\": 0, \"draw\": 52}, {\"draws\": 52, \"mouse\": 5, \"mu_intercept_per_group\": 11.920921325683594, \"sigma_intercept_per_group\": 0.1771198809146881, \"sigma_obs\": 169.0983123779297, \"slope\": -0.08501783758401871, \"chain\": 0, \"draw\": 52}, {\"draws\": 52, \"mouse\": 6, \"mu_intercept_per_group\": 11.560277938842773, \"sigma_intercept_per_group\": 0.1771198809146881, \"sigma_obs\": 169.0983123779297, \"slope\": -0.08501783758401871, \"chain\": 0, \"draw\": 52}, {\"draws\": 52, \"mouse\": 7, \"mu_intercept_per_group\": 10.52945327758789, \"sigma_intercept_per_group\": 0.1771198809146881, \"sigma_obs\": 169.0983123779297, \"slope\": -0.08501783758401871, \"chain\": 0, \"draw\": 52}, {\"draws\": 53, \"mouse\": 0, \"mu_intercept_per_group\": 14.164900779724121, \"sigma_intercept_per_group\": 0.17713415622711182, \"sigma_obs\": 170.07354736328125, \"slope\": -0.08507801592350006, \"chain\": 0, \"draw\": 53}, {\"draws\": 53, \"mouse\": 1, \"mu_intercept_per_group\": 13.929883003234863, \"sigma_intercept_per_group\": 0.17713415622711182, \"sigma_obs\": 170.07354736328125, \"slope\": -0.08507801592350006, \"chain\": 0, \"draw\": 53}, {\"draws\": 53, \"mouse\": 2, \"mu_intercept_per_group\": 13.496155738830566, \"sigma_intercept_per_group\": 0.17713415622711182, \"sigma_obs\": 170.07354736328125, \"slope\": -0.08507801592350006, \"chain\": 0, \"draw\": 53}, {\"draws\": 53, \"mouse\": 3, \"mu_intercept_per_group\": 12.787067413330078, \"sigma_intercept_per_group\": 0.17713415622711182, \"sigma_obs\": 170.07354736328125, \"slope\": -0.08507801592350006, \"chain\": 0, \"draw\": 53}, {\"draws\": 53, \"mouse\": 4, \"mu_intercept_per_group\": 12.146099090576172, \"sigma_intercept_per_group\": 0.17713415622711182, \"sigma_obs\": 170.07354736328125, \"slope\": -0.08507801592350006, \"chain\": 0, \"draw\": 53}, {\"draws\": 53, \"mouse\": 5, \"mu_intercept_per_group\": 11.79558277130127, \"sigma_intercept_per_group\": 0.17713415622711182, \"sigma_obs\": 170.07354736328125, \"slope\": -0.08507801592350006, \"chain\": 0, \"draw\": 53}, {\"draws\": 53, \"mouse\": 6, \"mu_intercept_per_group\": 11.44605827331543, \"sigma_intercept_per_group\": 0.17713415622711182, \"sigma_obs\": 170.07354736328125, \"slope\": -0.08507801592350006, \"chain\": 0, \"draw\": 53}, {\"draws\": 53, \"mouse\": 7, \"mu_intercept_per_group\": 10.448501586914062, \"sigma_intercept_per_group\": 0.17713415622711182, \"sigma_obs\": 170.07354736328125, \"slope\": -0.08507801592350006, \"chain\": 0, \"draw\": 53}, {\"draws\": 54, \"mouse\": 0, \"mu_intercept_per_group\": 9.905590057373047, \"sigma_intercept_per_group\": 0.2398945540189743, \"sigma_obs\": 156.91049194335938, \"slope\": -0.0529816634953022, \"chain\": 0, \"draw\": 54}, {\"draws\": 54, \"mouse\": 1, \"mu_intercept_per_group\": 9.74461841583252, \"sigma_intercept_per_group\": 0.2398945540189743, \"sigma_obs\": 156.91049194335938, \"slope\": -0.0529816634953022, \"chain\": 0, \"draw\": 54}, {\"draws\": 54, \"mouse\": 2, \"mu_intercept_per_group\": 9.750185012817383, \"sigma_intercept_per_group\": 0.2398945540189743, \"sigma_obs\": 156.91049194335938, \"slope\": -0.0529816634953022, \"chain\": 0, \"draw\": 54}, {\"draws\": 54, \"mouse\": 3, \"mu_intercept_per_group\": 9.136056900024414, \"sigma_intercept_per_group\": 0.2398945540189743, \"sigma_obs\": 156.91049194335938, \"slope\": -0.0529816634953022, \"chain\": 0, \"draw\": 54}, {\"draws\": 54, \"mouse\": 4, \"mu_intercept_per_group\": 8.62152099609375, \"sigma_intercept_per_group\": 0.2398945540189743, \"sigma_obs\": 156.91049194335938, \"slope\": -0.0529816634953022, \"chain\": 0, \"draw\": 54}, {\"draws\": 54, \"mouse\": 5, \"mu_intercept_per_group\": 8.386284828186035, \"sigma_intercept_per_group\": 0.2398945540189743, \"sigma_obs\": 156.91049194335938, \"slope\": -0.0529816634953022, \"chain\": 0, \"draw\": 54}, {\"draws\": 54, \"mouse\": 6, \"mu_intercept_per_group\": 7.42163610458374, \"sigma_intercept_per_group\": 0.2398945540189743, \"sigma_obs\": 156.91049194335938, \"slope\": -0.0529816634953022, \"chain\": 0, \"draw\": 54}, {\"draws\": 54, \"mouse\": 7, \"mu_intercept_per_group\": 7.074305057525635, \"sigma_intercept_per_group\": 0.2398945540189743, \"sigma_obs\": 156.91049194335938, \"slope\": -0.0529816634953022, \"chain\": 0, \"draw\": 54}, {\"draws\": 55, \"mouse\": 0, \"mu_intercept_per_group\": 9.992388725280762, \"sigma_intercept_per_group\": 0.24634918570518494, \"sigma_obs\": 154.7362060546875, \"slope\": -0.05156698822975159, \"chain\": 0, \"draw\": 55}, {\"draws\": 55, \"mouse\": 1, \"mu_intercept_per_group\": 9.594450950622559, \"sigma_intercept_per_group\": 0.24634918570518494, \"sigma_obs\": 154.7362060546875, \"slope\": -0.05156698822975159, \"chain\": 0, \"draw\": 55}, {\"draws\": 55, \"mouse\": 2, \"mu_intercept_per_group\": 9.062707901000977, \"sigma_intercept_per_group\": 0.24634918570518494, \"sigma_obs\": 154.7362060546875, \"slope\": -0.05156698822975159, \"chain\": 0, \"draw\": 55}, {\"draws\": 55, \"mouse\": 3, \"mu_intercept_per_group\": 8.509256362915039, \"sigma_intercept_per_group\": 0.24634918570518494, \"sigma_obs\": 154.7362060546875, \"slope\": -0.05156698822975159, \"chain\": 0, \"draw\": 55}, {\"draws\": 55, \"mouse\": 4, \"mu_intercept_per_group\": 8.391430854797363, \"sigma_intercept_per_group\": 0.24634918570518494, \"sigma_obs\": 154.7362060546875, \"slope\": -0.05156698822975159, \"chain\": 0, \"draw\": 55}, {\"draws\": 55, \"mouse\": 5, \"mu_intercept_per_group\": 7.700706958770752, \"sigma_intercept_per_group\": 0.24634918570518494, \"sigma_obs\": 154.7362060546875, \"slope\": -0.05156698822975159, \"chain\": 0, \"draw\": 55}, {\"draws\": 55, \"mouse\": 6, \"mu_intercept_per_group\": 7.611809730529785, \"sigma_intercept_per_group\": 0.24634918570518494, \"sigma_obs\": 154.7362060546875, \"slope\": -0.05156698822975159, \"chain\": 0, \"draw\": 55}, {\"draws\": 55, \"mouse\": 7, \"mu_intercept_per_group\": 7.33848237991333, \"sigma_intercept_per_group\": 0.24634918570518494, \"sigma_obs\": 154.7362060546875, \"slope\": -0.05156698822975159, \"chain\": 0, \"draw\": 55}, {\"draws\": 56, \"mouse\": 0, \"mu_intercept_per_group\": 9.683135986328125, \"sigma_intercept_per_group\": 0.24579234421253204, \"sigma_obs\": 154.51797485351562, \"slope\": -0.0537227988243103, \"chain\": 0, \"draw\": 56}, {\"draws\": 56, \"mouse\": 1, \"mu_intercept_per_group\": 9.290193557739258, \"sigma_intercept_per_group\": 0.24579234421253204, \"sigma_obs\": 154.51797485351562, \"slope\": -0.0537227988243103, \"chain\": 0, \"draw\": 56}, {\"draws\": 56, \"mouse\": 2, \"mu_intercept_per_group\": 9.189096450805664, \"sigma_intercept_per_group\": 0.24579234421253204, \"sigma_obs\": 154.51797485351562, \"slope\": -0.0537227988243103, \"chain\": 0, \"draw\": 56}, {\"draws\": 56, \"mouse\": 3, \"mu_intercept_per_group\": 8.722697257995605, \"sigma_intercept_per_group\": 0.24579234421253204, \"sigma_obs\": 154.51797485351562, \"slope\": -0.0537227988243103, \"chain\": 0, \"draw\": 56}, {\"draws\": 56, \"mouse\": 4, \"mu_intercept_per_group\": 8.592327117919922, \"sigma_intercept_per_group\": 0.24579234421253204, \"sigma_obs\": 154.51797485351562, \"slope\": -0.0537227988243103, \"chain\": 0, \"draw\": 56}, {\"draws\": 56, \"mouse\": 5, \"mu_intercept_per_group\": 8.198957443237305, \"sigma_intercept_per_group\": 0.24579234421253204, \"sigma_obs\": 154.51797485351562, \"slope\": -0.0537227988243103, \"chain\": 0, \"draw\": 56}, {\"draws\": 56, \"mouse\": 6, \"mu_intercept_per_group\": 7.217520236968994, \"sigma_intercept_per_group\": 0.24579234421253204, \"sigma_obs\": 154.51797485351562, \"slope\": -0.0537227988243103, \"chain\": 0, \"draw\": 56}, {\"draws\": 56, \"mouse\": 7, \"mu_intercept_per_group\": 6.914643287658691, \"sigma_intercept_per_group\": 0.24579234421253204, \"sigma_obs\": 154.51797485351562, \"slope\": -0.0537227988243103, \"chain\": 0, \"draw\": 56}, {\"draws\": 57, \"mouse\": 0, \"mu_intercept_per_group\": 9.790510177612305, \"sigma_intercept_per_group\": 0.24848099052906036, \"sigma_obs\": 153.87747192382812, \"slope\": -0.05198294669389725, \"chain\": 0, \"draw\": 57}, {\"draws\": 57, \"mouse\": 1, \"mu_intercept_per_group\": 9.408540725708008, \"sigma_intercept_per_group\": 0.24848099052906036, \"sigma_obs\": 153.87747192382812, \"slope\": -0.05198294669389725, \"chain\": 0, \"draw\": 57}, {\"draws\": 57, \"mouse\": 2, \"mu_intercept_per_group\": 9.009614944458008, \"sigma_intercept_per_group\": 0.24848099052906036, \"sigma_obs\": 153.87747192382812, \"slope\": -0.05198294669389725, \"chain\": 0, \"draw\": 57}, {\"draws\": 57, \"mouse\": 3, \"mu_intercept_per_group\": 8.37399673461914, \"sigma_intercept_per_group\": 0.24848099052906036, \"sigma_obs\": 153.87747192382812, \"slope\": -0.05198294669389725, \"chain\": 0, \"draw\": 57}, {\"draws\": 57, \"mouse\": 4, \"mu_intercept_per_group\": 8.198963165283203, \"sigma_intercept_per_group\": 0.24848099052906036, \"sigma_obs\": 153.87747192382812, \"slope\": -0.05198294669389725, \"chain\": 0, \"draw\": 57}, {\"draws\": 57, \"mouse\": 5, \"mu_intercept_per_group\": 7.747584819793701, \"sigma_intercept_per_group\": 0.24848099052906036, \"sigma_obs\": 153.87747192382812, \"slope\": -0.05198294669389725, \"chain\": 0, \"draw\": 57}, {\"draws\": 57, \"mouse\": 6, \"mu_intercept_per_group\": 7.502307415008545, \"sigma_intercept_per_group\": 0.24848099052906036, \"sigma_obs\": 153.87747192382812, \"slope\": -0.05198294669389725, \"chain\": 0, \"draw\": 57}, {\"draws\": 57, \"mouse\": 7, \"mu_intercept_per_group\": 6.962954521179199, \"sigma_intercept_per_group\": 0.24848099052906036, \"sigma_obs\": 153.87747192382812, \"slope\": -0.05198294669389725, \"chain\": 0, \"draw\": 57}, {\"draws\": 58, \"mouse\": 0, \"mu_intercept_per_group\": 9.566569328308105, \"sigma_intercept_per_group\": 0.24967031180858612, \"sigma_obs\": 156.89784240722656, \"slope\": -0.05138508230447769, \"chain\": 0, \"draw\": 58}, {\"draws\": 58, \"mouse\": 1, \"mu_intercept_per_group\": 9.170567512512207, \"sigma_intercept_per_group\": 0.24967031180858612, \"sigma_obs\": 156.89784240722656, \"slope\": -0.05138508230447769, \"chain\": 0, \"draw\": 58}, {\"draws\": 58, \"mouse\": 2, \"mu_intercept_per_group\": 9.028348922729492, \"sigma_intercept_per_group\": 0.24967031180858612, \"sigma_obs\": 156.89784240722656, \"slope\": -0.05138508230447769, \"chain\": 0, \"draw\": 58}, {\"draws\": 58, \"mouse\": 3, \"mu_intercept_per_group\": 8.612771987915039, \"sigma_intercept_per_group\": 0.24967031180858612, \"sigma_obs\": 156.89784240722656, \"slope\": -0.05138508230447769, \"chain\": 0, \"draw\": 58}, {\"draws\": 58, \"mouse\": 4, \"mu_intercept_per_group\": 8.318748474121094, \"sigma_intercept_per_group\": 0.24967031180858612, \"sigma_obs\": 156.89784240722656, \"slope\": -0.05138508230447769, \"chain\": 0, \"draw\": 58}, {\"draws\": 58, \"mouse\": 5, \"mu_intercept_per_group\": 7.949585437774658, \"sigma_intercept_per_group\": 0.24967031180858612, \"sigma_obs\": 156.89784240722656, \"slope\": -0.05138508230447769, \"chain\": 0, \"draw\": 58}, {\"draws\": 58, \"mouse\": 6, \"mu_intercept_per_group\": 7.124637126922607, \"sigma_intercept_per_group\": 0.24967031180858612, \"sigma_obs\": 156.89784240722656, \"slope\": -0.05138508230447769, \"chain\": 0, \"draw\": 58}, {\"draws\": 58, \"mouse\": 7, \"mu_intercept_per_group\": 6.848593711853027, \"sigma_intercept_per_group\": 0.24967031180858612, \"sigma_obs\": 156.89784240722656, \"slope\": -0.05138508230447769, \"chain\": 0, \"draw\": 58}, {\"draws\": 59, \"mouse\": 0, \"mu_intercept_per_group\": 9.478168487548828, \"sigma_intercept_per_group\": 0.2538353502750397, \"sigma_obs\": 156.1645050048828, \"slope\": -0.05022045969963074, \"chain\": 0, \"draw\": 59}, {\"draws\": 59, \"mouse\": 1, \"mu_intercept_per_group\": 9.17834758758545, \"sigma_intercept_per_group\": 0.2538353502750397, \"sigma_obs\": 156.1645050048828, \"slope\": -0.05022045969963074, \"chain\": 0, \"draw\": 59}, {\"draws\": 59, \"mouse\": 2, \"mu_intercept_per_group\": 9.210389137268066, \"sigma_intercept_per_group\": 0.2538353502750397, \"sigma_obs\": 156.1645050048828, \"slope\": -0.05022045969963074, \"chain\": 0, \"draw\": 59}, {\"draws\": 59, \"mouse\": 3, \"mu_intercept_per_group\": 8.625540733337402, \"sigma_intercept_per_group\": 0.2538353502750397, \"sigma_obs\": 156.1645050048828, \"slope\": -0.05022045969963074, \"chain\": 0, \"draw\": 59}, {\"draws\": 59, \"mouse\": 4, \"mu_intercept_per_group\": 8.199609756469727, \"sigma_intercept_per_group\": 0.2538353502750397, \"sigma_obs\": 156.1645050048828, \"slope\": -0.05022045969963074, \"chain\": 0, \"draw\": 59}, {\"draws\": 59, \"mouse\": 5, \"mu_intercept_per_group\": 8.004487991333008, \"sigma_intercept_per_group\": 0.2538353502750397, \"sigma_obs\": 156.1645050048828, \"slope\": -0.05022045969963074, \"chain\": 0, \"draw\": 59}, {\"draws\": 59, \"mouse\": 6, \"mu_intercept_per_group\": 7.149324417114258, \"sigma_intercept_per_group\": 0.2538353502750397, \"sigma_obs\": 156.1645050048828, \"slope\": -0.05022045969963074, \"chain\": 0, \"draw\": 59}, {\"draws\": 59, \"mouse\": 7, \"mu_intercept_per_group\": 6.797736167907715, \"sigma_intercept_per_group\": 0.2538353502750397, \"sigma_obs\": 156.1645050048828, \"slope\": -0.05022045969963074, \"chain\": 0, \"draw\": 59}, {\"draws\": 60, \"mouse\": 0, \"mu_intercept_per_group\": 8.691878318786621, \"sigma_intercept_per_group\": 0.283780962228775, \"sigma_obs\": 157.39352416992188, \"slope\": -0.05518951639533043, \"chain\": 0, \"draw\": 60}, {\"draws\": 60, \"mouse\": 1, \"mu_intercept_per_group\": 7.954767227172852, \"sigma_intercept_per_group\": 0.283780962228775, \"sigma_obs\": 157.39352416992188, \"slope\": -0.05518951639533043, \"chain\": 0, \"draw\": 60}, {\"draws\": 60, \"mouse\": 2, \"mu_intercept_per_group\": 8.100520133972168, \"sigma_intercept_per_group\": 0.283780962228775, \"sigma_obs\": 157.39352416992188, \"slope\": -0.05518951639533043, \"chain\": 0, \"draw\": 60}, {\"draws\": 60, \"mouse\": 3, \"mu_intercept_per_group\": 7.523282527923584, \"sigma_intercept_per_group\": 0.283780962228775, \"sigma_obs\": 157.39352416992188, \"slope\": -0.05518951639533043, \"chain\": 0, \"draw\": 60}, {\"draws\": 60, \"mouse\": 4, \"mu_intercept_per_group\": 7.455847263336182, \"sigma_intercept_per_group\": 0.283780962228775, \"sigma_obs\": 157.39352416992188, \"slope\": -0.05518951639533043, \"chain\": 0, \"draw\": 60}, {\"draws\": 60, \"mouse\": 5, \"mu_intercept_per_group\": 6.88386344909668, \"sigma_intercept_per_group\": 0.283780962228775, \"sigma_obs\": 157.39352416992188, \"slope\": -0.05518951639533043, \"chain\": 0, \"draw\": 60}, {\"draws\": 60, \"mouse\": 6, \"mu_intercept_per_group\": 6.614201068878174, \"sigma_intercept_per_group\": 0.283780962228775, \"sigma_obs\": 157.39352416992188, \"slope\": -0.05518951639533043, \"chain\": 0, \"draw\": 60}, {\"draws\": 60, \"mouse\": 7, \"mu_intercept_per_group\": 6.171677112579346, \"sigma_intercept_per_group\": 0.283780962228775, \"sigma_obs\": 157.39352416992188, \"slope\": -0.05518951639533043, \"chain\": 0, \"draw\": 60}, {\"draws\": 61, \"mouse\": 0, \"mu_intercept_per_group\": 8.75419807434082, \"sigma_intercept_per_group\": 0.2853471040725708, \"sigma_obs\": 162.316650390625, \"slope\": -0.05636799335479736, \"chain\": 0, \"draw\": 61}, {\"draws\": 61, \"mouse\": 1, \"mu_intercept_per_group\": 8.420756340026855, \"sigma_intercept_per_group\": 0.2853471040725708, \"sigma_obs\": 162.316650390625, \"slope\": -0.05636799335479736, \"chain\": 0, \"draw\": 61}, {\"draws\": 61, \"mouse\": 2, \"mu_intercept_per_group\": 7.887269020080566, \"sigma_intercept_per_group\": 0.2853471040725708, \"sigma_obs\": 162.316650390625, \"slope\": -0.05636799335479736, \"chain\": 0, \"draw\": 61}, {\"draws\": 61, \"mouse\": 3, \"mu_intercept_per_group\": 7.59274435043335, \"sigma_intercept_per_group\": 0.2853471040725708, \"sigma_obs\": 162.316650390625, \"slope\": -0.05636799335479736, \"chain\": 0, \"draw\": 61}, {\"draws\": 61, \"mouse\": 4, \"mu_intercept_per_group\": 7.336015224456787, \"sigma_intercept_per_group\": 0.2853471040725708, \"sigma_obs\": 162.316650390625, \"slope\": -0.05636799335479736, \"chain\": 0, \"draw\": 61}, {\"draws\": 61, \"mouse\": 5, \"mu_intercept_per_group\": 6.849796772003174, \"sigma_intercept_per_group\": 0.2853471040725708, \"sigma_obs\": 162.316650390625, \"slope\": -0.05636799335479736, \"chain\": 0, \"draw\": 61}, {\"draws\": 61, \"mouse\": 6, \"mu_intercept_per_group\": 6.654525279998779, \"sigma_intercept_per_group\": 0.2853471040725708, \"sigma_obs\": 162.316650390625, \"slope\": -0.05636799335479736, \"chain\": 0, \"draw\": 61}, {\"draws\": 61, \"mouse\": 7, \"mu_intercept_per_group\": 6.201704025268555, \"sigma_intercept_per_group\": 0.2853471040725708, \"sigma_obs\": 162.316650390625, \"slope\": -0.05636799335479736, \"chain\": 0, \"draw\": 61}, {\"draws\": 62, \"mouse\": 0, \"mu_intercept_per_group\": 4.85686731338501, \"sigma_intercept_per_group\": 0.5009305477142334, \"sigma_obs\": 158.755859375, \"slope\": -0.08378080278635025, \"chain\": 0, \"draw\": 62}, {\"draws\": 62, \"mouse\": 1, \"mu_intercept_per_group\": 4.782672882080078, \"sigma_intercept_per_group\": 0.5009305477142334, \"sigma_obs\": 158.755859375, \"slope\": -0.08378080278635025, \"chain\": 0, \"draw\": 62}, {\"draws\": 62, \"mouse\": 2, \"mu_intercept_per_group\": 4.690329551696777, \"sigma_intercept_per_group\": 0.5009305477142334, \"sigma_obs\": 158.755859375, \"slope\": -0.08378080278635025, \"chain\": 0, \"draw\": 62}, {\"draws\": 62, \"mouse\": 3, \"mu_intercept_per_group\": 4.42426061630249, \"sigma_intercept_per_group\": 0.5009305477142334, \"sigma_obs\": 158.755859375, \"slope\": -0.08378080278635025, \"chain\": 0, \"draw\": 62}, {\"draws\": 62, \"mouse\": 4, \"mu_intercept_per_group\": 4.194204807281494, \"sigma_intercept_per_group\": 0.5009305477142334, \"sigma_obs\": 158.755859375, \"slope\": -0.08378080278635025, \"chain\": 0, \"draw\": 62}, {\"draws\": 62, \"mouse\": 5, \"mu_intercept_per_group\": 3.9356651306152344, \"sigma_intercept_per_group\": 0.5009305477142334, \"sigma_obs\": 158.755859375, \"slope\": -0.08378080278635025, \"chain\": 0, \"draw\": 62}, {\"draws\": 62, \"mouse\": 6, \"mu_intercept_per_group\": 3.8309552669525146, \"sigma_intercept_per_group\": 0.5009305477142334, \"sigma_obs\": 158.755859375, \"slope\": -0.08378080278635025, \"chain\": 0, \"draw\": 62}, {\"draws\": 62, \"mouse\": 7, \"mu_intercept_per_group\": 3.5715837478637695, \"sigma_intercept_per_group\": 0.5009305477142334, \"sigma_obs\": 158.755859375, \"slope\": -0.08378080278635025, \"chain\": 0, \"draw\": 62}, {\"draws\": 63, \"mouse\": 0, \"mu_intercept_per_group\": 4.974742889404297, \"sigma_intercept_per_group\": 0.49677810072898865, \"sigma_obs\": 158.47019958496094, \"slope\": -0.08418974280357361, \"chain\": 0, \"draw\": 63}, {\"draws\": 63, \"mouse\": 1, \"mu_intercept_per_group\": 4.875605583190918, \"sigma_intercept_per_group\": 0.49677810072898865, \"sigma_obs\": 158.47019958496094, \"slope\": -0.08418974280357361, \"chain\": 0, \"draw\": 63}, {\"draws\": 63, \"mouse\": 2, \"mu_intercept_per_group\": 4.682271957397461, \"sigma_intercept_per_group\": 0.49677810072898865, \"sigma_obs\": 158.47019958496094, \"slope\": -0.08418974280357361, \"chain\": 0, \"draw\": 63}, {\"draws\": 63, \"mouse\": 3, \"mu_intercept_per_group\": 4.403522491455078, \"sigma_intercept_per_group\": 0.49677810072898865, \"sigma_obs\": 158.47019958496094, \"slope\": -0.08418974280357361, \"chain\": 0, \"draw\": 63}, {\"draws\": 63, \"mouse\": 4, \"mu_intercept_per_group\": 4.378589153289795, \"sigma_intercept_per_group\": 0.49677810072898865, \"sigma_obs\": 158.47019958496094, \"slope\": -0.08418974280357361, \"chain\": 0, \"draw\": 63}, {\"draws\": 63, \"mouse\": 5, \"mu_intercept_per_group\": 4.209735870361328, \"sigma_intercept_per_group\": 0.49677810072898865, \"sigma_obs\": 158.47019958496094, \"slope\": -0.08418974280357361, \"chain\": 0, \"draw\": 63}, {\"draws\": 63, \"mouse\": 6, \"mu_intercept_per_group\": 3.681575059890747, \"sigma_intercept_per_group\": 0.49677810072898865, \"sigma_obs\": 158.47019958496094, \"slope\": -0.08418974280357361, \"chain\": 0, \"draw\": 63}, {\"draws\": 63, \"mouse\": 7, \"mu_intercept_per_group\": 3.5455942153930664, \"sigma_intercept_per_group\": 0.49677810072898865, \"sigma_obs\": 158.47019958496094, \"slope\": -0.08418974280357361, \"chain\": 0, \"draw\": 63}, {\"draws\": 64, \"mouse\": 0, \"mu_intercept_per_group\": 5.0351691246032715, \"sigma_intercept_per_group\": 0.501488208770752, \"sigma_obs\": 158.75146484375, \"slope\": -0.08403941243886948, \"chain\": 0, \"draw\": 64}, {\"draws\": 64, \"mouse\": 1, \"mu_intercept_per_group\": 4.735069274902344, \"sigma_intercept_per_group\": 0.501488208770752, \"sigma_obs\": 158.75146484375, \"slope\": -0.08403941243886948, \"chain\": 0, \"draw\": 64}, {\"draws\": 64, \"mouse\": 2, \"mu_intercept_per_group\": 4.739682674407959, \"sigma_intercept_per_group\": 0.501488208770752, \"sigma_obs\": 158.75146484375, \"slope\": -0.08403941243886948, \"chain\": 0, \"draw\": 64}, {\"draws\": 64, \"mouse\": 3, \"mu_intercept_per_group\": 4.269834518432617, \"sigma_intercept_per_group\": 0.501488208770752, \"sigma_obs\": 158.75146484375, \"slope\": -0.08403941243886948, \"chain\": 0, \"draw\": 64}, {\"draws\": 64, \"mouse\": 4, \"mu_intercept_per_group\": 4.2418341636657715, \"sigma_intercept_per_group\": 0.501488208770752, \"sigma_obs\": 158.75146484375, \"slope\": -0.08403941243886948, \"chain\": 0, \"draw\": 64}, {\"draws\": 64, \"mouse\": 5, \"mu_intercept_per_group\": 3.865407943725586, \"sigma_intercept_per_group\": 0.501488208770752, \"sigma_obs\": 158.75146484375, \"slope\": -0.08403941243886948, \"chain\": 0, \"draw\": 64}, {\"draws\": 64, \"mouse\": 6, \"mu_intercept_per_group\": 3.9415431022644043, \"sigma_intercept_per_group\": 0.501488208770752, \"sigma_obs\": 158.75146484375, \"slope\": -0.08403941243886948, \"chain\": 0, \"draw\": 64}, {\"draws\": 64, \"mouse\": 7, \"mu_intercept_per_group\": 3.6880502700805664, \"sigma_intercept_per_group\": 0.501488208770752, \"sigma_obs\": 158.75146484375, \"slope\": -0.08403941243886948, \"chain\": 0, \"draw\": 64}, {\"draws\": 65, \"mouse\": 0, \"mu_intercept_per_group\": 4.901198863983154, \"sigma_intercept_per_group\": 0.49243953824043274, \"sigma_obs\": 159.19728088378906, \"slope\": -0.08406035602092743, \"chain\": 0, \"draw\": 65}, {\"draws\": 65, \"mouse\": 1, \"mu_intercept_per_group\": 4.82256555557251, \"sigma_intercept_per_group\": 0.49243953824043274, \"sigma_obs\": 159.19728088378906, \"slope\": -0.08406035602092743, \"chain\": 0, \"draw\": 65}, {\"draws\": 65, \"mouse\": 2, \"mu_intercept_per_group\": 4.5767035484313965, \"sigma_intercept_per_group\": 0.49243953824043274, \"sigma_obs\": 159.19728088378906, \"slope\": -0.08406035602092743, \"chain\": 0, \"draw\": 65}, {\"draws\": 65, \"mouse\": 3, \"mu_intercept_per_group\": 4.6218953132629395, \"sigma_intercept_per_group\": 0.49243953824043274, \"sigma_obs\": 159.19728088378906, \"slope\": -0.08406035602092743, \"chain\": 0, \"draw\": 65}, {\"draws\": 65, \"mouse\": 4, \"mu_intercept_per_group\": 4.392316818237305, \"sigma_intercept_per_group\": 0.49243953824043274, \"sigma_obs\": 159.19728088378906, \"slope\": -0.08406035602092743, \"chain\": 0, \"draw\": 65}, {\"draws\": 65, \"mouse\": 5, \"mu_intercept_per_group\": 4.1310858726501465, \"sigma_intercept_per_group\": 0.49243953824043274, \"sigma_obs\": 159.19728088378906, \"slope\": -0.08406035602092743, \"chain\": 0, \"draw\": 65}, {\"draws\": 65, \"mouse\": 6, \"mu_intercept_per_group\": 3.736093521118164, \"sigma_intercept_per_group\": 0.49243953824043274, \"sigma_obs\": 159.19728088378906, \"slope\": -0.08406035602092743, \"chain\": 0, \"draw\": 65}, {\"draws\": 65, \"mouse\": 7, \"mu_intercept_per_group\": 3.647214651107788, \"sigma_intercept_per_group\": 0.49243953824043274, \"sigma_obs\": 159.19728088378906, \"slope\": -0.08406035602092743, \"chain\": 0, \"draw\": 65}, {\"draws\": 66, \"mouse\": 0, \"mu_intercept_per_group\": 5.167934894561768, \"sigma_intercept_per_group\": 0.48963239789009094, \"sigma_obs\": 158.24728393554688, \"slope\": -0.08364278823137283, \"chain\": 0, \"draw\": 66}, {\"draws\": 66, \"mouse\": 1, \"mu_intercept_per_group\": 4.8487868309021, \"sigma_intercept_per_group\": 0.48963239789009094, \"sigma_obs\": 158.24728393554688, \"slope\": -0.08364278823137283, \"chain\": 0, \"draw\": 66}, {\"draws\": 66, \"mouse\": 2, \"mu_intercept_per_group\": 4.821292400360107, \"sigma_intercept_per_group\": 0.48963239789009094, \"sigma_obs\": 158.24728393554688, \"slope\": -0.08364278823137283, \"chain\": 0, \"draw\": 66}, {\"draws\": 66, \"mouse\": 3, \"mu_intercept_per_group\": 4.271872520446777, \"sigma_intercept_per_group\": 0.48963239789009094, \"sigma_obs\": 158.24728393554688, \"slope\": -0.08364278823137283, \"chain\": 0, \"draw\": 66}, {\"draws\": 66, \"mouse\": 4, \"mu_intercept_per_group\": 4.232344627380371, \"sigma_intercept_per_group\": 0.48963239789009094, \"sigma_obs\": 158.24728393554688, \"slope\": -0.08364278823137283, \"chain\": 0, \"draw\": 66}, {\"draws\": 66, \"mouse\": 5, \"mu_intercept_per_group\": 4.082041263580322, \"sigma_intercept_per_group\": 0.48963239789009094, \"sigma_obs\": 158.24728393554688, \"slope\": -0.08364278823137283, \"chain\": 0, \"draw\": 66}, {\"draws\": 66, \"mouse\": 6, \"mu_intercept_per_group\": 3.965404987335205, \"sigma_intercept_per_group\": 0.48963239789009094, \"sigma_obs\": 158.24728393554688, \"slope\": -0.08364278823137283, \"chain\": 0, \"draw\": 66}, {\"draws\": 66, \"mouse\": 7, \"mu_intercept_per_group\": 3.6416077613830566, \"sigma_intercept_per_group\": 0.48963239789009094, \"sigma_obs\": 158.24728393554688, \"slope\": -0.08364278823137283, \"chain\": 0, \"draw\": 66}, {\"draws\": 67, \"mouse\": 0, \"mu_intercept_per_group\": 5.157055377960205, \"sigma_intercept_per_group\": 0.4734147787094116, \"sigma_obs\": 158.17132568359375, \"slope\": -0.08368877321481705, \"chain\": 0, \"draw\": 67}, {\"draws\": 67, \"mouse\": 1, \"mu_intercept_per_group\": 5.05577278137207, \"sigma_intercept_per_group\": 0.4734147787094116, \"sigma_obs\": 158.17132568359375, \"slope\": -0.08368877321481705, \"chain\": 0, \"draw\": 67}, {\"draws\": 67, \"mouse\": 2, \"mu_intercept_per_group\": 4.798159122467041, \"sigma_intercept_per_group\": 0.4734147787094116, \"sigma_obs\": 158.17132568359375, \"slope\": -0.08368877321481705, \"chain\": 0, \"draw\": 67}, {\"draws\": 67, \"mouse\": 3, \"mu_intercept_per_group\": 4.752787113189697, \"sigma_intercept_per_group\": 0.4734147787094116, \"sigma_obs\": 158.17132568359375, \"slope\": -0.08368877321481705, \"chain\": 0, \"draw\": 67}, {\"draws\": 67, \"mouse\": 4, \"mu_intercept_per_group\": 4.631338119506836, \"sigma_intercept_per_group\": 0.4734147787094116, \"sigma_obs\": 158.17132568359375, \"slope\": -0.08368877321481705, \"chain\": 0, \"draw\": 67}, {\"draws\": 67, \"mouse\": 5, \"mu_intercept_per_group\": 4.295096397399902, \"sigma_intercept_per_group\": 0.4734147787094116, \"sigma_obs\": 158.17132568359375, \"slope\": -0.08368877321481705, \"chain\": 0, \"draw\": 67}, {\"draws\": 67, \"mouse\": 6, \"mu_intercept_per_group\": 3.8570873737335205, \"sigma_intercept_per_group\": 0.4734147787094116, \"sigma_obs\": 158.17132568359375, \"slope\": -0.08368877321481705, \"chain\": 0, \"draw\": 67}, {\"draws\": 67, \"mouse\": 7, \"mu_intercept_per_group\": 3.7009201049804688, \"sigma_intercept_per_group\": 0.4734147787094116, \"sigma_obs\": 158.17132568359375, \"slope\": -0.08368877321481705, \"chain\": 0, \"draw\": 67}, {\"draws\": 68, \"mouse\": 0, \"mu_intercept_per_group\": 5.122366905212402, \"sigma_intercept_per_group\": 0.47291383147239685, \"sigma_obs\": 158.1659698486328, \"slope\": -0.08390376716852188, \"chain\": 0, \"draw\": 68}, {\"draws\": 68, \"mouse\": 1, \"mu_intercept_per_group\": 5.0386433601379395, \"sigma_intercept_per_group\": 0.47291383147239685, \"sigma_obs\": 158.1659698486328, \"slope\": -0.08390376716852188, \"chain\": 0, \"draw\": 68}, {\"draws\": 68, \"mouse\": 2, \"mu_intercept_per_group\": 4.8268585205078125, \"sigma_intercept_per_group\": 0.47291383147239685, \"sigma_obs\": 158.1659698486328, \"slope\": -0.08390376716852188, \"chain\": 0, \"draw\": 68}, {\"draws\": 68, \"mouse\": 3, \"mu_intercept_per_group\": 4.734978675842285, \"sigma_intercept_per_group\": 0.47291383147239685, \"sigma_obs\": 158.1659698486328, \"slope\": -0.08390376716852188, \"chain\": 0, \"draw\": 68}, {\"draws\": 68, \"mouse\": 4, \"mu_intercept_per_group\": 4.683581829071045, \"sigma_intercept_per_group\": 0.47291383147239685, \"sigma_obs\": 158.1659698486328, \"slope\": -0.08390376716852188, \"chain\": 0, \"draw\": 68}, {\"draws\": 68, \"mouse\": 5, \"mu_intercept_per_group\": 4.272711753845215, \"sigma_intercept_per_group\": 0.47291383147239685, \"sigma_obs\": 158.1659698486328, \"slope\": -0.08390376716852188, \"chain\": 0, \"draw\": 68}, {\"draws\": 68, \"mouse\": 6, \"mu_intercept_per_group\": 3.8643789291381836, \"sigma_intercept_per_group\": 0.47291383147239685, \"sigma_obs\": 158.1659698486328, \"slope\": -0.08390376716852188, \"chain\": 0, \"draw\": 68}, {\"draws\": 68, \"mouse\": 7, \"mu_intercept_per_group\": 3.7087156772613525, \"sigma_intercept_per_group\": 0.47291383147239685, \"sigma_obs\": 158.1659698486328, \"slope\": -0.08390376716852188, \"chain\": 0, \"draw\": 68}, {\"draws\": 69, \"mouse\": 0, \"mu_intercept_per_group\": 6.236408710479736, \"sigma_intercept_per_group\": 0.39624616503715515, \"sigma_obs\": 158.51547241210938, \"slope\": -0.09068131446838379, \"chain\": 0, \"draw\": 69}, {\"draws\": 69, \"mouse\": 1, \"mu_intercept_per_group\": 6.134072303771973, \"sigma_intercept_per_group\": 0.39624616503715515, \"sigma_obs\": 158.51547241210938, \"slope\": -0.09068131446838379, \"chain\": 0, \"draw\": 69}, {\"draws\": 69, \"mouse\": 2, \"mu_intercept_per_group\": 5.935792922973633, \"sigma_intercept_per_group\": 0.39624616503715515, \"sigma_obs\": 158.51547241210938, \"slope\": -0.09068131446838379, \"chain\": 0, \"draw\": 69}, {\"draws\": 69, \"mouse\": 3, \"mu_intercept_per_group\": 5.362965106964111, \"sigma_intercept_per_group\": 0.39624616503715515, \"sigma_obs\": 158.51547241210938, \"slope\": -0.09068131446838379, \"chain\": 0, \"draw\": 69}, {\"draws\": 69, \"mouse\": 4, \"mu_intercept_per_group\": 5.368797779083252, \"sigma_intercept_per_group\": 0.39624616503715515, \"sigma_obs\": 158.51547241210938, \"slope\": -0.09068131446838379, \"chain\": 0, \"draw\": 69}, {\"draws\": 69, \"mouse\": 5, \"mu_intercept_per_group\": 5.097139835357666, \"sigma_intercept_per_group\": 0.39624616503715515, \"sigma_obs\": 158.51547241210938, \"slope\": -0.09068131446838379, \"chain\": 0, \"draw\": 69}, {\"draws\": 69, \"mouse\": 6, \"mu_intercept_per_group\": 4.91923713684082, \"sigma_intercept_per_group\": 0.39624616503715515, \"sigma_obs\": 158.51547241210938, \"slope\": -0.09068131446838379, \"chain\": 0, \"draw\": 69}, {\"draws\": 69, \"mouse\": 7, \"mu_intercept_per_group\": 4.634211540222168, \"sigma_intercept_per_group\": 0.39624616503715515, \"sigma_obs\": 158.51547241210938, \"slope\": -0.09068131446838379, \"chain\": 0, \"draw\": 69}, {\"draws\": 70, \"mouse\": 0, \"mu_intercept_per_group\": 7.265211582183838, \"sigma_intercept_per_group\": 0.33869871497154236, \"sigma_obs\": 154.96356201171875, \"slope\": -0.08490786701440811, \"chain\": 0, \"draw\": 70}, {\"draws\": 70, \"mouse\": 1, \"mu_intercept_per_group\": 7.153355121612549, \"sigma_intercept_per_group\": 0.33869871497154236, \"sigma_obs\": 154.96356201171875, \"slope\": -0.08490786701440811, \"chain\": 0, \"draw\": 70}, {\"draws\": 70, \"mouse\": 2, \"mu_intercept_per_group\": 6.784670829772949, \"sigma_intercept_per_group\": 0.33869871497154236, \"sigma_obs\": 154.96356201171875, \"slope\": -0.08490786701440811, \"chain\": 0, \"draw\": 70}, {\"draws\": 70, \"mouse\": 3, \"mu_intercept_per_group\": 6.4652862548828125, \"sigma_intercept_per_group\": 0.33869871497154236, \"sigma_obs\": 154.96356201171875, \"slope\": -0.08490786701440811, \"chain\": 0, \"draw\": 70}, {\"draws\": 70, \"mouse\": 4, \"mu_intercept_per_group\": 6.324701309204102, \"sigma_intercept_per_group\": 0.33869871497154236, \"sigma_obs\": 154.96356201171875, \"slope\": -0.08490786701440811, \"chain\": 0, \"draw\": 70}, {\"draws\": 70, \"mouse\": 5, \"mu_intercept_per_group\": 5.97094202041626, \"sigma_intercept_per_group\": 0.33869871497154236, \"sigma_obs\": 154.96356201171875, \"slope\": -0.08490786701440811, \"chain\": 0, \"draw\": 70}, {\"draws\": 70, \"mouse\": 6, \"mu_intercept_per_group\": 5.403751373291016, \"sigma_intercept_per_group\": 0.33869871497154236, \"sigma_obs\": 154.96356201171875, \"slope\": -0.08490786701440811, \"chain\": 0, \"draw\": 70}, {\"draws\": 70, \"mouse\": 7, \"mu_intercept_per_group\": 5.068994998931885, \"sigma_intercept_per_group\": 0.33869871497154236, \"sigma_obs\": 154.96356201171875, \"slope\": -0.08490786701440811, \"chain\": 0, \"draw\": 70}, {\"draws\": 71, \"mouse\": 0, \"mu_intercept_per_group\": 7.434309959411621, \"sigma_intercept_per_group\": 0.33445873856544495, \"sigma_obs\": 151.58316040039062, \"slope\": -0.07765326648950577, \"chain\": 0, \"draw\": 71}, {\"draws\": 71, \"mouse\": 1, \"mu_intercept_per_group\": 7.043099403381348, \"sigma_intercept_per_group\": 0.33445873856544495, \"sigma_obs\": 151.58316040039062, \"slope\": -0.07765326648950577, \"chain\": 0, \"draw\": 71}, {\"draws\": 71, \"mouse\": 2, \"mu_intercept_per_group\": 6.945951461791992, \"sigma_intercept_per_group\": 0.33445873856544495, \"sigma_obs\": 151.58316040039062, \"slope\": -0.07765326648950577, \"chain\": 0, \"draw\": 71}, {\"draws\": 71, \"mouse\": 3, \"mu_intercept_per_group\": 6.54403018951416, \"sigma_intercept_per_group\": 0.33445873856544495, \"sigma_obs\": 151.58316040039062, \"slope\": -0.07765326648950577, \"chain\": 0, \"draw\": 71}, {\"draws\": 71, \"mouse\": 4, \"mu_intercept_per_group\": 6.265527248382568, \"sigma_intercept_per_group\": 0.33445873856544495, \"sigma_obs\": 151.58316040039062, \"slope\": -0.07765326648950577, \"chain\": 0, \"draw\": 71}, {\"draws\": 71, \"mouse\": 5, \"mu_intercept_per_group\": 5.9447855949401855, \"sigma_intercept_per_group\": 0.33445873856544495, \"sigma_obs\": 151.58316040039062, \"slope\": -0.07765326648950577, \"chain\": 0, \"draw\": 71}, {\"draws\": 71, \"mouse\": 6, \"mu_intercept_per_group\": 5.352157115936279, \"sigma_intercept_per_group\": 0.33445873856544495, \"sigma_obs\": 151.58316040039062, \"slope\": -0.07765326648950577, \"chain\": 0, \"draw\": 71}, {\"draws\": 71, \"mouse\": 7, \"mu_intercept_per_group\": 5.1234283447265625, \"sigma_intercept_per_group\": 0.33445873856544495, \"sigma_obs\": 151.58316040039062, \"slope\": -0.07765326648950577, \"chain\": 0, \"draw\": 71}, {\"draws\": 72, \"mouse\": 0, \"mu_intercept_per_group\": 7.447770595550537, \"sigma_intercept_per_group\": 0.33060142397880554, \"sigma_obs\": 151.1606903076172, \"slope\": -0.07972335815429688, \"chain\": 0, \"draw\": 72}, {\"draws\": 72, \"mouse\": 1, \"mu_intercept_per_group\": 7.050269603729248, \"sigma_intercept_per_group\": 0.33060142397880554, \"sigma_obs\": 151.1606903076172, \"slope\": -0.07972335815429688, \"chain\": 0, \"draw\": 72}, {\"draws\": 72, \"mouse\": 2, \"mu_intercept_per_group\": 6.867201805114746, \"sigma_intercept_per_group\": 0.33060142397880554, \"sigma_obs\": 151.1606903076172, \"slope\": -0.07972335815429688, \"chain\": 0, \"draw\": 72}, {\"draws\": 72, \"mouse\": 3, \"mu_intercept_per_group\": 6.484268665313721, \"sigma_intercept_per_group\": 0.33060142397880554, \"sigma_obs\": 151.1606903076172, \"slope\": -0.07972335815429688, \"chain\": 0, \"draw\": 72}, {\"draws\": 72, \"mouse\": 4, \"mu_intercept_per_group\": 6.434943199157715, \"sigma_intercept_per_group\": 0.33060142397880554, \"sigma_obs\": 151.1606903076172, \"slope\": -0.07972335815429688, \"chain\": 0, \"draw\": 72}, {\"draws\": 72, \"mouse\": 5, \"mu_intercept_per_group\": 5.993097305297852, \"sigma_intercept_per_group\": 0.33060142397880554, \"sigma_obs\": 151.1606903076172, \"slope\": -0.07972335815429688, \"chain\": 0, \"draw\": 72}, {\"draws\": 72, \"mouse\": 6, \"mu_intercept_per_group\": 5.673398971557617, \"sigma_intercept_per_group\": 0.33060142397880554, \"sigma_obs\": 151.1606903076172, \"slope\": -0.07972335815429688, \"chain\": 0, \"draw\": 72}, {\"draws\": 72, \"mouse\": 7, \"mu_intercept_per_group\": 5.449479103088379, \"sigma_intercept_per_group\": 0.33060142397880554, \"sigma_obs\": 151.1606903076172, \"slope\": -0.07972335815429688, \"chain\": 0, \"draw\": 72}, {\"draws\": 73, \"mouse\": 0, \"mu_intercept_per_group\": 7.5202555656433105, \"sigma_intercept_per_group\": 0.32223963737487793, \"sigma_obs\": 151.11212158203125, \"slope\": -0.07994206994771957, \"chain\": 0, \"draw\": 73}, {\"draws\": 73, \"mouse\": 1, \"mu_intercept_per_group\": 7.206103324890137, \"sigma_intercept_per_group\": 0.32223963737487793, \"sigma_obs\": 151.11212158203125, \"slope\": -0.07994206994771957, \"chain\": 0, \"draw\": 73}, {\"draws\": 73, \"mouse\": 2, \"mu_intercept_per_group\": 7.12349271774292, \"sigma_intercept_per_group\": 0.32223963737487793, \"sigma_obs\": 151.11212158203125, \"slope\": -0.07994206994771957, \"chain\": 0, \"draw\": 73}, {\"draws\": 73, \"mouse\": 3, \"mu_intercept_per_group\": 6.706259250640869, \"sigma_intercept_per_group\": 0.32223963737487793, \"sigma_obs\": 151.11212158203125, \"slope\": -0.07994206994771957, \"chain\": 0, \"draw\": 73}, {\"draws\": 73, \"mouse\": 4, \"mu_intercept_per_group\": 6.099185466766357, \"sigma_intercept_per_group\": 0.32223963737487793, \"sigma_obs\": 151.11212158203125, \"slope\": -0.07994206994771957, \"chain\": 0, \"draw\": 73}, {\"draws\": 73, \"mouse\": 5, \"mu_intercept_per_group\": 5.966148376464844, \"sigma_intercept_per_group\": 0.32223963737487793, \"sigma_obs\": 151.11212158203125, \"slope\": -0.07994206994771957, \"chain\": 0, \"draw\": 73}, {\"draws\": 73, \"mouse\": 6, \"mu_intercept_per_group\": 5.6825852394104, \"sigma_intercept_per_group\": 0.32223963737487793, \"sigma_obs\": 151.11212158203125, \"slope\": -0.07994206994771957, \"chain\": 0, \"draw\": 73}, {\"draws\": 73, \"mouse\": 7, \"mu_intercept_per_group\": 5.443253517150879, \"sigma_intercept_per_group\": 0.32223963737487793, \"sigma_obs\": 151.11212158203125, \"slope\": -0.07994206994771957, \"chain\": 0, \"draw\": 73}, {\"draws\": 74, \"mouse\": 0, \"mu_intercept_per_group\": 7.623154640197754, \"sigma_intercept_per_group\": 0.32478827238082886, \"sigma_obs\": 153.9460906982422, \"slope\": -0.08185550570487976, \"chain\": 0, \"draw\": 74}, {\"draws\": 74, \"mouse\": 1, \"mu_intercept_per_group\": 7.443437099456787, \"sigma_intercept_per_group\": 0.32478827238082886, \"sigma_obs\": 153.9460906982422, \"slope\": -0.08185550570487976, \"chain\": 0, \"draw\": 74}, {\"draws\": 74, \"mouse\": 2, \"mu_intercept_per_group\": 7.103631019592285, \"sigma_intercept_per_group\": 0.32478827238082886, \"sigma_obs\": 153.9460906982422, \"slope\": -0.08185550570487976, \"chain\": 0, \"draw\": 74}, {\"draws\": 74, \"mouse\": 3, \"mu_intercept_per_group\": 6.703413963317871, \"sigma_intercept_per_group\": 0.32478827238082886, \"sigma_obs\": 153.9460906982422, \"slope\": -0.08185550570487976, \"chain\": 0, \"draw\": 74}, {\"draws\": 74, \"mouse\": 4, \"mu_intercept_per_group\": 6.4495344161987305, \"sigma_intercept_per_group\": 0.32478827238082886, \"sigma_obs\": 153.9460906982422, \"slope\": -0.08185550570487976, \"chain\": 0, \"draw\": 74}, {\"draws\": 74, \"mouse\": 5, \"mu_intercept_per_group\": 6.284425735473633, \"sigma_intercept_per_group\": 0.32478827238082886, \"sigma_obs\": 153.9460906982422, \"slope\": -0.08185550570487976, \"chain\": 0, \"draw\": 74}, {\"draws\": 74, \"mouse\": 6, \"mu_intercept_per_group\": 5.735116004943848, \"sigma_intercept_per_group\": 0.32478827238082886, \"sigma_obs\": 153.9460906982422, \"slope\": -0.08185550570487976, \"chain\": 0, \"draw\": 74}, {\"draws\": 74, \"mouse\": 7, \"mu_intercept_per_group\": 5.325150012969971, \"sigma_intercept_per_group\": 0.32478827238082886, \"sigma_obs\": 153.9460906982422, \"slope\": -0.08185550570487976, \"chain\": 0, \"draw\": 74}, {\"draws\": 75, \"mouse\": 0, \"mu_intercept_per_group\": 7.402453899383545, \"sigma_intercept_per_group\": 0.323393851518631, \"sigma_obs\": 154.33917236328125, \"slope\": -0.08074545115232468, \"chain\": 0, \"draw\": 75}, {\"draws\": 75, \"mouse\": 1, \"mu_intercept_per_group\": 7.3366169929504395, \"sigma_intercept_per_group\": 0.323393851518631, \"sigma_obs\": 154.33917236328125, \"slope\": -0.08074545115232468, \"chain\": 0, \"draw\": 75}, {\"draws\": 75, \"mouse\": 2, \"mu_intercept_per_group\": 7.037899971008301, \"sigma_intercept_per_group\": 0.323393851518631, \"sigma_obs\": 154.33917236328125, \"slope\": -0.08074545115232468, \"chain\": 0, \"draw\": 75}, {\"draws\": 75, \"mouse\": 3, \"mu_intercept_per_group\": 6.568286895751953, \"sigma_intercept_per_group\": 0.323393851518631, \"sigma_obs\": 154.33917236328125, \"slope\": -0.08074545115232468, \"chain\": 0, \"draw\": 75}, {\"draws\": 75, \"mouse\": 4, \"mu_intercept_per_group\": 6.403061866760254, \"sigma_intercept_per_group\": 0.323393851518631, \"sigma_obs\": 154.33917236328125, \"slope\": -0.08074545115232468, \"chain\": 0, \"draw\": 75}, {\"draws\": 75, \"mouse\": 5, \"mu_intercept_per_group\": 6.1024909019470215, \"sigma_intercept_per_group\": 0.323393851518631, \"sigma_obs\": 154.33917236328125, \"slope\": -0.08074545115232468, \"chain\": 0, \"draw\": 75}, {\"draws\": 75, \"mouse\": 6, \"mu_intercept_per_group\": 5.75762414932251, \"sigma_intercept_per_group\": 0.323393851518631, \"sigma_obs\": 154.33917236328125, \"slope\": -0.08074545115232468, \"chain\": 0, \"draw\": 75}, {\"draws\": 75, \"mouse\": 7, \"mu_intercept_per_group\": 5.658205509185791, \"sigma_intercept_per_group\": 0.323393851518631, \"sigma_obs\": 154.33917236328125, \"slope\": -0.08074545115232468, \"chain\": 0, \"draw\": 75}, {\"draws\": 76, \"mouse\": 0, \"mu_intercept_per_group\": 7.9916582107543945, \"sigma_intercept_per_group\": 0.3010760545730591, \"sigma_obs\": 155.9769744873047, \"slope\": -0.06362541764974594, \"chain\": 0, \"draw\": 76}, {\"draws\": 76, \"mouse\": 1, \"mu_intercept_per_group\": 7.777157783508301, \"sigma_intercept_per_group\": 0.3010760545730591, \"sigma_obs\": 155.9769744873047, \"slope\": -0.06362541764974594, \"chain\": 0, \"draw\": 76}, {\"draws\": 76, \"mouse\": 2, \"mu_intercept_per_group\": 7.62942361831665, \"sigma_intercept_per_group\": 0.3010760545730591, \"sigma_obs\": 155.9769744873047, \"slope\": -0.06362541764974594, \"chain\": 0, \"draw\": 76}, {\"draws\": 76, \"mouse\": 3, \"mu_intercept_per_group\": 7.097559452056885, \"sigma_intercept_per_group\": 0.3010760545730591, \"sigma_obs\": 155.9769744873047, \"slope\": -0.06362541764974594, \"chain\": 0, \"draw\": 76}, {\"draws\": 76, \"mouse\": 4, \"mu_intercept_per_group\": 6.891611099243164, \"sigma_intercept_per_group\": 0.3010760545730591, \"sigma_obs\": 155.9769744873047, \"slope\": -0.06362541764974594, \"chain\": 0, \"draw\": 76}, {\"draws\": 76, \"mouse\": 5, \"mu_intercept_per_group\": 6.396708965301514, \"sigma_intercept_per_group\": 0.3010760545730591, \"sigma_obs\": 155.9769744873047, \"slope\": -0.06362541764974594, \"chain\": 0, \"draw\": 76}, {\"draws\": 76, \"mouse\": 6, \"mu_intercept_per_group\": 5.8911919593811035, \"sigma_intercept_per_group\": 0.3010760545730591, \"sigma_obs\": 155.9769744873047, \"slope\": -0.06362541764974594, \"chain\": 0, \"draw\": 76}, {\"draws\": 76, \"mouse\": 7, \"mu_intercept_per_group\": 5.829976558685303, \"sigma_intercept_per_group\": 0.3010760545730591, \"sigma_obs\": 155.9769744873047, \"slope\": -0.06362541764974594, \"chain\": 0, \"draw\": 76}, {\"draws\": 77, \"mouse\": 0, \"mu_intercept_per_group\": 9.262932777404785, \"sigma_intercept_per_group\": 0.2668921947479248, \"sigma_obs\": 158.10397338867188, \"slope\": -0.056283753365278244, \"chain\": 0, \"draw\": 77}, {\"draws\": 77, \"mouse\": 1, \"mu_intercept_per_group\": 8.837209701538086, \"sigma_intercept_per_group\": 0.2668921947479248, \"sigma_obs\": 158.10397338867188, \"slope\": -0.056283753365278244, \"chain\": 0, \"draw\": 77}, {\"draws\": 77, \"mouse\": 2, \"mu_intercept_per_group\": 8.606148719787598, \"sigma_intercept_per_group\": 0.2668921947479248, \"sigma_obs\": 158.10397338867188, \"slope\": -0.056283753365278244, \"chain\": 0, \"draw\": 77}, {\"draws\": 77, \"mouse\": 3, \"mu_intercept_per_group\": 8.175063133239746, \"sigma_intercept_per_group\": 0.2668921947479248, \"sigma_obs\": 158.10397338867188, \"slope\": -0.056283753365278244, \"chain\": 0, \"draw\": 77}, {\"draws\": 77, \"mouse\": 4, \"mu_intercept_per_group\": 7.969593048095703, \"sigma_intercept_per_group\": 0.2668921947479248, \"sigma_obs\": 158.10397338867188, \"slope\": -0.056283753365278244, \"chain\": 0, \"draw\": 77}, {\"draws\": 77, \"mouse\": 5, \"mu_intercept_per_group\": 7.663737773895264, \"sigma_intercept_per_group\": 0.2668921947479248, \"sigma_obs\": 158.10397338867188, \"slope\": -0.056283753365278244, \"chain\": 0, \"draw\": 77}, {\"draws\": 77, \"mouse\": 6, \"mu_intercept_per_group\": 6.817408084869385, \"sigma_intercept_per_group\": 0.2668921947479248, \"sigma_obs\": 158.10397338867188, \"slope\": -0.056283753365278244, \"chain\": 0, \"draw\": 77}, {\"draws\": 77, \"mouse\": 7, \"mu_intercept_per_group\": 6.627413749694824, \"sigma_intercept_per_group\": 0.2668921947479248, \"sigma_obs\": 158.10397338867188, \"slope\": -0.056283753365278244, \"chain\": 0, \"draw\": 77}, {\"draws\": 78, \"mouse\": 0, \"mu_intercept_per_group\": 9.181779861450195, \"sigma_intercept_per_group\": 0.2699497640132904, \"sigma_obs\": 159.25657653808594, \"slope\": -0.05776249244809151, \"chain\": 0, \"draw\": 78}, {\"draws\": 78, \"mouse\": 1, \"mu_intercept_per_group\": 8.88425064086914, \"sigma_intercept_per_group\": 0.2699497640132904, \"sigma_obs\": 159.25657653808594, \"slope\": -0.05776249244809151, \"chain\": 0, \"draw\": 78}, {\"draws\": 78, \"mouse\": 2, \"mu_intercept_per_group\": 8.603400230407715, \"sigma_intercept_per_group\": 0.2699497640132904, \"sigma_obs\": 159.25657653808594, \"slope\": -0.05776249244809151, \"chain\": 0, \"draw\": 78}, {\"draws\": 78, \"mouse\": 3, \"mu_intercept_per_group\": 8.106103897094727, \"sigma_intercept_per_group\": 0.2699497640132904, \"sigma_obs\": 159.25657653808594, \"slope\": -0.05776249244809151, \"chain\": 0, \"draw\": 78}, {\"draws\": 78, \"mouse\": 4, \"mu_intercept_per_group\": 7.969788551330566, \"sigma_intercept_per_group\": 0.2699497640132904, \"sigma_obs\": 159.25657653808594, \"slope\": -0.05776249244809151, \"chain\": 0, \"draw\": 78}, {\"draws\": 78, \"mouse\": 5, \"mu_intercept_per_group\": 7.175731182098389, \"sigma_intercept_per_group\": 0.2699497640132904, \"sigma_obs\": 159.25657653808594, \"slope\": -0.05776249244809151, \"chain\": 0, \"draw\": 78}, {\"draws\": 78, \"mouse\": 6, \"mu_intercept_per_group\": 7.213284015655518, \"sigma_intercept_per_group\": 0.2699497640132904, \"sigma_obs\": 159.25657653808594, \"slope\": -0.05776249244809151, \"chain\": 0, \"draw\": 78}, {\"draws\": 78, \"mouse\": 7, \"mu_intercept_per_group\": 6.777933597564697, \"sigma_intercept_per_group\": 0.2699497640132904, \"sigma_obs\": 159.25657653808594, \"slope\": -0.05776249244809151, \"chain\": 0, \"draw\": 78}, {\"draws\": 79, \"mouse\": 0, \"mu_intercept_per_group\": 9.107172966003418, \"sigma_intercept_per_group\": 0.2738286554813385, \"sigma_obs\": 159.13330078125, \"slope\": -0.058024074882268906, \"chain\": 0, \"draw\": 79}, {\"draws\": 79, \"mouse\": 1, \"mu_intercept_per_group\": 8.766807556152344, \"sigma_intercept_per_group\": 0.2738286554813385, \"sigma_obs\": 159.13330078125, \"slope\": -0.058024074882268906, \"chain\": 0, \"draw\": 79}, {\"draws\": 79, \"mouse\": 2, \"mu_intercept_per_group\": 8.518353462219238, \"sigma_intercept_per_group\": 0.2738286554813385, \"sigma_obs\": 159.13330078125, \"slope\": -0.058024074882268906, \"chain\": 0, \"draw\": 79}, {\"draws\": 79, \"mouse\": 3, \"mu_intercept_per_group\": 8.17392635345459, \"sigma_intercept_per_group\": 0.2738286554813385, \"sigma_obs\": 159.13330078125, \"slope\": -0.058024074882268906, \"chain\": 0, \"draw\": 79}, {\"draws\": 79, \"mouse\": 4, \"mu_intercept_per_group\": 7.683578968048096, \"sigma_intercept_per_group\": 0.2738286554813385, \"sigma_obs\": 159.13330078125, \"slope\": -0.058024074882268906, \"chain\": 0, \"draw\": 79}, {\"draws\": 79, \"mouse\": 5, \"mu_intercept_per_group\": 7.163759708404541, \"sigma_intercept_per_group\": 0.2738286554813385, \"sigma_obs\": 159.13330078125, \"slope\": -0.058024074882268906, \"chain\": 0, \"draw\": 79}, {\"draws\": 79, \"mouse\": 6, \"mu_intercept_per_group\": 6.9546074867248535, \"sigma_intercept_per_group\": 0.2738286554813385, \"sigma_obs\": 159.13330078125, \"slope\": -0.058024074882268906, \"chain\": 0, \"draw\": 79}, {\"draws\": 79, \"mouse\": 7, \"mu_intercept_per_group\": 6.46820592880249, \"sigma_intercept_per_group\": 0.2738286554813385, \"sigma_obs\": 159.13330078125, \"slope\": -0.058024074882268906, \"chain\": 0, \"draw\": 79}, {\"draws\": 80, \"mouse\": 0, \"mu_intercept_per_group\": 9.089599609375, \"sigma_intercept_per_group\": 0.2680009603500366, \"sigma_obs\": 159.3310089111328, \"slope\": -0.058389075100421906, \"chain\": 0, \"draw\": 80}, {\"draws\": 80, \"mouse\": 1, \"mu_intercept_per_group\": 8.731108665466309, \"sigma_intercept_per_group\": 0.2680009603500366, \"sigma_obs\": 159.3310089111328, \"slope\": -0.058389075100421906, \"chain\": 0, \"draw\": 80}, {\"draws\": 80, \"mouse\": 2, \"mu_intercept_per_group\": 8.342570304870605, \"sigma_intercept_per_group\": 0.2680009603500366, \"sigma_obs\": 159.3310089111328, \"slope\": -0.058389075100421906, \"chain\": 0, \"draw\": 80}, {\"draws\": 80, \"mouse\": 3, \"mu_intercept_per_group\": 8.109792709350586, \"sigma_intercept_per_group\": 0.2680009603500366, \"sigma_obs\": 159.3310089111328, \"slope\": -0.058389075100421906, \"chain\": 0, \"draw\": 80}, {\"draws\": 80, \"mouse\": 4, \"mu_intercept_per_group\": 7.779293060302734, \"sigma_intercept_per_group\": 0.2680009603500366, \"sigma_obs\": 159.3310089111328, \"slope\": -0.058389075100421906, \"chain\": 0, \"draw\": 80}, {\"draws\": 80, \"mouse\": 5, \"mu_intercept_per_group\": 7.077509880065918, \"sigma_intercept_per_group\": 0.2680009603500366, \"sigma_obs\": 159.3310089111328, \"slope\": -0.058389075100421906, \"chain\": 0, \"draw\": 80}, {\"draws\": 80, \"mouse\": 6, \"mu_intercept_per_group\": 6.875425338745117, \"sigma_intercept_per_group\": 0.2680009603500366, \"sigma_obs\": 159.3310089111328, \"slope\": -0.058389075100421906, \"chain\": 0, \"draw\": 80}, {\"draws\": 80, \"mouse\": 7, \"mu_intercept_per_group\": 6.564381122589111, \"sigma_intercept_per_group\": 0.2680009603500366, \"sigma_obs\": 159.3310089111328, \"slope\": -0.058389075100421906, \"chain\": 0, \"draw\": 80}, {\"draws\": 81, \"mouse\": 0, \"mu_intercept_per_group\": 9.228191375732422, \"sigma_intercept_per_group\": 0.26575708389282227, \"sigma_obs\": 157.92254638671875, \"slope\": -0.05801021680235863, \"chain\": 0, \"draw\": 81}, {\"draws\": 81, \"mouse\": 1, \"mu_intercept_per_group\": 8.89433479309082, \"sigma_intercept_per_group\": 0.26575708389282227, \"sigma_obs\": 157.92254638671875, \"slope\": -0.05801021680235863, \"chain\": 0, \"draw\": 81}, {\"draws\": 81, \"mouse\": 2, \"mu_intercept_per_group\": 8.77619457244873, \"sigma_intercept_per_group\": 0.26575708389282227, \"sigma_obs\": 157.92254638671875, \"slope\": -0.05801021680235863, \"chain\": 0, \"draw\": 81}, {\"draws\": 81, \"mouse\": 3, \"mu_intercept_per_group\": 8.095866203308105, \"sigma_intercept_per_group\": 0.26575708389282227, \"sigma_obs\": 157.92254638671875, \"slope\": -0.05801021680235863, \"chain\": 0, \"draw\": 81}, {\"draws\": 81, \"mouse\": 4, \"mu_intercept_per_group\": 7.854727745056152, \"sigma_intercept_per_group\": 0.26575708389282227, \"sigma_obs\": 157.92254638671875, \"slope\": -0.05801021680235863, \"chain\": 0, \"draw\": 81}, {\"draws\": 81, \"mouse\": 5, \"mu_intercept_per_group\": 7.7125725746154785, \"sigma_intercept_per_group\": 0.26575708389282227, \"sigma_obs\": 157.92254638671875, \"slope\": -0.05801021680235863, \"chain\": 0, \"draw\": 81}, {\"draws\": 81, \"mouse\": 6, \"mu_intercept_per_group\": 6.989586353302002, \"sigma_intercept_per_group\": 0.26575708389282227, \"sigma_obs\": 157.92254638671875, \"slope\": -0.05801021680235863, \"chain\": 0, \"draw\": 81}, {\"draws\": 81, \"mouse\": 7, \"mu_intercept_per_group\": 6.623661041259766, \"sigma_intercept_per_group\": 0.26575708389282227, \"sigma_obs\": 157.92254638671875, \"slope\": -0.05801021680235863, \"chain\": 0, \"draw\": 81}, {\"draws\": 82, \"mouse\": 0, \"mu_intercept_per_group\": 9.424500465393066, \"sigma_intercept_per_group\": 0.26209354400634766, \"sigma_obs\": 158.884521484375, \"slope\": -0.0570523627102375, \"chain\": 0, \"draw\": 82}, {\"draws\": 82, \"mouse\": 1, \"mu_intercept_per_group\": 8.898722648620605, \"sigma_intercept_per_group\": 0.26209354400634766, \"sigma_obs\": 158.884521484375, \"slope\": -0.0570523627102375, \"chain\": 0, \"draw\": 82}, {\"draws\": 82, \"mouse\": 2, \"mu_intercept_per_group\": 8.478804588317871, \"sigma_intercept_per_group\": 0.26209354400634766, \"sigma_obs\": 158.884521484375, \"slope\": -0.0570523627102375, \"chain\": 0, \"draw\": 82}, {\"draws\": 82, \"mouse\": 3, \"mu_intercept_per_group\": 8.234590530395508, \"sigma_intercept_per_group\": 0.26209354400634766, \"sigma_obs\": 158.884521484375, \"slope\": -0.0570523627102375, \"chain\": 0, \"draw\": 82}, {\"draws\": 82, \"mouse\": 4, \"mu_intercept_per_group\": 7.965239524841309, \"sigma_intercept_per_group\": 0.26209354400634766, \"sigma_obs\": 158.884521484375, \"slope\": -0.0570523627102375, \"chain\": 0, \"draw\": 82}, {\"draws\": 82, \"mouse\": 5, \"mu_intercept_per_group\": 7.318826198577881, \"sigma_intercept_per_group\": 0.26209354400634766, \"sigma_obs\": 158.884521484375, \"slope\": -0.0570523627102375, \"chain\": 0, \"draw\": 82}, {\"draws\": 82, \"mouse\": 6, \"mu_intercept_per_group\": 7.040539741516113, \"sigma_intercept_per_group\": 0.26209354400634766, \"sigma_obs\": 158.884521484375, \"slope\": -0.0570523627102375, \"chain\": 0, \"draw\": 82}, {\"draws\": 82, \"mouse\": 7, \"mu_intercept_per_group\": 6.961883544921875, \"sigma_intercept_per_group\": 0.26209354400634766, \"sigma_obs\": 158.884521484375, \"slope\": -0.0570523627102375, \"chain\": 0, \"draw\": 82}, {\"draws\": 83, \"mouse\": 0, \"mu_intercept_per_group\": 9.122271537780762, \"sigma_intercept_per_group\": 0.262488454580307, \"sigma_obs\": 158.77296447753906, \"slope\": -0.058051466941833496, \"chain\": 0, \"draw\": 83}, {\"draws\": 83, \"mouse\": 1, \"mu_intercept_per_group\": 8.896050453186035, \"sigma_intercept_per_group\": 0.262488454580307, \"sigma_obs\": 158.77296447753906, \"slope\": -0.058051466941833496, \"chain\": 0, \"draw\": 83}, {\"draws\": 83, \"mouse\": 2, \"mu_intercept_per_group\": 8.907968521118164, \"sigma_intercept_per_group\": 0.262488454580307, \"sigma_obs\": 158.77296447753906, \"slope\": -0.058051466941833496, \"chain\": 0, \"draw\": 83}, {\"draws\": 83, \"mouse\": 3, \"mu_intercept_per_group\": 8.160042762756348, \"sigma_intercept_per_group\": 0.262488454580307, \"sigma_obs\": 158.77296447753906, \"slope\": -0.058051466941833496, \"chain\": 0, \"draw\": 83}, {\"draws\": 83, \"mouse\": 4, \"mu_intercept_per_group\": 8.138762474060059, \"sigma_intercept_per_group\": 0.262488454580307, \"sigma_obs\": 158.77296447753906, \"slope\": -0.058051466941833496, \"chain\": 0, \"draw\": 83}, {\"draws\": 83, \"mouse\": 5, \"mu_intercept_per_group\": 7.444986343383789, \"sigma_intercept_per_group\": 0.262488454580307, \"sigma_obs\": 158.77296447753906, \"slope\": -0.058051466941833496, \"chain\": 0, \"draw\": 83}, {\"draws\": 83, \"mouse\": 6, \"mu_intercept_per_group\": 7.283814907073975, \"sigma_intercept_per_group\": 0.262488454580307, \"sigma_obs\": 158.77296447753906, \"slope\": -0.058051466941833496, \"chain\": 0, \"draw\": 83}, {\"draws\": 83, \"mouse\": 7, \"mu_intercept_per_group\": 6.854051113128662, \"sigma_intercept_per_group\": 0.262488454580307, \"sigma_obs\": 158.77296447753906, \"slope\": -0.058051466941833496, \"chain\": 0, \"draw\": 83}, {\"draws\": 84, \"mouse\": 0, \"mu_intercept_per_group\": 11.859444618225098, \"sigma_intercept_per_group\": 0.2080070823431015, \"sigma_obs\": 157.9208984375, \"slope\": -0.08613904565572739, \"chain\": 0, \"draw\": 84}, {\"draws\": 84, \"mouse\": 1, \"mu_intercept_per_group\": 11.401199340820312, \"sigma_intercept_per_group\": 0.2080070823431015, \"sigma_obs\": 157.9208984375, \"slope\": -0.08613904565572739, \"chain\": 0, \"draw\": 84}, {\"draws\": 84, \"mouse\": 2, \"mu_intercept_per_group\": 11.222925186157227, \"sigma_intercept_per_group\": 0.2080070823431015, \"sigma_obs\": 157.9208984375, \"slope\": -0.08613904565572739, \"chain\": 0, \"draw\": 84}, {\"draws\": 84, \"mouse\": 3, \"mu_intercept_per_group\": 10.256462097167969, \"sigma_intercept_per_group\": 0.2080070823431015, \"sigma_obs\": 157.9208984375, \"slope\": -0.08613904565572739, \"chain\": 0, \"draw\": 84}, {\"draws\": 84, \"mouse\": 4, \"mu_intercept_per_group\": 10.0493803024292, \"sigma_intercept_per_group\": 0.2080070823431015, \"sigma_obs\": 157.9208984375, \"slope\": -0.08613904565572739, \"chain\": 0, \"draw\": 84}, {\"draws\": 84, \"mouse\": 5, \"mu_intercept_per_group\": 9.758752822875977, \"sigma_intercept_per_group\": 0.2080070823431015, \"sigma_obs\": 157.9208984375, \"slope\": -0.08613904565572739, \"chain\": 0, \"draw\": 84}, {\"draws\": 84, \"mouse\": 6, \"mu_intercept_per_group\": 9.19989013671875, \"sigma_intercept_per_group\": 0.2080070823431015, \"sigma_obs\": 157.9208984375, \"slope\": -0.08613904565572739, \"chain\": 0, \"draw\": 84}, {\"draws\": 84, \"mouse\": 7, \"mu_intercept_per_group\": 8.454754829406738, \"sigma_intercept_per_group\": 0.2080070823431015, \"sigma_obs\": 157.9208984375, \"slope\": -0.08613904565572739, \"chain\": 0, \"draw\": 84}, {\"draws\": 85, \"mouse\": 0, \"mu_intercept_per_group\": 12.930909156799316, \"sigma_intercept_per_group\": 0.1899368166923523, \"sigma_obs\": 153.411376953125, \"slope\": -0.08185828477144241, \"chain\": 0, \"draw\": 85}, {\"draws\": 85, \"mouse\": 1, \"mu_intercept_per_group\": 12.56022834777832, \"sigma_intercept_per_group\": 0.1899368166923523, \"sigma_obs\": 153.411376953125, \"slope\": -0.08185828477144241, \"chain\": 0, \"draw\": 85}, {\"draws\": 85, \"mouse\": 2, \"mu_intercept_per_group\": 11.953472137451172, \"sigma_intercept_per_group\": 0.1899368166923523, \"sigma_obs\": 153.411376953125, \"slope\": -0.08185828477144241, \"chain\": 0, \"draw\": 85}, {\"draws\": 85, \"mouse\": 3, \"mu_intercept_per_group\": 11.424859046936035, \"sigma_intercept_per_group\": 0.1899368166923523, \"sigma_obs\": 153.411376953125, \"slope\": -0.08185828477144241, \"chain\": 0, \"draw\": 85}, {\"draws\": 85, \"mouse\": 4, \"mu_intercept_per_group\": 10.968379974365234, \"sigma_intercept_per_group\": 0.1899368166923523, \"sigma_obs\": 153.411376953125, \"slope\": -0.08185828477144241, \"chain\": 0, \"draw\": 85}, {\"draws\": 85, \"mouse\": 5, \"mu_intercept_per_group\": 10.62282657623291, \"sigma_intercept_per_group\": 0.1899368166923523, \"sigma_obs\": 153.411376953125, \"slope\": -0.08185828477144241, \"chain\": 0, \"draw\": 85}, {\"draws\": 85, \"mouse\": 6, \"mu_intercept_per_group\": 10.10873031616211, \"sigma_intercept_per_group\": 0.1899368166923523, \"sigma_obs\": 153.411376953125, \"slope\": -0.08185828477144241, \"chain\": 0, \"draw\": 85}, {\"draws\": 85, \"mouse\": 7, \"mu_intercept_per_group\": 9.113402366638184, \"sigma_intercept_per_group\": 0.1899368166923523, \"sigma_obs\": 153.411376953125, \"slope\": -0.08185828477144241, \"chain\": 0, \"draw\": 85}, {\"draws\": 86, \"mouse\": 0, \"mu_intercept_per_group\": 13.200339317321777, \"sigma_intercept_per_group\": 0.1871066391468048, \"sigma_obs\": 153.4518280029297, \"slope\": -0.0800139456987381, \"chain\": 0, \"draw\": 86}, {\"draws\": 86, \"mouse\": 1, \"mu_intercept_per_group\": 12.308511734008789, \"sigma_intercept_per_group\": 0.1871066391468048, \"sigma_obs\": 153.4518280029297, \"slope\": -0.0800139456987381, \"chain\": 0, \"draw\": 86}, {\"draws\": 86, \"mouse\": 2, \"mu_intercept_per_group\": 12.551633834838867, \"sigma_intercept_per_group\": 0.1871066391468048, \"sigma_obs\": 153.4518280029297, \"slope\": -0.0800139456987381, \"chain\": 0, \"draw\": 86}, {\"draws\": 86, \"mouse\": 3, \"mu_intercept_per_group\": 11.298617362976074, \"sigma_intercept_per_group\": 0.1871066391468048, \"sigma_obs\": 153.4518280029297, \"slope\": -0.0800139456987381, \"chain\": 0, \"draw\": 86}, {\"draws\": 86, \"mouse\": 4, \"mu_intercept_per_group\": 11.14986515045166, \"sigma_intercept_per_group\": 0.1871066391468048, \"sigma_obs\": 153.4518280029297, \"slope\": -0.0800139456987381, \"chain\": 0, \"draw\": 86}, {\"draws\": 86, \"mouse\": 5, \"mu_intercept_per_group\": 10.438314437866211, \"sigma_intercept_per_group\": 0.1871066391468048, \"sigma_obs\": 153.4518280029297, \"slope\": -0.0800139456987381, \"chain\": 0, \"draw\": 86}, {\"draws\": 86, \"mouse\": 6, \"mu_intercept_per_group\": 10.177766799926758, \"sigma_intercept_per_group\": 0.1871066391468048, \"sigma_obs\": 153.4518280029297, \"slope\": -0.0800139456987381, \"chain\": 0, \"draw\": 86}, {\"draws\": 86, \"mouse\": 7, \"mu_intercept_per_group\": 9.01955509185791, \"sigma_intercept_per_group\": 0.1871066391468048, \"sigma_obs\": 153.4518280029297, \"slope\": -0.0800139456987381, \"chain\": 0, \"draw\": 86}, {\"draws\": 87, \"mouse\": 0, \"mu_intercept_per_group\": 14.257213592529297, \"sigma_intercept_per_group\": 0.17536471784114838, \"sigma_obs\": 153.89633178710938, \"slope\": -0.07325274497270584, \"chain\": 0, \"draw\": 87}, {\"draws\": 87, \"mouse\": 1, \"mu_intercept_per_group\": 13.611419677734375, \"sigma_intercept_per_group\": 0.17536471784114838, \"sigma_obs\": 153.89633178710938, \"slope\": -0.07325274497270584, \"chain\": 0, \"draw\": 87}, {\"draws\": 87, \"mouse\": 2, \"mu_intercept_per_group\": 13.255388259887695, \"sigma_intercept_per_group\": 0.17536471784114838, \"sigma_obs\": 153.89633178710938, \"slope\": -0.07325274497270584, \"chain\": 0, \"draw\": 87}, {\"draws\": 87, \"mouse\": 3, \"mu_intercept_per_group\": 12.008169174194336, \"sigma_intercept_per_group\": 0.17536471784114838, \"sigma_obs\": 153.89633178710938, \"slope\": -0.07325274497270584, \"chain\": 0, \"draw\": 87}, {\"draws\": 87, \"mouse\": 4, \"mu_intercept_per_group\": 11.910066604614258, \"sigma_intercept_per_group\": 0.17536471784114838, \"sigma_obs\": 153.89633178710938, \"slope\": -0.07325274497270584, \"chain\": 0, \"draw\": 87}, {\"draws\": 87, \"mouse\": 5, \"mu_intercept_per_group\": 11.1248140335083, \"sigma_intercept_per_group\": 0.17536471784114838, \"sigma_obs\": 153.89633178710938, \"slope\": -0.07325274497270584, \"chain\": 0, \"draw\": 87}, {\"draws\": 87, \"mouse\": 6, \"mu_intercept_per_group\": 10.834962844848633, \"sigma_intercept_per_group\": 0.17536471784114838, \"sigma_obs\": 153.89633178710938, \"slope\": -0.07325274497270584, \"chain\": 0, \"draw\": 87}, {\"draws\": 87, \"mouse\": 7, \"mu_intercept_per_group\": 9.951822280883789, \"sigma_intercept_per_group\": 0.17536471784114838, \"sigma_obs\": 153.89633178710938, \"slope\": -0.07325274497270584, \"chain\": 0, \"draw\": 87}, {\"draws\": 88, \"mouse\": 0, \"mu_intercept_per_group\": 14.945744514465332, \"sigma_intercept_per_group\": 0.16953900456428528, \"sigma_obs\": 161.3378143310547, \"slope\": -0.0784773975610733, \"chain\": 0, \"draw\": 88}, {\"draws\": 88, \"mouse\": 1, \"mu_intercept_per_group\": 14.41346549987793, \"sigma_intercept_per_group\": 0.16953900456428528, \"sigma_obs\": 161.3378143310547, \"slope\": -0.0784773975610733, \"chain\": 0, \"draw\": 88}, {\"draws\": 88, \"mouse\": 2, \"mu_intercept_per_group\": 14.120406150817871, \"sigma_intercept_per_group\": 0.16953900456428528, \"sigma_obs\": 161.3378143310547, \"slope\": -0.0784773975610733, \"chain\": 0, \"draw\": 88}, {\"draws\": 88, \"mouse\": 3, \"mu_intercept_per_group\": 12.688517570495605, \"sigma_intercept_per_group\": 0.16953900456428528, \"sigma_obs\": 161.3378143310547, \"slope\": -0.0784773975610733, \"chain\": 0, \"draw\": 88}, {\"draws\": 88, \"mouse\": 4, \"mu_intercept_per_group\": 12.56185531616211, \"sigma_intercept_per_group\": 0.16953900456428528, \"sigma_obs\": 161.3378143310547, \"slope\": -0.0784773975610733, \"chain\": 0, \"draw\": 88}, {\"draws\": 88, \"mouse\": 5, \"mu_intercept_per_group\": 12.120564460754395, \"sigma_intercept_per_group\": 0.16953900456428528, \"sigma_obs\": 161.3378143310547, \"slope\": -0.0784773975610733, \"chain\": 0, \"draw\": 88}, {\"draws\": 88, \"mouse\": 6, \"mu_intercept_per_group\": 11.584918975830078, \"sigma_intercept_per_group\": 0.16953900456428528, \"sigma_obs\": 161.3378143310547, \"slope\": -0.0784773975610733, \"chain\": 0, \"draw\": 88}, {\"draws\": 88, \"mouse\": 7, \"mu_intercept_per_group\": 10.297228813171387, \"sigma_intercept_per_group\": 0.16953900456428528, \"sigma_obs\": 161.3378143310547, \"slope\": -0.0784773975610733, \"chain\": 0, \"draw\": 88}, {\"draws\": 89, \"mouse\": 0, \"mu_intercept_per_group\": 14.661724090576172, \"sigma_intercept_per_group\": 0.16852346062660217, \"sigma_obs\": 158.86376953125, \"slope\": -0.07958276569843292, \"chain\": 0, \"draw\": 89}, {\"draws\": 89, \"mouse\": 1, \"mu_intercept_per_group\": 14.077878952026367, \"sigma_intercept_per_group\": 0.16852346062660217, \"sigma_obs\": 158.86376953125, \"slope\": -0.07958276569843292, \"chain\": 0, \"draw\": 89}, {\"draws\": 89, \"mouse\": 2, \"mu_intercept_per_group\": 13.554404258728027, \"sigma_intercept_per_group\": 0.16852346062660217, \"sigma_obs\": 158.86376953125, \"slope\": -0.07958276569843292, \"chain\": 0, \"draw\": 89}, {\"draws\": 89, \"mouse\": 3, \"mu_intercept_per_group\": 13.201452255249023, \"sigma_intercept_per_group\": 0.16852346062660217, \"sigma_obs\": 158.86376953125, \"slope\": -0.07958276569843292, \"chain\": 0, \"draw\": 89}, {\"draws\": 89, \"mouse\": 4, \"mu_intercept_per_group\": 12.43230152130127, \"sigma_intercept_per_group\": 0.16852346062660217, \"sigma_obs\": 158.86376953125, \"slope\": -0.07958276569843292, \"chain\": 0, \"draw\": 89}, {\"draws\": 89, \"mouse\": 5, \"mu_intercept_per_group\": 12.242555618286133, \"sigma_intercept_per_group\": 0.16852346062660217, \"sigma_obs\": 158.86376953125, \"slope\": -0.07958276569843292, \"chain\": 0, \"draw\": 89}, {\"draws\": 89, \"mouse\": 6, \"mu_intercept_per_group\": 11.254465103149414, \"sigma_intercept_per_group\": 0.16852346062660217, \"sigma_obs\": 158.86376953125, \"slope\": -0.07958276569843292, \"chain\": 0, \"draw\": 89}, {\"draws\": 89, \"mouse\": 7, \"mu_intercept_per_group\": 10.800638198852539, \"sigma_intercept_per_group\": 0.16852346062660217, \"sigma_obs\": 158.86376953125, \"slope\": -0.07958276569843292, \"chain\": 0, \"draw\": 89}, {\"draws\": 90, \"mouse\": 0, \"mu_intercept_per_group\": 15.145071029663086, \"sigma_intercept_per_group\": 0.16530296206474304, \"sigma_obs\": 161.84019470214844, \"slope\": -0.07906254380941391, \"chain\": 0, \"draw\": 90}, {\"draws\": 90, \"mouse\": 1, \"mu_intercept_per_group\": 14.643963813781738, \"sigma_intercept_per_group\": 0.16530296206474304, \"sigma_obs\": 161.84019470214844, \"slope\": -0.07906254380941391, \"chain\": 0, \"draw\": 90}, {\"draws\": 90, \"mouse\": 2, \"mu_intercept_per_group\": 14.091994285583496, \"sigma_intercept_per_group\": 0.16530296206474304, \"sigma_obs\": 161.84019470214844, \"slope\": -0.07906254380941391, \"chain\": 0, \"draw\": 90}, {\"draws\": 90, \"mouse\": 3, \"mu_intercept_per_group\": 13.317730903625488, \"sigma_intercept_per_group\": 0.16530296206474304, \"sigma_obs\": 161.84019470214844, \"slope\": -0.07906254380941391, \"chain\": 0, \"draw\": 90}, {\"draws\": 90, \"mouse\": 4, \"mu_intercept_per_group\": 13.211380958557129, \"sigma_intercept_per_group\": 0.16530296206474304, \"sigma_obs\": 161.84019470214844, \"slope\": -0.07906254380941391, \"chain\": 0, \"draw\": 90}, {\"draws\": 90, \"mouse\": 5, \"mu_intercept_per_group\": 12.125602722167969, \"sigma_intercept_per_group\": 0.16530296206474304, \"sigma_obs\": 161.84019470214844, \"slope\": -0.07906254380941391, \"chain\": 0, \"draw\": 90}, {\"draws\": 90, \"mouse\": 6, \"mu_intercept_per_group\": 11.483768463134766, \"sigma_intercept_per_group\": 0.16530296206474304, \"sigma_obs\": 161.84019470214844, \"slope\": -0.07906254380941391, \"chain\": 0, \"draw\": 90}, {\"draws\": 90, \"mouse\": 7, \"mu_intercept_per_group\": 10.726998329162598, \"sigma_intercept_per_group\": 0.16530296206474304, \"sigma_obs\": 161.84019470214844, \"slope\": -0.07906254380941391, \"chain\": 0, \"draw\": 90}, {\"draws\": 91, \"mouse\": 0, \"mu_intercept_per_group\": 9.546856880187988, \"sigma_intercept_per_group\": 0.25834834575653076, \"sigma_obs\": 164.44674682617188, \"slope\": -0.0646577700972557, \"chain\": 0, \"draw\": 91}, {\"draws\": 91, \"mouse\": 1, \"mu_intercept_per_group\": 9.205914497375488, \"sigma_intercept_per_group\": 0.25834834575653076, \"sigma_obs\": 164.44674682617188, \"slope\": -0.0646577700972557, \"chain\": 0, \"draw\": 91}, {\"draws\": 91, \"mouse\": 2, \"mu_intercept_per_group\": 9.0103178024292, \"sigma_intercept_per_group\": 0.25834834575653076, \"sigma_obs\": 164.44674682617188, \"slope\": -0.0646577700972557, \"chain\": 0, \"draw\": 91}, {\"draws\": 91, \"mouse\": 3, \"mu_intercept_per_group\": 8.506121635437012, \"sigma_intercept_per_group\": 0.25834834575653076, \"sigma_obs\": 164.44674682617188, \"slope\": -0.0646577700972557, \"chain\": 0, \"draw\": 91}, {\"draws\": 91, \"mouse\": 4, \"mu_intercept_per_group\": 8.29809856414795, \"sigma_intercept_per_group\": 0.25834834575653076, \"sigma_obs\": 164.44674682617188, \"slope\": -0.0646577700972557, \"chain\": 0, \"draw\": 91}, {\"draws\": 91, \"mouse\": 5, \"mu_intercept_per_group\": 8.081048011779785, \"sigma_intercept_per_group\": 0.25834834575653076, \"sigma_obs\": 164.44674682617188, \"slope\": -0.0646577700972557, \"chain\": 0, \"draw\": 91}, {\"draws\": 91, \"mouse\": 6, \"mu_intercept_per_group\": 7.328127384185791, \"sigma_intercept_per_group\": 0.25834834575653076, \"sigma_obs\": 164.44674682617188, \"slope\": -0.0646577700972557, \"chain\": 0, \"draw\": 91}, {\"draws\": 91, \"mouse\": 7, \"mu_intercept_per_group\": 7.087150573730469, \"sigma_intercept_per_group\": 0.25834834575653076, \"sigma_obs\": 164.44674682617188, \"slope\": -0.0646577700972557, \"chain\": 0, \"draw\": 91}, {\"draws\": 92, \"mouse\": 0, \"mu_intercept_per_group\": 9.717559814453125, \"sigma_intercept_per_group\": 0.25926411151885986, \"sigma_obs\": 165.06524658203125, \"slope\": -0.0671563521027565, \"chain\": 0, \"draw\": 92}, {\"draws\": 92, \"mouse\": 1, \"mu_intercept_per_group\": 9.341772079467773, \"sigma_intercept_per_group\": 0.25926411151885986, \"sigma_obs\": 165.06524658203125, \"slope\": -0.0671563521027565, \"chain\": 0, \"draw\": 92}, {\"draws\": 92, \"mouse\": 2, \"mu_intercept_per_group\": 9.083029747009277, \"sigma_intercept_per_group\": 0.25926411151885986, \"sigma_obs\": 165.06524658203125, \"slope\": -0.0671563521027565, \"chain\": 0, \"draw\": 92}, {\"draws\": 92, \"mouse\": 3, \"mu_intercept_per_group\": 8.529755592346191, \"sigma_intercept_per_group\": 0.25926411151885986, \"sigma_obs\": 165.06524658203125, \"slope\": -0.0671563521027565, \"chain\": 0, \"draw\": 92}, {\"draws\": 92, \"mouse\": 4, \"mu_intercept_per_group\": 8.236589431762695, \"sigma_intercept_per_group\": 0.25926411151885986, \"sigma_obs\": 165.06524658203125, \"slope\": -0.0671563521027565, \"chain\": 0, \"draw\": 92}, {\"draws\": 92, \"mouse\": 5, \"mu_intercept_per_group\": 7.721078872680664, \"sigma_intercept_per_group\": 0.25926411151885986, \"sigma_obs\": 165.06524658203125, \"slope\": -0.0671563521027565, \"chain\": 0, \"draw\": 92}, {\"draws\": 92, \"mouse\": 6, \"mu_intercept_per_group\": 7.154973030090332, \"sigma_intercept_per_group\": 0.25926411151885986, \"sigma_obs\": 165.06524658203125, \"slope\": -0.0671563521027565, \"chain\": 0, \"draw\": 92}, {\"draws\": 92, \"mouse\": 7, \"mu_intercept_per_group\": 7.081457614898682, \"sigma_intercept_per_group\": 0.25926411151885986, \"sigma_obs\": 165.06524658203125, \"slope\": -0.0671563521027565, \"chain\": 0, \"draw\": 92}, {\"draws\": 93, \"mouse\": 0, \"mu_intercept_per_group\": 9.75882339477539, \"sigma_intercept_per_group\": 0.2589695453643799, \"sigma_obs\": 161.81195068359375, \"slope\": -0.07147413492202759, \"chain\": 0, \"draw\": 93}, {\"draws\": 93, \"mouse\": 1, \"mu_intercept_per_group\": 9.14988899230957, \"sigma_intercept_per_group\": 0.2589695453643799, \"sigma_obs\": 161.81195068359375, \"slope\": -0.07147413492202759, \"chain\": 0, \"draw\": 93}, {\"draws\": 93, \"mouse\": 2, \"mu_intercept_per_group\": 8.905679702758789, \"sigma_intercept_per_group\": 0.2589695453643799, \"sigma_obs\": 161.81195068359375, \"slope\": -0.07147413492202759, \"chain\": 0, \"draw\": 93}, {\"draws\": 93, \"mouse\": 3, \"mu_intercept_per_group\": 8.563804626464844, \"sigma_intercept_per_group\": 0.2589695453643799, \"sigma_obs\": 161.81195068359375, \"slope\": -0.07147413492202759, \"chain\": 0, \"draw\": 93}, {\"draws\": 93, \"mouse\": 4, \"mu_intercept_per_group\": 8.360590934753418, \"sigma_intercept_per_group\": 0.2589695453643799, \"sigma_obs\": 161.81195068359375, \"slope\": -0.07147413492202759, \"chain\": 0, \"draw\": 93}, {\"draws\": 93, \"mouse\": 5, \"mu_intercept_per_group\": 7.8467793464660645, \"sigma_intercept_per_group\": 0.2589695453643799, \"sigma_obs\": 161.81195068359375, \"slope\": -0.07147413492202759, \"chain\": 0, \"draw\": 93}, {\"draws\": 93, \"mouse\": 6, \"mu_intercept_per_group\": 7.282569885253906, \"sigma_intercept_per_group\": 0.2589695453643799, \"sigma_obs\": 161.81195068359375, \"slope\": -0.07147413492202759, \"chain\": 0, \"draw\": 93}, {\"draws\": 93, \"mouse\": 7, \"mu_intercept_per_group\": 6.9631147384643555, \"sigma_intercept_per_group\": 0.2589695453643799, \"sigma_obs\": 161.81195068359375, \"slope\": -0.07147413492202759, \"chain\": 0, \"draw\": 93}, {\"draws\": 94, \"mouse\": 0, \"mu_intercept_per_group\": 9.988249778747559, \"sigma_intercept_per_group\": 0.2557237446308136, \"sigma_obs\": 163.7110595703125, \"slope\": -0.07124871760606766, \"chain\": 0, \"draw\": 94}, {\"draws\": 94, \"mouse\": 1, \"mu_intercept_per_group\": 9.30176830291748, \"sigma_intercept_per_group\": 0.2557237446308136, \"sigma_obs\": 163.7110595703125, \"slope\": -0.07124871760606766, \"chain\": 0, \"draw\": 94}, {\"draws\": 94, \"mouse\": 2, \"mu_intercept_per_group\": 9.027585983276367, \"sigma_intercept_per_group\": 0.2557237446308136, \"sigma_obs\": 163.7110595703125, \"slope\": -0.07124871760606766, \"chain\": 0, \"draw\": 94}, {\"draws\": 94, \"mouse\": 3, \"mu_intercept_per_group\": 8.598124504089355, \"sigma_intercept_per_group\": 0.2557237446308136, \"sigma_obs\": 163.7110595703125, \"slope\": -0.07124871760606766, \"chain\": 0, \"draw\": 94}, {\"draws\": 94, \"mouse\": 4, \"mu_intercept_per_group\": 8.411674499511719, \"sigma_intercept_per_group\": 0.2557237446308136, \"sigma_obs\": 163.7110595703125, \"slope\": -0.07124871760606766, \"chain\": 0, \"draw\": 94}, {\"draws\": 94, \"mouse\": 5, \"mu_intercept_per_group\": 7.987309455871582, \"sigma_intercept_per_group\": 0.2557237446308136, \"sigma_obs\": 163.7110595703125, \"slope\": -0.07124871760606766, \"chain\": 0, \"draw\": 94}, {\"draws\": 94, \"mouse\": 6, \"mu_intercept_per_group\": 7.472925186157227, \"sigma_intercept_per_group\": 0.2557237446308136, \"sigma_obs\": 163.7110595703125, \"slope\": -0.07124871760606766, \"chain\": 0, \"draw\": 94}, {\"draws\": 94, \"mouse\": 7, \"mu_intercept_per_group\": 7.068853378295898, \"sigma_intercept_per_group\": 0.2557237446308136, \"sigma_obs\": 163.7110595703125, \"slope\": -0.07124871760606766, \"chain\": 0, \"draw\": 94}, {\"draws\": 95, \"mouse\": 0, \"mu_intercept_per_group\": 9.256851196289062, \"sigma_intercept_per_group\": 0.273408979177475, \"sigma_obs\": 165.6446990966797, \"slope\": -0.07009971886873245, \"chain\": 0, \"draw\": 95}, {\"draws\": 95, \"mouse\": 1, \"mu_intercept_per_group\": 9.004755973815918, \"sigma_intercept_per_group\": 0.273408979177475, \"sigma_obs\": 165.6446990966797, \"slope\": -0.07009971886873245, \"chain\": 0, \"draw\": 95}, {\"draws\": 95, \"mouse\": 2, \"mu_intercept_per_group\": 8.555004119873047, \"sigma_intercept_per_group\": 0.273408979177475, \"sigma_obs\": 165.6446990966797, \"slope\": -0.07009971886873245, \"chain\": 0, \"draw\": 95}, {\"draws\": 95, \"mouse\": 3, \"mu_intercept_per_group\": 7.971333980560303, \"sigma_intercept_per_group\": 0.273408979177475, \"sigma_obs\": 165.6446990966797, \"slope\": -0.07009971886873245, \"chain\": 0, \"draw\": 95}, {\"draws\": 95, \"mouse\": 4, \"mu_intercept_per_group\": 7.949249267578125, \"sigma_intercept_per_group\": 0.273408979177475, \"sigma_obs\": 165.6446990966797, \"slope\": -0.07009971886873245, \"chain\": 0, \"draw\": 95}, {\"draws\": 95, \"mouse\": 5, \"mu_intercept_per_group\": 7.393370628356934, \"sigma_intercept_per_group\": 0.273408979177475, \"sigma_obs\": 165.6446990966797, \"slope\": -0.07009971886873245, \"chain\": 0, \"draw\": 95}, {\"draws\": 95, \"mouse\": 6, \"mu_intercept_per_group\": 7.156670570373535, \"sigma_intercept_per_group\": 0.273408979177475, \"sigma_obs\": 165.6446990966797, \"slope\": -0.07009971886873245, \"chain\": 0, \"draw\": 95}, {\"draws\": 95, \"mouse\": 7, \"mu_intercept_per_group\": 6.792860984802246, \"sigma_intercept_per_group\": 0.273408979177475, \"sigma_obs\": 165.6446990966797, \"slope\": -0.07009971886873245, \"chain\": 0, \"draw\": 95}, {\"draws\": 96, \"mouse\": 0, \"mu_intercept_per_group\": 9.262042999267578, \"sigma_intercept_per_group\": 0.26898518204689026, \"sigma_obs\": 166.72940063476562, \"slope\": -0.0720701515674591, \"chain\": 0, \"draw\": 96}, {\"draws\": 96, \"mouse\": 1, \"mu_intercept_per_group\": 9.00426197052002, \"sigma_intercept_per_group\": 0.26898518204689026, \"sigma_obs\": 166.72940063476562, \"slope\": -0.0720701515674591, \"chain\": 0, \"draw\": 96}, {\"draws\": 96, \"mouse\": 2, \"mu_intercept_per_group\": 8.71425724029541, \"sigma_intercept_per_group\": 0.26898518204689026, \"sigma_obs\": 166.72940063476562, \"slope\": -0.0720701515674591, \"chain\": 0, \"draw\": 96}, {\"draws\": 96, \"mouse\": 3, \"mu_intercept_per_group\": 8.527578353881836, \"sigma_intercept_per_group\": 0.26898518204689026, \"sigma_obs\": 166.72940063476562, \"slope\": -0.0720701515674591, \"chain\": 0, \"draw\": 96}, {\"draws\": 96, \"mouse\": 4, \"mu_intercept_per_group\": 7.9930739402771, \"sigma_intercept_per_group\": 0.26898518204689026, \"sigma_obs\": 166.72940063476562, \"slope\": -0.0720701515674591, \"chain\": 0, \"draw\": 96}, {\"draws\": 96, \"mouse\": 5, \"mu_intercept_per_group\": 7.701657772064209, \"sigma_intercept_per_group\": 0.26898518204689026, \"sigma_obs\": 166.72940063476562, \"slope\": -0.0720701515674591, \"chain\": 0, \"draw\": 96}, {\"draws\": 96, \"mouse\": 6, \"mu_intercept_per_group\": 6.977758884429932, \"sigma_intercept_per_group\": 0.26898518204689026, \"sigma_obs\": 166.72940063476562, \"slope\": -0.0720701515674591, \"chain\": 0, \"draw\": 96}, {\"draws\": 96, \"mouse\": 7, \"mu_intercept_per_group\": 6.739654064178467, \"sigma_intercept_per_group\": 0.26898518204689026, \"sigma_obs\": 166.72940063476562, \"slope\": -0.0720701515674591, \"chain\": 0, \"draw\": 96}, {\"draws\": 97, \"mouse\": 0, \"mu_intercept_per_group\": 9.657544136047363, \"sigma_intercept_per_group\": 0.25587448477745056, \"sigma_obs\": 158.0679473876953, \"slope\": -0.08683540672063828, \"chain\": 0, \"draw\": 97}, {\"draws\": 97, \"mouse\": 1, \"mu_intercept_per_group\": 9.449053764343262, \"sigma_intercept_per_group\": 0.25587448477745056, \"sigma_obs\": 158.0679473876953, \"slope\": -0.08683540672063828, \"chain\": 0, \"draw\": 97}, {\"draws\": 97, \"mouse\": 2, \"mu_intercept_per_group\": 9.10388469696045, \"sigma_intercept_per_group\": 0.25587448477745056, \"sigma_obs\": 158.0679473876953, \"slope\": -0.08683540672063828, \"chain\": 0, \"draw\": 97}, {\"draws\": 97, \"mouse\": 3, \"mu_intercept_per_group\": 8.446187019348145, \"sigma_intercept_per_group\": 0.25587448477745056, \"sigma_obs\": 158.0679473876953, \"slope\": -0.08683540672063828, \"chain\": 0, \"draw\": 97}, {\"draws\": 97, \"mouse\": 4, \"mu_intercept_per_group\": 8.488409042358398, \"sigma_intercept_per_group\": 0.25587448477745056, \"sigma_obs\": 158.0679473876953, \"slope\": -0.08683540672063828, \"chain\": 0, \"draw\": 97}, {\"draws\": 97, \"mouse\": 5, \"mu_intercept_per_group\": 7.830046653747559, \"sigma_intercept_per_group\": 0.25587448477745056, \"sigma_obs\": 158.0679473876953, \"slope\": -0.08683540672063828, \"chain\": 0, \"draw\": 97}, {\"draws\": 97, \"mouse\": 6, \"mu_intercept_per_group\": 7.467113018035889, \"sigma_intercept_per_group\": 0.25587448477745056, \"sigma_obs\": 158.0679473876953, \"slope\": -0.08683540672063828, \"chain\": 0, \"draw\": 97}, {\"draws\": 97, \"mouse\": 7, \"mu_intercept_per_group\": 6.806373119354248, \"sigma_intercept_per_group\": 0.25587448477745056, \"sigma_obs\": 158.0679473876953, \"slope\": -0.08683540672063828, \"chain\": 0, \"draw\": 97}, {\"draws\": 98, \"mouse\": 0, \"mu_intercept_per_group\": 9.52878189086914, \"sigma_intercept_per_group\": 0.25758156180381775, \"sigma_obs\": 152.64999389648438, \"slope\": -0.06648445129394531, \"chain\": 0, \"draw\": 98}, {\"draws\": 98, \"mouse\": 1, \"mu_intercept_per_group\": 9.146008491516113, \"sigma_intercept_per_group\": 0.25758156180381775, \"sigma_obs\": 152.64999389648438, \"slope\": -0.06648445129394531, \"chain\": 0, \"draw\": 98}, {\"draws\": 98, \"mouse\": 2, \"mu_intercept_per_group\": 8.775811195373535, \"sigma_intercept_per_group\": 0.25758156180381775, \"sigma_obs\": 152.64999389648438, \"slope\": -0.06648445129394531, \"chain\": 0, \"draw\": 98}, {\"draws\": 98, \"mouse\": 3, \"mu_intercept_per_group\": 8.03921127319336, \"sigma_intercept_per_group\": 0.25758156180381775, \"sigma_obs\": 152.64999389648438, \"slope\": -0.06648445129394531, \"chain\": 0, \"draw\": 98}, {\"draws\": 98, \"mouse\": 4, \"mu_intercept_per_group\": 8.28063678741455, \"sigma_intercept_per_group\": 0.25758156180381775, \"sigma_obs\": 152.64999389648438, \"slope\": -0.06648445129394531, \"chain\": 0, \"draw\": 98}, {\"draws\": 98, \"mouse\": 5, \"mu_intercept_per_group\": 7.744578838348389, \"sigma_intercept_per_group\": 0.25758156180381775, \"sigma_obs\": 152.64999389648438, \"slope\": -0.06648445129394531, \"chain\": 0, \"draw\": 98}, {\"draws\": 98, \"mouse\": 6, \"mu_intercept_per_group\": 7.030550479888916, \"sigma_intercept_per_group\": 0.25758156180381775, \"sigma_obs\": 152.64999389648438, \"slope\": -0.06648445129394531, \"chain\": 0, \"draw\": 98}, {\"draws\": 98, \"mouse\": 7, \"mu_intercept_per_group\": 6.978766441345215, \"sigma_intercept_per_group\": 0.25758156180381775, \"sigma_obs\": 152.64999389648438, \"slope\": -0.06648445129394531, \"chain\": 0, \"draw\": 98}, {\"draws\": 99, \"mouse\": 0, \"mu_intercept_per_group\": 9.423467636108398, \"sigma_intercept_per_group\": 0.25415515899658203, \"sigma_obs\": 152.27951049804688, \"slope\": -0.06680312752723694, \"chain\": 0, \"draw\": 99}, {\"draws\": 99, \"mouse\": 1, \"mu_intercept_per_group\": 9.294093132019043, \"sigma_intercept_per_group\": 0.25415515899658203, \"sigma_obs\": 152.27951049804688, \"slope\": -0.06680312752723694, \"chain\": 0, \"draw\": 99}, {\"draws\": 99, \"mouse\": 2, \"mu_intercept_per_group\": 8.996757507324219, \"sigma_intercept_per_group\": 0.25415515899658203, \"sigma_obs\": 152.27951049804688, \"slope\": -0.06680312752723694, \"chain\": 0, \"draw\": 99}, {\"draws\": 99, \"mouse\": 3, \"mu_intercept_per_group\": 8.55203914642334, \"sigma_intercept_per_group\": 0.25415515899658203, \"sigma_obs\": 152.27951049804688, \"slope\": -0.06680312752723694, \"chain\": 0, \"draw\": 99}, {\"draws\": 99, \"mouse\": 4, \"mu_intercept_per_group\": 8.020492553710938, \"sigma_intercept_per_group\": 0.25415515899658203, \"sigma_obs\": 152.27951049804688, \"slope\": -0.06680312752723694, \"chain\": 0, \"draw\": 99}, {\"draws\": 99, \"mouse\": 5, \"mu_intercept_per_group\": 7.882414817810059, \"sigma_intercept_per_group\": 0.25415515899658203, \"sigma_obs\": 152.27951049804688, \"slope\": -0.06680312752723694, \"chain\": 0, \"draw\": 99}, {\"draws\": 99, \"mouse\": 6, \"mu_intercept_per_group\": 7.044028282165527, \"sigma_intercept_per_group\": 0.25415515899658203, \"sigma_obs\": 152.27951049804688, \"slope\": -0.06680312752723694, \"chain\": 0, \"draw\": 99}, {\"draws\": 99, \"mouse\": 7, \"mu_intercept_per_group\": 7.012374401092529, \"sigma_intercept_per_group\": 0.25415515899658203, \"sigma_obs\": 152.27951049804688, \"slope\": -0.06680312752723694, \"chain\": 0, \"draw\": 99}, {\"draws\": 100, \"mouse\": 0, \"mu_intercept_per_group\": 9.515165328979492, \"sigma_intercept_per_group\": 0.25503215193748474, \"sigma_obs\": 151.52159118652344, \"slope\": -0.06603378057479858, \"chain\": 0, \"draw\": 100}, {\"draws\": 100, \"mouse\": 1, \"mu_intercept_per_group\": 9.031721115112305, \"sigma_intercept_per_group\": 0.25503215193748474, \"sigma_obs\": 151.52159118652344, \"slope\": -0.06603378057479858, \"chain\": 0, \"draw\": 100}, {\"draws\": 100, \"mouse\": 2, \"mu_intercept_per_group\": 8.802446365356445, \"sigma_intercept_per_group\": 0.25503215193748474, \"sigma_obs\": 151.52159118652344, \"slope\": -0.06603378057479858, \"chain\": 0, \"draw\": 100}, {\"draws\": 100, \"mouse\": 3, \"mu_intercept_per_group\": 8.21654987335205, \"sigma_intercept_per_group\": 0.25503215193748474, \"sigma_obs\": 151.52159118652344, \"slope\": -0.06603378057479858, \"chain\": 0, \"draw\": 100}, {\"draws\": 100, \"mouse\": 4, \"mu_intercept_per_group\": 8.271002769470215, \"sigma_intercept_per_group\": 0.25503215193748474, \"sigma_obs\": 151.52159118652344, \"slope\": -0.06603378057479858, \"chain\": 0, \"draw\": 100}, {\"draws\": 100, \"mouse\": 5, \"mu_intercept_per_group\": 7.468994617462158, \"sigma_intercept_per_group\": 0.25503215193748474, \"sigma_obs\": 151.52159118652344, \"slope\": -0.06603378057479858, \"chain\": 0, \"draw\": 100}, {\"draws\": 100, \"mouse\": 6, \"mu_intercept_per_group\": 7.180510997772217, \"sigma_intercept_per_group\": 0.25503215193748474, \"sigma_obs\": 151.52159118652344, \"slope\": -0.06603378057479858, \"chain\": 0, \"draw\": 100}, {\"draws\": 100, \"mouse\": 7, \"mu_intercept_per_group\": 6.625424861907959, \"sigma_intercept_per_group\": 0.25503215193748474, \"sigma_obs\": 151.52159118652344, \"slope\": -0.06603378057479858, \"chain\": 0, \"draw\": 100}, {\"draws\": 101, \"mouse\": 0, \"mu_intercept_per_group\": 10.758295059204102, \"sigma_intercept_per_group\": 0.22438520193099976, \"sigma_obs\": 157.87623596191406, \"slope\": -0.06675434112548828, \"chain\": 0, \"draw\": 101}, {\"draws\": 101, \"mouse\": 1, \"mu_intercept_per_group\": 10.502988815307617, \"sigma_intercept_per_group\": 0.22438520193099976, \"sigma_obs\": 157.87623596191406, \"slope\": -0.06675434112548828, \"chain\": 0, \"draw\": 101}, {\"draws\": 101, \"mouse\": 2, \"mu_intercept_per_group\": 10.126362800598145, \"sigma_intercept_per_group\": 0.22438520193099976, \"sigma_obs\": 157.87623596191406, \"slope\": -0.06675434112548828, \"chain\": 0, \"draw\": 101}, {\"draws\": 101, \"mouse\": 3, \"mu_intercept_per_group\": 9.777774810791016, \"sigma_intercept_per_group\": 0.22438520193099976, \"sigma_obs\": 157.87623596191406, \"slope\": -0.06675434112548828, \"chain\": 0, \"draw\": 101}, {\"draws\": 101, \"mouse\": 4, \"mu_intercept_per_group\": 9.235834121704102, \"sigma_intercept_per_group\": 0.22438520193099976, \"sigma_obs\": 157.87623596191406, \"slope\": -0.06675434112548828, \"chain\": 0, \"draw\": 101}, {\"draws\": 101, \"mouse\": 5, \"mu_intercept_per_group\": 8.517163276672363, \"sigma_intercept_per_group\": 0.22438520193099976, \"sigma_obs\": 157.87623596191406, \"slope\": -0.06675434112548828, \"chain\": 0, \"draw\": 101}, {\"draws\": 101, \"mouse\": 6, \"mu_intercept_per_group\": 8.256769180297852, \"sigma_intercept_per_group\": 0.22438520193099976, \"sigma_obs\": 157.87623596191406, \"slope\": -0.06675434112548828, \"chain\": 0, \"draw\": 101}, {\"draws\": 101, \"mouse\": 7, \"mu_intercept_per_group\": 7.950786590576172, \"sigma_intercept_per_group\": 0.22438520193099976, \"sigma_obs\": 157.87623596191406, \"slope\": -0.06675434112548828, \"chain\": 0, \"draw\": 101}, {\"draws\": 102, \"mouse\": 0, \"mu_intercept_per_group\": 8.606261253356934, \"sigma_intercept_per_group\": 0.29671114683151245, \"sigma_obs\": 162.47586059570312, \"slope\": -0.06894110143184662, \"chain\": 0, \"draw\": 102}, {\"draws\": 102, \"mouse\": 1, \"mu_intercept_per_group\": 8.128616333007812, \"sigma_intercept_per_group\": 0.29671114683151245, \"sigma_obs\": 162.47586059570312, \"slope\": -0.06894110143184662, \"chain\": 0, \"draw\": 102}, {\"draws\": 102, \"mouse\": 2, \"mu_intercept_per_group\": 7.737556457519531, \"sigma_intercept_per_group\": 0.29671114683151245, \"sigma_obs\": 162.47586059570312, \"slope\": -0.06894110143184662, \"chain\": 0, \"draw\": 102}, {\"draws\": 102, \"mouse\": 3, \"mu_intercept_per_group\": 7.423410415649414, \"sigma_intercept_per_group\": 0.29671114683151245, \"sigma_obs\": 162.47586059570312, \"slope\": -0.06894110143184662, \"chain\": 0, \"draw\": 102}, {\"draws\": 102, \"mouse\": 4, \"mu_intercept_per_group\": 7.446576118469238, \"sigma_intercept_per_group\": 0.29671114683151245, \"sigma_obs\": 162.47586059570312, \"slope\": -0.06894110143184662, \"chain\": 0, \"draw\": 102}, {\"draws\": 102, \"mouse\": 5, \"mu_intercept_per_group\": 6.8055338859558105, \"sigma_intercept_per_group\": 0.29671114683151245, \"sigma_obs\": 162.47586059570312, \"slope\": -0.06894110143184662, \"chain\": 0, \"draw\": 102}, {\"draws\": 102, \"mouse\": 6, \"mu_intercept_per_group\": 6.456021308898926, \"sigma_intercept_per_group\": 0.29671114683151245, \"sigma_obs\": 162.47586059570312, \"slope\": -0.06894110143184662, \"chain\": 0, \"draw\": 102}, {\"draws\": 102, \"mouse\": 7, \"mu_intercept_per_group\": 5.9433417320251465, \"sigma_intercept_per_group\": 0.29671114683151245, \"sigma_obs\": 162.47586059570312, \"slope\": -0.06894110143184662, \"chain\": 0, \"draw\": 102}, {\"draws\": 103, \"mouse\": 0, \"mu_intercept_per_group\": 7.950255870819092, \"sigma_intercept_per_group\": 0.31059131026268005, \"sigma_obs\": 160.77679443359375, \"slope\": -0.07496802508831024, \"chain\": 0, \"draw\": 103}, {\"draws\": 103, \"mouse\": 1, \"mu_intercept_per_group\": 7.706029415130615, \"sigma_intercept_per_group\": 0.31059131026268005, \"sigma_obs\": 160.77679443359375, \"slope\": -0.07496802508831024, \"chain\": 0, \"draw\": 103}, {\"draws\": 103, \"mouse\": 2, \"mu_intercept_per_group\": 7.806159973144531, \"sigma_intercept_per_group\": 0.31059131026268005, \"sigma_obs\": 160.77679443359375, \"slope\": -0.07496802508831024, \"chain\": 0, \"draw\": 103}, {\"draws\": 103, \"mouse\": 3, \"mu_intercept_per_group\": 6.954006195068359, \"sigma_intercept_per_group\": 0.31059131026268005, \"sigma_obs\": 160.77679443359375, \"slope\": -0.07496802508831024, \"chain\": 0, \"draw\": 103}, {\"draws\": 103, \"mouse\": 4, \"mu_intercept_per_group\": 7.171308517456055, \"sigma_intercept_per_group\": 0.31059131026268005, \"sigma_obs\": 160.77679443359375, \"slope\": -0.07496802508831024, \"chain\": 0, \"draw\": 103}, {\"draws\": 103, \"mouse\": 5, \"mu_intercept_per_group\": 6.548717021942139, \"sigma_intercept_per_group\": 0.31059131026268005, \"sigma_obs\": 160.77679443359375, \"slope\": -0.07496802508831024, \"chain\": 0, \"draw\": 103}, {\"draws\": 103, \"mouse\": 6, \"mu_intercept_per_group\": 6.119701385498047, \"sigma_intercept_per_group\": 0.31059131026268005, \"sigma_obs\": 160.77679443359375, \"slope\": -0.07496802508831024, \"chain\": 0, \"draw\": 103}, {\"draws\": 103, \"mouse\": 7, \"mu_intercept_per_group\": 5.731505870819092, \"sigma_intercept_per_group\": 0.31059131026268005, \"sigma_obs\": 160.77679443359375, \"slope\": -0.07496802508831024, \"chain\": 0, \"draw\": 103}, {\"draws\": 104, \"mouse\": 0, \"mu_intercept_per_group\": 8.458051681518555, \"sigma_intercept_per_group\": 0.2924935221672058, \"sigma_obs\": 158.45228576660156, \"slope\": -0.07714059948921204, \"chain\": 0, \"draw\": 104}, {\"draws\": 104, \"mouse\": 1, \"mu_intercept_per_group\": 8.308649063110352, \"sigma_intercept_per_group\": 0.2924935221672058, \"sigma_obs\": 158.45228576660156, \"slope\": -0.07714059948921204, \"chain\": 0, \"draw\": 104}, {\"draws\": 104, \"mouse\": 2, \"mu_intercept_per_group\": 7.701066970825195, \"sigma_intercept_per_group\": 0.2924935221672058, \"sigma_obs\": 158.45228576660156, \"slope\": -0.07714059948921204, \"chain\": 0, \"draw\": 104}, {\"draws\": 104, \"mouse\": 3, \"mu_intercept_per_group\": 7.454189777374268, \"sigma_intercept_per_group\": 0.2924935221672058, \"sigma_obs\": 158.45228576660156, \"slope\": -0.07714059948921204, \"chain\": 0, \"draw\": 104}, {\"draws\": 104, \"mouse\": 4, \"mu_intercept_per_group\": 7.379286766052246, \"sigma_intercept_per_group\": 0.2924935221672058, \"sigma_obs\": 158.45228576660156, \"slope\": -0.07714059948921204, \"chain\": 0, \"draw\": 104}, {\"draws\": 104, \"mouse\": 5, \"mu_intercept_per_group\": 6.82001256942749, \"sigma_intercept_per_group\": 0.2924935221672058, \"sigma_obs\": 158.45228576660156, \"slope\": -0.07714059948921204, \"chain\": 0, \"draw\": 104}, {\"draws\": 104, \"mouse\": 6, \"mu_intercept_per_group\": 6.353787422180176, \"sigma_intercept_per_group\": 0.2924935221672058, \"sigma_obs\": 158.45228576660156, \"slope\": -0.07714059948921204, \"chain\": 0, \"draw\": 104}, {\"draws\": 104, \"mouse\": 7, \"mu_intercept_per_group\": 6.098912239074707, \"sigma_intercept_per_group\": 0.2924935221672058, \"sigma_obs\": 158.45228576660156, \"slope\": -0.07714059948921204, \"chain\": 0, \"draw\": 104}, {\"draws\": 105, \"mouse\": 0, \"mu_intercept_per_group\": 8.446882247924805, \"sigma_intercept_per_group\": 0.29246580600738525, \"sigma_obs\": 159.19439697265625, \"slope\": -0.07773999124765396, \"chain\": 0, \"draw\": 105}, {\"draws\": 105, \"mouse\": 1, \"mu_intercept_per_group\": 8.031575202941895, \"sigma_intercept_per_group\": 0.29246580600738525, \"sigma_obs\": 159.19439697265625, \"slope\": -0.07773999124765396, \"chain\": 0, \"draw\": 105}, {\"draws\": 105, \"mouse\": 2, \"mu_intercept_per_group\": 8.034173965454102, \"sigma_intercept_per_group\": 0.29246580600738525, \"sigma_obs\": 159.19439697265625, \"slope\": -0.07773999124765396, \"chain\": 0, \"draw\": 105}, {\"draws\": 105, \"mouse\": 3, \"mu_intercept_per_group\": 7.561001300811768, \"sigma_intercept_per_group\": 0.29246580600738525, \"sigma_obs\": 159.19439697265625, \"slope\": -0.07773999124765396, \"chain\": 0, \"draw\": 105}, {\"draws\": 105, \"mouse\": 4, \"mu_intercept_per_group\": 7.253861904144287, \"sigma_intercept_per_group\": 0.29246580600738525, \"sigma_obs\": 159.19439697265625, \"slope\": -0.07773999124765396, \"chain\": 0, \"draw\": 105}, {\"draws\": 105, \"mouse\": 5, \"mu_intercept_per_group\": 6.710346221923828, \"sigma_intercept_per_group\": 0.29246580600738525, \"sigma_obs\": 159.19439697265625, \"slope\": -0.07773999124765396, \"chain\": 0, \"draw\": 105}, {\"draws\": 105, \"mouse\": 6, \"mu_intercept_per_group\": 6.351110458374023, \"sigma_intercept_per_group\": 0.29246580600738525, \"sigma_obs\": 159.19439697265625, \"slope\": -0.07773999124765396, \"chain\": 0, \"draw\": 105}, {\"draws\": 105, \"mouse\": 7, \"mu_intercept_per_group\": 6.276414394378662, \"sigma_intercept_per_group\": 0.29246580600738525, \"sigma_obs\": 159.19439697265625, \"slope\": -0.07773999124765396, \"chain\": 0, \"draw\": 105}, {\"draws\": 106, \"mouse\": 0, \"mu_intercept_per_group\": 8.565783500671387, \"sigma_intercept_per_group\": 0.288221538066864, \"sigma_obs\": 159.42486572265625, \"slope\": -0.07802875339984894, \"chain\": 0, \"draw\": 106}, {\"draws\": 106, \"mouse\": 1, \"mu_intercept_per_group\": 8.35279369354248, \"sigma_intercept_per_group\": 0.288221538066864, \"sigma_obs\": 159.42486572265625, \"slope\": -0.07802875339984894, \"chain\": 0, \"draw\": 106}, {\"draws\": 106, \"mouse\": 2, \"mu_intercept_per_group\": 8.075251579284668, \"sigma_intercept_per_group\": 0.288221538066864, \"sigma_obs\": 159.42486572265625, \"slope\": -0.07802875339984894, \"chain\": 0, \"draw\": 106}, {\"draws\": 106, \"mouse\": 3, \"mu_intercept_per_group\": 7.3218607902526855, \"sigma_intercept_per_group\": 0.288221538066864, \"sigma_obs\": 159.42486572265625, \"slope\": -0.07802875339984894, \"chain\": 0, \"draw\": 106}, {\"draws\": 106, \"mouse\": 4, \"mu_intercept_per_group\": 7.410887241363525, \"sigma_intercept_per_group\": 0.288221538066864, \"sigma_obs\": 159.42486572265625, \"slope\": -0.07802875339984894, \"chain\": 0, \"draw\": 106}, {\"draws\": 106, \"mouse\": 5, \"mu_intercept_per_group\": 6.807801246643066, \"sigma_intercept_per_group\": 0.288221538066864, \"sigma_obs\": 159.42486572265625, \"slope\": -0.07802875339984894, \"chain\": 0, \"draw\": 106}, {\"draws\": 106, \"mouse\": 6, \"mu_intercept_per_group\": 6.467483043670654, \"sigma_intercept_per_group\": 0.288221538066864, \"sigma_obs\": 159.42486572265625, \"slope\": -0.07802875339984894, \"chain\": 0, \"draw\": 106}, {\"draws\": 106, \"mouse\": 7, \"mu_intercept_per_group\": 6.1388092041015625, \"sigma_intercept_per_group\": 0.288221538066864, \"sigma_obs\": 159.42486572265625, \"slope\": -0.07802875339984894, \"chain\": 0, \"draw\": 106}, {\"draws\": 107, \"mouse\": 0, \"mu_intercept_per_group\": 8.345372200012207, \"sigma_intercept_per_group\": 0.29904571175575256, \"sigma_obs\": 161.39321899414062, \"slope\": -0.08586928248405457, \"chain\": 0, \"draw\": 107}, {\"draws\": 107, \"mouse\": 1, \"mu_intercept_per_group\": 7.998184680938721, \"sigma_intercept_per_group\": 0.29904571175575256, \"sigma_obs\": 161.39321899414062, \"slope\": -0.08586928248405457, \"chain\": 0, \"draw\": 107}, {\"draws\": 107, \"mouse\": 2, \"mu_intercept_per_group\": 7.825473308563232, \"sigma_intercept_per_group\": 0.29904571175575256, \"sigma_obs\": 161.39321899414062, \"slope\": -0.08586928248405457, \"chain\": 0, \"draw\": 107}, {\"draws\": 107, \"mouse\": 3, \"mu_intercept_per_group\": 7.655464172363281, \"sigma_intercept_per_group\": 0.29904571175575256, \"sigma_obs\": 161.39321899414062, \"slope\": -0.08586928248405457, \"chain\": 0, \"draw\": 107}, {\"draws\": 107, \"mouse\": 4, \"mu_intercept_per_group\": 7.378668308258057, \"sigma_intercept_per_group\": 0.29904571175575256, \"sigma_obs\": 161.39321899414062, \"slope\": -0.08586928248405457, \"chain\": 0, \"draw\": 107}, {\"draws\": 107, \"mouse\": 5, \"mu_intercept_per_group\": 6.775999069213867, \"sigma_intercept_per_group\": 0.29904571175575256, \"sigma_obs\": 161.39321899414062, \"slope\": -0.08586928248405457, \"chain\": 0, \"draw\": 107}, {\"draws\": 107, \"mouse\": 6, \"mu_intercept_per_group\": 6.4126667976379395, \"sigma_intercept_per_group\": 0.29904571175575256, \"sigma_obs\": 161.39321899414062, \"slope\": -0.08586928248405457, \"chain\": 0, \"draw\": 107}, {\"draws\": 107, \"mouse\": 7, \"mu_intercept_per_group\": 6.179506301879883, \"sigma_intercept_per_group\": 0.29904571175575256, \"sigma_obs\": 161.39321899414062, \"slope\": -0.08586928248405457, \"chain\": 0, \"draw\": 107}, {\"draws\": 108, \"mouse\": 0, \"mu_intercept_per_group\": 8.17770767211914, \"sigma_intercept_per_group\": 0.3005812466144562, \"sigma_obs\": 162.899658203125, \"slope\": -0.07970759272575378, \"chain\": 0, \"draw\": 108}, {\"draws\": 108, \"mouse\": 1, \"mu_intercept_per_group\": 7.826645374298096, \"sigma_intercept_per_group\": 0.3005812466144562, \"sigma_obs\": 162.899658203125, \"slope\": -0.07970759272575378, \"chain\": 0, \"draw\": 108}, {\"draws\": 108, \"mouse\": 2, \"mu_intercept_per_group\": 7.731570720672607, \"sigma_intercept_per_group\": 0.3005812466144562, \"sigma_obs\": 162.899658203125, \"slope\": -0.07970759272575378, \"chain\": 0, \"draw\": 108}, {\"draws\": 108, \"mouse\": 3, \"mu_intercept_per_group\": 7.319296360015869, \"sigma_intercept_per_group\": 0.3005812466144562, \"sigma_obs\": 162.899658203125, \"slope\": -0.07970759272575378, \"chain\": 0, \"draw\": 108}, {\"draws\": 108, \"mouse\": 4, \"mu_intercept_per_group\": 7.35896635055542, \"sigma_intercept_per_group\": 0.3005812466144562, \"sigma_obs\": 162.899658203125, \"slope\": -0.07970759272575378, \"chain\": 0, \"draw\": 108}, {\"draws\": 108, \"mouse\": 5, \"mu_intercept_per_group\": 6.858768463134766, \"sigma_intercept_per_group\": 0.3005812466144562, \"sigma_obs\": 162.899658203125, \"slope\": -0.07970759272575378, \"chain\": 0, \"draw\": 108}, {\"draws\": 108, \"mouse\": 6, \"mu_intercept_per_group\": 6.552213191986084, \"sigma_intercept_per_group\": 0.3005812466144562, \"sigma_obs\": 162.899658203125, \"slope\": -0.07970759272575378, \"chain\": 0, \"draw\": 108}, {\"draws\": 108, \"mouse\": 7, \"mu_intercept_per_group\": 6.223027229309082, \"sigma_intercept_per_group\": 0.3005812466144562, \"sigma_obs\": 162.899658203125, \"slope\": -0.07970759272575378, \"chain\": 0, \"draw\": 108}, {\"draws\": 109, \"mouse\": 0, \"mu_intercept_per_group\": 8.182146072387695, \"sigma_intercept_per_group\": 0.300949364900589, \"sigma_obs\": 162.92855834960938, \"slope\": -0.07966126501560211, \"chain\": 0, \"draw\": 109}, {\"draws\": 109, \"mouse\": 1, \"mu_intercept_per_group\": 7.8461408615112305, \"sigma_intercept_per_group\": 0.300949364900589, \"sigma_obs\": 162.92855834960938, \"slope\": -0.07966126501560211, \"chain\": 0, \"draw\": 109}, {\"draws\": 109, \"mouse\": 2, \"mu_intercept_per_group\": 7.713223934173584, \"sigma_intercept_per_group\": 0.300949364900589, \"sigma_obs\": 162.92855834960938, \"slope\": -0.07966126501560211, \"chain\": 0, \"draw\": 109}, {\"draws\": 109, \"mouse\": 3, \"mu_intercept_per_group\": 7.318726062774658, \"sigma_intercept_per_group\": 0.300949364900589, \"sigma_obs\": 162.92855834960938, \"slope\": -0.07966126501560211, \"chain\": 0, \"draw\": 109}, {\"draws\": 109, \"mouse\": 4, \"mu_intercept_per_group\": 7.354818344116211, \"sigma_intercept_per_group\": 0.300949364900589, \"sigma_obs\": 162.92855834960938, \"slope\": -0.07966126501560211, \"chain\": 0, \"draw\": 109}, {\"draws\": 109, \"mouse\": 5, \"mu_intercept_per_group\": 6.865117073059082, \"sigma_intercept_per_group\": 0.300949364900589, \"sigma_obs\": 162.92855834960938, \"slope\": -0.07966126501560211, \"chain\": 0, \"draw\": 109}, {\"draws\": 109, \"mouse\": 6, \"mu_intercept_per_group\": 6.577397346496582, \"sigma_intercept_per_group\": 0.300949364900589, \"sigma_obs\": 162.92855834960938, \"slope\": -0.07966126501560211, \"chain\": 0, \"draw\": 109}, {\"draws\": 109, \"mouse\": 7, \"mu_intercept_per_group\": 6.224674701690674, \"sigma_intercept_per_group\": 0.300949364900589, \"sigma_obs\": 162.92855834960938, \"slope\": -0.07966126501560211, \"chain\": 0, \"draw\": 109}, {\"draws\": 110, \"mouse\": 0, \"mu_intercept_per_group\": 8.8229398727417, \"sigma_intercept_per_group\": 0.2797752916812897, \"sigma_obs\": 157.89303588867188, \"slope\": -0.07331150025129318, \"chain\": 0, \"draw\": 110}, {\"draws\": 110, \"mouse\": 1, \"mu_intercept_per_group\": 8.488423347473145, \"sigma_intercept_per_group\": 0.2797752916812897, \"sigma_obs\": 157.89303588867188, \"slope\": -0.07331150025129318, \"chain\": 0, \"draw\": 110}, {\"draws\": 110, \"mouse\": 2, \"mu_intercept_per_group\": 8.363724708557129, \"sigma_intercept_per_group\": 0.2797752916812897, \"sigma_obs\": 157.89303588867188, \"slope\": -0.07331150025129318, \"chain\": 0, \"draw\": 110}, {\"draws\": 110, \"mouse\": 3, \"mu_intercept_per_group\": 7.856945514678955, \"sigma_intercept_per_group\": 0.2797752916812897, \"sigma_obs\": 157.89303588867188, \"slope\": -0.07331150025129318, \"chain\": 0, \"draw\": 110}, {\"draws\": 110, \"mouse\": 4, \"mu_intercept_per_group\": 7.303623199462891, \"sigma_intercept_per_group\": 0.2797752916812897, \"sigma_obs\": 157.89303588867188, \"slope\": -0.07331150025129318, \"chain\": 0, \"draw\": 110}, {\"draws\": 110, \"mouse\": 5, \"mu_intercept_per_group\": 6.9525041580200195, \"sigma_intercept_per_group\": 0.2797752916812897, \"sigma_obs\": 157.89303588867188, \"slope\": -0.07331150025129318, \"chain\": 0, \"draw\": 110}, {\"draws\": 110, \"mouse\": 6, \"mu_intercept_per_group\": 6.8009562492370605, \"sigma_intercept_per_group\": 0.2797752916812897, \"sigma_obs\": 157.89303588867188, \"slope\": -0.07331150025129318, \"chain\": 0, \"draw\": 110}, {\"draws\": 110, \"mouse\": 7, \"mu_intercept_per_group\": 6.404831886291504, \"sigma_intercept_per_group\": 0.2797752916812897, \"sigma_obs\": 157.89303588867188, \"slope\": -0.07331150025129318, \"chain\": 0, \"draw\": 110}, {\"draws\": 111, \"mouse\": 0, \"mu_intercept_per_group\": 9.259546279907227, \"sigma_intercept_per_group\": 0.2646237909793854, \"sigma_obs\": 150.0943145751953, \"slope\": -0.08531975001096725, \"chain\": 0, \"draw\": 111}, {\"draws\": 111, \"mouse\": 1, \"mu_intercept_per_group\": 8.800361633300781, \"sigma_intercept_per_group\": 0.2646237909793854, \"sigma_obs\": 150.0943145751953, \"slope\": -0.08531975001096725, \"chain\": 0, \"draw\": 111}, {\"draws\": 111, \"mouse\": 2, \"mu_intercept_per_group\": 8.42223072052002, \"sigma_intercept_per_group\": 0.2646237909793854, \"sigma_obs\": 150.0943145751953, \"slope\": -0.08531975001096725, \"chain\": 0, \"draw\": 111}, {\"draws\": 111, \"mouse\": 3, \"mu_intercept_per_group\": 8.166903495788574, \"sigma_intercept_per_group\": 0.2646237909793854, \"sigma_obs\": 150.0943145751953, \"slope\": -0.08531975001096725, \"chain\": 0, \"draw\": 111}, {\"draws\": 111, \"mouse\": 4, \"mu_intercept_per_group\": 8.009953498840332, \"sigma_intercept_per_group\": 0.2646237909793854, \"sigma_obs\": 150.0943145751953, \"slope\": -0.08531975001096725, \"chain\": 0, \"draw\": 111}, {\"draws\": 111, \"mouse\": 5, \"mu_intercept_per_group\": 7.394583225250244, \"sigma_intercept_per_group\": 0.2646237909793854, \"sigma_obs\": 150.0943145751953, \"slope\": -0.08531975001096725, \"chain\": 0, \"draw\": 111}, {\"draws\": 111, \"mouse\": 6, \"mu_intercept_per_group\": 7.190965175628662, \"sigma_intercept_per_group\": 0.2646237909793854, \"sigma_obs\": 150.0943145751953, \"slope\": -0.08531975001096725, \"chain\": 0, \"draw\": 111}, {\"draws\": 111, \"mouse\": 7, \"mu_intercept_per_group\": 6.592959880828857, \"sigma_intercept_per_group\": 0.2646237909793854, \"sigma_obs\": 150.0943145751953, \"slope\": -0.08531975001096725, \"chain\": 0, \"draw\": 111}, {\"draws\": 112, \"mouse\": 0, \"mu_intercept_per_group\": 8.564152717590332, \"sigma_intercept_per_group\": 0.28805121779441833, \"sigma_obs\": 157.71861267089844, \"slope\": -0.07541786134243011, \"chain\": 0, \"draw\": 112}, {\"draws\": 112, \"mouse\": 1, \"mu_intercept_per_group\": 8.238680839538574, \"sigma_intercept_per_group\": 0.28805121779441833, \"sigma_obs\": 157.71861267089844, \"slope\": -0.07541786134243011, \"chain\": 0, \"draw\": 112}, {\"draws\": 112, \"mouse\": 2, \"mu_intercept_per_group\": 8.025127410888672, \"sigma_intercept_per_group\": 0.28805121779441833, \"sigma_obs\": 157.71861267089844, \"slope\": -0.07541786134243011, \"chain\": 0, \"draw\": 112}, {\"draws\": 112, \"mouse\": 3, \"mu_intercept_per_group\": 7.709183216094971, \"sigma_intercept_per_group\": 0.28805121779441833, \"sigma_obs\": 157.71861267089844, \"slope\": -0.07541786134243011, \"chain\": 0, \"draw\": 112}, {\"draws\": 112, \"mouse\": 4, \"mu_intercept_per_group\": 7.4307732582092285, \"sigma_intercept_per_group\": 0.28805121779441833, \"sigma_obs\": 157.71861267089844, \"slope\": -0.07541786134243011, \"chain\": 0, \"draw\": 112}, {\"draws\": 112, \"mouse\": 5, \"mu_intercept_per_group\": 7.036696434020996, \"sigma_intercept_per_group\": 0.28805121779441833, \"sigma_obs\": 157.71861267089844, \"slope\": -0.07541786134243011, \"chain\": 0, \"draw\": 112}, {\"draws\": 112, \"mouse\": 6, \"mu_intercept_per_group\": 6.513364315032959, \"sigma_intercept_per_group\": 0.28805121779441833, \"sigma_obs\": 157.71861267089844, \"slope\": -0.07541786134243011, \"chain\": 0, \"draw\": 112}, {\"draws\": 112, \"mouse\": 7, \"mu_intercept_per_group\": 6.207810878753662, \"sigma_intercept_per_group\": 0.28805121779441833, \"sigma_obs\": 157.71861267089844, \"slope\": -0.07541786134243011, \"chain\": 0, \"draw\": 112}, {\"draws\": 113, \"mouse\": 0, \"mu_intercept_per_group\": 8.790970802307129, \"sigma_intercept_per_group\": 0.2825278043746948, \"sigma_obs\": 157.7416229248047, \"slope\": -0.07403550297021866, \"chain\": 0, \"draw\": 113}, {\"draws\": 113, \"mouse\": 1, \"mu_intercept_per_group\": 8.504632949829102, \"sigma_intercept_per_group\": 0.2825278043746948, \"sigma_obs\": 157.7416229248047, \"slope\": -0.07403550297021866, \"chain\": 0, \"draw\": 113}, {\"draws\": 113, \"mouse\": 2, \"mu_intercept_per_group\": 8.254159927368164, \"sigma_intercept_per_group\": 0.2825278043746948, \"sigma_obs\": 157.7416229248047, \"slope\": -0.07403550297021866, \"chain\": 0, \"draw\": 113}, {\"draws\": 113, \"mouse\": 3, \"mu_intercept_per_group\": 7.5739827156066895, \"sigma_intercept_per_group\": 0.2825278043746948, \"sigma_obs\": 157.7416229248047, \"slope\": -0.07403550297021866, \"chain\": 0, \"draw\": 113}, {\"draws\": 113, \"mouse\": 4, \"mu_intercept_per_group\": 7.4958295822143555, \"sigma_intercept_per_group\": 0.2825278043746948, \"sigma_obs\": 157.7416229248047, \"slope\": -0.07403550297021866, \"chain\": 0, \"draw\": 113}, {\"draws\": 113, \"mouse\": 5, \"mu_intercept_per_group\": 6.997560501098633, \"sigma_intercept_per_group\": 0.2825278043746948, \"sigma_obs\": 157.7416229248047, \"slope\": -0.07403550297021866, \"chain\": 0, \"draw\": 113}, {\"draws\": 113, \"mouse\": 6, \"mu_intercept_per_group\": 6.555383205413818, \"sigma_intercept_per_group\": 0.2825278043746948, \"sigma_obs\": 157.7416229248047, \"slope\": -0.07403550297021866, \"chain\": 0, \"draw\": 113}, {\"draws\": 113, \"mouse\": 7, \"mu_intercept_per_group\": 6.284942150115967, \"sigma_intercept_per_group\": 0.2825278043746948, \"sigma_obs\": 157.7416229248047, \"slope\": -0.07403550297021866, \"chain\": 0, \"draw\": 113}, {\"draws\": 114, \"mouse\": 0, \"mu_intercept_per_group\": 8.592856407165527, \"sigma_intercept_per_group\": 0.2806258499622345, \"sigma_obs\": 148.05210876464844, \"slope\": -0.08340426534414291, \"chain\": 0, \"draw\": 114}, {\"draws\": 114, \"mouse\": 1, \"mu_intercept_per_group\": 8.357179641723633, \"sigma_intercept_per_group\": 0.2806258499622345, \"sigma_obs\": 148.05210876464844, \"slope\": -0.08340426534414291, \"chain\": 0, \"draw\": 114}, {\"draws\": 114, \"mouse\": 2, \"mu_intercept_per_group\": 8.036510467529297, \"sigma_intercept_per_group\": 0.2806258499622345, \"sigma_obs\": 148.05210876464844, \"slope\": -0.08340426534414291, \"chain\": 0, \"draw\": 114}, {\"draws\": 114, \"mouse\": 3, \"mu_intercept_per_group\": 7.538753986358643, \"sigma_intercept_per_group\": 0.2806258499622345, \"sigma_obs\": 148.05210876464844, \"slope\": -0.08340426534414291, \"chain\": 0, \"draw\": 114}, {\"draws\": 114, \"mouse\": 4, \"mu_intercept_per_group\": 7.207892894744873, \"sigma_intercept_per_group\": 0.2806258499622345, \"sigma_obs\": 148.05210876464844, \"slope\": -0.08340426534414291, \"chain\": 0, \"draw\": 114}, {\"draws\": 114, \"mouse\": 5, \"mu_intercept_per_group\": 6.879100799560547, \"sigma_intercept_per_group\": 0.2806258499622345, \"sigma_obs\": 148.05210876464844, \"slope\": -0.08340426534414291, \"chain\": 0, \"draw\": 114}, {\"draws\": 114, \"mouse\": 6, \"mu_intercept_per_group\": 6.868764400482178, \"sigma_intercept_per_group\": 0.2806258499622345, \"sigma_obs\": 148.05210876464844, \"slope\": -0.08340426534414291, \"chain\": 0, \"draw\": 114}, {\"draws\": 114, \"mouse\": 7, \"mu_intercept_per_group\": 6.177318572998047, \"sigma_intercept_per_group\": 0.2806258499622345, \"sigma_obs\": 148.05210876464844, \"slope\": -0.08340426534414291, \"chain\": 0, \"draw\": 114}, {\"draws\": 115, \"mouse\": 0, \"mu_intercept_per_group\": 8.679725646972656, \"sigma_intercept_per_group\": 0.27902472019195557, \"sigma_obs\": 147.56600952148438, \"slope\": -0.08430342376232147, \"chain\": 0, \"draw\": 115}, {\"draws\": 115, \"mouse\": 1, \"mu_intercept_per_group\": 8.281317710876465, \"sigma_intercept_per_group\": 0.27902472019195557, \"sigma_obs\": 147.56600952148438, \"slope\": -0.08430342376232147, \"chain\": 0, \"draw\": 115}, {\"draws\": 115, \"mouse\": 2, \"mu_intercept_per_group\": 8.056784629821777, \"sigma_intercept_per_group\": 0.27902472019195557, \"sigma_obs\": 147.56600952148438, \"slope\": -0.08430342376232147, \"chain\": 0, \"draw\": 115}, {\"draws\": 115, \"mouse\": 3, \"mu_intercept_per_group\": 7.587977409362793, \"sigma_intercept_per_group\": 0.27902472019195557, \"sigma_obs\": 147.56600952148438, \"slope\": -0.08430342376232147, \"chain\": 0, \"draw\": 115}, {\"draws\": 115, \"mouse\": 4, \"mu_intercept_per_group\": 7.5346527099609375, \"sigma_intercept_per_group\": 0.27902472019195557, \"sigma_obs\": 147.56600952148438, \"slope\": -0.08430342376232147, \"chain\": 0, \"draw\": 115}, {\"draws\": 115, \"mouse\": 5, \"mu_intercept_per_group\": 7.110036373138428, \"sigma_intercept_per_group\": 0.27902472019195557, \"sigma_obs\": 147.56600952148438, \"slope\": -0.08430342376232147, \"chain\": 0, \"draw\": 115}, {\"draws\": 115, \"mouse\": 6, \"mu_intercept_per_group\": 6.554876804351807, \"sigma_intercept_per_group\": 0.27902472019195557, \"sigma_obs\": 147.56600952148438, \"slope\": -0.08430342376232147, \"chain\": 0, \"draw\": 115}, {\"draws\": 115, \"mouse\": 7, \"mu_intercept_per_group\": 6.071606636047363, \"sigma_intercept_per_group\": 0.27902472019195557, \"sigma_obs\": 147.56600952148438, \"slope\": -0.08430342376232147, \"chain\": 0, \"draw\": 115}, {\"draws\": 116, \"mouse\": 0, \"mu_intercept_per_group\": 8.763647079467773, \"sigma_intercept_per_group\": 0.2756165564060211, \"sigma_obs\": 145.68910217285156, \"slope\": -0.08492368459701538, \"chain\": 0, \"draw\": 116}, {\"draws\": 116, \"mouse\": 1, \"mu_intercept_per_group\": 8.635726928710938, \"sigma_intercept_per_group\": 0.2756165564060211, \"sigma_obs\": 145.68910217285156, \"slope\": -0.08492368459701538, \"chain\": 0, \"draw\": 116}, {\"draws\": 116, \"mouse\": 2, \"mu_intercept_per_group\": 7.96897554397583, \"sigma_intercept_per_group\": 0.2756165564060211, \"sigma_obs\": 145.68910217285156, \"slope\": -0.08492368459701538, \"chain\": 0, \"draw\": 116}, {\"draws\": 116, \"mouse\": 3, \"mu_intercept_per_group\": 7.6830949783325195, \"sigma_intercept_per_group\": 0.2756165564060211, \"sigma_obs\": 145.68910217285156, \"slope\": -0.08492368459701538, \"chain\": 0, \"draw\": 116}, {\"draws\": 116, \"mouse\": 4, \"mu_intercept_per_group\": 7.39412260055542, \"sigma_intercept_per_group\": 0.2756165564060211, \"sigma_obs\": 145.68910217285156, \"slope\": -0.08492368459701538, \"chain\": 0, \"draw\": 116}, {\"draws\": 116, \"mouse\": 5, \"mu_intercept_per_group\": 6.936707496643066, \"sigma_intercept_per_group\": 0.2756165564060211, \"sigma_obs\": 145.68910217285156, \"slope\": -0.08492368459701538, \"chain\": 0, \"draw\": 116}, {\"draws\": 116, \"mouse\": 6, \"mu_intercept_per_group\": 6.5840654373168945, \"sigma_intercept_per_group\": 0.2756165564060211, \"sigma_obs\": 145.68910217285156, \"slope\": -0.08492368459701538, \"chain\": 0, \"draw\": 116}, {\"draws\": 116, \"mouse\": 7, \"mu_intercept_per_group\": 6.280997276306152, \"sigma_intercept_per_group\": 0.2756165564060211, \"sigma_obs\": 145.68910217285156, \"slope\": -0.08492368459701538, \"chain\": 0, \"draw\": 116}, {\"draws\": 117, \"mouse\": 0, \"mu_intercept_per_group\": 8.758569717407227, \"sigma_intercept_per_group\": 0.27561306953430176, \"sigma_obs\": 146.1589813232422, \"slope\": -0.08597608655691147, \"chain\": 0, \"draw\": 117}, {\"draws\": 117, \"mouse\": 1, \"mu_intercept_per_group\": 8.239155769348145, \"sigma_intercept_per_group\": 0.27561306953430176, \"sigma_obs\": 146.1589813232422, \"slope\": -0.08597608655691147, \"chain\": 0, \"draw\": 117}, {\"draws\": 117, \"mouse\": 2, \"mu_intercept_per_group\": 8.4087495803833, \"sigma_intercept_per_group\": 0.27561306953430176, \"sigma_obs\": 146.1589813232422, \"slope\": -0.08597608655691147, \"chain\": 0, \"draw\": 117}, {\"draws\": 117, \"mouse\": 3, \"mu_intercept_per_group\": 7.805088996887207, \"sigma_intercept_per_group\": 0.27561306953430176, \"sigma_obs\": 146.1589813232422, \"slope\": -0.08597608655691147, \"chain\": 0, \"draw\": 117}, {\"draws\": 117, \"mouse\": 4, \"mu_intercept_per_group\": 7.6309428215026855, \"sigma_intercept_per_group\": 0.27561306953430176, \"sigma_obs\": 146.1589813232422, \"slope\": -0.08597608655691147, \"chain\": 0, \"draw\": 117}, {\"draws\": 117, \"mouse\": 5, \"mu_intercept_per_group\": 7.2496185302734375, \"sigma_intercept_per_group\": 0.27561306953430176, \"sigma_obs\": 146.1589813232422, \"slope\": -0.08597608655691147, \"chain\": 0, \"draw\": 117}, {\"draws\": 117, \"mouse\": 6, \"mu_intercept_per_group\": 6.437630653381348, \"sigma_intercept_per_group\": 0.27561306953430176, \"sigma_obs\": 146.1589813232422, \"slope\": -0.08597608655691147, \"chain\": 0, \"draw\": 117}, {\"draws\": 117, \"mouse\": 7, \"mu_intercept_per_group\": 6.14479398727417, \"sigma_intercept_per_group\": 0.27561306953430176, \"sigma_obs\": 146.1589813232422, \"slope\": -0.08597608655691147, \"chain\": 0, \"draw\": 117}, {\"draws\": 118, \"mouse\": 0, \"mu_intercept_per_group\": 8.836217880249023, \"sigma_intercept_per_group\": 0.27954527735710144, \"sigma_obs\": 146.92405700683594, \"slope\": -0.08576726913452148, \"chain\": 0, \"draw\": 118}, {\"draws\": 118, \"mouse\": 1, \"mu_intercept_per_group\": 8.1808443069458, \"sigma_intercept_per_group\": 0.27954527735710144, \"sigma_obs\": 146.92405700683594, \"slope\": -0.08576726913452148, \"chain\": 0, \"draw\": 118}, {\"draws\": 118, \"mouse\": 2, \"mu_intercept_per_group\": 7.946525573730469, \"sigma_intercept_per_group\": 0.27954527735710144, \"sigma_obs\": 146.92405700683594, \"slope\": -0.08576726913452148, \"chain\": 0, \"draw\": 118}, {\"draws\": 118, \"mouse\": 3, \"mu_intercept_per_group\": 7.505255222320557, \"sigma_intercept_per_group\": 0.27954527735710144, \"sigma_obs\": 146.92405700683594, \"slope\": -0.08576726913452148, \"chain\": 0, \"draw\": 118}, {\"draws\": 118, \"mouse\": 4, \"mu_intercept_per_group\": 7.298460483551025, \"sigma_intercept_per_group\": 0.27954527735710144, \"sigma_obs\": 146.92405700683594, \"slope\": -0.08576726913452148, \"chain\": 0, \"draw\": 118}, {\"draws\": 118, \"mouse\": 5, \"mu_intercept_per_group\": 6.8266496658325195, \"sigma_intercept_per_group\": 0.27954527735710144, \"sigma_obs\": 146.92405700683594, \"slope\": -0.08576726913452148, \"chain\": 0, \"draw\": 118}, {\"draws\": 118, \"mouse\": 6, \"mu_intercept_per_group\": 6.720686912536621, \"sigma_intercept_per_group\": 0.27954527735710144, \"sigma_obs\": 146.92405700683594, \"slope\": -0.08576726913452148, \"chain\": 0, \"draw\": 118}, {\"draws\": 118, \"mouse\": 7, \"mu_intercept_per_group\": 5.944568157196045, \"sigma_intercept_per_group\": 0.27954527735710144, \"sigma_obs\": 146.92405700683594, \"slope\": -0.08576726913452148, \"chain\": 0, \"draw\": 118}, {\"draws\": 119, \"mouse\": 0, \"mu_intercept_per_group\": 9.032866477966309, \"sigma_intercept_per_group\": 0.278367280960083, \"sigma_obs\": 178.82301330566406, \"slope\": -0.06529782712459564, \"chain\": 0, \"draw\": 119}, {\"draws\": 119, \"mouse\": 1, \"mu_intercept_per_group\": 9.033376693725586, \"sigma_intercept_per_group\": 0.278367280960083, \"sigma_obs\": 178.82301330566406, \"slope\": -0.06529782712459564, \"chain\": 0, \"draw\": 119}, {\"draws\": 119, \"mouse\": 2, \"mu_intercept_per_group\": 8.609672546386719, \"sigma_intercept_per_group\": 0.278367280960083, \"sigma_obs\": 178.82301330566406, \"slope\": -0.06529782712459564, \"chain\": 0, \"draw\": 119}, {\"draws\": 119, \"mouse\": 3, \"mu_intercept_per_group\": 8.23281192779541, \"sigma_intercept_per_group\": 0.278367280960083, \"sigma_obs\": 178.82301330566406, \"slope\": -0.06529782712459564, \"chain\": 0, \"draw\": 119}, {\"draws\": 119, \"mouse\": 4, \"mu_intercept_per_group\": 7.951777935028076, \"sigma_intercept_per_group\": 0.278367280960083, \"sigma_obs\": 178.82301330566406, \"slope\": -0.06529782712459564, \"chain\": 0, \"draw\": 119}, {\"draws\": 119, \"mouse\": 5, \"mu_intercept_per_group\": 7.472460746765137, \"sigma_intercept_per_group\": 0.278367280960083, \"sigma_obs\": 178.82301330566406, \"slope\": -0.06529782712459564, \"chain\": 0, \"draw\": 119}, {\"draws\": 119, \"mouse\": 6, \"mu_intercept_per_group\": 7.054827690124512, \"sigma_intercept_per_group\": 0.278367280960083, \"sigma_obs\": 178.82301330566406, \"slope\": -0.06529782712459564, \"chain\": 0, \"draw\": 119}, {\"draws\": 119, \"mouse\": 7, \"mu_intercept_per_group\": 7.171665668487549, \"sigma_intercept_per_group\": 0.278367280960083, \"sigma_obs\": 178.82301330566406, \"slope\": -0.06529782712459564, \"chain\": 0, \"draw\": 119}, {\"draws\": 120, \"mouse\": 0, \"mu_intercept_per_group\": 11.918063163757324, \"sigma_intercept_per_group\": 0.19608236849308014, \"sigma_obs\": 150.50582885742188, \"slope\": -0.051058538258075714, \"chain\": 0, \"draw\": 120}, {\"draws\": 120, \"mouse\": 1, \"mu_intercept_per_group\": 11.75811767578125, \"sigma_intercept_per_group\": 0.19608236849308014, \"sigma_obs\": 150.50582885742188, \"slope\": -0.051058538258075714, \"chain\": 0, \"draw\": 120}, {\"draws\": 120, \"mouse\": 2, \"mu_intercept_per_group\": 11.449556350708008, \"sigma_intercept_per_group\": 0.19608236849308014, \"sigma_obs\": 150.50582885742188, \"slope\": -0.051058538258075714, \"chain\": 0, \"draw\": 120}, {\"draws\": 120, \"mouse\": 3, \"mu_intercept_per_group\": 10.735610008239746, \"sigma_intercept_per_group\": 0.19608236849308014, \"sigma_obs\": 150.50582885742188, \"slope\": -0.051058538258075714, \"chain\": 0, \"draw\": 120}, {\"draws\": 120, \"mouse\": 4, \"mu_intercept_per_group\": 10.462844848632812, \"sigma_intercept_per_group\": 0.19608236849308014, \"sigma_obs\": 150.50582885742188, \"slope\": -0.051058538258075714, \"chain\": 0, \"draw\": 120}, {\"draws\": 120, \"mouse\": 5, \"mu_intercept_per_group\": 9.986202239990234, \"sigma_intercept_per_group\": 0.19608236849308014, \"sigma_obs\": 150.50582885742188, \"slope\": -0.051058538258075714, \"chain\": 0, \"draw\": 120}, {\"draws\": 120, \"mouse\": 6, \"mu_intercept_per_group\": 9.24874210357666, \"sigma_intercept_per_group\": 0.19608236849308014, \"sigma_obs\": 150.50582885742188, \"slope\": -0.051058538258075714, \"chain\": 0, \"draw\": 120}, {\"draws\": 120, \"mouse\": 7, \"mu_intercept_per_group\": 8.653514862060547, \"sigma_intercept_per_group\": 0.19608236849308014, \"sigma_obs\": 150.50582885742188, \"slope\": -0.051058538258075714, \"chain\": 0, \"draw\": 120}, {\"draws\": 121, \"mouse\": 0, \"mu_intercept_per_group\": 12.870468139648438, \"sigma_intercept_per_group\": 0.19251707196235657, \"sigma_obs\": 157.96908569335938, \"slope\": -0.04754164442420006, \"chain\": 0, \"draw\": 121}, {\"draws\": 121, \"mouse\": 1, \"mu_intercept_per_group\": 12.072922706604004, \"sigma_intercept_per_group\": 0.19251707196235657, \"sigma_obs\": 157.96908569335938, \"slope\": -0.04754164442420006, \"chain\": 0, \"draw\": 121}, {\"draws\": 121, \"mouse\": 2, \"mu_intercept_per_group\": 11.59459400177002, \"sigma_intercept_per_group\": 0.19251707196235657, \"sigma_obs\": 157.96908569335938, \"slope\": -0.04754164442420006, \"chain\": 0, \"draw\": 121}, {\"draws\": 121, \"mouse\": 3, \"mu_intercept_per_group\": 10.99384880065918, \"sigma_intercept_per_group\": 0.19251707196235657, \"sigma_obs\": 157.96908569335938, \"slope\": -0.04754164442420006, \"chain\": 0, \"draw\": 121}, {\"draws\": 121, \"mouse\": 4, \"mu_intercept_per_group\": 10.77109432220459, \"sigma_intercept_per_group\": 0.19251707196235657, \"sigma_obs\": 157.96908569335938, \"slope\": -0.04754164442420006, \"chain\": 0, \"draw\": 121}, {\"draws\": 121, \"mouse\": 5, \"mu_intercept_per_group\": 10.504254341125488, \"sigma_intercept_per_group\": 0.19251707196235657, \"sigma_obs\": 157.96908569335938, \"slope\": -0.04754164442420006, \"chain\": 0, \"draw\": 121}, {\"draws\": 121, \"mouse\": 6, \"mu_intercept_per_group\": 9.580557823181152, \"sigma_intercept_per_group\": 0.19251707196235657, \"sigma_obs\": 157.96908569335938, \"slope\": -0.04754164442420006, \"chain\": 0, \"draw\": 121}, {\"draws\": 121, \"mouse\": 7, \"mu_intercept_per_group\": 9.151267051696777, \"sigma_intercept_per_group\": 0.19251707196235657, \"sigma_obs\": 157.96908569335938, \"slope\": -0.04754164442420006, \"chain\": 0, \"draw\": 121}, {\"draws\": 122, \"mouse\": 0, \"mu_intercept_per_group\": 13.258306503295898, \"sigma_intercept_per_group\": 0.1903223991394043, \"sigma_obs\": 152.5171356201172, \"slope\": -0.07231267541646957, \"chain\": 0, \"draw\": 122}, {\"draws\": 122, \"mouse\": 1, \"mu_intercept_per_group\": 12.3153076171875, \"sigma_intercept_per_group\": 0.1903223991394043, \"sigma_obs\": 152.5171356201172, \"slope\": -0.07231267541646957, \"chain\": 0, \"draw\": 122}, {\"draws\": 122, \"mouse\": 2, \"mu_intercept_per_group\": 12.052894592285156, \"sigma_intercept_per_group\": 0.1903223991394043, \"sigma_obs\": 152.5171356201172, \"slope\": -0.07231267541646957, \"chain\": 0, \"draw\": 122}, {\"draws\": 122, \"mouse\": 3, \"mu_intercept_per_group\": 11.265806198120117, \"sigma_intercept_per_group\": 0.1903223991394043, \"sigma_obs\": 152.5171356201172, \"slope\": -0.07231267541646957, \"chain\": 0, \"draw\": 122}, {\"draws\": 122, \"mouse\": 4, \"mu_intercept_per_group\": 11.064386367797852, \"sigma_intercept_per_group\": 0.1903223991394043, \"sigma_obs\": 152.5171356201172, \"slope\": -0.07231267541646957, \"chain\": 0, \"draw\": 122}, {\"draws\": 122, \"mouse\": 5, \"mu_intercept_per_group\": 10.125423431396484, \"sigma_intercept_per_group\": 0.1903223991394043, \"sigma_obs\": 152.5171356201172, \"slope\": -0.07231267541646957, \"chain\": 0, \"draw\": 122}, {\"draws\": 122, \"mouse\": 6, \"mu_intercept_per_group\": 9.384833335876465, \"sigma_intercept_per_group\": 0.1903223991394043, \"sigma_obs\": 152.5171356201172, \"slope\": -0.07231267541646957, \"chain\": 0, \"draw\": 122}, {\"draws\": 122, \"mouse\": 7, \"mu_intercept_per_group\": 9.254203796386719, \"sigma_intercept_per_group\": 0.1903223991394043, \"sigma_obs\": 152.5171356201172, \"slope\": -0.07231267541646957, \"chain\": 0, \"draw\": 122}, {\"draws\": 123, \"mouse\": 0, \"mu_intercept_per_group\": 12.641355514526367, \"sigma_intercept_per_group\": 0.2038101851940155, \"sigma_obs\": 169.1246795654297, \"slope\": -0.0708099901676178, \"chain\": 0, \"draw\": 123}, {\"draws\": 123, \"mouse\": 1, \"mu_intercept_per_group\": 11.893732070922852, \"sigma_intercept_per_group\": 0.2038101851940155, \"sigma_obs\": 169.1246795654297, \"slope\": -0.0708099901676178, \"chain\": 0, \"draw\": 123}, {\"draws\": 123, \"mouse\": 2, \"mu_intercept_per_group\": 11.650727272033691, \"sigma_intercept_per_group\": 0.2038101851940155, \"sigma_obs\": 169.1246795654297, \"slope\": -0.0708099901676178, \"chain\": 0, \"draw\": 123}, {\"draws\": 123, \"mouse\": 3, \"mu_intercept_per_group\": 11.388423919677734, \"sigma_intercept_per_group\": 0.2038101851940155, \"sigma_obs\": 169.1246795654297, \"slope\": -0.0708099901676178, \"chain\": 0, \"draw\": 123}, {\"draws\": 123, \"mouse\": 4, \"mu_intercept_per_group\": 10.454917907714844, \"sigma_intercept_per_group\": 0.2038101851940155, \"sigma_obs\": 169.1246795654297, \"slope\": -0.0708099901676178, \"chain\": 0, \"draw\": 123}, {\"draws\": 123, \"mouse\": 5, \"mu_intercept_per_group\": 10.319425582885742, \"sigma_intercept_per_group\": 0.2038101851940155, \"sigma_obs\": 169.1246795654297, \"slope\": -0.0708099901676178, \"chain\": 0, \"draw\": 123}, {\"draws\": 123, \"mouse\": 6, \"mu_intercept_per_group\": 9.263901710510254, \"sigma_intercept_per_group\": 0.2038101851940155, \"sigma_obs\": 169.1246795654297, \"slope\": -0.0708099901676178, \"chain\": 0, \"draw\": 123}, {\"draws\": 123, \"mouse\": 7, \"mu_intercept_per_group\": 9.157331466674805, \"sigma_intercept_per_group\": 0.2038101851940155, \"sigma_obs\": 169.1246795654297, \"slope\": -0.0708099901676178, \"chain\": 0, \"draw\": 123}, {\"draws\": 124, \"mouse\": 0, \"mu_intercept_per_group\": 11.83597469329834, \"sigma_intercept_per_group\": 0.2055572271347046, \"sigma_obs\": 155.93807983398438, \"slope\": -0.0621790736913681, \"chain\": 0, \"draw\": 124}, {\"draws\": 124, \"mouse\": 1, \"mu_intercept_per_group\": 11.145489692687988, \"sigma_intercept_per_group\": 0.2055572271347046, \"sigma_obs\": 155.93807983398438, \"slope\": -0.0621790736913681, \"chain\": 0, \"draw\": 124}, {\"draws\": 124, \"mouse\": 2, \"mu_intercept_per_group\": 10.977812767028809, \"sigma_intercept_per_group\": 0.2055572271347046, \"sigma_obs\": 155.93807983398438, \"slope\": -0.0621790736913681, \"chain\": 0, \"draw\": 124}, {\"draws\": 124, \"mouse\": 3, \"mu_intercept_per_group\": 10.093681335449219, \"sigma_intercept_per_group\": 0.2055572271347046, \"sigma_obs\": 155.93807983398438, \"slope\": -0.0621790736913681, \"chain\": 0, \"draw\": 124}, {\"draws\": 124, \"mouse\": 4, \"mu_intercept_per_group\": 10.30210018157959, \"sigma_intercept_per_group\": 0.2055572271347046, \"sigma_obs\": 155.93807983398438, \"slope\": -0.0621790736913681, \"chain\": 0, \"draw\": 124}, {\"draws\": 124, \"mouse\": 5, \"mu_intercept_per_group\": 9.403181076049805, \"sigma_intercept_per_group\": 0.2055572271347046, \"sigma_obs\": 155.93807983398438, \"slope\": -0.0621790736913681, \"chain\": 0, \"draw\": 124}, {\"draws\": 124, \"mouse\": 6, \"mu_intercept_per_group\": 8.843820571899414, \"sigma_intercept_per_group\": 0.2055572271347046, \"sigma_obs\": 155.93807983398438, \"slope\": -0.0621790736913681, \"chain\": 0, \"draw\": 124}, {\"draws\": 124, \"mouse\": 7, \"mu_intercept_per_group\": 8.51993465423584, \"sigma_intercept_per_group\": 0.2055572271347046, \"sigma_obs\": 155.93807983398438, \"slope\": -0.0621790736913681, \"chain\": 0, \"draw\": 124}, {\"draws\": 125, \"mouse\": 0, \"mu_intercept_per_group\": 11.697173118591309, \"sigma_intercept_per_group\": 0.2060561627149582, \"sigma_obs\": 154.77938842773438, \"slope\": -0.06362639367580414, \"chain\": 0, \"draw\": 125}, {\"draws\": 125, \"mouse\": 1, \"mu_intercept_per_group\": 11.654281616210938, \"sigma_intercept_per_group\": 0.2060561627149582, \"sigma_obs\": 154.77938842773438, \"slope\": -0.06362639367580414, \"chain\": 0, \"draw\": 125}, {\"draws\": 125, \"mouse\": 2, \"mu_intercept_per_group\": 11.089667320251465, \"sigma_intercept_per_group\": 0.2060561627149582, \"sigma_obs\": 154.77938842773438, \"slope\": -0.06362639367580414, \"chain\": 0, \"draw\": 125}, {\"draws\": 125, \"mouse\": 3, \"mu_intercept_per_group\": 10.700891494750977, \"sigma_intercept_per_group\": 0.2060561627149582, \"sigma_obs\": 154.77938842773438, \"slope\": -0.06362639367580414, \"chain\": 0, \"draw\": 125}, {\"draws\": 125, \"mouse\": 4, \"mu_intercept_per_group\": 9.830099105834961, \"sigma_intercept_per_group\": 0.2060561627149582, \"sigma_obs\": 154.77938842773438, \"slope\": -0.06362639367580414, \"chain\": 0, \"draw\": 125}, {\"draws\": 125, \"mouse\": 5, \"mu_intercept_per_group\": 9.651820182800293, \"sigma_intercept_per_group\": 0.2060561627149582, \"sigma_obs\": 154.77938842773438, \"slope\": -0.06362639367580414, \"chain\": 0, \"draw\": 125}, {\"draws\": 125, \"mouse\": 6, \"mu_intercept_per_group\": 9.351930618286133, \"sigma_intercept_per_group\": 0.2060561627149582, \"sigma_obs\": 154.77938842773438, \"slope\": -0.06362639367580414, \"chain\": 0, \"draw\": 125}, {\"draws\": 125, \"mouse\": 7, \"mu_intercept_per_group\": 8.536650657653809, \"sigma_intercept_per_group\": 0.2060561627149582, \"sigma_obs\": 154.77938842773438, \"slope\": -0.06362639367580414, \"chain\": 0, \"draw\": 125}, {\"draws\": 126, \"mouse\": 0, \"mu_intercept_per_group\": 12.0147066116333, \"sigma_intercept_per_group\": 0.20441944897174835, \"sigma_obs\": 151.37384033203125, \"slope\": -0.06751809269189835, \"chain\": 0, \"draw\": 126}, {\"draws\": 126, \"mouse\": 1, \"mu_intercept_per_group\": 11.292555809020996, \"sigma_intercept_per_group\": 0.20441944897174835, \"sigma_obs\": 151.37384033203125, \"slope\": -0.06751809269189835, \"chain\": 0, \"draw\": 126}, {\"draws\": 126, \"mouse\": 2, \"mu_intercept_per_group\": 11.157466888427734, \"sigma_intercept_per_group\": 0.20441944897174835, \"sigma_obs\": 151.37384033203125, \"slope\": -0.06751809269189835, \"chain\": 0, \"draw\": 126}, {\"draws\": 126, \"mouse\": 3, \"mu_intercept_per_group\": 10.101211547851562, \"sigma_intercept_per_group\": 0.20441944897174835, \"sigma_obs\": 151.37384033203125, \"slope\": -0.06751809269189835, \"chain\": 0, \"draw\": 126}, {\"draws\": 126, \"mouse\": 4, \"mu_intercept_per_group\": 10.40632438659668, \"sigma_intercept_per_group\": 0.20441944897174835, \"sigma_obs\": 151.37384033203125, \"slope\": -0.06751809269189835, \"chain\": 0, \"draw\": 126}, {\"draws\": 126, \"mouse\": 5, \"mu_intercept_per_group\": 9.547274589538574, \"sigma_intercept_per_group\": 0.20441944897174835, \"sigma_obs\": 151.37384033203125, \"slope\": -0.06751809269189835, \"chain\": 0, \"draw\": 126}, {\"draws\": 126, \"mouse\": 6, \"mu_intercept_per_group\": 8.592730522155762, \"sigma_intercept_per_group\": 0.20441944897174835, \"sigma_obs\": 151.37384033203125, \"slope\": -0.06751809269189835, \"chain\": 0, \"draw\": 126}, {\"draws\": 126, \"mouse\": 7, \"mu_intercept_per_group\": 8.670496940612793, \"sigma_intercept_per_group\": 0.20441944897174835, \"sigma_obs\": 151.37384033203125, \"slope\": -0.06751809269189835, \"chain\": 0, \"draw\": 126}, {\"draws\": 127, \"mouse\": 0, \"mu_intercept_per_group\": 12.594693183898926, \"sigma_intercept_per_group\": 0.19315645098686218, \"sigma_obs\": 145.0337371826172, \"slope\": -0.06984712183475494, \"chain\": 0, \"draw\": 127}, {\"draws\": 127, \"mouse\": 1, \"mu_intercept_per_group\": 11.680908203125, \"sigma_intercept_per_group\": 0.19315645098686218, \"sigma_obs\": 145.0337371826172, \"slope\": -0.06984712183475494, \"chain\": 0, \"draw\": 127}, {\"draws\": 127, \"mouse\": 2, \"mu_intercept_per_group\": 11.621062278747559, \"sigma_intercept_per_group\": 0.19315645098686218, \"sigma_obs\": 145.0337371826172, \"slope\": -0.06984712183475494, \"chain\": 0, \"draw\": 127}, {\"draws\": 127, \"mouse\": 3, \"mu_intercept_per_group\": 10.66779899597168, \"sigma_intercept_per_group\": 0.19315645098686218, \"sigma_obs\": 145.0337371826172, \"slope\": -0.06984712183475494, \"chain\": 0, \"draw\": 127}, {\"draws\": 127, \"mouse\": 4, \"mu_intercept_per_group\": 10.427151679992676, \"sigma_intercept_per_group\": 0.19315645098686218, \"sigma_obs\": 145.0337371826172, \"slope\": -0.06984712183475494, \"chain\": 0, \"draw\": 127}, {\"draws\": 127, \"mouse\": 5, \"mu_intercept_per_group\": 9.89911937713623, \"sigma_intercept_per_group\": 0.19315645098686218, \"sigma_obs\": 145.0337371826172, \"slope\": -0.06984712183475494, \"chain\": 0, \"draw\": 127}, {\"draws\": 127, \"mouse\": 6, \"mu_intercept_per_group\": 9.496810913085938, \"sigma_intercept_per_group\": 0.19315645098686218, \"sigma_obs\": 145.0337371826172, \"slope\": -0.06984712183475494, \"chain\": 0, \"draw\": 127}, {\"draws\": 127, \"mouse\": 7, \"mu_intercept_per_group\": 8.572182655334473, \"sigma_intercept_per_group\": 0.19315645098686218, \"sigma_obs\": 145.0337371826172, \"slope\": -0.06984712183475494, \"chain\": 0, \"draw\": 127}, {\"draws\": 128, \"mouse\": 0, \"mu_intercept_per_group\": 12.13380241394043, \"sigma_intercept_per_group\": 0.19235563278198242, \"sigma_obs\": 144.1612548828125, \"slope\": -0.07053137570619583, \"chain\": 0, \"draw\": 128}, {\"draws\": 128, \"mouse\": 1, \"mu_intercept_per_group\": 12.052610397338867, \"sigma_intercept_per_group\": 0.19235563278198242, \"sigma_obs\": 144.1612548828125, \"slope\": -0.07053137570619583, \"chain\": 0, \"draw\": 128}, {\"draws\": 128, \"mouse\": 2, \"mu_intercept_per_group\": 11.7264404296875, \"sigma_intercept_per_group\": 0.19235563278198242, \"sigma_obs\": 144.1612548828125, \"slope\": -0.07053137570619583, \"chain\": 0, \"draw\": 128}, {\"draws\": 128, \"mouse\": 3, \"mu_intercept_per_group\": 11.20209789276123, \"sigma_intercept_per_group\": 0.19235563278198242, \"sigma_obs\": 144.1612548828125, \"slope\": -0.07053137570619583, \"chain\": 0, \"draw\": 128}, {\"draws\": 128, \"mouse\": 4, \"mu_intercept_per_group\": 10.464133262634277, \"sigma_intercept_per_group\": 0.19235563278198242, \"sigma_obs\": 144.1612548828125, \"slope\": -0.07053137570619583, \"chain\": 0, \"draw\": 128}, {\"draws\": 128, \"mouse\": 5, \"mu_intercept_per_group\": 9.781477928161621, \"sigma_intercept_per_group\": 0.19235563278198242, \"sigma_obs\": 144.1612548828125, \"slope\": -0.07053137570619583, \"chain\": 0, \"draw\": 128}, {\"draws\": 128, \"mouse\": 6, \"mu_intercept_per_group\": 9.567992210388184, \"sigma_intercept_per_group\": 0.19235563278198242, \"sigma_obs\": 144.1612548828125, \"slope\": -0.07053137570619583, \"chain\": 0, \"draw\": 128}, {\"draws\": 128, \"mouse\": 7, \"mu_intercept_per_group\": 8.733546257019043, \"sigma_intercept_per_group\": 0.19235563278198242, \"sigma_obs\": 144.1612548828125, \"slope\": -0.07053137570619583, \"chain\": 0, \"draw\": 128}, {\"draws\": 129, \"mouse\": 0, \"mu_intercept_per_group\": 12.573515892028809, \"sigma_intercept_per_group\": 0.19161444902420044, \"sigma_obs\": 144.03262329101562, \"slope\": -0.0687822550535202, \"chain\": 0, \"draw\": 129}, {\"draws\": 129, \"mouse\": 1, \"mu_intercept_per_group\": 11.360381126403809, \"sigma_intercept_per_group\": 0.19161444902420044, \"sigma_obs\": 144.03262329101562, \"slope\": -0.0687822550535202, \"chain\": 0, \"draw\": 129}, {\"draws\": 129, \"mouse\": 2, \"mu_intercept_per_group\": 11.241724967956543, \"sigma_intercept_per_group\": 0.19161444902420044, \"sigma_obs\": 144.03262329101562, \"slope\": -0.0687822550535202, \"chain\": 0, \"draw\": 129}, {\"draws\": 129, \"mouse\": 3, \"mu_intercept_per_group\": 10.350977897644043, \"sigma_intercept_per_group\": 0.19161444902420044, \"sigma_obs\": 144.03262329101562, \"slope\": -0.0687822550535202, \"chain\": 0, \"draw\": 129}, {\"draws\": 129, \"mouse\": 4, \"mu_intercept_per_group\": 10.84930419921875, \"sigma_intercept_per_group\": 0.19161444902420044, \"sigma_obs\": 144.03262329101562, \"slope\": -0.0687822550535202, \"chain\": 0, \"draw\": 129}, {\"draws\": 129, \"mouse\": 5, \"mu_intercept_per_group\": 10.17911148071289, \"sigma_intercept_per_group\": 0.19161444902420044, \"sigma_obs\": 144.03262329101562, \"slope\": -0.0687822550535202, \"chain\": 0, \"draw\": 129}, {\"draws\": 129, \"mouse\": 6, \"mu_intercept_per_group\": 9.539262771606445, \"sigma_intercept_per_group\": 0.19161444902420044, \"sigma_obs\": 144.03262329101562, \"slope\": -0.0687822550535202, \"chain\": 0, \"draw\": 129}, {\"draws\": 129, \"mouse\": 7, \"mu_intercept_per_group\": 8.435267448425293, \"sigma_intercept_per_group\": 0.19161444902420044, \"sigma_obs\": 144.03262329101562, \"slope\": -0.0687822550535202, \"chain\": 0, \"draw\": 129}, {\"draws\": 130, \"mouse\": 0, \"mu_intercept_per_group\": 11.8933687210083, \"sigma_intercept_per_group\": 0.19202548265457153, \"sigma_obs\": 145.2775115966797, \"slope\": -0.07052041590213776, \"chain\": 0, \"draw\": 130}, {\"draws\": 130, \"mouse\": 1, \"mu_intercept_per_group\": 12.1476469039917, \"sigma_intercept_per_group\": 0.19202548265457153, \"sigma_obs\": 145.2775115966797, \"slope\": -0.07052041590213776, \"chain\": 0, \"draw\": 130}, {\"draws\": 130, \"mouse\": 2, \"mu_intercept_per_group\": 11.768684387207031, \"sigma_intercept_per_group\": 0.19202548265457153, \"sigma_obs\": 145.2775115966797, \"slope\": -0.07052041590213776, \"chain\": 0, \"draw\": 130}, {\"draws\": 130, \"mouse\": 3, \"mu_intercept_per_group\": 10.640853881835938, \"sigma_intercept_per_group\": 0.19202548265457153, \"sigma_obs\": 145.2775115966797, \"slope\": -0.07052041590213776, \"chain\": 0, \"draw\": 130}, {\"draws\": 130, \"mouse\": 4, \"mu_intercept_per_group\": 10.343358039855957, \"sigma_intercept_per_group\": 0.19202548265457153, \"sigma_obs\": 145.2775115966797, \"slope\": -0.07052041590213776, \"chain\": 0, \"draw\": 130}, {\"draws\": 130, \"mouse\": 5, \"mu_intercept_per_group\": 10.181940078735352, \"sigma_intercept_per_group\": 0.19202548265457153, \"sigma_obs\": 145.2775115966797, \"slope\": -0.07052041590213776, \"chain\": 0, \"draw\": 130}, {\"draws\": 130, \"mouse\": 6, \"mu_intercept_per_group\": 9.124899864196777, \"sigma_intercept_per_group\": 0.19202548265457153, \"sigma_obs\": 145.2775115966797, \"slope\": -0.07052041590213776, \"chain\": 0, \"draw\": 130}, {\"draws\": 130, \"mouse\": 7, \"mu_intercept_per_group\": 8.95760440826416, \"sigma_intercept_per_group\": 0.19202548265457153, \"sigma_obs\": 145.2775115966797, \"slope\": -0.07052041590213776, \"chain\": 0, \"draw\": 130}, {\"draws\": 131, \"mouse\": 0, \"mu_intercept_per_group\": 12.451099395751953, \"sigma_intercept_per_group\": 0.1940954029560089, \"sigma_obs\": 146.48446655273438, \"slope\": -0.07289060950279236, \"chain\": 0, \"draw\": 131}, {\"draws\": 131, \"mouse\": 1, \"mu_intercept_per_group\": 11.710000038146973, \"sigma_intercept_per_group\": 0.1940954029560089, \"sigma_obs\": 146.48446655273438, \"slope\": -0.07289060950279236, \"chain\": 0, \"draw\": 131}, {\"draws\": 131, \"mouse\": 2, \"mu_intercept_per_group\": 11.265276908874512, \"sigma_intercept_per_group\": 0.1940954029560089, \"sigma_obs\": 146.48446655273438, \"slope\": -0.07289060950279236, \"chain\": 0, \"draw\": 131}, {\"draws\": 131, \"mouse\": 3, \"mu_intercept_per_group\": 10.79900074005127, \"sigma_intercept_per_group\": 0.1940954029560089, \"sigma_obs\": 146.48446655273438, \"slope\": -0.07289060950279236, \"chain\": 0, \"draw\": 131}, {\"draws\": 131, \"mouse\": 4, \"mu_intercept_per_group\": 10.436509132385254, \"sigma_intercept_per_group\": 0.1940954029560089, \"sigma_obs\": 146.48446655273438, \"slope\": -0.07289060950279236, \"chain\": 0, \"draw\": 131}, {\"draws\": 131, \"mouse\": 5, \"mu_intercept_per_group\": 9.821388244628906, \"sigma_intercept_per_group\": 0.1940954029560089, \"sigma_obs\": 146.48446655273438, \"slope\": -0.07289060950279236, \"chain\": 0, \"draw\": 131}, {\"draws\": 131, \"mouse\": 6, \"mu_intercept_per_group\": 9.000207901000977, \"sigma_intercept_per_group\": 0.1940954029560089, \"sigma_obs\": 146.48446655273438, \"slope\": -0.07289060950279236, \"chain\": 0, \"draw\": 131}, {\"draws\": 131, \"mouse\": 7, \"mu_intercept_per_group\": 8.842596054077148, \"sigma_intercept_per_group\": 0.1940954029560089, \"sigma_obs\": 146.48446655273438, \"slope\": -0.07289060950279236, \"chain\": 0, \"draw\": 131}, {\"draws\": 132, \"mouse\": 0, \"mu_intercept_per_group\": 14.291290283203125, \"sigma_intercept_per_group\": 0.1746538281440735, \"sigma_obs\": 160.90956115722656, \"slope\": -0.07250581681728363, \"chain\": 0, \"draw\": 132}, {\"draws\": 132, \"mouse\": 1, \"mu_intercept_per_group\": 13.521441459655762, \"sigma_intercept_per_group\": 0.1746538281440735, \"sigma_obs\": 160.90956115722656, \"slope\": -0.07250581681728363, \"chain\": 0, \"draw\": 132}, {\"draws\": 132, \"mouse\": 2, \"mu_intercept_per_group\": 13.343746185302734, \"sigma_intercept_per_group\": 0.1746538281440735, \"sigma_obs\": 160.90956115722656, \"slope\": -0.07250581681728363, \"chain\": 0, \"draw\": 132}, {\"draws\": 132, \"mouse\": 3, \"mu_intercept_per_group\": 12.497323036193848, \"sigma_intercept_per_group\": 0.1746538281440735, \"sigma_obs\": 160.90956115722656, \"slope\": -0.07250581681728363, \"chain\": 0, \"draw\": 132}, {\"draws\": 132, \"mouse\": 4, \"mu_intercept_per_group\": 12.166444778442383, \"sigma_intercept_per_group\": 0.1746538281440735, \"sigma_obs\": 160.90956115722656, \"slope\": -0.07250581681728363, \"chain\": 0, \"draw\": 132}, {\"draws\": 132, \"mouse\": 5, \"mu_intercept_per_group\": 11.290264129638672, \"sigma_intercept_per_group\": 0.1746538281440735, \"sigma_obs\": 160.90956115722656, \"slope\": -0.07250581681728363, \"chain\": 0, \"draw\": 132}, {\"draws\": 132, \"mouse\": 6, \"mu_intercept_per_group\": 10.751971244812012, \"sigma_intercept_per_group\": 0.1746538281440735, \"sigma_obs\": 160.90956115722656, \"slope\": -0.07250581681728363, \"chain\": 0, \"draw\": 132}, {\"draws\": 132, \"mouse\": 7, \"mu_intercept_per_group\": 10.399792671203613, \"sigma_intercept_per_group\": 0.1746538281440735, \"sigma_obs\": 160.90956115722656, \"slope\": -0.07250581681728363, \"chain\": 0, \"draw\": 132}, {\"draws\": 133, \"mouse\": 0, \"mu_intercept_per_group\": 13.441335678100586, \"sigma_intercept_per_group\": 0.18535825610160828, \"sigma_obs\": 163.6750030517578, \"slope\": -0.07472415268421173, \"chain\": 0, \"draw\": 133}, {\"draws\": 133, \"mouse\": 1, \"mu_intercept_per_group\": 13.249741554260254, \"sigma_intercept_per_group\": 0.18535825610160828, \"sigma_obs\": 163.6750030517578, \"slope\": -0.07472415268421173, \"chain\": 0, \"draw\": 133}, {\"draws\": 133, \"mouse\": 2, \"mu_intercept_per_group\": 12.338512420654297, \"sigma_intercept_per_group\": 0.18535825610160828, \"sigma_obs\": 163.6750030517578, \"slope\": -0.07472415268421173, \"chain\": 0, \"draw\": 133}, {\"draws\": 133, \"mouse\": 3, \"mu_intercept_per_group\": 12.099169731140137, \"sigma_intercept_per_group\": 0.18535825610160828, \"sigma_obs\": 163.6750030517578, \"slope\": -0.07472415268421173, \"chain\": 0, \"draw\": 133}, {\"draws\": 133, \"mouse\": 4, \"mu_intercept_per_group\": 11.69543743133545, \"sigma_intercept_per_group\": 0.18535825610160828, \"sigma_obs\": 163.6750030517578, \"slope\": -0.07472415268421173, \"chain\": 0, \"draw\": 133}, {\"draws\": 133, \"mouse\": 5, \"mu_intercept_per_group\": 11.219503402709961, \"sigma_intercept_per_group\": 0.18535825610160828, \"sigma_obs\": 163.6750030517578, \"slope\": -0.07472415268421173, \"chain\": 0, \"draw\": 133}, {\"draws\": 133, \"mouse\": 6, \"mu_intercept_per_group\": 10.389815330505371, \"sigma_intercept_per_group\": 0.18535825610160828, \"sigma_obs\": 163.6750030517578, \"slope\": -0.07472415268421173, \"chain\": 0, \"draw\": 133}, {\"draws\": 133, \"mouse\": 7, \"mu_intercept_per_group\": 9.67620849609375, \"sigma_intercept_per_group\": 0.18535825610160828, \"sigma_obs\": 163.6750030517578, \"slope\": -0.07472415268421173, \"chain\": 0, \"draw\": 133}, {\"draws\": 134, \"mouse\": 0, \"mu_intercept_per_group\": 13.299036979675293, \"sigma_intercept_per_group\": 0.1861807256937027, \"sigma_obs\": 163.82998657226562, \"slope\": -0.07380729168653488, \"chain\": 0, \"draw\": 134}, {\"draws\": 134, \"mouse\": 1, \"mu_intercept_per_group\": 13.045611381530762, \"sigma_intercept_per_group\": 0.1861807256937027, \"sigma_obs\": 163.82998657226562, \"slope\": -0.07380729168653488, \"chain\": 0, \"draw\": 134}, {\"draws\": 134, \"mouse\": 2, \"mu_intercept_per_group\": 12.718839645385742, \"sigma_intercept_per_group\": 0.1861807256937027, \"sigma_obs\": 163.82998657226562, \"slope\": -0.07380729168653488, \"chain\": 0, \"draw\": 134}, {\"draws\": 134, \"mouse\": 3, \"mu_intercept_per_group\": 11.841585159301758, \"sigma_intercept_per_group\": 0.1861807256937027, \"sigma_obs\": 163.82998657226562, \"slope\": -0.07380729168653488, \"chain\": 0, \"draw\": 134}, {\"draws\": 134, \"mouse\": 4, \"mu_intercept_per_group\": 11.763323783874512, \"sigma_intercept_per_group\": 0.1861807256937027, \"sigma_obs\": 163.82998657226562, \"slope\": -0.07380729168653488, \"chain\": 0, \"draw\": 134}, {\"draws\": 134, \"mouse\": 5, \"mu_intercept_per_group\": 11.06330394744873, \"sigma_intercept_per_group\": 0.1861807256937027, \"sigma_obs\": 163.82998657226562, \"slope\": -0.07380729168653488, \"chain\": 0, \"draw\": 134}, {\"draws\": 134, \"mouse\": 6, \"mu_intercept_per_group\": 10.201749801635742, \"sigma_intercept_per_group\": 0.1861807256937027, \"sigma_obs\": 163.82998657226562, \"slope\": -0.07380729168653488, \"chain\": 0, \"draw\": 134}, {\"draws\": 134, \"mouse\": 7, \"mu_intercept_per_group\": 9.632550239562988, \"sigma_intercept_per_group\": 0.1861807256937027, \"sigma_obs\": 163.82998657226562, \"slope\": -0.07380729168653488, \"chain\": 0, \"draw\": 134}, {\"draws\": 135, \"mouse\": 0, \"mu_intercept_per_group\": 13.810992240905762, \"sigma_intercept_per_group\": 0.1834157258272171, \"sigma_obs\": 164.04074096679688, \"slope\": -0.07453044503927231, \"chain\": 0, \"draw\": 135}, {\"draws\": 135, \"mouse\": 1, \"mu_intercept_per_group\": 12.753889083862305, \"sigma_intercept_per_group\": 0.1834157258272171, \"sigma_obs\": 164.04074096679688, \"slope\": -0.07453044503927231, \"chain\": 0, \"draw\": 135}, {\"draws\": 135, \"mouse\": 2, \"mu_intercept_per_group\": 12.947464942932129, \"sigma_intercept_per_group\": 0.1834157258272171, \"sigma_obs\": 164.04074096679688, \"slope\": -0.07453044503927231, \"chain\": 0, \"draw\": 135}, {\"draws\": 135, \"mouse\": 3, \"mu_intercept_per_group\": 12.14404582977295, \"sigma_intercept_per_group\": 0.1834157258272171, \"sigma_obs\": 164.04074096679688, \"slope\": -0.07453044503927231, \"chain\": 0, \"draw\": 135}, {\"draws\": 135, \"mouse\": 4, \"mu_intercept_per_group\": 11.62448787689209, \"sigma_intercept_per_group\": 0.1834157258272171, \"sigma_obs\": 164.04074096679688, \"slope\": -0.07453044503927231, \"chain\": 0, \"draw\": 135}, {\"draws\": 135, \"mouse\": 5, \"mu_intercept_per_group\": 11.147049903869629, \"sigma_intercept_per_group\": 0.1834157258272171, \"sigma_obs\": 164.04074096679688, \"slope\": -0.07453044503927231, \"chain\": 0, \"draw\": 135}, {\"draws\": 135, \"mouse\": 6, \"mu_intercept_per_group\": 10.410737037658691, \"sigma_intercept_per_group\": 0.1834157258272171, \"sigma_obs\": 164.04074096679688, \"slope\": -0.07453044503927231, \"chain\": 0, \"draw\": 135}, {\"draws\": 135, \"mouse\": 7, \"mu_intercept_per_group\": 9.212915420532227, \"sigma_intercept_per_group\": 0.1834157258272171, \"sigma_obs\": 164.04074096679688, \"slope\": -0.07453044503927231, \"chain\": 0, \"draw\": 135}, {\"draws\": 136, \"mouse\": 0, \"mu_intercept_per_group\": 13.657554626464844, \"sigma_intercept_per_group\": 0.18326741456985474, \"sigma_obs\": 160.38514709472656, \"slope\": -0.08851780742406845, \"chain\": 0, \"draw\": 136}, {\"draws\": 136, \"mouse\": 1, \"mu_intercept_per_group\": 13.5403413772583, \"sigma_intercept_per_group\": 0.18326741456985474, \"sigma_obs\": 160.38514709472656, \"slope\": -0.08851780742406845, \"chain\": 0, \"draw\": 136}, {\"draws\": 136, \"mouse\": 2, \"mu_intercept_per_group\": 12.69253921508789, \"sigma_intercept_per_group\": 0.18326741456985474, \"sigma_obs\": 160.38514709472656, \"slope\": -0.08851780742406845, \"chain\": 0, \"draw\": 136}, {\"draws\": 136, \"mouse\": 3, \"mu_intercept_per_group\": 12.175396919250488, \"sigma_intercept_per_group\": 0.18326741456985474, \"sigma_obs\": 160.38514709472656, \"slope\": -0.08851780742406845, \"chain\": 0, \"draw\": 136}, {\"draws\": 136, \"mouse\": 4, \"mu_intercept_per_group\": 11.673381805419922, \"sigma_intercept_per_group\": 0.18326741456985474, \"sigma_obs\": 160.38514709472656, \"slope\": -0.08851780742406845, \"chain\": 0, \"draw\": 136}, {\"draws\": 136, \"mouse\": 5, \"mu_intercept_per_group\": 11.097105026245117, \"sigma_intercept_per_group\": 0.18326741456985474, \"sigma_obs\": 160.38514709472656, \"slope\": -0.08851780742406845, \"chain\": 0, \"draw\": 136}, {\"draws\": 136, \"mouse\": 6, \"mu_intercept_per_group\": 10.371919631958008, \"sigma_intercept_per_group\": 0.18326741456985474, \"sigma_obs\": 160.38514709472656, \"slope\": -0.08851780742406845, \"chain\": 0, \"draw\": 136}, {\"draws\": 136, \"mouse\": 7, \"mu_intercept_per_group\": 9.404891967773438, \"sigma_intercept_per_group\": 0.18326741456985474, \"sigma_obs\": 160.38514709472656, \"slope\": -0.08851780742406845, \"chain\": 0, \"draw\": 136}, {\"draws\": 137, \"mouse\": 0, \"mu_intercept_per_group\": 11.781492233276367, \"sigma_intercept_per_group\": 0.20772071182727814, \"sigma_obs\": 158.14808654785156, \"slope\": -0.08969800919294357, \"chain\": 0, \"draw\": 137}, {\"draws\": 137, \"mouse\": 1, \"mu_intercept_per_group\": 11.694907188415527, \"sigma_intercept_per_group\": 0.20772071182727814, \"sigma_obs\": 158.14808654785156, \"slope\": -0.08969800919294357, \"chain\": 0, \"draw\": 137}, {\"draws\": 137, \"mouse\": 2, \"mu_intercept_per_group\": 10.85633659362793, \"sigma_intercept_per_group\": 0.20772071182727814, \"sigma_obs\": 158.14808654785156, \"slope\": -0.08969800919294357, \"chain\": 0, \"draw\": 137}, {\"draws\": 137, \"mouse\": 3, \"mu_intercept_per_group\": 10.373477935791016, \"sigma_intercept_per_group\": 0.20772071182727814, \"sigma_obs\": 158.14808654785156, \"slope\": -0.08969800919294357, \"chain\": 0, \"draw\": 137}, {\"draws\": 137, \"mouse\": 4, \"mu_intercept_per_group\": 10.598870277404785, \"sigma_intercept_per_group\": 0.20772071182727814, \"sigma_obs\": 158.14808654785156, \"slope\": -0.08969800919294357, \"chain\": 0, \"draw\": 137}, {\"draws\": 137, \"mouse\": 5, \"mu_intercept_per_group\": 9.849200248718262, \"sigma_intercept_per_group\": 0.20772071182727814, \"sigma_obs\": 158.14808654785156, \"slope\": -0.08969800919294357, \"chain\": 0, \"draw\": 137}, {\"draws\": 137, \"mouse\": 6, \"mu_intercept_per_group\": 9.281116485595703, \"sigma_intercept_per_group\": 0.20772071182727814, \"sigma_obs\": 158.14808654785156, \"slope\": -0.08969800919294357, \"chain\": 0, \"draw\": 137}, {\"draws\": 137, \"mouse\": 7, \"mu_intercept_per_group\": 8.66775131225586, \"sigma_intercept_per_group\": 0.20772071182727814, \"sigma_obs\": 158.14808654785156, \"slope\": -0.08969800919294357, \"chain\": 0, \"draw\": 137}, {\"draws\": 138, \"mouse\": 0, \"mu_intercept_per_group\": 10.601251602172852, \"sigma_intercept_per_group\": 0.24075542390346527, \"sigma_obs\": 166.82943725585938, \"slope\": -0.07384990900754929, \"chain\": 0, \"draw\": 138}, {\"draws\": 138, \"mouse\": 1, \"mu_intercept_per_group\": 9.889619827270508, \"sigma_intercept_per_group\": 0.24075542390346527, \"sigma_obs\": 166.82943725585938, \"slope\": -0.07384990900754929, \"chain\": 0, \"draw\": 138}, {\"draws\": 138, \"mouse\": 2, \"mu_intercept_per_group\": 9.877388954162598, \"sigma_intercept_per_group\": 0.24075542390346527, \"sigma_obs\": 166.82943725585938, \"slope\": -0.07384990900754929, \"chain\": 0, \"draw\": 138}, {\"draws\": 138, \"mouse\": 3, \"mu_intercept_per_group\": 9.196370124816895, \"sigma_intercept_per_group\": 0.24075542390346527, \"sigma_obs\": 166.82943725585938, \"slope\": -0.07384990900754929, \"chain\": 0, \"draw\": 138}, {\"draws\": 138, \"mouse\": 4, \"mu_intercept_per_group\": 9.349370956420898, \"sigma_intercept_per_group\": 0.24075542390346527, \"sigma_obs\": 166.82943725585938, \"slope\": -0.07384990900754929, \"chain\": 0, \"draw\": 138}, {\"draws\": 138, \"mouse\": 5, \"mu_intercept_per_group\": 8.465767860412598, \"sigma_intercept_per_group\": 0.24075542390346527, \"sigma_obs\": 166.82943725585938, \"slope\": -0.07384990900754929, \"chain\": 0, \"draw\": 138}, {\"draws\": 138, \"mouse\": 6, \"mu_intercept_per_group\": 7.918816566467285, \"sigma_intercept_per_group\": 0.24075542390346527, \"sigma_obs\": 166.82943725585938, \"slope\": -0.07384990900754929, \"chain\": 0, \"draw\": 138}, {\"draws\": 138, \"mouse\": 7, \"mu_intercept_per_group\": 7.431509494781494, \"sigma_intercept_per_group\": 0.24075542390346527, \"sigma_obs\": 166.82943725585938, \"slope\": -0.07384990900754929, \"chain\": 0, \"draw\": 138}, {\"draws\": 139, \"mouse\": 0, \"mu_intercept_per_group\": 11.219581604003906, \"sigma_intercept_per_group\": 0.2188684642314911, \"sigma_obs\": 150.23294067382812, \"slope\": -0.08015690743923187, \"chain\": 0, \"draw\": 139}, {\"draws\": 139, \"mouse\": 1, \"mu_intercept_per_group\": 10.390241622924805, \"sigma_intercept_per_group\": 0.2188684642314911, \"sigma_obs\": 150.23294067382812, \"slope\": -0.08015690743923187, \"chain\": 0, \"draw\": 139}, {\"draws\": 139, \"mouse\": 2, \"mu_intercept_per_group\": 10.493548393249512, \"sigma_intercept_per_group\": 0.2188684642314911, \"sigma_obs\": 150.23294067382812, \"slope\": -0.08015690743923187, \"chain\": 0, \"draw\": 139}, {\"draws\": 139, \"mouse\": 3, \"mu_intercept_per_group\": 9.930641174316406, \"sigma_intercept_per_group\": 0.2188684642314911, \"sigma_obs\": 150.23294067382812, \"slope\": -0.08015690743923187, \"chain\": 0, \"draw\": 139}, {\"draws\": 139, \"mouse\": 4, \"mu_intercept_per_group\": 9.207184791564941, \"sigma_intercept_per_group\": 0.2188684642314911, \"sigma_obs\": 150.23294067382812, \"slope\": -0.08015690743923187, \"chain\": 0, \"draw\": 139}, {\"draws\": 139, \"mouse\": 5, \"mu_intercept_per_group\": 9.096236228942871, \"sigma_intercept_per_group\": 0.2188684642314911, \"sigma_obs\": 150.23294067382812, \"slope\": -0.08015690743923187, \"chain\": 0, \"draw\": 139}, {\"draws\": 139, \"mouse\": 6, \"mu_intercept_per_group\": 8.384930610656738, \"sigma_intercept_per_group\": 0.2188684642314911, \"sigma_obs\": 150.23294067382812, \"slope\": -0.08015690743923187, \"chain\": 0, \"draw\": 139}, {\"draws\": 139, \"mouse\": 7, \"mu_intercept_per_group\": 7.895573616027832, \"sigma_intercept_per_group\": 0.2188684642314911, \"sigma_obs\": 150.23294067382812, \"slope\": -0.08015690743923187, \"chain\": 0, \"draw\": 139}, {\"draws\": 140, \"mouse\": 0, \"mu_intercept_per_group\": 11.24211311340332, \"sigma_intercept_per_group\": 0.219269797205925, \"sigma_obs\": 149.90777587890625, \"slope\": -0.07501793652772903, \"chain\": 0, \"draw\": 140}, {\"draws\": 140, \"mouse\": 1, \"mu_intercept_per_group\": 10.711899757385254, \"sigma_intercept_per_group\": 0.219269797205925, \"sigma_obs\": 149.90777587890625, \"slope\": -0.07501793652772903, \"chain\": 0, \"draw\": 140}, {\"draws\": 140, \"mouse\": 2, \"mu_intercept_per_group\": 10.341612815856934, \"sigma_intercept_per_group\": 0.219269797205925, \"sigma_obs\": 149.90777587890625, \"slope\": -0.07501793652772903, \"chain\": 0, \"draw\": 140}, {\"draws\": 140, \"mouse\": 3, \"mu_intercept_per_group\": 9.409369468688965, \"sigma_intercept_per_group\": 0.219269797205925, \"sigma_obs\": 149.90777587890625, \"slope\": -0.07501793652772903, \"chain\": 0, \"draw\": 140}, {\"draws\": 140, \"mouse\": 4, \"mu_intercept_per_group\": 9.704047203063965, \"sigma_intercept_per_group\": 0.219269797205925, \"sigma_obs\": 149.90777587890625, \"slope\": -0.07501793652772903, \"chain\": 0, \"draw\": 140}, {\"draws\": 140, \"mouse\": 5, \"mu_intercept_per_group\": 8.768258094787598, \"sigma_intercept_per_group\": 0.219269797205925, \"sigma_obs\": 149.90777587890625, \"slope\": -0.07501793652772903, \"chain\": 0, \"draw\": 140}, {\"draws\": 140, \"mouse\": 6, \"mu_intercept_per_group\": 8.322547912597656, \"sigma_intercept_per_group\": 0.219269797205925, \"sigma_obs\": 149.90777587890625, \"slope\": -0.07501793652772903, \"chain\": 0, \"draw\": 140}, {\"draws\": 140, \"mouse\": 7, \"mu_intercept_per_group\": 7.961656093597412, \"sigma_intercept_per_group\": 0.219269797205925, \"sigma_obs\": 149.90777587890625, \"slope\": -0.07501793652772903, \"chain\": 0, \"draw\": 140}, {\"draws\": 141, \"mouse\": 0, \"mu_intercept_per_group\": 10.654595375061035, \"sigma_intercept_per_group\": 0.2467852383852005, \"sigma_obs\": 187.04905700683594, \"slope\": -0.07135816663503647, \"chain\": 0, \"draw\": 141}, {\"draws\": 141, \"mouse\": 1, \"mu_intercept_per_group\": 10.348434448242188, \"sigma_intercept_per_group\": 0.2467852383852005, \"sigma_obs\": 187.04905700683594, \"slope\": -0.07135816663503647, \"chain\": 0, \"draw\": 141}, {\"draws\": 141, \"mouse\": 2, \"mu_intercept_per_group\": 10.179481506347656, \"sigma_intercept_per_group\": 0.2467852383852005, \"sigma_obs\": 187.04905700683594, \"slope\": -0.07135816663503647, \"chain\": 0, \"draw\": 141}, {\"draws\": 141, \"mouse\": 3, \"mu_intercept_per_group\": 9.383651733398438, \"sigma_intercept_per_group\": 0.2467852383852005, \"sigma_obs\": 187.04905700683594, \"slope\": -0.07135816663503647, \"chain\": 0, \"draw\": 141}, {\"draws\": 141, \"mouse\": 4, \"mu_intercept_per_group\": 9.086193084716797, \"sigma_intercept_per_group\": 0.2467852383852005, \"sigma_obs\": 187.04905700683594, \"slope\": -0.07135816663503647, \"chain\": 0, \"draw\": 141}, {\"draws\": 141, \"mouse\": 5, \"mu_intercept_per_group\": 8.849737167358398, \"sigma_intercept_per_group\": 0.2467852383852005, \"sigma_obs\": 187.04905700683594, \"slope\": -0.07135816663503647, \"chain\": 0, \"draw\": 141}, {\"draws\": 141, \"mouse\": 6, \"mu_intercept_per_group\": 8.241796493530273, \"sigma_intercept_per_group\": 0.2467852383852005, \"sigma_obs\": 187.04905700683594, \"slope\": -0.07135816663503647, \"chain\": 0, \"draw\": 141}, {\"draws\": 141, \"mouse\": 7, \"mu_intercept_per_group\": 7.894007205963135, \"sigma_intercept_per_group\": 0.2467852383852005, \"sigma_obs\": 187.04905700683594, \"slope\": -0.07135816663503647, \"chain\": 0, \"draw\": 141}, {\"draws\": 142, \"mouse\": 0, \"mu_intercept_per_group\": 9.669611930847168, \"sigma_intercept_per_group\": 0.25515279173851013, \"sigma_obs\": 168.02496337890625, \"slope\": -0.061102963984012604, \"chain\": 0, \"draw\": 142}, {\"draws\": 142, \"mouse\": 1, \"mu_intercept_per_group\": 9.59598445892334, \"sigma_intercept_per_group\": 0.25515279173851013, \"sigma_obs\": 168.02496337890625, \"slope\": -0.061102963984012604, \"chain\": 0, \"draw\": 142}, {\"draws\": 142, \"mouse\": 2, \"mu_intercept_per_group\": 9.301135063171387, \"sigma_intercept_per_group\": 0.25515279173851013, \"sigma_obs\": 168.02496337890625, \"slope\": -0.061102963984012604, \"chain\": 0, \"draw\": 142}, {\"draws\": 142, \"mouse\": 3, \"mu_intercept_per_group\": 8.73697566986084, \"sigma_intercept_per_group\": 0.25515279173851013, \"sigma_obs\": 168.02496337890625, \"slope\": -0.061102963984012604, \"chain\": 0, \"draw\": 142}, {\"draws\": 142, \"mouse\": 4, \"mu_intercept_per_group\": 8.455824851989746, \"sigma_intercept_per_group\": 0.25515279173851013, \"sigma_obs\": 168.02496337890625, \"slope\": -0.061102963984012604, \"chain\": 0, \"draw\": 142}, {\"draws\": 142, \"mouse\": 5, \"mu_intercept_per_group\": 7.797563076019287, \"sigma_intercept_per_group\": 0.25515279173851013, \"sigma_obs\": 168.02496337890625, \"slope\": -0.061102963984012604, \"chain\": 0, \"draw\": 142}, {\"draws\": 142, \"mouse\": 6, \"mu_intercept_per_group\": 7.507855415344238, \"sigma_intercept_per_group\": 0.25515279173851013, \"sigma_obs\": 168.02496337890625, \"slope\": -0.061102963984012604, \"chain\": 0, \"draw\": 142}, {\"draws\": 142, \"mouse\": 7, \"mu_intercept_per_group\": 7.007476329803467, \"sigma_intercept_per_group\": 0.25515279173851013, \"sigma_obs\": 168.02496337890625, \"slope\": -0.061102963984012604, \"chain\": 0, \"draw\": 142}, {\"draws\": 143, \"mouse\": 0, \"mu_intercept_per_group\": 10.179548263549805, \"sigma_intercept_per_group\": 0.24844345450401306, \"sigma_obs\": 162.0292205810547, \"slope\": -0.05770641937851906, \"chain\": 0, \"draw\": 143}, {\"draws\": 143, \"mouse\": 1, \"mu_intercept_per_group\": 9.501975059509277, \"sigma_intercept_per_group\": 0.24844345450401306, \"sigma_obs\": 162.0292205810547, \"slope\": -0.05770641937851906, \"chain\": 0, \"draw\": 143}, {\"draws\": 143, \"mouse\": 2, \"mu_intercept_per_group\": 9.448648452758789, \"sigma_intercept_per_group\": 0.24844345450401306, \"sigma_obs\": 162.0292205810547, \"slope\": -0.05770641937851906, \"chain\": 0, \"draw\": 143}, {\"draws\": 143, \"mouse\": 3, \"mu_intercept_per_group\": 8.776057243347168, \"sigma_intercept_per_group\": 0.24844345450401306, \"sigma_obs\": 162.0292205810547, \"slope\": -0.05770641937851906, \"chain\": 0, \"draw\": 143}, {\"draws\": 143, \"mouse\": 4, \"mu_intercept_per_group\": 8.55322265625, \"sigma_intercept_per_group\": 0.24844345450401306, \"sigma_obs\": 162.0292205810547, \"slope\": -0.05770641937851906, \"chain\": 0, \"draw\": 143}, {\"draws\": 143, \"mouse\": 5, \"mu_intercept_per_group\": 7.854974269866943, \"sigma_intercept_per_group\": 0.24844345450401306, \"sigma_obs\": 162.0292205810547, \"slope\": -0.05770641937851906, \"chain\": 0, \"draw\": 143}, {\"draws\": 143, \"mouse\": 6, \"mu_intercept_per_group\": 7.4617414474487305, \"sigma_intercept_per_group\": 0.24844345450401306, \"sigma_obs\": 162.0292205810547, \"slope\": -0.05770641937851906, \"chain\": 0, \"draw\": 143}, {\"draws\": 143, \"mouse\": 7, \"mu_intercept_per_group\": 6.966365814208984, \"sigma_intercept_per_group\": 0.24844345450401306, \"sigma_obs\": 162.0292205810547, \"slope\": -0.05770641937851906, \"chain\": 0, \"draw\": 143}, {\"draws\": 144, \"mouse\": 0, \"mu_intercept_per_group\": 9.908455848693848, \"sigma_intercept_per_group\": 0.24818305671215057, \"sigma_obs\": 163.388671875, \"slope\": -0.0567491352558136, \"chain\": 0, \"draw\": 144}, {\"draws\": 144, \"mouse\": 1, \"mu_intercept_per_group\": 9.504878997802734, \"sigma_intercept_per_group\": 0.24818305671215057, \"sigma_obs\": 163.388671875, \"slope\": -0.0567491352558136, \"chain\": 0, \"draw\": 144}, {\"draws\": 144, \"mouse\": 2, \"mu_intercept_per_group\": 8.989916801452637, \"sigma_intercept_per_group\": 0.24818305671215057, \"sigma_obs\": 163.388671875, \"slope\": -0.0567491352558136, \"chain\": 0, \"draw\": 144}, {\"draws\": 144, \"mouse\": 3, \"mu_intercept_per_group\": 8.772378921508789, \"sigma_intercept_per_group\": 0.24818305671215057, \"sigma_obs\": 163.388671875, \"slope\": -0.0567491352558136, \"chain\": 0, \"draw\": 144}, {\"draws\": 144, \"mouse\": 4, \"mu_intercept_per_group\": 8.627069473266602, \"sigma_intercept_per_group\": 0.24818305671215057, \"sigma_obs\": 163.388671875, \"slope\": -0.0567491352558136, \"chain\": 0, \"draw\": 144}, {\"draws\": 144, \"mouse\": 5, \"mu_intercept_per_group\": 8.301981925964355, \"sigma_intercept_per_group\": 0.24818305671215057, \"sigma_obs\": 163.388671875, \"slope\": -0.0567491352558136, \"chain\": 0, \"draw\": 144}, {\"draws\": 144, \"mouse\": 6, \"mu_intercept_per_group\": 7.633028507232666, \"sigma_intercept_per_group\": 0.24818305671215057, \"sigma_obs\": 163.388671875, \"slope\": -0.0567491352558136, \"chain\": 0, \"draw\": 144}, {\"draws\": 144, \"mouse\": 7, \"mu_intercept_per_group\": 7.413685321807861, \"sigma_intercept_per_group\": 0.24818305671215057, \"sigma_obs\": 163.388671875, \"slope\": -0.0567491352558136, \"chain\": 0, \"draw\": 144}, {\"draws\": 145, \"mouse\": 0, \"mu_intercept_per_group\": 11.40310001373291, \"sigma_intercept_per_group\": 0.2081475555896759, \"sigma_obs\": 157.4453887939453, \"slope\": -0.048227131366729736, \"chain\": 0, \"draw\": 145}, {\"draws\": 145, \"mouse\": 1, \"mu_intercept_per_group\": 11.191426277160645, \"sigma_intercept_per_group\": 0.2081475555896759, \"sigma_obs\": 157.4453887939453, \"slope\": -0.048227131366729736, \"chain\": 0, \"draw\": 145}, {\"draws\": 145, \"mouse\": 2, \"mu_intercept_per_group\": 10.621270179748535, \"sigma_intercept_per_group\": 0.2081475555896759, \"sigma_obs\": 157.4453887939453, \"slope\": -0.048227131366729736, \"chain\": 0, \"draw\": 145}, {\"draws\": 145, \"mouse\": 3, \"mu_intercept_per_group\": 10.377705574035645, \"sigma_intercept_per_group\": 0.2081475555896759, \"sigma_obs\": 157.4453887939453, \"slope\": -0.048227131366729736, \"chain\": 0, \"draw\": 145}, {\"draws\": 145, \"mouse\": 4, \"mu_intercept_per_group\": 9.855303764343262, \"sigma_intercept_per_group\": 0.2081475555896759, \"sigma_obs\": 157.4453887939453, \"slope\": -0.048227131366729736, \"chain\": 0, \"draw\": 145}, {\"draws\": 145, \"mouse\": 5, \"mu_intercept_per_group\": 9.071330070495605, \"sigma_intercept_per_group\": 0.2081475555896759, \"sigma_obs\": 157.4453887939453, \"slope\": -0.048227131366729736, \"chain\": 0, \"draw\": 145}, {\"draws\": 145, \"mouse\": 6, \"mu_intercept_per_group\": 8.720873832702637, \"sigma_intercept_per_group\": 0.2081475555896759, \"sigma_obs\": 157.4453887939453, \"slope\": -0.048227131366729736, \"chain\": 0, \"draw\": 145}, {\"draws\": 145, \"mouse\": 7, \"mu_intercept_per_group\": 8.158282279968262, \"sigma_intercept_per_group\": 0.2081475555896759, \"sigma_obs\": 157.4453887939453, \"slope\": -0.048227131366729736, \"chain\": 0, \"draw\": 145}, {\"draws\": 146, \"mouse\": 0, \"mu_intercept_per_group\": 11.57927131652832, \"sigma_intercept_per_group\": 0.2140108048915863, \"sigma_obs\": 156.63038635253906, \"slope\": -0.04766397178173065, \"chain\": 0, \"draw\": 146}, {\"draws\": 146, \"mouse\": 1, \"mu_intercept_per_group\": 10.886274337768555, \"sigma_intercept_per_group\": 0.2140108048915863, \"sigma_obs\": 156.63038635253906, \"slope\": -0.04766397178173065, \"chain\": 0, \"draw\": 146}, {\"draws\": 146, \"mouse\": 2, \"mu_intercept_per_group\": 10.840693473815918, \"sigma_intercept_per_group\": 0.2140108048915863, \"sigma_obs\": 156.63038635253906, \"slope\": -0.04766397178173065, \"chain\": 0, \"draw\": 146}, {\"draws\": 146, \"mouse\": 3, \"mu_intercept_per_group\": 9.845710754394531, \"sigma_intercept_per_group\": 0.2140108048915863, \"sigma_obs\": 156.63038635253906, \"slope\": -0.04766397178173065, \"chain\": 0, \"draw\": 146}, {\"draws\": 146, \"mouse\": 4, \"mu_intercept_per_group\": 9.832014083862305, \"sigma_intercept_per_group\": 0.2140108048915863, \"sigma_obs\": 156.63038635253906, \"slope\": -0.04766397178173065, \"chain\": 0, \"draw\": 146}, {\"draws\": 146, \"mouse\": 5, \"mu_intercept_per_group\": 9.396336555480957, \"sigma_intercept_per_group\": 0.2140108048915863, \"sigma_obs\": 156.63038635253906, \"slope\": -0.04766397178173065, \"chain\": 0, \"draw\": 146}, {\"draws\": 146, \"mouse\": 6, \"mu_intercept_per_group\": 8.616584777832031, \"sigma_intercept_per_group\": 0.2140108048915863, \"sigma_obs\": 156.63038635253906, \"slope\": -0.04766397178173065, \"chain\": 0, \"draw\": 146}, {\"draws\": 146, \"mouse\": 7, \"mu_intercept_per_group\": 8.137787818908691, \"sigma_intercept_per_group\": 0.2140108048915863, \"sigma_obs\": 156.63038635253906, \"slope\": -0.04766397178173065, \"chain\": 0, \"draw\": 146}, {\"draws\": 147, \"mouse\": 0, \"mu_intercept_per_group\": 11.169819831848145, \"sigma_intercept_per_group\": 0.2154686450958252, \"sigma_obs\": 156.86216735839844, \"slope\": -0.046809300780296326, \"chain\": 0, \"draw\": 147}, {\"draws\": 147, \"mouse\": 1, \"mu_intercept_per_group\": 11.044824600219727, \"sigma_intercept_per_group\": 0.2154686450958252, \"sigma_obs\": 156.86216735839844, \"slope\": -0.046809300780296326, \"chain\": 0, \"draw\": 147}, {\"draws\": 147, \"mouse\": 2, \"mu_intercept_per_group\": 10.397209167480469, \"sigma_intercept_per_group\": 0.2154686450958252, \"sigma_obs\": 156.86216735839844, \"slope\": -0.046809300780296326, \"chain\": 0, \"draw\": 147}, {\"draws\": 147, \"mouse\": 3, \"mu_intercept_per_group\": 10.223481178283691, \"sigma_intercept_per_group\": 0.2154686450958252, \"sigma_obs\": 156.86216735839844, \"slope\": -0.046809300780296326, \"chain\": 0, \"draw\": 147}, {\"draws\": 147, \"mouse\": 4, \"mu_intercept_per_group\": 9.64330768585205, \"sigma_intercept_per_group\": 0.2154686450958252, \"sigma_obs\": 156.86216735839844, \"slope\": -0.046809300780296326, \"chain\": 0, \"draw\": 147}, {\"draws\": 147, \"mouse\": 5, \"mu_intercept_per_group\": 9.138727188110352, \"sigma_intercept_per_group\": 0.2154686450958252, \"sigma_obs\": 156.86216735839844, \"slope\": -0.046809300780296326, \"chain\": 0, \"draw\": 147}, {\"draws\": 147, \"mouse\": 6, \"mu_intercept_per_group\": 8.28892993927002, \"sigma_intercept_per_group\": 0.2154686450958252, \"sigma_obs\": 156.86216735839844, \"slope\": -0.046809300780296326, \"chain\": 0, \"draw\": 147}, {\"draws\": 147, \"mouse\": 7, \"mu_intercept_per_group\": 7.948302745819092, \"sigma_intercept_per_group\": 0.2154686450958252, \"sigma_obs\": 156.86216735839844, \"slope\": -0.046809300780296326, \"chain\": 0, \"draw\": 147}, {\"draws\": 148, \"mouse\": 0, \"mu_intercept_per_group\": 11.181853294372559, \"sigma_intercept_per_group\": 0.2149808406829834, \"sigma_obs\": 157.16485595703125, \"slope\": -0.047177840024232864, \"chain\": 0, \"draw\": 148}, {\"draws\": 148, \"mouse\": 1, \"mu_intercept_per_group\": 10.94811725616455, \"sigma_intercept_per_group\": 0.2149808406829834, \"sigma_obs\": 157.16485595703125, \"slope\": -0.047177840024232864, \"chain\": 0, \"draw\": 148}, {\"draws\": 148, \"mouse\": 2, \"mu_intercept_per_group\": 10.357928276062012, \"sigma_intercept_per_group\": 0.2149808406829834, \"sigma_obs\": 157.16485595703125, \"slope\": -0.047177840024232864, \"chain\": 0, \"draw\": 148}, {\"draws\": 148, \"mouse\": 3, \"mu_intercept_per_group\": 10.07763385772705, \"sigma_intercept_per_group\": 0.2149808406829834, \"sigma_obs\": 157.16485595703125, \"slope\": -0.047177840024232864, \"chain\": 0, \"draw\": 148}, {\"draws\": 148, \"mouse\": 4, \"mu_intercept_per_group\": 9.572176933288574, \"sigma_intercept_per_group\": 0.2149808406829834, \"sigma_obs\": 157.16485595703125, \"slope\": -0.047177840024232864, \"chain\": 0, \"draw\": 148}, {\"draws\": 148, \"mouse\": 5, \"mu_intercept_per_group\": 9.185563087463379, \"sigma_intercept_per_group\": 0.2149808406829834, \"sigma_obs\": 157.16485595703125, \"slope\": -0.047177840024232864, \"chain\": 0, \"draw\": 148}, {\"draws\": 148, \"mouse\": 6, \"mu_intercept_per_group\": 8.41705322265625, \"sigma_intercept_per_group\": 0.2149808406829834, \"sigma_obs\": 157.16485595703125, \"slope\": -0.047177840024232864, \"chain\": 0, \"draw\": 148}, {\"draws\": 148, \"mouse\": 7, \"mu_intercept_per_group\": 7.992602825164795, \"sigma_intercept_per_group\": 0.2149808406829834, \"sigma_obs\": 157.16485595703125, \"slope\": -0.047177840024232864, \"chain\": 0, \"draw\": 148}, {\"draws\": 149, \"mouse\": 0, \"mu_intercept_per_group\": 11.354310035705566, \"sigma_intercept_per_group\": 0.2152392864227295, \"sigma_obs\": 159.24093627929688, \"slope\": -0.04895968362689018, \"chain\": 0, \"draw\": 149}, {\"draws\": 149, \"mouse\": 1, \"mu_intercept_per_group\": 10.856414794921875, \"sigma_intercept_per_group\": 0.2152392864227295, \"sigma_obs\": 159.24093627929688, \"slope\": -0.04895968362689018, \"chain\": 0, \"draw\": 149}, {\"draws\": 149, \"mouse\": 2, \"mu_intercept_per_group\": 10.71235466003418, \"sigma_intercept_per_group\": 0.2152392864227295, \"sigma_obs\": 159.24093627929688, \"slope\": -0.04895968362689018, \"chain\": 0, \"draw\": 149}, {\"draws\": 149, \"mouse\": 3, \"mu_intercept_per_group\": 9.521296501159668, \"sigma_intercept_per_group\": 0.2152392864227295, \"sigma_obs\": 159.24093627929688, \"slope\": -0.04895968362689018, \"chain\": 0, \"draw\": 149}, {\"draws\": 149, \"mouse\": 4, \"mu_intercept_per_group\": 9.603719711303711, \"sigma_intercept_per_group\": 0.2152392864227295, \"sigma_obs\": 159.24093627929688, \"slope\": -0.04895968362689018, \"chain\": 0, \"draw\": 149}, {\"draws\": 149, \"mouse\": 5, \"mu_intercept_per_group\": 9.138786315917969, \"sigma_intercept_per_group\": 0.2152392864227295, \"sigma_obs\": 159.24093627929688, \"slope\": -0.04895968362689018, \"chain\": 0, \"draw\": 149}, {\"draws\": 149, \"mouse\": 6, \"mu_intercept_per_group\": 8.67266845703125, \"sigma_intercept_per_group\": 0.2152392864227295, \"sigma_obs\": 159.24093627929688, \"slope\": -0.04895968362689018, \"chain\": 0, \"draw\": 149}, {\"draws\": 149, \"mouse\": 7, \"mu_intercept_per_group\": 8.272984504699707, \"sigma_intercept_per_group\": 0.2152392864227295, \"sigma_obs\": 159.24093627929688, \"slope\": -0.04895968362689018, \"chain\": 0, \"draw\": 149}, {\"draws\": 150, \"mouse\": 0, \"mu_intercept_per_group\": 11.732406616210938, \"sigma_intercept_per_group\": 0.20890580117702484, \"sigma_obs\": 159.28558349609375, \"slope\": -0.04195057973265648, \"chain\": 0, \"draw\": 150}, {\"draws\": 150, \"mouse\": 1, \"mu_intercept_per_group\": 11.186448097229004, \"sigma_intercept_per_group\": 0.20890580117702484, \"sigma_obs\": 159.28558349609375, \"slope\": -0.04195057973265648, \"chain\": 0, \"draw\": 150}, {\"draws\": 150, \"mouse\": 2, \"mu_intercept_per_group\": 10.729243278503418, \"sigma_intercept_per_group\": 0.20890580117702484, \"sigma_obs\": 159.28558349609375, \"slope\": -0.04195057973265648, \"chain\": 0, \"draw\": 150}, {\"draws\": 150, \"mouse\": 3, \"mu_intercept_per_group\": 10.704113006591797, \"sigma_intercept_per_group\": 0.20890580117702484, \"sigma_obs\": 159.28558349609375, \"slope\": -0.04195057973265648, \"chain\": 0, \"draw\": 150}, {\"draws\": 150, \"mouse\": 4, \"mu_intercept_per_group\": 10.058969497680664, \"sigma_intercept_per_group\": 0.20890580117702484, \"sigma_obs\": 159.28558349609375, \"slope\": -0.04195057973265648, \"chain\": 0, \"draw\": 150}, {\"draws\": 150, \"mouse\": 5, \"mu_intercept_per_group\": 9.431356430053711, \"sigma_intercept_per_group\": 0.20890580117702484, \"sigma_obs\": 159.28558349609375, \"slope\": -0.04195057973265648, \"chain\": 0, \"draw\": 150}, {\"draws\": 150, \"mouse\": 6, \"mu_intercept_per_group\": 8.753015518188477, \"sigma_intercept_per_group\": 0.20890580117702484, \"sigma_obs\": 159.28558349609375, \"slope\": -0.04195057973265648, \"chain\": 0, \"draw\": 150}, {\"draws\": 150, \"mouse\": 7, \"mu_intercept_per_group\": 8.30279541015625, \"sigma_intercept_per_group\": 0.20890580117702484, \"sigma_obs\": 159.28558349609375, \"slope\": -0.04195057973265648, \"chain\": 0, \"draw\": 150}, {\"draws\": 151, \"mouse\": 0, \"mu_intercept_per_group\": 12.129623413085938, \"sigma_intercept_per_group\": 0.20246759057044983, \"sigma_obs\": 160.9936065673828, \"slope\": -0.05216521769762039, \"chain\": 0, \"draw\": 151}, {\"draws\": 151, \"mouse\": 1, \"mu_intercept_per_group\": 11.29650592803955, \"sigma_intercept_per_group\": 0.20246759057044983, \"sigma_obs\": 160.9936065673828, \"slope\": -0.05216521769762039, \"chain\": 0, \"draw\": 151}, {\"draws\": 151, \"mouse\": 2, \"mu_intercept_per_group\": 11.115351676940918, \"sigma_intercept_per_group\": 0.20246759057044983, \"sigma_obs\": 160.9936065673828, \"slope\": -0.05216521769762039, \"chain\": 0, \"draw\": 151}, {\"draws\": 151, \"mouse\": 3, \"mu_intercept_per_group\": 11.065754890441895, \"sigma_intercept_per_group\": 0.20246759057044983, \"sigma_obs\": 160.9936065673828, \"slope\": -0.05216521769762039, \"chain\": 0, \"draw\": 151}, {\"draws\": 151, \"mouse\": 4, \"mu_intercept_per_group\": 10.409952163696289, \"sigma_intercept_per_group\": 0.20246759057044983, \"sigma_obs\": 160.9936065673828, \"slope\": -0.05216521769762039, \"chain\": 0, \"draw\": 151}, {\"draws\": 151, \"mouse\": 5, \"mu_intercept_per_group\": 9.6802978515625, \"sigma_intercept_per_group\": 0.20246759057044983, \"sigma_obs\": 160.9936065673828, \"slope\": -0.05216521769762039, \"chain\": 0, \"draw\": 151}, {\"draws\": 151, \"mouse\": 6, \"mu_intercept_per_group\": 9.092430114746094, \"sigma_intercept_per_group\": 0.20246759057044983, \"sigma_obs\": 160.9936065673828, \"slope\": -0.05216521769762039, \"chain\": 0, \"draw\": 151}, {\"draws\": 151, \"mouse\": 7, \"mu_intercept_per_group\": 8.87704849243164, \"sigma_intercept_per_group\": 0.20246759057044983, \"sigma_obs\": 160.9936065673828, \"slope\": -0.05216521769762039, \"chain\": 0, \"draw\": 151}, {\"draws\": 152, \"mouse\": 0, \"mu_intercept_per_group\": 14.280380249023438, \"sigma_intercept_per_group\": 0.17439651489257812, \"sigma_obs\": 159.08860778808594, \"slope\": -0.0926549881696701, \"chain\": 0, \"draw\": 152}, {\"draws\": 152, \"mouse\": 1, \"mu_intercept_per_group\": 13.789888381958008, \"sigma_intercept_per_group\": 0.17439651489257812, \"sigma_obs\": 159.08860778808594, \"slope\": -0.0926549881696701, \"chain\": 0, \"draw\": 152}, {\"draws\": 152, \"mouse\": 2, \"mu_intercept_per_group\": 13.89755630493164, \"sigma_intercept_per_group\": 0.17439651489257812, \"sigma_obs\": 159.08860778808594, \"slope\": -0.0926549881696701, \"chain\": 0, \"draw\": 152}, {\"draws\": 152, \"mouse\": 3, \"mu_intercept_per_group\": 12.520130157470703, \"sigma_intercept_per_group\": 0.17439651489257812, \"sigma_obs\": 159.08860778808594, \"slope\": -0.0926549881696701, \"chain\": 0, \"draw\": 152}, {\"draws\": 152, \"mouse\": 4, \"mu_intercept_per_group\": 11.781599044799805, \"sigma_intercept_per_group\": 0.17439651489257812, \"sigma_obs\": 159.08860778808594, \"slope\": -0.0926549881696701, \"chain\": 0, \"draw\": 152}, {\"draws\": 152, \"mouse\": 5, \"mu_intercept_per_group\": 11.494766235351562, \"sigma_intercept_per_group\": 0.17439651489257812, \"sigma_obs\": 159.08860778808594, \"slope\": -0.0926549881696701, \"chain\": 0, \"draw\": 152}, {\"draws\": 152, \"mouse\": 6, \"mu_intercept_per_group\": 10.887489318847656, \"sigma_intercept_per_group\": 0.17439651489257812, \"sigma_obs\": 159.08860778808594, \"slope\": -0.0926549881696701, \"chain\": 0, \"draw\": 152}, {\"draws\": 152, \"mouse\": 7, \"mu_intercept_per_group\": 9.980668067932129, \"sigma_intercept_per_group\": 0.17439651489257812, \"sigma_obs\": 159.08860778808594, \"slope\": -0.0926549881696701, \"chain\": 0, \"draw\": 152}, {\"draws\": 153, \"mouse\": 0, \"mu_intercept_per_group\": 11.905967712402344, \"sigma_intercept_per_group\": 0.20767128467559814, \"sigma_obs\": 159.68507385253906, \"slope\": -0.08928100764751434, \"chain\": 0, \"draw\": 153}, {\"draws\": 153, \"mouse\": 1, \"mu_intercept_per_group\": 11.317276000976562, \"sigma_intercept_per_group\": 0.20767128467559814, \"sigma_obs\": 159.68507385253906, \"slope\": -0.08928100764751434, \"chain\": 0, \"draw\": 153}, {\"draws\": 153, \"mouse\": 2, \"mu_intercept_per_group\": 11.07491397857666, \"sigma_intercept_per_group\": 0.20767128467559814, \"sigma_obs\": 159.68507385253906, \"slope\": -0.08928100764751434, \"chain\": 0, \"draw\": 153}, {\"draws\": 153, \"mouse\": 3, \"mu_intercept_per_group\": 10.915292739868164, \"sigma_intercept_per_group\": 0.20767128467559814, \"sigma_obs\": 159.68507385253906, \"slope\": -0.08928100764751434, \"chain\": 0, \"draw\": 153}, {\"draws\": 153, \"mouse\": 4, \"mu_intercept_per_group\": 10.580131530761719, \"sigma_intercept_per_group\": 0.20767128467559814, \"sigma_obs\": 159.68507385253906, \"slope\": -0.08928100764751434, \"chain\": 0, \"draw\": 153}, {\"draws\": 153, \"mouse\": 5, \"mu_intercept_per_group\": 9.953330039978027, \"sigma_intercept_per_group\": 0.20767128467559814, \"sigma_obs\": 159.68507385253906, \"slope\": -0.08928100764751434, \"chain\": 0, \"draw\": 153}, {\"draws\": 153, \"mouse\": 6, \"mu_intercept_per_group\": 9.19456672668457, \"sigma_intercept_per_group\": 0.20767128467559814, \"sigma_obs\": 159.68507385253906, \"slope\": -0.08928100764751434, \"chain\": 0, \"draw\": 153}, {\"draws\": 153, \"mouse\": 7, \"mu_intercept_per_group\": 8.936951637268066, \"sigma_intercept_per_group\": 0.20767128467559814, \"sigma_obs\": 159.68507385253906, \"slope\": -0.08928100764751434, \"chain\": 0, \"draw\": 153}, {\"draws\": 154, \"mouse\": 0, \"mu_intercept_per_group\": 12.345358848571777, \"sigma_intercept_per_group\": 0.2036626636981964, \"sigma_obs\": 159.58953857421875, \"slope\": -0.08774926513433456, \"chain\": 0, \"draw\": 154}, {\"draws\": 154, \"mouse\": 1, \"mu_intercept_per_group\": 12.072524070739746, \"sigma_intercept_per_group\": 0.2036626636981964, \"sigma_obs\": 159.58953857421875, \"slope\": -0.08774926513433456, \"chain\": 0, \"draw\": 154}, {\"draws\": 154, \"mouse\": 2, \"mu_intercept_per_group\": 11.600444793701172, \"sigma_intercept_per_group\": 0.2036626636981964, \"sigma_obs\": 159.58953857421875, \"slope\": -0.08774926513433456, \"chain\": 0, \"draw\": 154}, {\"draws\": 154, \"mouse\": 3, \"mu_intercept_per_group\": 10.394002914428711, \"sigma_intercept_per_group\": 0.2036626636981964, \"sigma_obs\": 159.58953857421875, \"slope\": -0.08774926513433456, \"chain\": 0, \"draw\": 154}, {\"draws\": 154, \"mouse\": 4, \"mu_intercept_per_group\": 10.356345176696777, \"sigma_intercept_per_group\": 0.2036626636981964, \"sigma_obs\": 159.58953857421875, \"slope\": -0.08774926513433456, \"chain\": 0, \"draw\": 154}, {\"draws\": 154, \"mouse\": 5, \"mu_intercept_per_group\": 9.788569450378418, \"sigma_intercept_per_group\": 0.2036626636981964, \"sigma_obs\": 159.58953857421875, \"slope\": -0.08774926513433456, \"chain\": 0, \"draw\": 154}, {\"draws\": 154, \"mouse\": 6, \"mu_intercept_per_group\": 8.940919876098633, \"sigma_intercept_per_group\": 0.2036626636981964, \"sigma_obs\": 159.58953857421875, \"slope\": -0.08774926513433456, \"chain\": 0, \"draw\": 154}, {\"draws\": 154, \"mouse\": 7, \"mu_intercept_per_group\": 9.018279075622559, \"sigma_intercept_per_group\": 0.2036626636981964, \"sigma_obs\": 159.58953857421875, \"slope\": -0.08774926513433456, \"chain\": 0, \"draw\": 154}, {\"draws\": 155, \"mouse\": 0, \"mu_intercept_per_group\": 12.298068046569824, \"sigma_intercept_per_group\": 0.20423145592212677, \"sigma_obs\": 159.40008544921875, \"slope\": -0.08784037083387375, \"chain\": 0, \"draw\": 155}, {\"draws\": 155, \"mouse\": 1, \"mu_intercept_per_group\": 12.083168029785156, \"sigma_intercept_per_group\": 0.20423145592212677, \"sigma_obs\": 159.40008544921875, \"slope\": -0.08784037083387375, \"chain\": 0, \"draw\": 155}, {\"draws\": 155, \"mouse\": 2, \"mu_intercept_per_group\": 11.462555885314941, \"sigma_intercept_per_group\": 0.20423145592212677, \"sigma_obs\": 159.40008544921875, \"slope\": -0.08784037083387375, \"chain\": 0, \"draw\": 155}, {\"draws\": 155, \"mouse\": 3, \"mu_intercept_per_group\": 10.488271713256836, \"sigma_intercept_per_group\": 0.20423145592212677, \"sigma_obs\": 159.40008544921875, \"slope\": -0.08784037083387375, \"chain\": 0, \"draw\": 155}, {\"draws\": 155, \"mouse\": 4, \"mu_intercept_per_group\": 10.371254920959473, \"sigma_intercept_per_group\": 0.20423145592212677, \"sigma_obs\": 159.40008544921875, \"slope\": -0.08784037083387375, \"chain\": 0, \"draw\": 155}, {\"draws\": 155, \"mouse\": 5, \"mu_intercept_per_group\": 9.865310668945312, \"sigma_intercept_per_group\": 0.20423145592212677, \"sigma_obs\": 159.40008544921875, \"slope\": -0.08784037083387375, \"chain\": 0, \"draw\": 155}, {\"draws\": 155, \"mouse\": 6, \"mu_intercept_per_group\": 8.993457794189453, \"sigma_intercept_per_group\": 0.20423145592212677, \"sigma_obs\": 159.40008544921875, \"slope\": -0.08784037083387375, \"chain\": 0, \"draw\": 155}, {\"draws\": 155, \"mouse\": 7, \"mu_intercept_per_group\": 8.77242660522461, \"sigma_intercept_per_group\": 0.20423145592212677, \"sigma_obs\": 159.40008544921875, \"slope\": -0.08784037083387375, \"chain\": 0, \"draw\": 155}, {\"draws\": 156, \"mouse\": 0, \"mu_intercept_per_group\": 12.023998260498047, \"sigma_intercept_per_group\": 0.20735818147659302, \"sigma_obs\": 159.53118896484375, \"slope\": -0.08664131909608841, \"chain\": 0, \"draw\": 156}, {\"draws\": 156, \"mouse\": 1, \"mu_intercept_per_group\": 11.515717506408691, \"sigma_intercept_per_group\": 0.20735818147659302, \"sigma_obs\": 159.53118896484375, \"slope\": -0.08664131909608841, \"chain\": 0, \"draw\": 156}, {\"draws\": 156, \"mouse\": 2, \"mu_intercept_per_group\": 11.184751510620117, \"sigma_intercept_per_group\": 0.20735818147659302, \"sigma_obs\": 159.53118896484375, \"slope\": -0.08664131909608841, \"chain\": 0, \"draw\": 156}, {\"draws\": 156, \"mouse\": 3, \"mu_intercept_per_group\": 10.582265853881836, \"sigma_intercept_per_group\": 0.20735818147659302, \"sigma_obs\": 159.53118896484375, \"slope\": -0.08664131909608841, \"chain\": 0, \"draw\": 156}, {\"draws\": 156, \"mouse\": 4, \"mu_intercept_per_group\": 10.468996047973633, \"sigma_intercept_per_group\": 0.20735818147659302, \"sigma_obs\": 159.53118896484375, \"slope\": -0.08664131909608841, \"chain\": 0, \"draw\": 156}, {\"draws\": 156, \"mouse\": 5, \"mu_intercept_per_group\": 9.841209411621094, \"sigma_intercept_per_group\": 0.20735818147659302, \"sigma_obs\": 159.53118896484375, \"slope\": -0.08664131909608841, \"chain\": 0, \"draw\": 156}, {\"draws\": 156, \"mouse\": 6, \"mu_intercept_per_group\": 9.073390007019043, \"sigma_intercept_per_group\": 0.20735818147659302, \"sigma_obs\": 159.53118896484375, \"slope\": -0.08664131909608841, \"chain\": 0, \"draw\": 156}, {\"draws\": 156, \"mouse\": 7, \"mu_intercept_per_group\": 8.671232223510742, \"sigma_intercept_per_group\": 0.20735818147659302, \"sigma_obs\": 159.53118896484375, \"slope\": -0.08664131909608841, \"chain\": 0, \"draw\": 156}, {\"draws\": 157, \"mouse\": 0, \"mu_intercept_per_group\": 11.963287353515625, \"sigma_intercept_per_group\": 0.20589368045330048, \"sigma_obs\": 159.4303436279297, \"slope\": -0.08766443282365799, \"chain\": 0, \"draw\": 157}, {\"draws\": 157, \"mouse\": 1, \"mu_intercept_per_group\": 11.873506546020508, \"sigma_intercept_per_group\": 0.20589368045330048, \"sigma_obs\": 159.4303436279297, \"slope\": -0.08766443282365799, \"chain\": 0, \"draw\": 157}, {\"draws\": 157, \"mouse\": 2, \"mu_intercept_per_group\": 11.260961532592773, \"sigma_intercept_per_group\": 0.20589368045330048, \"sigma_obs\": 159.4303436279297, \"slope\": -0.08766443282365799, \"chain\": 0, \"draw\": 157}, {\"draws\": 157, \"mouse\": 3, \"mu_intercept_per_group\": 10.688194274902344, \"sigma_intercept_per_group\": 0.20589368045330048, \"sigma_obs\": 159.4303436279297, \"slope\": -0.08766443282365799, \"chain\": 0, \"draw\": 157}, {\"draws\": 157, \"mouse\": 4, \"mu_intercept_per_group\": 10.424776077270508, \"sigma_intercept_per_group\": 0.20589368045330048, \"sigma_obs\": 159.4303436279297, \"slope\": -0.08766443282365799, \"chain\": 0, \"draw\": 157}, {\"draws\": 157, \"mouse\": 5, \"mu_intercept_per_group\": 10.206121444702148, \"sigma_intercept_per_group\": 0.20589368045330048, \"sigma_obs\": 159.4303436279297, \"slope\": -0.08766443282365799, \"chain\": 0, \"draw\": 157}, {\"draws\": 157, \"mouse\": 6, \"mu_intercept_per_group\": 8.906441688537598, \"sigma_intercept_per_group\": 0.20589368045330048, \"sigma_obs\": 159.4303436279297, \"slope\": -0.08766443282365799, \"chain\": 0, \"draw\": 157}, {\"draws\": 157, \"mouse\": 7, \"mu_intercept_per_group\": 8.314787864685059, \"sigma_intercept_per_group\": 0.20589368045330048, \"sigma_obs\": 159.4303436279297, \"slope\": -0.08766443282365799, \"chain\": 0, \"draw\": 157}, {\"draws\": 158, \"mouse\": 0, \"mu_intercept_per_group\": 12.21318244934082, \"sigma_intercept_per_group\": 0.20305481553077698, \"sigma_obs\": 164.74200439453125, \"slope\": -0.08380372077226639, \"chain\": 0, \"draw\": 158}, {\"draws\": 158, \"mouse\": 1, \"mu_intercept_per_group\": 12.160143852233887, \"sigma_intercept_per_group\": 0.20305481553077698, \"sigma_obs\": 164.74200439453125, \"slope\": -0.08380372077226639, \"chain\": 0, \"draw\": 158}, {\"draws\": 158, \"mouse\": 2, \"mu_intercept_per_group\": 11.546220779418945, \"sigma_intercept_per_group\": 0.20305481553077698, \"sigma_obs\": 164.74200439453125, \"slope\": -0.08380372077226639, \"chain\": 0, \"draw\": 158}, {\"draws\": 158, \"mouse\": 3, \"mu_intercept_per_group\": 10.967022895812988, \"sigma_intercept_per_group\": 0.20305481553077698, \"sigma_obs\": 164.74200439453125, \"slope\": -0.08380372077226639, \"chain\": 0, \"draw\": 158}, {\"draws\": 158, \"mouse\": 4, \"mu_intercept_per_group\": 10.448108673095703, \"sigma_intercept_per_group\": 0.20305481553077698, \"sigma_obs\": 164.74200439453125, \"slope\": -0.08380372077226639, \"chain\": 0, \"draw\": 158}, {\"draws\": 158, \"mouse\": 5, \"mu_intercept_per_group\": 9.915489196777344, \"sigma_intercept_per_group\": 0.20305481553077698, \"sigma_obs\": 164.74200439453125, \"slope\": -0.08380372077226639, \"chain\": 0, \"draw\": 158}, {\"draws\": 158, \"mouse\": 6, \"mu_intercept_per_group\": 9.624066352844238, \"sigma_intercept_per_group\": 0.20305481553077698, \"sigma_obs\": 164.74200439453125, \"slope\": -0.08380372077226639, \"chain\": 0, \"draw\": 158}, {\"draws\": 158, \"mouse\": 7, \"mu_intercept_per_group\": 9.303577423095703, \"sigma_intercept_per_group\": 0.20305481553077698, \"sigma_obs\": 164.74200439453125, \"slope\": -0.08380372077226639, \"chain\": 0, \"draw\": 158}, {\"draws\": 159, \"mouse\": 0, \"mu_intercept_per_group\": 12.08231258392334, \"sigma_intercept_per_group\": 0.19890598952770233, \"sigma_obs\": 148.2738037109375, \"slope\": -0.05468747392296791, \"chain\": 0, \"draw\": 159}, {\"draws\": 159, \"mouse\": 1, \"mu_intercept_per_group\": 11.352950096130371, \"sigma_intercept_per_group\": 0.19890598952770233, \"sigma_obs\": 148.2738037109375, \"slope\": -0.05468747392296791, \"chain\": 0, \"draw\": 159}, {\"draws\": 159, \"mouse\": 2, \"mu_intercept_per_group\": 11.264138221740723, \"sigma_intercept_per_group\": 0.19890598952770233, \"sigma_obs\": 148.2738037109375, \"slope\": -0.05468747392296791, \"chain\": 0, \"draw\": 159}, {\"draws\": 159, \"mouse\": 3, \"mu_intercept_per_group\": 10.76264762878418, \"sigma_intercept_per_group\": 0.19890598952770233, \"sigma_obs\": 148.2738037109375, \"slope\": -0.05468747392296791, \"chain\": 0, \"draw\": 159}, {\"draws\": 159, \"mouse\": 4, \"mu_intercept_per_group\": 10.375713348388672, \"sigma_intercept_per_group\": 0.19890598952770233, \"sigma_obs\": 148.2738037109375, \"slope\": -0.05468747392296791, \"chain\": 0, \"draw\": 159}, {\"draws\": 159, \"mouse\": 5, \"mu_intercept_per_group\": 9.551764488220215, \"sigma_intercept_per_group\": 0.19890598952770233, \"sigma_obs\": 148.2738037109375, \"slope\": -0.05468747392296791, \"chain\": 0, \"draw\": 159}, {\"draws\": 159, \"mouse\": 6, \"mu_intercept_per_group\": 8.991506576538086, \"sigma_intercept_per_group\": 0.19890598952770233, \"sigma_obs\": 148.2738037109375, \"slope\": -0.05468747392296791, \"chain\": 0, \"draw\": 159}, {\"draws\": 159, \"mouse\": 7, \"mu_intercept_per_group\": 8.223774909973145, \"sigma_intercept_per_group\": 0.19890598952770233, \"sigma_obs\": 148.2738037109375, \"slope\": -0.05468747392296791, \"chain\": 0, \"draw\": 159}, {\"draws\": 160, \"mouse\": 0, \"mu_intercept_per_group\": 12.084900856018066, \"sigma_intercept_per_group\": 0.1983698159456253, \"sigma_obs\": 149.03872680664062, \"slope\": -0.056552156805992126, \"chain\": 0, \"draw\": 160}, {\"draws\": 160, \"mouse\": 1, \"mu_intercept_per_group\": 11.388998985290527, \"sigma_intercept_per_group\": 0.1983698159456253, \"sigma_obs\": 149.03872680664062, \"slope\": -0.056552156805992126, \"chain\": 0, \"draw\": 160}, {\"draws\": 160, \"mouse\": 2, \"mu_intercept_per_group\": 10.995237350463867, \"sigma_intercept_per_group\": 0.1983698159456253, \"sigma_obs\": 149.03872680664062, \"slope\": -0.056552156805992126, \"chain\": 0, \"draw\": 160}, {\"draws\": 160, \"mouse\": 3, \"mu_intercept_per_group\": 10.738988876342773, \"sigma_intercept_per_group\": 0.1983698159456253, \"sigma_obs\": 149.03872680664062, \"slope\": -0.056552156805992126, \"chain\": 0, \"draw\": 160}, {\"draws\": 160, \"mouse\": 4, \"mu_intercept_per_group\": 10.745882987976074, \"sigma_intercept_per_group\": 0.1983698159456253, \"sigma_obs\": 149.03872680664062, \"slope\": -0.056552156805992126, \"chain\": 0, \"draw\": 160}, {\"draws\": 160, \"mouse\": 5, \"mu_intercept_per_group\": 9.310670852661133, \"sigma_intercept_per_group\": 0.1983698159456253, \"sigma_obs\": 149.03872680664062, \"slope\": -0.056552156805992126, \"chain\": 0, \"draw\": 160}, {\"draws\": 160, \"mouse\": 6, \"mu_intercept_per_group\": 8.691998481750488, \"sigma_intercept_per_group\": 0.1983698159456253, \"sigma_obs\": 149.03872680664062, \"slope\": -0.056552156805992126, \"chain\": 0, \"draw\": 160}, {\"draws\": 160, \"mouse\": 7, \"mu_intercept_per_group\": 8.082609176635742, \"sigma_intercept_per_group\": 0.1983698159456253, \"sigma_obs\": 149.03872680664062, \"slope\": -0.056552156805992126, \"chain\": 0, \"draw\": 160}, {\"draws\": 161, \"mouse\": 0, \"mu_intercept_per_group\": 11.757798194885254, \"sigma_intercept_per_group\": 0.19915053248405457, \"sigma_obs\": 150.9479217529297, \"slope\": -0.05072511360049248, \"chain\": 0, \"draw\": 161}, {\"draws\": 161, \"mouse\": 1, \"mu_intercept_per_group\": 11.55105209350586, \"sigma_intercept_per_group\": 0.19915053248405457, \"sigma_obs\": 150.9479217529297, \"slope\": -0.05072511360049248, \"chain\": 0, \"draw\": 161}, {\"draws\": 161, \"mouse\": 2, \"mu_intercept_per_group\": 11.221611022949219, \"sigma_intercept_per_group\": 0.19915053248405457, \"sigma_obs\": 150.9479217529297, \"slope\": -0.05072511360049248, \"chain\": 0, \"draw\": 161}, {\"draws\": 161, \"mouse\": 3, \"mu_intercept_per_group\": 10.195233345031738, \"sigma_intercept_per_group\": 0.19915053248405457, \"sigma_obs\": 150.9479217529297, \"slope\": -0.05072511360049248, \"chain\": 0, \"draw\": 161}, {\"draws\": 161, \"mouse\": 4, \"mu_intercept_per_group\": 9.617670059204102, \"sigma_intercept_per_group\": 0.19915053248405457, \"sigma_obs\": 150.9479217529297, \"slope\": -0.05072511360049248, \"chain\": 0, \"draw\": 161}, {\"draws\": 161, \"mouse\": 5, \"mu_intercept_per_group\": 9.789255142211914, \"sigma_intercept_per_group\": 0.19915053248405457, \"sigma_obs\": 150.9479217529297, \"slope\": -0.05072511360049248, \"chain\": 0, \"draw\": 161}, {\"draws\": 161, \"mouse\": 6, \"mu_intercept_per_group\": 9.062437057495117, \"sigma_intercept_per_group\": 0.19915053248405457, \"sigma_obs\": 150.9479217529297, \"slope\": -0.05072511360049248, \"chain\": 0, \"draw\": 161}, {\"draws\": 161, \"mouse\": 7, \"mu_intercept_per_group\": 9.213068962097168, \"sigma_intercept_per_group\": 0.19915053248405457, \"sigma_obs\": 150.9479217529297, \"slope\": -0.05072511360049248, \"chain\": 0, \"draw\": 161}, {\"draws\": 162, \"mouse\": 0, \"mu_intercept_per_group\": 12.060370445251465, \"sigma_intercept_per_group\": 0.19959218800067902, \"sigma_obs\": 150.45689392089844, \"slope\": -0.051548976451158524, \"chain\": 0, \"draw\": 162}, {\"draws\": 162, \"mouse\": 1, \"mu_intercept_per_group\": 11.123934745788574, \"sigma_intercept_per_group\": 0.19959218800067902, \"sigma_obs\": 150.45689392089844, \"slope\": -0.051548976451158524, \"chain\": 0, \"draw\": 162}, {\"draws\": 162, \"mouse\": 2, \"mu_intercept_per_group\": 10.73715591430664, \"sigma_intercept_per_group\": 0.19959218800067902, \"sigma_obs\": 150.45689392089844, \"slope\": -0.051548976451158524, \"chain\": 0, \"draw\": 162}, {\"draws\": 162, \"mouse\": 3, \"mu_intercept_per_group\": 10.587942123413086, \"sigma_intercept_per_group\": 0.19959218800067902, \"sigma_obs\": 150.45689392089844, \"slope\": -0.051548976451158524, \"chain\": 0, \"draw\": 162}, {\"draws\": 162, \"mouse\": 4, \"mu_intercept_per_group\": 10.243244171142578, \"sigma_intercept_per_group\": 0.19959218800067902, \"sigma_obs\": 150.45689392089844, \"slope\": -0.051548976451158524, \"chain\": 0, \"draw\": 162}, {\"draws\": 162, \"mouse\": 5, \"mu_intercept_per_group\": 9.638693809509277, \"sigma_intercept_per_group\": 0.19959218800067902, \"sigma_obs\": 150.45689392089844, \"slope\": -0.051548976451158524, \"chain\": 0, \"draw\": 162}, {\"draws\": 162, \"mouse\": 6, \"mu_intercept_per_group\": 9.031464576721191, \"sigma_intercept_per_group\": 0.19959218800067902, \"sigma_obs\": 150.45689392089844, \"slope\": -0.051548976451158524, \"chain\": 0, \"draw\": 162}, {\"draws\": 162, \"mouse\": 7, \"mu_intercept_per_group\": 9.028419494628906, \"sigma_intercept_per_group\": 0.19959218800067902, \"sigma_obs\": 150.45689392089844, \"slope\": -0.051548976451158524, \"chain\": 0, \"draw\": 162}, {\"draws\": 163, \"mouse\": 0, \"mu_intercept_per_group\": 13.90755558013916, \"sigma_intercept_per_group\": 0.1754406988620758, \"sigma_obs\": 156.95120239257812, \"slope\": -0.06794841587543488, \"chain\": 0, \"draw\": 163}, {\"draws\": 163, \"mouse\": 1, \"mu_intercept_per_group\": 13.438485145568848, \"sigma_intercept_per_group\": 0.1754406988620758, \"sigma_obs\": 156.95120239257812, \"slope\": -0.06794841587543488, \"chain\": 0, \"draw\": 163}, {\"draws\": 163, \"mouse\": 2, \"mu_intercept_per_group\": 13.113179206848145, \"sigma_intercept_per_group\": 0.1754406988620758, \"sigma_obs\": 156.95120239257812, \"slope\": -0.06794841587543488, \"chain\": 0, \"draw\": 163}, {\"draws\": 163, \"mouse\": 3, \"mu_intercept_per_group\": 12.251472473144531, \"sigma_intercept_per_group\": 0.1754406988620758, \"sigma_obs\": 156.95120239257812, \"slope\": -0.06794841587543488, \"chain\": 0, \"draw\": 163}, {\"draws\": 163, \"mouse\": 4, \"mu_intercept_per_group\": 12.147873878479004, \"sigma_intercept_per_group\": 0.1754406988620758, \"sigma_obs\": 156.95120239257812, \"slope\": -0.06794841587543488, \"chain\": 0, \"draw\": 163}, {\"draws\": 163, \"mouse\": 5, \"mu_intercept_per_group\": 11.47966194152832, \"sigma_intercept_per_group\": 0.1754406988620758, \"sigma_obs\": 156.95120239257812, \"slope\": -0.06794841587543488, \"chain\": 0, \"draw\": 163}, {\"draws\": 163, \"mouse\": 6, \"mu_intercept_per_group\": 10.338125228881836, \"sigma_intercept_per_group\": 0.1754406988620758, \"sigma_obs\": 156.95120239257812, \"slope\": -0.06794841587543488, \"chain\": 0, \"draw\": 163}, {\"draws\": 163, \"mouse\": 7, \"mu_intercept_per_group\": 9.35842227935791, \"sigma_intercept_per_group\": 0.1754406988620758, \"sigma_obs\": 156.95120239257812, \"slope\": -0.06794841587543488, \"chain\": 0, \"draw\": 163}, {\"draws\": 164, \"mouse\": 0, \"mu_intercept_per_group\": 8.492605209350586, \"sigma_intercept_per_group\": 0.2890729308128357, \"sigma_obs\": 159.3734130859375, \"slope\": -0.07538288086652756, \"chain\": 0, \"draw\": 164}, {\"draws\": 164, \"mouse\": 1, \"mu_intercept_per_group\": 8.436477661132812, \"sigma_intercept_per_group\": 0.2890729308128357, \"sigma_obs\": 159.3734130859375, \"slope\": -0.07538288086652756, \"chain\": 0, \"draw\": 164}, {\"draws\": 164, \"mouse\": 2, \"mu_intercept_per_group\": 8.135791778564453, \"sigma_intercept_per_group\": 0.2890729308128357, \"sigma_obs\": 159.3734130859375, \"slope\": -0.07538288086652756, \"chain\": 0, \"draw\": 164}, {\"draws\": 164, \"mouse\": 3, \"mu_intercept_per_group\": 7.7062458992004395, \"sigma_intercept_per_group\": 0.2890729308128357, \"sigma_obs\": 159.3734130859375, \"slope\": -0.07538288086652756, \"chain\": 0, \"draw\": 164}, {\"draws\": 164, \"mouse\": 4, \"mu_intercept_per_group\": 7.291903972625732, \"sigma_intercept_per_group\": 0.2890729308128357, \"sigma_obs\": 159.3734130859375, \"slope\": -0.07538288086652756, \"chain\": 0, \"draw\": 164}, {\"draws\": 164, \"mouse\": 5, \"mu_intercept_per_group\": 7.183645248413086, \"sigma_intercept_per_group\": 0.2890729308128357, \"sigma_obs\": 159.3734130859375, \"slope\": -0.07538288086652756, \"chain\": 0, \"draw\": 164}, {\"draws\": 164, \"mouse\": 6, \"mu_intercept_per_group\": 6.226927757263184, \"sigma_intercept_per_group\": 0.2890729308128357, \"sigma_obs\": 159.3734130859375, \"slope\": -0.07538288086652756, \"chain\": 0, \"draw\": 164}, {\"draws\": 164, \"mouse\": 7, \"mu_intercept_per_group\": 6.181626319885254, \"sigma_intercept_per_group\": 0.2890729308128357, \"sigma_obs\": 159.3734130859375, \"slope\": -0.07538288086652756, \"chain\": 0, \"draw\": 164}, {\"draws\": 165, \"mouse\": 0, \"mu_intercept_per_group\": 8.87048053741455, \"sigma_intercept_per_group\": 0.28625836968421936, \"sigma_obs\": 158.17742919921875, \"slope\": -0.07458198815584183, \"chain\": 0, \"draw\": 165}, {\"draws\": 165, \"mouse\": 1, \"mu_intercept_per_group\": 8.177042961120605, \"sigma_intercept_per_group\": 0.28625836968421936, \"sigma_obs\": 158.17742919921875, \"slope\": -0.07458198815584183, \"chain\": 0, \"draw\": 165}, {\"draws\": 165, \"mouse\": 2, \"mu_intercept_per_group\": 8.19905948638916, \"sigma_intercept_per_group\": 0.28625836968421936, \"sigma_obs\": 158.17742919921875, \"slope\": -0.07458198815584183, \"chain\": 0, \"draw\": 165}, {\"draws\": 165, \"mouse\": 3, \"mu_intercept_per_group\": 7.748135089874268, \"sigma_intercept_per_group\": 0.28625836968421936, \"sigma_obs\": 158.17742919921875, \"slope\": -0.07458198815584183, \"chain\": 0, \"draw\": 165}, {\"draws\": 165, \"mouse\": 4, \"mu_intercept_per_group\": 7.378511905670166, \"sigma_intercept_per_group\": 0.28625836968421936, \"sigma_obs\": 158.17742919921875, \"slope\": -0.07458198815584183, \"chain\": 0, \"draw\": 165}, {\"draws\": 165, \"mouse\": 5, \"mu_intercept_per_group\": 6.786886692047119, \"sigma_intercept_per_group\": 0.28625836968421936, \"sigma_obs\": 158.17742919921875, \"slope\": -0.07458198815584183, \"chain\": 0, \"draw\": 165}, {\"draws\": 165, \"mouse\": 6, \"mu_intercept_per_group\": 5.983675003051758, \"sigma_intercept_per_group\": 0.28625836968421936, \"sigma_obs\": 158.17742919921875, \"slope\": -0.07458198815584183, \"chain\": 0, \"draw\": 165}, {\"draws\": 165, \"mouse\": 7, \"mu_intercept_per_group\": 6.166525840759277, \"sigma_intercept_per_group\": 0.28625836968421936, \"sigma_obs\": 158.17742919921875, \"slope\": -0.07458198815584183, \"chain\": 0, \"draw\": 165}, {\"draws\": 166, \"mouse\": 0, \"mu_intercept_per_group\": 8.46670150756836, \"sigma_intercept_per_group\": 0.2909453511238098, \"sigma_obs\": 159.20790100097656, \"slope\": -0.07380065321922302, \"chain\": 0, \"draw\": 166}, {\"draws\": 166, \"mouse\": 1, \"mu_intercept_per_group\": 8.30587100982666, \"sigma_intercept_per_group\": 0.2909453511238098, \"sigma_obs\": 159.20790100097656, \"slope\": -0.07380065321922302, \"chain\": 0, \"draw\": 166}, {\"draws\": 166, \"mouse\": 2, \"mu_intercept_per_group\": 8.025303840637207, \"sigma_intercept_per_group\": 0.2909453511238098, \"sigma_obs\": 159.20790100097656, \"slope\": -0.07380065321922302, \"chain\": 0, \"draw\": 166}, {\"draws\": 166, \"mouse\": 3, \"mu_intercept_per_group\": 7.468910217285156, \"sigma_intercept_per_group\": 0.2909453511238098, \"sigma_obs\": 159.20790100097656, \"slope\": -0.07380065321922302, \"chain\": 0, \"draw\": 166}, {\"draws\": 166, \"mouse\": 4, \"mu_intercept_per_group\": 7.2683844566345215, \"sigma_intercept_per_group\": 0.2909453511238098, \"sigma_obs\": 159.20790100097656, \"slope\": -0.07380065321922302, \"chain\": 0, \"draw\": 166}, {\"draws\": 166, \"mouse\": 5, \"mu_intercept_per_group\": 6.897929668426514, \"sigma_intercept_per_group\": 0.2909453511238098, \"sigma_obs\": 159.20790100097656, \"slope\": -0.07380065321922302, \"chain\": 0, \"draw\": 166}, {\"draws\": 166, \"mouse\": 6, \"mu_intercept_per_group\": 6.515230655670166, \"sigma_intercept_per_group\": 0.2909453511238098, \"sigma_obs\": 159.20790100097656, \"slope\": -0.07380065321922302, \"chain\": 0, \"draw\": 166}, {\"draws\": 166, \"mouse\": 7, \"mu_intercept_per_group\": 5.995739936828613, \"sigma_intercept_per_group\": 0.2909453511238098, \"sigma_obs\": 159.20790100097656, \"slope\": -0.07380065321922302, \"chain\": 0, \"draw\": 166}, {\"draws\": 167, \"mouse\": 0, \"mu_intercept_per_group\": 8.747814178466797, \"sigma_intercept_per_group\": 0.28025364875793457, \"sigma_obs\": 156.4676513671875, \"slope\": -0.07330888509750366, \"chain\": 0, \"draw\": 167}, {\"draws\": 167, \"mouse\": 1, \"mu_intercept_per_group\": 8.50523853302002, \"sigma_intercept_per_group\": 0.28025364875793457, \"sigma_obs\": 156.4676513671875, \"slope\": -0.07330888509750366, \"chain\": 0, \"draw\": 167}, {\"draws\": 167, \"mouse\": 2, \"mu_intercept_per_group\": 8.185791969299316, \"sigma_intercept_per_group\": 0.28025364875793457, \"sigma_obs\": 156.4676513671875, \"slope\": -0.07330888509750366, \"chain\": 0, \"draw\": 167}, {\"draws\": 167, \"mouse\": 3, \"mu_intercept_per_group\": 7.715628147125244, \"sigma_intercept_per_group\": 0.28025364875793457, \"sigma_obs\": 156.4676513671875, \"slope\": -0.07330888509750366, \"chain\": 0, \"draw\": 167}, {\"draws\": 167, \"mouse\": 4, \"mu_intercept_per_group\": 7.382551670074463, \"sigma_intercept_per_group\": 0.28025364875793457, \"sigma_obs\": 156.4676513671875, \"slope\": -0.07330888509750366, \"chain\": 0, \"draw\": 167}, {\"draws\": 167, \"mouse\": 5, \"mu_intercept_per_group\": 6.913071155548096, \"sigma_intercept_per_group\": 0.28025364875793457, \"sigma_obs\": 156.4676513671875, \"slope\": -0.07330888509750366, \"chain\": 0, \"draw\": 167}, {\"draws\": 167, \"mouse\": 6, \"mu_intercept_per_group\": 6.533966064453125, \"sigma_intercept_per_group\": 0.28025364875793457, \"sigma_obs\": 156.4676513671875, \"slope\": -0.07330888509750366, \"chain\": 0, \"draw\": 167}, {\"draws\": 167, \"mouse\": 7, \"mu_intercept_per_group\": 6.390814304351807, \"sigma_intercept_per_group\": 0.28025364875793457, \"sigma_obs\": 156.4676513671875, \"slope\": -0.07330888509750366, \"chain\": 0, \"draw\": 167}, {\"draws\": 168, \"mouse\": 0, \"mu_intercept_per_group\": 8.580538749694824, \"sigma_intercept_per_group\": 0.28658685088157654, \"sigma_obs\": 158.20323181152344, \"slope\": -0.06996563076972961, \"chain\": 0, \"draw\": 168}, {\"draws\": 168, \"mouse\": 1, \"mu_intercept_per_group\": 8.426797866821289, \"sigma_intercept_per_group\": 0.28658685088157654, \"sigma_obs\": 158.20323181152344, \"slope\": -0.06996563076972961, \"chain\": 0, \"draw\": 168}, {\"draws\": 168, \"mouse\": 2, \"mu_intercept_per_group\": 8.089828491210938, \"sigma_intercept_per_group\": 0.28658685088157654, \"sigma_obs\": 158.20323181152344, \"slope\": -0.06996563076972961, \"chain\": 0, \"draw\": 168}, {\"draws\": 168, \"mouse\": 3, \"mu_intercept_per_group\": 7.618765354156494, \"sigma_intercept_per_group\": 0.28658685088157654, \"sigma_obs\": 158.20323181152344, \"slope\": -0.06996563076972961, \"chain\": 0, \"draw\": 168}, {\"draws\": 168, \"mouse\": 4, \"mu_intercept_per_group\": 7.54367208480835, \"sigma_intercept_per_group\": 0.28658685088157654, \"sigma_obs\": 158.20323181152344, \"slope\": -0.06996563076972961, \"chain\": 0, \"draw\": 168}, {\"draws\": 168, \"mouse\": 5, \"mu_intercept_per_group\": 7.125349044799805, \"sigma_intercept_per_group\": 0.28658685088157654, \"sigma_obs\": 158.20323181152344, \"slope\": -0.06996563076972961, \"chain\": 0, \"draw\": 168}, {\"draws\": 168, \"mouse\": 6, \"mu_intercept_per_group\": 6.564696788787842, \"sigma_intercept_per_group\": 0.28658685088157654, \"sigma_obs\": 158.20323181152344, \"slope\": -0.06996563076972961, \"chain\": 0, \"draw\": 168}, {\"draws\": 168, \"mouse\": 7, \"mu_intercept_per_group\": 6.112890720367432, \"sigma_intercept_per_group\": 0.28658685088157654, \"sigma_obs\": 158.20323181152344, \"slope\": -0.06996563076972961, \"chain\": 0, \"draw\": 168}, {\"draws\": 169, \"mouse\": 0, \"mu_intercept_per_group\": 9.120675086975098, \"sigma_intercept_per_group\": 0.2803913950920105, \"sigma_obs\": 167.97674560546875, \"slope\": -0.0758894756436348, \"chain\": 0, \"draw\": 169}, {\"draws\": 169, \"mouse\": 1, \"mu_intercept_per_group\": 8.94775676727295, \"sigma_intercept_per_group\": 0.2803913950920105, \"sigma_obs\": 167.97674560546875, \"slope\": -0.0758894756436348, \"chain\": 0, \"draw\": 169}, {\"draws\": 169, \"mouse\": 2, \"mu_intercept_per_group\": 8.465381622314453, \"sigma_intercept_per_group\": 0.2803913950920105, \"sigma_obs\": 167.97674560546875, \"slope\": -0.0758894756436348, \"chain\": 0, \"draw\": 169}, {\"draws\": 169, \"mouse\": 3, \"mu_intercept_per_group\": 8.031455039978027, \"sigma_intercept_per_group\": 0.2803913950920105, \"sigma_obs\": 167.97674560546875, \"slope\": -0.0758894756436348, \"chain\": 0, \"draw\": 169}, {\"draws\": 169, \"mouse\": 4, \"mu_intercept_per_group\": 7.67788553237915, \"sigma_intercept_per_group\": 0.2803913950920105, \"sigma_obs\": 167.97674560546875, \"slope\": -0.0758894756436348, \"chain\": 0, \"draw\": 169}, {\"draws\": 169, \"mouse\": 5, \"mu_intercept_per_group\": 7.457334041595459, \"sigma_intercept_per_group\": 0.2803913950920105, \"sigma_obs\": 167.97674560546875, \"slope\": -0.0758894756436348, \"chain\": 0, \"draw\": 169}, {\"draws\": 169, \"mouse\": 6, \"mu_intercept_per_group\": 7.053785800933838, \"sigma_intercept_per_group\": 0.2803913950920105, \"sigma_obs\": 167.97674560546875, \"slope\": -0.0758894756436348, \"chain\": 0, \"draw\": 169}, {\"draws\": 169, \"mouse\": 7, \"mu_intercept_per_group\": 6.423900604248047, \"sigma_intercept_per_group\": 0.2803913950920105, \"sigma_obs\": 167.97674560546875, \"slope\": -0.0758894756436348, \"chain\": 0, \"draw\": 169}, {\"draws\": 170, \"mouse\": 0, \"mu_intercept_per_group\": 8.869333267211914, \"sigma_intercept_per_group\": 0.2760220766067505, \"sigma_obs\": 160.37872314453125, \"slope\": -0.064585842192173, \"chain\": 0, \"draw\": 170}, {\"draws\": 170, \"mouse\": 1, \"mu_intercept_per_group\": 8.736527442932129, \"sigma_intercept_per_group\": 0.2760220766067505, \"sigma_obs\": 160.37872314453125, \"slope\": -0.064585842192173, \"chain\": 0, \"draw\": 170}, {\"draws\": 170, \"mouse\": 2, \"mu_intercept_per_group\": 8.357150077819824, \"sigma_intercept_per_group\": 0.2760220766067505, \"sigma_obs\": 160.37872314453125, \"slope\": -0.064585842192173, \"chain\": 0, \"draw\": 170}, {\"draws\": 170, \"mouse\": 3, \"mu_intercept_per_group\": 7.761438369750977, \"sigma_intercept_per_group\": 0.2760220766067505, \"sigma_obs\": 160.37872314453125, \"slope\": -0.064585842192173, \"chain\": 0, \"draw\": 170}, {\"draws\": 170, \"mouse\": 4, \"mu_intercept_per_group\": 7.854923248291016, \"sigma_intercept_per_group\": 0.2760220766067505, \"sigma_obs\": 160.37872314453125, \"slope\": -0.064585842192173, \"chain\": 0, \"draw\": 170}, {\"draws\": 170, \"mouse\": 5, \"mu_intercept_per_group\": 7.112229824066162, \"sigma_intercept_per_group\": 0.2760220766067505, \"sigma_obs\": 160.37872314453125, \"slope\": -0.064585842192173, \"chain\": 0, \"draw\": 170}, {\"draws\": 170, \"mouse\": 6, \"mu_intercept_per_group\": 6.730544567108154, \"sigma_intercept_per_group\": 0.2760220766067505, \"sigma_obs\": 160.37872314453125, \"slope\": -0.064585842192173, \"chain\": 0, \"draw\": 170}, {\"draws\": 170, \"mouse\": 7, \"mu_intercept_per_group\": 6.40588903427124, \"sigma_intercept_per_group\": 0.2760220766067505, \"sigma_obs\": 160.37872314453125, \"slope\": -0.064585842192173, \"chain\": 0, \"draw\": 170}, {\"draws\": 171, \"mouse\": 0, \"mu_intercept_per_group\": 9.096535682678223, \"sigma_intercept_per_group\": 0.2738156318664551, \"sigma_obs\": 161.3124237060547, \"slope\": -0.06416492909193039, \"chain\": 0, \"draw\": 171}, {\"draws\": 171, \"mouse\": 1, \"mu_intercept_per_group\": 8.587177276611328, \"sigma_intercept_per_group\": 0.2738156318664551, \"sigma_obs\": 161.3124237060547, \"slope\": -0.06416492909193039, \"chain\": 0, \"draw\": 171}, {\"draws\": 171, \"mouse\": 2, \"mu_intercept_per_group\": 8.477428436279297, \"sigma_intercept_per_group\": 0.2738156318664551, \"sigma_obs\": 161.3124237060547, \"slope\": -0.06416492909193039, \"chain\": 0, \"draw\": 171}, {\"draws\": 171, \"mouse\": 3, \"mu_intercept_per_group\": 8.101653099060059, \"sigma_intercept_per_group\": 0.2738156318664551, \"sigma_obs\": 161.3124237060547, \"slope\": -0.06416492909193039, \"chain\": 0, \"draw\": 171}, {\"draws\": 171, \"mouse\": 4, \"mu_intercept_per_group\": 7.5502119064331055, \"sigma_intercept_per_group\": 0.2738156318664551, \"sigma_obs\": 161.3124237060547, \"slope\": -0.06416492909193039, \"chain\": 0, \"draw\": 171}, {\"draws\": 171, \"mouse\": 5, \"mu_intercept_per_group\": 7.623770713806152, \"sigma_intercept_per_group\": 0.2738156318664551, \"sigma_obs\": 161.3124237060547, \"slope\": -0.06416492909193039, \"chain\": 0, \"draw\": 171}, {\"draws\": 171, \"mouse\": 6, \"mu_intercept_per_group\": 6.7867302894592285, \"sigma_intercept_per_group\": 0.2738156318664551, \"sigma_obs\": 161.3124237060547, \"slope\": -0.06416492909193039, \"chain\": 0, \"draw\": 171}, {\"draws\": 171, \"mouse\": 7, \"mu_intercept_per_group\": 6.460968017578125, \"sigma_intercept_per_group\": 0.2738156318664551, \"sigma_obs\": 161.3124237060547, \"slope\": -0.06416492909193039, \"chain\": 0, \"draw\": 171}, {\"draws\": 172, \"mouse\": 0, \"mu_intercept_per_group\": 15.37911319732666, \"sigma_intercept_per_group\": 0.1634259670972824, \"sigma_obs\": 160.86575317382812, \"slope\": -0.07606299221515656, \"chain\": 0, \"draw\": 172}, {\"draws\": 172, \"mouse\": 1, \"mu_intercept_per_group\": 14.550561904907227, \"sigma_intercept_per_group\": 0.1634259670972824, \"sigma_obs\": 160.86575317382812, \"slope\": -0.07606299221515656, \"chain\": 0, \"draw\": 172}, {\"draws\": 172, \"mouse\": 2, \"mu_intercept_per_group\": 14.572346687316895, \"sigma_intercept_per_group\": 0.1634259670972824, \"sigma_obs\": 160.86575317382812, \"slope\": -0.07606299221515656, \"chain\": 0, \"draw\": 172}, {\"draws\": 172, \"mouse\": 3, \"mu_intercept_per_group\": 13.086894035339355, \"sigma_intercept_per_group\": 0.1634259670972824, \"sigma_obs\": 160.86575317382812, \"slope\": -0.07606299221515656, \"chain\": 0, \"draw\": 172}, {\"draws\": 172, \"mouse\": 4, \"mu_intercept_per_group\": 12.897979736328125, \"sigma_intercept_per_group\": 0.1634259670972824, \"sigma_obs\": 160.86575317382812, \"slope\": -0.07606299221515656, \"chain\": 0, \"draw\": 172}, {\"draws\": 172, \"mouse\": 5, \"mu_intercept_per_group\": 12.16652774810791, \"sigma_intercept_per_group\": 0.1634259670972824, \"sigma_obs\": 160.86575317382812, \"slope\": -0.07606299221515656, \"chain\": 0, \"draw\": 172}, {\"draws\": 172, \"mouse\": 6, \"mu_intercept_per_group\": 11.403779983520508, \"sigma_intercept_per_group\": 0.1634259670972824, \"sigma_obs\": 160.86575317382812, \"slope\": -0.07606299221515656, \"chain\": 0, \"draw\": 172}, {\"draws\": 172, \"mouse\": 7, \"mu_intercept_per_group\": 10.74280834197998, \"sigma_intercept_per_group\": 0.1634259670972824, \"sigma_obs\": 160.86575317382812, \"slope\": -0.07606299221515656, \"chain\": 0, \"draw\": 172}, {\"draws\": 173, \"mouse\": 0, \"mu_intercept_per_group\": 14.907410621643066, \"sigma_intercept_per_group\": 0.16500717401504517, \"sigma_obs\": 162.29730224609375, \"slope\": -0.07763592153787613, \"chain\": 0, \"draw\": 173}, {\"draws\": 173, \"mouse\": 1, \"mu_intercept_per_group\": 14.671822547912598, \"sigma_intercept_per_group\": 0.16500717401504517, \"sigma_obs\": 162.29730224609375, \"slope\": -0.07763592153787613, \"chain\": 0, \"draw\": 173}, {\"draws\": 173, \"mouse\": 2, \"mu_intercept_per_group\": 14.191316604614258, \"sigma_intercept_per_group\": 0.16500717401504517, \"sigma_obs\": 162.29730224609375, \"slope\": -0.07763592153787613, \"chain\": 0, \"draw\": 173}, {\"draws\": 173, \"mouse\": 3, \"mu_intercept_per_group\": 13.808283805847168, \"sigma_intercept_per_group\": 0.16500717401504517, \"sigma_obs\": 162.29730224609375, \"slope\": -0.07763592153787613, \"chain\": 0, \"draw\": 173}, {\"draws\": 173, \"mouse\": 4, \"mu_intercept_per_group\": 12.8400297164917, \"sigma_intercept_per_group\": 0.16500717401504517, \"sigma_obs\": 162.29730224609375, \"slope\": -0.07763592153787613, \"chain\": 0, \"draw\": 173}, {\"draws\": 173, \"mouse\": 5, \"mu_intercept_per_group\": 12.245416641235352, \"sigma_intercept_per_group\": 0.16500717401504517, \"sigma_obs\": 162.29730224609375, \"slope\": -0.07763592153787613, \"chain\": 0, \"draw\": 173}, {\"draws\": 173, \"mouse\": 6, \"mu_intercept_per_group\": 11.531363487243652, \"sigma_intercept_per_group\": 0.16500717401504517, \"sigma_obs\": 162.29730224609375, \"slope\": -0.07763592153787613, \"chain\": 0, \"draw\": 173}, {\"draws\": 173, \"mouse\": 7, \"mu_intercept_per_group\": 11.234159469604492, \"sigma_intercept_per_group\": 0.16500717401504517, \"sigma_obs\": 162.29730224609375, \"slope\": -0.07763592153787613, \"chain\": 0, \"draw\": 173}, {\"draws\": 174, \"mouse\": 0, \"mu_intercept_per_group\": 15.41973876953125, \"sigma_intercept_per_group\": 0.16339153051376343, \"sigma_obs\": 162.16207885742188, \"slope\": -0.07760380953550339, \"chain\": 0, \"draw\": 174}, {\"draws\": 174, \"mouse\": 1, \"mu_intercept_per_group\": 14.544820785522461, \"sigma_intercept_per_group\": 0.16339153051376343, \"sigma_obs\": 162.16207885742188, \"slope\": -0.07760380953550339, \"chain\": 0, \"draw\": 174}, {\"draws\": 174, \"mouse\": 2, \"mu_intercept_per_group\": 14.187894821166992, \"sigma_intercept_per_group\": 0.16339153051376343, \"sigma_obs\": 162.16207885742188, \"slope\": -0.07760380953550339, \"chain\": 0, \"draw\": 174}, {\"draws\": 174, \"mouse\": 3, \"mu_intercept_per_group\": 13.10802173614502, \"sigma_intercept_per_group\": 0.16339153051376343, \"sigma_obs\": 162.16207885742188, \"slope\": -0.07760380953550339, \"chain\": 0, \"draw\": 174}, {\"draws\": 174, \"mouse\": 4, \"mu_intercept_per_group\": 13.067526817321777, \"sigma_intercept_per_group\": 0.16339153051376343, \"sigma_obs\": 162.16207885742188, \"slope\": -0.07760380953550339, \"chain\": 0, \"draw\": 174}, {\"draws\": 174, \"mouse\": 5, \"mu_intercept_per_group\": 12.508084297180176, \"sigma_intercept_per_group\": 0.16339153051376343, \"sigma_obs\": 162.16207885742188, \"slope\": -0.07760380953550339, \"chain\": 0, \"draw\": 174}, {\"draws\": 174, \"mouse\": 6, \"mu_intercept_per_group\": 11.812211990356445, \"sigma_intercept_per_group\": 0.16339153051376343, \"sigma_obs\": 162.16207885742188, \"slope\": -0.07760380953550339, \"chain\": 0, \"draw\": 174}, {\"draws\": 174, \"mouse\": 7, \"mu_intercept_per_group\": 11.16889476776123, \"sigma_intercept_per_group\": 0.16339153051376343, \"sigma_obs\": 162.16207885742188, \"slope\": -0.07760380953550339, \"chain\": 0, \"draw\": 174}, {\"draws\": 175, \"mouse\": 0, \"mu_intercept_per_group\": 15.29621696472168, \"sigma_intercept_per_group\": 0.16404275596141815, \"sigma_obs\": 162.8765106201172, \"slope\": -0.07840478420257568, \"chain\": 0, \"draw\": 175}, {\"draws\": 175, \"mouse\": 1, \"mu_intercept_per_group\": 14.683649063110352, \"sigma_intercept_per_group\": 0.16404275596141815, \"sigma_obs\": 162.8765106201172, \"slope\": -0.07840478420257568, \"chain\": 0, \"draw\": 175}, {\"draws\": 175, \"mouse\": 2, \"mu_intercept_per_group\": 13.946147918701172, \"sigma_intercept_per_group\": 0.16404275596141815, \"sigma_obs\": 162.8765106201172, \"slope\": -0.07840478420257568, \"chain\": 0, \"draw\": 175}, {\"draws\": 175, \"mouse\": 3, \"mu_intercept_per_group\": 13.611648559570312, \"sigma_intercept_per_group\": 0.16404275596141815, \"sigma_obs\": 162.8765106201172, \"slope\": -0.07840478420257568, \"chain\": 0, \"draw\": 175}, {\"draws\": 175, \"mouse\": 4, \"mu_intercept_per_group\": 13.393599510192871, \"sigma_intercept_per_group\": 0.16404275596141815, \"sigma_obs\": 162.8765106201172, \"slope\": -0.07840478420257568, \"chain\": 0, \"draw\": 175}, {\"draws\": 175, \"mouse\": 5, \"mu_intercept_per_group\": 12.21714973449707, \"sigma_intercept_per_group\": 0.16404275596141815, \"sigma_obs\": 162.8765106201172, \"slope\": -0.07840478420257568, \"chain\": 0, \"draw\": 175}, {\"draws\": 175, \"mouse\": 6, \"mu_intercept_per_group\": 11.8609619140625, \"sigma_intercept_per_group\": 0.16404275596141815, \"sigma_obs\": 162.8765106201172, \"slope\": -0.07840478420257568, \"chain\": 0, \"draw\": 175}, {\"draws\": 175, \"mouse\": 7, \"mu_intercept_per_group\": 10.875673294067383, \"sigma_intercept_per_group\": 0.16404275596141815, \"sigma_obs\": 162.8765106201172, \"slope\": -0.07840478420257568, \"chain\": 0, \"draw\": 175}, {\"draws\": 176, \"mouse\": 0, \"mu_intercept_per_group\": 12.87527847290039, \"sigma_intercept_per_group\": 0.19361062347888947, \"sigma_obs\": 159.84298706054688, \"slope\": -0.05209970846772194, \"chain\": 0, \"draw\": 176}, {\"draws\": 176, \"mouse\": 1, \"mu_intercept_per_group\": 12.142366409301758, \"sigma_intercept_per_group\": 0.19361062347888947, \"sigma_obs\": 159.84298706054688, \"slope\": -0.05209970846772194, \"chain\": 0, \"draw\": 176}, {\"draws\": 176, \"mouse\": 2, \"mu_intercept_per_group\": 11.956067085266113, \"sigma_intercept_per_group\": 0.19361062347888947, \"sigma_obs\": 159.84298706054688, \"slope\": -0.05209970846772194, \"chain\": 0, \"draw\": 176}, {\"draws\": 176, \"mouse\": 3, \"mu_intercept_per_group\": 10.840436935424805, \"sigma_intercept_per_group\": 0.19361062347888947, \"sigma_obs\": 159.84298706054688, \"slope\": -0.05209970846772194, \"chain\": 0, \"draw\": 176}, {\"draws\": 176, \"mouse\": 4, \"mu_intercept_per_group\": 10.766679763793945, \"sigma_intercept_per_group\": 0.19361062347888947, \"sigma_obs\": 159.84298706054688, \"slope\": -0.05209970846772194, \"chain\": 0, \"draw\": 176}, {\"draws\": 176, \"mouse\": 5, \"mu_intercept_per_group\": 10.261514663696289, \"sigma_intercept_per_group\": 0.19361062347888947, \"sigma_obs\": 159.84298706054688, \"slope\": -0.05209970846772194, \"chain\": 0, \"draw\": 176}, {\"draws\": 176, \"mouse\": 6, \"mu_intercept_per_group\": 9.550872802734375, \"sigma_intercept_per_group\": 0.19361062347888947, \"sigma_obs\": 159.84298706054688, \"slope\": -0.05209970846772194, \"chain\": 0, \"draw\": 176}, {\"draws\": 176, \"mouse\": 7, \"mu_intercept_per_group\": 9.013946533203125, \"sigma_intercept_per_group\": 0.19361062347888947, \"sigma_obs\": 159.84298706054688, \"slope\": -0.05209970846772194, \"chain\": 0, \"draw\": 176}, {\"draws\": 177, \"mouse\": 0, \"mu_intercept_per_group\": 12.911210060119629, \"sigma_intercept_per_group\": 0.19405969977378845, \"sigma_obs\": 159.58026123046875, \"slope\": -0.0518856905400753, \"chain\": 0, \"draw\": 177}, {\"draws\": 177, \"mouse\": 1, \"mu_intercept_per_group\": 12.109136581420898, \"sigma_intercept_per_group\": 0.19405969977378845, \"sigma_obs\": 159.58026123046875, \"slope\": -0.0518856905400753, \"chain\": 0, \"draw\": 177}, {\"draws\": 177, \"mouse\": 2, \"mu_intercept_per_group\": 11.64076042175293, \"sigma_intercept_per_group\": 0.19405969977378845, \"sigma_obs\": 159.58026123046875, \"slope\": -0.0518856905400753, \"chain\": 0, \"draw\": 177}, {\"draws\": 177, \"mouse\": 3, \"mu_intercept_per_group\": 10.91890811920166, \"sigma_intercept_per_group\": 0.19405969977378845, \"sigma_obs\": 159.58026123046875, \"slope\": -0.0518856905400753, \"chain\": 0, \"draw\": 177}, {\"draws\": 177, \"mouse\": 4, \"mu_intercept_per_group\": 10.837711334228516, \"sigma_intercept_per_group\": 0.19405969977378845, \"sigma_obs\": 159.58026123046875, \"slope\": -0.0518856905400753, \"chain\": 0, \"draw\": 177}, {\"draws\": 177, \"mouse\": 5, \"mu_intercept_per_group\": 10.31231689453125, \"sigma_intercept_per_group\": 0.19405969977378845, \"sigma_obs\": 159.58026123046875, \"slope\": -0.0518856905400753, \"chain\": 0, \"draw\": 177}, {\"draws\": 177, \"mouse\": 6, \"mu_intercept_per_group\": 9.510400772094727, \"sigma_intercept_per_group\": 0.19405969977378845, \"sigma_obs\": 159.58026123046875, \"slope\": -0.0518856905400753, \"chain\": 0, \"draw\": 177}, {\"draws\": 177, \"mouse\": 7, \"mu_intercept_per_group\": 9.063937187194824, \"sigma_intercept_per_group\": 0.19405969977378845, \"sigma_obs\": 159.58026123046875, \"slope\": -0.0518856905400753, \"chain\": 0, \"draw\": 177}, {\"draws\": 178, \"mouse\": 0, \"mu_intercept_per_group\": 12.410449981689453, \"sigma_intercept_per_group\": 0.19300030171871185, \"sigma_obs\": 161.14114379882812, \"slope\": -0.04833322390913963, \"chain\": 0, \"draw\": 178}, {\"draws\": 178, \"mouse\": 1, \"mu_intercept_per_group\": 12.275012969970703, \"sigma_intercept_per_group\": 0.19300030171871185, \"sigma_obs\": 161.14114379882812, \"slope\": -0.04833322390913963, \"chain\": 0, \"draw\": 178}, {\"draws\": 178, \"mouse\": 2, \"mu_intercept_per_group\": 12.095458984375, \"sigma_intercept_per_group\": 0.19300030171871185, \"sigma_obs\": 161.14114379882812, \"slope\": -0.04833322390913963, \"chain\": 0, \"draw\": 178}, {\"draws\": 178, \"mouse\": 3, \"mu_intercept_per_group\": 11.008768081665039, \"sigma_intercept_per_group\": 0.19300030171871185, \"sigma_obs\": 161.14114379882812, \"slope\": -0.04833322390913963, \"chain\": 0, \"draw\": 178}, {\"draws\": 178, \"mouse\": 4, \"mu_intercept_per_group\": 10.747136116027832, \"sigma_intercept_per_group\": 0.19300030171871185, \"sigma_obs\": 161.14114379882812, \"slope\": -0.04833322390913963, \"chain\": 0, \"draw\": 178}, {\"draws\": 178, \"mouse\": 5, \"mu_intercept_per_group\": 10.168545722961426, \"sigma_intercept_per_group\": 0.19300030171871185, \"sigma_obs\": 161.14114379882812, \"slope\": -0.04833322390913963, \"chain\": 0, \"draw\": 178}, {\"draws\": 178, \"mouse\": 6, \"mu_intercept_per_group\": 9.84563159942627, \"sigma_intercept_per_group\": 0.19300030171871185, \"sigma_obs\": 161.14114379882812, \"slope\": -0.04833322390913963, \"chain\": 0, \"draw\": 178}, {\"draws\": 178, \"mouse\": 7, \"mu_intercept_per_group\": 9.192788124084473, \"sigma_intercept_per_group\": 0.19300030171871185, \"sigma_obs\": 161.14114379882812, \"slope\": -0.04833322390913963, \"chain\": 0, \"draw\": 178}, {\"draws\": 179, \"mouse\": 0, \"mu_intercept_per_group\": 12.978813171386719, \"sigma_intercept_per_group\": 0.19207102060317993, \"sigma_obs\": 160.49224853515625, \"slope\": -0.04938949644565582, \"chain\": 0, \"draw\": 179}, {\"draws\": 179, \"mouse\": 1, \"mu_intercept_per_group\": 12.213482856750488, \"sigma_intercept_per_group\": 0.19207102060317993, \"sigma_obs\": 160.49224853515625, \"slope\": -0.04938949644565582, \"chain\": 0, \"draw\": 179}, {\"draws\": 179, \"mouse\": 2, \"mu_intercept_per_group\": 11.766718864440918, \"sigma_intercept_per_group\": 0.19207102060317993, \"sigma_obs\": 160.49224853515625, \"slope\": -0.04938949644565582, \"chain\": 0, \"draw\": 179}, {\"draws\": 179, \"mouse\": 3, \"mu_intercept_per_group\": 11.074529647827148, \"sigma_intercept_per_group\": 0.19207102060317993, \"sigma_obs\": 160.49224853515625, \"slope\": -0.04938949644565582, \"chain\": 0, \"draw\": 179}, {\"draws\": 179, \"mouse\": 4, \"mu_intercept_per_group\": 10.651321411132812, \"sigma_intercept_per_group\": 0.19207102060317993, \"sigma_obs\": 160.49224853515625, \"slope\": -0.04938949644565582, \"chain\": 0, \"draw\": 179}, {\"draws\": 179, \"mouse\": 5, \"mu_intercept_per_group\": 10.244606971740723, \"sigma_intercept_per_group\": 0.19207102060317993, \"sigma_obs\": 160.49224853515625, \"slope\": -0.04938949644565582, \"chain\": 0, \"draw\": 179}, {\"draws\": 179, \"mouse\": 6, \"mu_intercept_per_group\": 9.967731475830078, \"sigma_intercept_per_group\": 0.19207102060317993, \"sigma_obs\": 160.49224853515625, \"slope\": -0.04938949644565582, \"chain\": 0, \"draw\": 179}, {\"draws\": 179, \"mouse\": 7, \"mu_intercept_per_group\": 8.863067626953125, \"sigma_intercept_per_group\": 0.19207102060317993, \"sigma_obs\": 160.49224853515625, \"slope\": -0.04938949644565582, \"chain\": 0, \"draw\": 179}, {\"draws\": 180, \"mouse\": 0, \"mu_intercept_per_group\": 9.767702102661133, \"sigma_intercept_per_group\": 0.2588346600532532, \"sigma_obs\": 169.4383544921875, \"slope\": -0.08949188888072968, \"chain\": 0, \"draw\": 180}, {\"draws\": 180, \"mouse\": 1, \"mu_intercept_per_group\": 9.6812162399292, \"sigma_intercept_per_group\": 0.2588346600532532, \"sigma_obs\": 169.4383544921875, \"slope\": -0.08949188888072968, \"chain\": 0, \"draw\": 180}, {\"draws\": 180, \"mouse\": 2, \"mu_intercept_per_group\": 9.282271385192871, \"sigma_intercept_per_group\": 0.2588346600532532, \"sigma_obs\": 169.4383544921875, \"slope\": -0.08949188888072968, \"chain\": 0, \"draw\": 180}, {\"draws\": 180, \"mouse\": 3, \"mu_intercept_per_group\": 8.555476188659668, \"sigma_intercept_per_group\": 0.2588346600532532, \"sigma_obs\": 169.4383544921875, \"slope\": -0.08949188888072968, \"chain\": 0, \"draw\": 180}, {\"draws\": 180, \"mouse\": 4, \"mu_intercept_per_group\": 8.66438102722168, \"sigma_intercept_per_group\": 0.2588346600532532, \"sigma_obs\": 169.4383544921875, \"slope\": -0.08949188888072968, \"chain\": 0, \"draw\": 180}, {\"draws\": 180, \"mouse\": 5, \"mu_intercept_per_group\": 7.969657897949219, \"sigma_intercept_per_group\": 0.2588346600532532, \"sigma_obs\": 169.4383544921875, \"slope\": -0.08949188888072968, \"chain\": 0, \"draw\": 180}, {\"draws\": 180, \"mouse\": 6, \"mu_intercept_per_group\": 7.602900981903076, \"sigma_intercept_per_group\": 0.2588346600532532, \"sigma_obs\": 169.4383544921875, \"slope\": -0.08949188888072968, \"chain\": 0, \"draw\": 180}, {\"draws\": 180, \"mouse\": 7, \"mu_intercept_per_group\": 7.179483890533447, \"sigma_intercept_per_group\": 0.2588346600532532, \"sigma_obs\": 169.4383544921875, \"slope\": -0.08949188888072968, \"chain\": 0, \"draw\": 180}, {\"draws\": 181, \"mouse\": 0, \"mu_intercept_per_group\": 9.827238082885742, \"sigma_intercept_per_group\": 0.25792431831359863, \"sigma_obs\": 168.59213256835938, \"slope\": -0.08880040049552917, \"chain\": 0, \"draw\": 181}, {\"draws\": 181, \"mouse\": 1, \"mu_intercept_per_group\": 9.642237663269043, \"sigma_intercept_per_group\": 0.25792431831359863, \"sigma_obs\": 168.59213256835938, \"slope\": -0.08880040049552917, \"chain\": 0, \"draw\": 181}, {\"draws\": 181, \"mouse\": 2, \"mu_intercept_per_group\": 9.360074996948242, \"sigma_intercept_per_group\": 0.25792431831359863, \"sigma_obs\": 168.59213256835938, \"slope\": -0.08880040049552917, \"chain\": 0, \"draw\": 181}, {\"draws\": 181, \"mouse\": 3, \"mu_intercept_per_group\": 8.83914566040039, \"sigma_intercept_per_group\": 0.25792431831359863, \"sigma_obs\": 168.59213256835938, \"slope\": -0.08880040049552917, \"chain\": 0, \"draw\": 181}, {\"draws\": 181, \"mouse\": 4, \"mu_intercept_per_group\": 8.367600440979004, \"sigma_intercept_per_group\": 0.25792431831359863, \"sigma_obs\": 168.59213256835938, \"slope\": -0.08880040049552917, \"chain\": 0, \"draw\": 181}, {\"draws\": 181, \"mouse\": 5, \"mu_intercept_per_group\": 8.34797191619873, \"sigma_intercept_per_group\": 0.25792431831359863, \"sigma_obs\": 168.59213256835938, \"slope\": -0.08880040049552917, \"chain\": 0, \"draw\": 181}, {\"draws\": 181, \"mouse\": 6, \"mu_intercept_per_group\": 7.30478048324585, \"sigma_intercept_per_group\": 0.25792431831359863, \"sigma_obs\": 168.59213256835938, \"slope\": -0.08880040049552917, \"chain\": 0, \"draw\": 181}, {\"draws\": 181, \"mouse\": 7, \"mu_intercept_per_group\": 7.110230445861816, \"sigma_intercept_per_group\": 0.25792431831359863, \"sigma_obs\": 168.59213256835938, \"slope\": -0.08880040049552917, \"chain\": 0, \"draw\": 181}, {\"draws\": 182, \"mouse\": 0, \"mu_intercept_per_group\": 9.855794906616211, \"sigma_intercept_per_group\": 0.2610728144645691, \"sigma_obs\": 168.91851806640625, \"slope\": -0.08900773525238037, \"chain\": 0, \"draw\": 182}, {\"draws\": 182, \"mouse\": 1, \"mu_intercept_per_group\": 9.526384353637695, \"sigma_intercept_per_group\": 0.2610728144645691, \"sigma_obs\": 168.91851806640625, \"slope\": -0.08900773525238037, \"chain\": 0, \"draw\": 182}, {\"draws\": 182, \"mouse\": 2, \"mu_intercept_per_group\": 9.285346031188965, \"sigma_intercept_per_group\": 0.2610728144645691, \"sigma_obs\": 168.91851806640625, \"slope\": -0.08900773525238037, \"chain\": 0, \"draw\": 182}, {\"draws\": 182, \"mouse\": 3, \"mu_intercept_per_group\": 8.660233497619629, \"sigma_intercept_per_group\": 0.2610728144645691, \"sigma_obs\": 168.91851806640625, \"slope\": -0.08900773525238037, \"chain\": 0, \"draw\": 182}, {\"draws\": 182, \"mouse\": 4, \"mu_intercept_per_group\": 8.52940845489502, \"sigma_intercept_per_group\": 0.2610728144645691, \"sigma_obs\": 168.91851806640625, \"slope\": -0.08900773525238037, \"chain\": 0, \"draw\": 182}, {\"draws\": 182, \"mouse\": 5, \"mu_intercept_per_group\": 8.19045639038086, \"sigma_intercept_per_group\": 0.2610728144645691, \"sigma_obs\": 168.91851806640625, \"slope\": -0.08900773525238037, \"chain\": 0, \"draw\": 182}, {\"draws\": 182, \"mouse\": 6, \"mu_intercept_per_group\": 7.380913257598877, \"sigma_intercept_per_group\": 0.2610728144645691, \"sigma_obs\": 168.91851806640625, \"slope\": -0.08900773525238037, \"chain\": 0, \"draw\": 182}, {\"draws\": 182, \"mouse\": 7, \"mu_intercept_per_group\": 7.18501091003418, \"sigma_intercept_per_group\": 0.2610728144645691, \"sigma_obs\": 168.91851806640625, \"slope\": -0.08900773525238037, \"chain\": 0, \"draw\": 182}, {\"draws\": 183, \"mouse\": 0, \"mu_intercept_per_group\": 9.235301971435547, \"sigma_intercept_per_group\": 0.27317458391189575, \"sigma_obs\": 166.5284423828125, \"slope\": -0.09608093649148941, \"chain\": 0, \"draw\": 183}, {\"draws\": 183, \"mouse\": 1, \"mu_intercept_per_group\": 9.232686042785645, \"sigma_intercept_per_group\": 0.27317458391189575, \"sigma_obs\": 166.5284423828125, \"slope\": -0.09608093649148941, \"chain\": 0, \"draw\": 183}, {\"draws\": 183, \"mouse\": 2, \"mu_intercept_per_group\": 8.925854682922363, \"sigma_intercept_per_group\": 0.27317458391189575, \"sigma_obs\": 166.5284423828125, \"slope\": -0.09608093649148941, \"chain\": 0, \"draw\": 183}, {\"draws\": 183, \"mouse\": 3, \"mu_intercept_per_group\": 8.204789161682129, \"sigma_intercept_per_group\": 0.27317458391189575, \"sigma_obs\": 166.5284423828125, \"slope\": -0.09608093649148941, \"chain\": 0, \"draw\": 183}, {\"draws\": 183, \"mouse\": 4, \"mu_intercept_per_group\": 8.265790939331055, \"sigma_intercept_per_group\": 0.27317458391189575, \"sigma_obs\": 166.5284423828125, \"slope\": -0.09608093649148941, \"chain\": 0, \"draw\": 183}, {\"draws\": 183, \"mouse\": 5, \"mu_intercept_per_group\": 7.759638786315918, \"sigma_intercept_per_group\": 0.27317458391189575, \"sigma_obs\": 166.5284423828125, \"slope\": -0.09608093649148941, \"chain\": 0, \"draw\": 183}, {\"draws\": 183, \"mouse\": 6, \"mu_intercept_per_group\": 7.020971298217773, \"sigma_intercept_per_group\": 0.27317458391189575, \"sigma_obs\": 166.5284423828125, \"slope\": -0.09608093649148941, \"chain\": 0, \"draw\": 183}, {\"draws\": 183, \"mouse\": 7, \"mu_intercept_per_group\": 6.785755634307861, \"sigma_intercept_per_group\": 0.27317458391189575, \"sigma_obs\": 166.5284423828125, \"slope\": -0.09608093649148941, \"chain\": 0, \"draw\": 183}, {\"draws\": 184, \"mouse\": 0, \"mu_intercept_per_group\": 9.388321876525879, \"sigma_intercept_per_group\": 0.2676829993724823, \"sigma_obs\": 166.21563720703125, \"slope\": -0.09656155109405518, \"chain\": 0, \"draw\": 184}, {\"draws\": 184, \"mouse\": 1, \"mu_intercept_per_group\": 9.117071151733398, \"sigma_intercept_per_group\": 0.2676829993724823, \"sigma_obs\": 166.21563720703125, \"slope\": -0.09656155109405518, \"chain\": 0, \"draw\": 184}, {\"draws\": 184, \"mouse\": 2, \"mu_intercept_per_group\": 8.976292610168457, \"sigma_intercept_per_group\": 0.2676829993724823, \"sigma_obs\": 166.21563720703125, \"slope\": -0.09656155109405518, \"chain\": 0, \"draw\": 184}, {\"draws\": 184, \"mouse\": 3, \"mu_intercept_per_group\": 8.197794914245605, \"sigma_intercept_per_group\": 0.2676829993724823, \"sigma_obs\": 166.21563720703125, \"slope\": -0.09656155109405518, \"chain\": 0, \"draw\": 184}, {\"draws\": 184, \"mouse\": 4, \"mu_intercept_per_group\": 8.423775672912598, \"sigma_intercept_per_group\": 0.2676829993724823, \"sigma_obs\": 166.21563720703125, \"slope\": -0.09656155109405518, \"chain\": 0, \"draw\": 184}, {\"draws\": 184, \"mouse\": 5, \"mu_intercept_per_group\": 7.613896369934082, \"sigma_intercept_per_group\": 0.2676829993724823, \"sigma_obs\": 166.21563720703125, \"slope\": -0.09656155109405518, \"chain\": 0, \"draw\": 184}, {\"draws\": 184, \"mouse\": 6, \"mu_intercept_per_group\": 6.977293014526367, \"sigma_intercept_per_group\": 0.2676829993724823, \"sigma_obs\": 166.21563720703125, \"slope\": -0.09656155109405518, \"chain\": 0, \"draw\": 184}, {\"draws\": 184, \"mouse\": 7, \"mu_intercept_per_group\": 6.70665979385376, \"sigma_intercept_per_group\": 0.2676829993724823, \"sigma_obs\": 166.21563720703125, \"slope\": -0.09656155109405518, \"chain\": 0, \"draw\": 184}, {\"draws\": 185, \"mouse\": 0, \"mu_intercept_per_group\": 11.323853492736816, \"sigma_intercept_per_group\": 0.20800185203552246, \"sigma_obs\": 156.7366943359375, \"slope\": -0.0454447977244854, \"chain\": 0, \"draw\": 185}, {\"draws\": 185, \"mouse\": 1, \"mu_intercept_per_group\": 11.150670051574707, \"sigma_intercept_per_group\": 0.20800185203552246, \"sigma_obs\": 156.7366943359375, \"slope\": -0.0454447977244854, \"chain\": 0, \"draw\": 185}, {\"draws\": 185, \"mouse\": 2, \"mu_intercept_per_group\": 10.582371711730957, \"sigma_intercept_per_group\": 0.20800185203552246, \"sigma_obs\": 156.7366943359375, \"slope\": -0.0454447977244854, \"chain\": 0, \"draw\": 185}, {\"draws\": 185, \"mouse\": 3, \"mu_intercept_per_group\": 9.962729454040527, \"sigma_intercept_per_group\": 0.20800185203552246, \"sigma_obs\": 156.7366943359375, \"slope\": -0.0454447977244854, \"chain\": 0, \"draw\": 185}, {\"draws\": 185, \"mouse\": 4, \"mu_intercept_per_group\": 10.038491249084473, \"sigma_intercept_per_group\": 0.20800185203552246, \"sigma_obs\": 156.7366943359375, \"slope\": -0.0454447977244854, \"chain\": 0, \"draw\": 185}, {\"draws\": 185, \"mouse\": 5, \"mu_intercept_per_group\": 9.562788963317871, \"sigma_intercept_per_group\": 0.20800185203552246, \"sigma_obs\": 156.7366943359375, \"slope\": -0.0454447977244854, \"chain\": 0, \"draw\": 185}, {\"draws\": 185, \"mouse\": 6, \"mu_intercept_per_group\": 8.882129669189453, \"sigma_intercept_per_group\": 0.20800185203552246, \"sigma_obs\": 156.7366943359375, \"slope\": -0.0454447977244854, \"chain\": 0, \"draw\": 185}, {\"draws\": 185, \"mouse\": 7, \"mu_intercept_per_group\": 8.2109956741333, \"sigma_intercept_per_group\": 0.20800185203552246, \"sigma_obs\": 156.7366943359375, \"slope\": -0.0454447977244854, \"chain\": 0, \"draw\": 185}, {\"draws\": 186, \"mouse\": 0, \"mu_intercept_per_group\": 11.866374015808105, \"sigma_intercept_per_group\": 0.19779756665229797, \"sigma_obs\": 137.70217895507812, \"slope\": -0.051584094762802124, \"chain\": 0, \"draw\": 186}, {\"draws\": 186, \"mouse\": 1, \"mu_intercept_per_group\": 11.214910507202148, \"sigma_intercept_per_group\": 0.19779756665229797, \"sigma_obs\": 137.70217895507812, \"slope\": -0.051584094762802124, \"chain\": 0, \"draw\": 186}, {\"draws\": 186, \"mouse\": 2, \"mu_intercept_per_group\": 10.868884086608887, \"sigma_intercept_per_group\": 0.19779756665229797, \"sigma_obs\": 137.70217895507812, \"slope\": -0.051584094762802124, \"chain\": 0, \"draw\": 186}, {\"draws\": 186, \"mouse\": 3, \"mu_intercept_per_group\": 10.491374015808105, \"sigma_intercept_per_group\": 0.19779756665229797, \"sigma_obs\": 137.70217895507812, \"slope\": -0.051584094762802124, \"chain\": 0, \"draw\": 186}, {\"draws\": 186, \"mouse\": 4, \"mu_intercept_per_group\": 9.891730308532715, \"sigma_intercept_per_group\": 0.19779756665229797, \"sigma_obs\": 137.70217895507812, \"slope\": -0.051584094762802124, \"chain\": 0, \"draw\": 186}, {\"draws\": 186, \"mouse\": 5, \"mu_intercept_per_group\": 9.287598609924316, \"sigma_intercept_per_group\": 0.19779756665229797, \"sigma_obs\": 137.70217895507812, \"slope\": -0.051584094762802124, \"chain\": 0, \"draw\": 186}, {\"draws\": 186, \"mouse\": 6, \"mu_intercept_per_group\": 8.762433052062988, \"sigma_intercept_per_group\": 0.19779756665229797, \"sigma_obs\": 137.70217895507812, \"slope\": -0.051584094762802124, \"chain\": 0, \"draw\": 186}, {\"draws\": 186, \"mouse\": 7, \"mu_intercept_per_group\": 8.189188003540039, \"sigma_intercept_per_group\": 0.19779756665229797, \"sigma_obs\": 137.70217895507812, \"slope\": -0.051584094762802124, \"chain\": 0, \"draw\": 186}, {\"draws\": 187, \"mouse\": 0, \"mu_intercept_per_group\": 11.709754943847656, \"sigma_intercept_per_group\": 0.2077205628156662, \"sigma_obs\": 155.4445343017578, \"slope\": -0.0636429414153099, \"chain\": 0, \"draw\": 187}, {\"draws\": 187, \"mouse\": 1, \"mu_intercept_per_group\": 11.297006607055664, \"sigma_intercept_per_group\": 0.2077205628156662, \"sigma_obs\": 155.4445343017578, \"slope\": -0.0636429414153099, \"chain\": 0, \"draw\": 187}, {\"draws\": 187, \"mouse\": 2, \"mu_intercept_per_group\": 10.975092887878418, \"sigma_intercept_per_group\": 0.2077205628156662, \"sigma_obs\": 155.4445343017578, \"slope\": -0.0636429414153099, \"chain\": 0, \"draw\": 187}, {\"draws\": 187, \"mouse\": 3, \"mu_intercept_per_group\": 10.463529586791992, \"sigma_intercept_per_group\": 0.2077205628156662, \"sigma_obs\": 155.4445343017578, \"slope\": -0.0636429414153099, \"chain\": 0, \"draw\": 187}, {\"draws\": 187, \"mouse\": 4, \"mu_intercept_per_group\": 10.0537691116333, \"sigma_intercept_per_group\": 0.2077205628156662, \"sigma_obs\": 155.4445343017578, \"slope\": -0.0636429414153099, \"chain\": 0, \"draw\": 187}, {\"draws\": 187, \"mouse\": 5, \"mu_intercept_per_group\": 9.607925415039062, \"sigma_intercept_per_group\": 0.2077205628156662, \"sigma_obs\": 155.4445343017578, \"slope\": -0.0636429414153099, \"chain\": 0, \"draw\": 187}, {\"draws\": 187, \"mouse\": 6, \"mu_intercept_per_group\": 9.08677864074707, \"sigma_intercept_per_group\": 0.2077205628156662, \"sigma_obs\": 155.4445343017578, \"slope\": -0.0636429414153099, \"chain\": 0, \"draw\": 187}, {\"draws\": 187, \"mouse\": 7, \"mu_intercept_per_group\": 8.228388786315918, \"sigma_intercept_per_group\": 0.2077205628156662, \"sigma_obs\": 155.4445343017578, \"slope\": -0.0636429414153099, \"chain\": 0, \"draw\": 187}, {\"draws\": 188, \"mouse\": 0, \"mu_intercept_per_group\": 9.072654724121094, \"sigma_intercept_per_group\": 0.2725541889667511, \"sigma_obs\": 158.8972625732422, \"slope\": -0.058115992695093155, \"chain\": 0, \"draw\": 188}, {\"draws\": 188, \"mouse\": 1, \"mu_intercept_per_group\": 8.575309753417969, \"sigma_intercept_per_group\": 0.2725541889667511, \"sigma_obs\": 158.8972625732422, \"slope\": -0.058115992695093155, \"chain\": 0, \"draw\": 188}, {\"draws\": 188, \"mouse\": 2, \"mu_intercept_per_group\": 8.574599266052246, \"sigma_intercept_per_group\": 0.2725541889667511, \"sigma_obs\": 158.8972625732422, \"slope\": -0.058115992695093155, \"chain\": 0, \"draw\": 188}, {\"draws\": 188, \"mouse\": 3, \"mu_intercept_per_group\": 7.736423969268799, \"sigma_intercept_per_group\": 0.2725541889667511, \"sigma_obs\": 158.8972625732422, \"slope\": -0.058115992695093155, \"chain\": 0, \"draw\": 188}, {\"draws\": 188, \"mouse\": 4, \"mu_intercept_per_group\": 7.632427215576172, \"sigma_intercept_per_group\": 0.2725541889667511, \"sigma_obs\": 158.8972625732422, \"slope\": -0.058115992695093155, \"chain\": 0, \"draw\": 188}, {\"draws\": 188, \"mouse\": 5, \"mu_intercept_per_group\": 7.310050010681152, \"sigma_intercept_per_group\": 0.2725541889667511, \"sigma_obs\": 158.8972625732422, \"slope\": -0.058115992695093155, \"chain\": 0, \"draw\": 188}, {\"draws\": 188, \"mouse\": 6, \"mu_intercept_per_group\": 6.877157688140869, \"sigma_intercept_per_group\": 0.2725541889667511, \"sigma_obs\": 158.8972625732422, \"slope\": -0.058115992695093155, \"chain\": 0, \"draw\": 188}, {\"draws\": 188, \"mouse\": 7, \"mu_intercept_per_group\": 6.667375087738037, \"sigma_intercept_per_group\": 0.2725541889667511, \"sigma_obs\": 158.8972625732422, \"slope\": -0.058115992695093155, \"chain\": 0, \"draw\": 188}, {\"draws\": 189, \"mouse\": 0, \"mu_intercept_per_group\": 8.923603057861328, \"sigma_intercept_per_group\": 0.27248647809028625, \"sigma_obs\": 158.94082641601562, \"slope\": -0.0570637546479702, \"chain\": 0, \"draw\": 189}, {\"draws\": 189, \"mouse\": 1, \"mu_intercept_per_group\": 8.713286399841309, \"sigma_intercept_per_group\": 0.27248647809028625, \"sigma_obs\": 158.94082641601562, \"slope\": -0.0570637546479702, \"chain\": 0, \"draw\": 189}, {\"draws\": 189, \"mouse\": 2, \"mu_intercept_per_group\": 8.198965072631836, \"sigma_intercept_per_group\": 0.27248647809028625, \"sigma_obs\": 158.94082641601562, \"slope\": -0.0570637546479702, \"chain\": 0, \"draw\": 189}, {\"draws\": 189, \"mouse\": 3, \"mu_intercept_per_group\": 8.085589408874512, \"sigma_intercept_per_group\": 0.27248647809028625, \"sigma_obs\": 158.94082641601562, \"slope\": -0.0570637546479702, \"chain\": 0, \"draw\": 189}, {\"draws\": 189, \"mouse\": 4, \"mu_intercept_per_group\": 7.736410140991211, \"sigma_intercept_per_group\": 0.27248647809028625, \"sigma_obs\": 158.94082641601562, \"slope\": -0.0570637546479702, \"chain\": 0, \"draw\": 189}, {\"draws\": 189, \"mouse\": 5, \"mu_intercept_per_group\": 7.158468246459961, \"sigma_intercept_per_group\": 0.27248647809028625, \"sigma_obs\": 158.94082641601562, \"slope\": -0.0570637546479702, \"chain\": 0, \"draw\": 189}, {\"draws\": 189, \"mouse\": 6, \"mu_intercept_per_group\": 7.09492301940918, \"sigma_intercept_per_group\": 0.27248647809028625, \"sigma_obs\": 158.94082641601562, \"slope\": -0.0570637546479702, \"chain\": 0, \"draw\": 189}, {\"draws\": 189, \"mouse\": 7, \"mu_intercept_per_group\": 6.420792579650879, \"sigma_intercept_per_group\": 0.27248647809028625, \"sigma_obs\": 158.94082641601562, \"slope\": -0.0570637546479702, \"chain\": 0, \"draw\": 189}, {\"draws\": 190, \"mouse\": 0, \"mu_intercept_per_group\": 8.819541931152344, \"sigma_intercept_per_group\": 0.27360427379608154, \"sigma_obs\": 157.90658569335938, \"slope\": -0.061126306653022766, \"chain\": 0, \"draw\": 190}, {\"draws\": 190, \"mouse\": 1, \"mu_intercept_per_group\": 8.647892951965332, \"sigma_intercept_per_group\": 0.27360427379608154, \"sigma_obs\": 157.90658569335938, \"slope\": -0.061126306653022766, \"chain\": 0, \"draw\": 190}, {\"draws\": 190, \"mouse\": 2, \"mu_intercept_per_group\": 8.46115779876709, \"sigma_intercept_per_group\": 0.27360427379608154, \"sigma_obs\": 157.90658569335938, \"slope\": -0.061126306653022766, \"chain\": 0, \"draw\": 190}, {\"draws\": 190, \"mouse\": 3, \"mu_intercept_per_group\": 7.78157377243042, \"sigma_intercept_per_group\": 0.27360427379608154, \"sigma_obs\": 157.90658569335938, \"slope\": -0.061126306653022766, \"chain\": 0, \"draw\": 190}, {\"draws\": 190, \"mouse\": 4, \"mu_intercept_per_group\": 7.570834636688232, \"sigma_intercept_per_group\": 0.27360427379608154, \"sigma_obs\": 157.90658569335938, \"slope\": -0.061126306653022766, \"chain\": 0, \"draw\": 190}, {\"draws\": 190, \"mouse\": 5, \"mu_intercept_per_group\": 7.425249099731445, \"sigma_intercept_per_group\": 0.27360427379608154, \"sigma_obs\": 157.90658569335938, \"slope\": -0.061126306653022766, \"chain\": 0, \"draw\": 190}, {\"draws\": 190, \"mouse\": 6, \"mu_intercept_per_group\": 6.474233150482178, \"sigma_intercept_per_group\": 0.27360427379608154, \"sigma_obs\": 157.90658569335938, \"slope\": -0.061126306653022766, \"chain\": 0, \"draw\": 190}, {\"draws\": 190, \"mouse\": 7, \"mu_intercept_per_group\": 6.525479793548584, \"sigma_intercept_per_group\": 0.27360427379608154, \"sigma_obs\": 157.90658569335938, \"slope\": -0.061126306653022766, \"chain\": 0, \"draw\": 190}, {\"draws\": 191, \"mouse\": 0, \"mu_intercept_per_group\": 10.523869514465332, \"sigma_intercept_per_group\": 0.23749935626983643, \"sigma_obs\": 168.54615783691406, \"slope\": -0.06740521639585495, \"chain\": 0, \"draw\": 191}, {\"draws\": 191, \"mouse\": 1, \"mu_intercept_per_group\": 10.292780876159668, \"sigma_intercept_per_group\": 0.23749935626983643, \"sigma_obs\": 168.54615783691406, \"slope\": -0.06740521639585495, \"chain\": 0, \"draw\": 191}, {\"draws\": 191, \"mouse\": 2, \"mu_intercept_per_group\": 10.0230131149292, \"sigma_intercept_per_group\": 0.23749935626983643, \"sigma_obs\": 168.54615783691406, \"slope\": -0.06740521639585495, \"chain\": 0, \"draw\": 191}, {\"draws\": 191, \"mouse\": 3, \"mu_intercept_per_group\": 9.27288818359375, \"sigma_intercept_per_group\": 0.23749935626983643, \"sigma_obs\": 168.54615783691406, \"slope\": -0.06740521639585495, \"chain\": 0, \"draw\": 191}, {\"draws\": 191, \"mouse\": 4, \"mu_intercept_per_group\": 9.013269424438477, \"sigma_intercept_per_group\": 0.23749935626983643, \"sigma_obs\": 168.54615783691406, \"slope\": -0.06740521639585495, \"chain\": 0, \"draw\": 191}, {\"draws\": 191, \"mouse\": 5, \"mu_intercept_per_group\": 8.653177261352539, \"sigma_intercept_per_group\": 0.23749935626983643, \"sigma_obs\": 168.54615783691406, \"slope\": -0.06740521639585495, \"chain\": 0, \"draw\": 191}, {\"draws\": 191, \"mouse\": 6, \"mu_intercept_per_group\": 8.417975425720215, \"sigma_intercept_per_group\": 0.23749935626983643, \"sigma_obs\": 168.54615783691406, \"slope\": -0.06740521639585495, \"chain\": 0, \"draw\": 191}, {\"draws\": 191, \"mouse\": 7, \"mu_intercept_per_group\": 7.795126914978027, \"sigma_intercept_per_group\": 0.23749935626983643, \"sigma_obs\": 168.54615783691406, \"slope\": -0.06740521639585495, \"chain\": 0, \"draw\": 191}, {\"draws\": 192, \"mouse\": 0, \"mu_intercept_per_group\": 8.381933212280273, \"sigma_intercept_per_group\": 0.29595261812210083, \"sigma_obs\": 161.15719604492188, \"slope\": -0.07736687362194061, \"chain\": 0, \"draw\": 192}, {\"draws\": 192, \"mouse\": 1, \"mu_intercept_per_group\": 8.26798152923584, \"sigma_intercept_per_group\": 0.29595261812210083, \"sigma_obs\": 161.15719604492188, \"slope\": -0.07736687362194061, \"chain\": 0, \"draw\": 192}, {\"draws\": 192, \"mouse\": 2, \"mu_intercept_per_group\": 7.887351036071777, \"sigma_intercept_per_group\": 0.29595261812210083, \"sigma_obs\": 161.15719604492188, \"slope\": -0.07736687362194061, \"chain\": 0, \"draw\": 192}, {\"draws\": 192, \"mouse\": 3, \"mu_intercept_per_group\": 7.4453511238098145, \"sigma_intercept_per_group\": 0.29595261812210083, \"sigma_obs\": 161.15719604492188, \"slope\": -0.07736687362194061, \"chain\": 0, \"draw\": 192}, {\"draws\": 192, \"mouse\": 4, \"mu_intercept_per_group\": 7.266376972198486, \"sigma_intercept_per_group\": 0.29595261812210083, \"sigma_obs\": 161.15719604492188, \"slope\": -0.07736687362194061, \"chain\": 0, \"draw\": 192}, {\"draws\": 192, \"mouse\": 5, \"mu_intercept_per_group\": 6.919520378112793, \"sigma_intercept_per_group\": 0.29595261812210083, \"sigma_obs\": 161.15719604492188, \"slope\": -0.07736687362194061, \"chain\": 0, \"draw\": 192}, {\"draws\": 192, \"mouse\": 6, \"mu_intercept_per_group\": 6.1964898109436035, \"sigma_intercept_per_group\": 0.29595261812210083, \"sigma_obs\": 161.15719604492188, \"slope\": -0.07736687362194061, \"chain\": 0, \"draw\": 192}, {\"draws\": 192, \"mouse\": 7, \"mu_intercept_per_group\": 5.926969528198242, \"sigma_intercept_per_group\": 0.29595261812210083, \"sigma_obs\": 161.15719604492188, \"slope\": -0.07736687362194061, \"chain\": 0, \"draw\": 192}, {\"draws\": 193, \"mouse\": 0, \"mu_intercept_per_group\": 8.475712776184082, \"sigma_intercept_per_group\": 0.2976952791213989, \"sigma_obs\": 161.05319213867188, \"slope\": -0.07689382880926132, \"chain\": 0, \"draw\": 193}, {\"draws\": 193, \"mouse\": 1, \"mu_intercept_per_group\": 8.086938858032227, \"sigma_intercept_per_group\": 0.2976952791213989, \"sigma_obs\": 161.05319213867188, \"slope\": -0.07689382880926132, \"chain\": 0, \"draw\": 193}, {\"draws\": 193, \"mouse\": 2, \"mu_intercept_per_group\": 7.98268985748291, \"sigma_intercept_per_group\": 0.2976952791213989, \"sigma_obs\": 161.05319213867188, \"slope\": -0.07689382880926132, \"chain\": 0, \"draw\": 193}, {\"draws\": 193, \"mouse\": 3, \"mu_intercept_per_group\": 7.58610725402832, \"sigma_intercept_per_group\": 0.2976952791213989, \"sigma_obs\": 161.05319213867188, \"slope\": -0.07689382880926132, \"chain\": 0, \"draw\": 193}, {\"draws\": 193, \"mouse\": 4, \"mu_intercept_per_group\": 7.209872245788574, \"sigma_intercept_per_group\": 0.2976952791213989, \"sigma_obs\": 161.05319213867188, \"slope\": -0.07689382880926132, \"chain\": 0, \"draw\": 193}, {\"draws\": 193, \"mouse\": 5, \"mu_intercept_per_group\": 6.835591793060303, \"sigma_intercept_per_group\": 0.2976952791213989, \"sigma_obs\": 161.05319213867188, \"slope\": -0.07689382880926132, \"chain\": 0, \"draw\": 193}, {\"draws\": 193, \"mouse\": 6, \"mu_intercept_per_group\": 6.221705913543701, \"sigma_intercept_per_group\": 0.2976952791213989, \"sigma_obs\": 161.05319213867188, \"slope\": -0.07689382880926132, \"chain\": 0, \"draw\": 193}, {\"draws\": 193, \"mouse\": 7, \"mu_intercept_per_group\": 6.078230381011963, \"sigma_intercept_per_group\": 0.2976952791213989, \"sigma_obs\": 161.05319213867188, \"slope\": -0.07689382880926132, \"chain\": 0, \"draw\": 193}, {\"draws\": 194, \"mouse\": 0, \"mu_intercept_per_group\": 9.118433952331543, \"sigma_intercept_per_group\": 0.2706083059310913, \"sigma_obs\": 149.54986572265625, \"slope\": -0.08255605399608612, \"chain\": 0, \"draw\": 194}, {\"draws\": 194, \"mouse\": 1, \"mu_intercept_per_group\": 8.793959617614746, \"sigma_intercept_per_group\": 0.2706083059310913, \"sigma_obs\": 149.54986572265625, \"slope\": -0.08255605399608612, \"chain\": 0, \"draw\": 194}, {\"draws\": 194, \"mouse\": 2, \"mu_intercept_per_group\": 8.514091491699219, \"sigma_intercept_per_group\": 0.2706083059310913, \"sigma_obs\": 149.54986572265625, \"slope\": -0.08255605399608612, \"chain\": 0, \"draw\": 194}, {\"draws\": 194, \"mouse\": 3, \"mu_intercept_per_group\": 7.785826683044434, \"sigma_intercept_per_group\": 0.2706083059310913, \"sigma_obs\": 149.54986572265625, \"slope\": -0.08255605399608612, \"chain\": 0, \"draw\": 194}, {\"draws\": 194, \"mouse\": 4, \"mu_intercept_per_group\": 7.54402494430542, \"sigma_intercept_per_group\": 0.2706083059310913, \"sigma_obs\": 149.54986572265625, \"slope\": -0.08255605399608612, \"chain\": 0, \"draw\": 194}, {\"draws\": 194, \"mouse\": 5, \"mu_intercept_per_group\": 7.334568500518799, \"sigma_intercept_per_group\": 0.2706083059310913, \"sigma_obs\": 149.54986572265625, \"slope\": -0.08255605399608612, \"chain\": 0, \"draw\": 194}, {\"draws\": 194, \"mouse\": 6, \"mu_intercept_per_group\": 6.614410400390625, \"sigma_intercept_per_group\": 0.2706083059310913, \"sigma_obs\": 149.54986572265625, \"slope\": -0.08255605399608612, \"chain\": 0, \"draw\": 194}, {\"draws\": 194, \"mouse\": 7, \"mu_intercept_per_group\": 6.344924449920654, \"sigma_intercept_per_group\": 0.2706083059310913, \"sigma_obs\": 149.54986572265625, \"slope\": -0.08255605399608612, \"chain\": 0, \"draw\": 194}, {\"draws\": 195, \"mouse\": 0, \"mu_intercept_per_group\": 9.118042945861816, \"sigma_intercept_per_group\": 0.26891371607780457, \"sigma_obs\": 148.85023498535156, \"slope\": -0.08244482427835464, \"chain\": 0, \"draw\": 195}, {\"draws\": 195, \"mouse\": 1, \"mu_intercept_per_group\": 8.753979682922363, \"sigma_intercept_per_group\": 0.26891371607780457, \"sigma_obs\": 148.85023498535156, \"slope\": -0.08244482427835464, \"chain\": 0, \"draw\": 195}, {\"draws\": 195, \"mouse\": 2, \"mu_intercept_per_group\": 8.399897575378418, \"sigma_intercept_per_group\": 0.26891371607780457, \"sigma_obs\": 148.85023498535156, \"slope\": -0.08244482427835464, \"chain\": 0, \"draw\": 195}, {\"draws\": 195, \"mouse\": 3, \"mu_intercept_per_group\": 7.686967849731445, \"sigma_intercept_per_group\": 0.26891371607780457, \"sigma_obs\": 148.85023498535156, \"slope\": -0.08244482427835464, \"chain\": 0, \"draw\": 195}, {\"draws\": 195, \"mouse\": 4, \"mu_intercept_per_group\": 7.468371391296387, \"sigma_intercept_per_group\": 0.26891371607780457, \"sigma_obs\": 148.85023498535156, \"slope\": -0.08244482427835464, \"chain\": 0, \"draw\": 195}, {\"draws\": 195, \"mouse\": 5, \"mu_intercept_per_group\": 7.4518022537231445, \"sigma_intercept_per_group\": 0.26891371607780457, \"sigma_obs\": 148.85023498535156, \"slope\": -0.08244482427835464, \"chain\": 0, \"draw\": 195}, {\"draws\": 195, \"mouse\": 6, \"mu_intercept_per_group\": 6.497798442840576, \"sigma_intercept_per_group\": 0.26891371607780457, \"sigma_obs\": 148.85023498535156, \"slope\": -0.08244482427835464, \"chain\": 0, \"draw\": 195}, {\"draws\": 195, \"mouse\": 7, \"mu_intercept_per_group\": 6.451847076416016, \"sigma_intercept_per_group\": 0.26891371607780457, \"sigma_obs\": 148.85023498535156, \"slope\": -0.08244482427835464, \"chain\": 0, \"draw\": 195}, {\"draws\": 196, \"mouse\": 0, \"mu_intercept_per_group\": 10.657878875732422, \"sigma_intercept_per_group\": 0.23379074037075043, \"sigma_obs\": 162.13031005859375, \"slope\": -0.09105995297431946, \"chain\": 0, \"draw\": 196}, {\"draws\": 196, \"mouse\": 1, \"mu_intercept_per_group\": 10.596589088439941, \"sigma_intercept_per_group\": 0.23379074037075043, \"sigma_obs\": 162.13031005859375, \"slope\": -0.09105995297431946, \"chain\": 0, \"draw\": 196}, {\"draws\": 196, \"mouse\": 2, \"mu_intercept_per_group\": 10.14070987701416, \"sigma_intercept_per_group\": 0.23379074037075043, \"sigma_obs\": 162.13031005859375, \"slope\": -0.09105995297431946, \"chain\": 0, \"draw\": 196}, {\"draws\": 196, \"mouse\": 3, \"mu_intercept_per_group\": 9.624320983886719, \"sigma_intercept_per_group\": 0.23379074037075043, \"sigma_obs\": 162.13031005859375, \"slope\": -0.09105995297431946, \"chain\": 0, \"draw\": 196}, {\"draws\": 196, \"mouse\": 4, \"mu_intercept_per_group\": 9.412190437316895, \"sigma_intercept_per_group\": 0.23379074037075043, \"sigma_obs\": 162.13031005859375, \"slope\": -0.09105995297431946, \"chain\": 0, \"draw\": 196}, {\"draws\": 196, \"mouse\": 5, \"mu_intercept_per_group\": 8.848888397216797, \"sigma_intercept_per_group\": 0.23379074037075043, \"sigma_obs\": 162.13031005859375, \"slope\": -0.09105995297431946, \"chain\": 0, \"draw\": 196}, {\"draws\": 196, \"mouse\": 6, \"mu_intercept_per_group\": 7.901275634765625, \"sigma_intercept_per_group\": 0.23379074037075043, \"sigma_obs\": 162.13031005859375, \"slope\": -0.09105995297431946, \"chain\": 0, \"draw\": 196}, {\"draws\": 196, \"mouse\": 7, \"mu_intercept_per_group\": 7.686730861663818, \"sigma_intercept_per_group\": 0.23379074037075043, \"sigma_obs\": 162.13031005859375, \"slope\": -0.09105995297431946, \"chain\": 0, \"draw\": 196}, {\"draws\": 197, \"mouse\": 0, \"mu_intercept_per_group\": 10.755325317382812, \"sigma_intercept_per_group\": 0.2377905547618866, \"sigma_obs\": 162.34576416015625, \"slope\": -0.09079325944185257, \"chain\": 0, \"draw\": 197}, {\"draws\": 197, \"mouse\": 1, \"mu_intercept_per_group\": 9.790091514587402, \"sigma_intercept_per_group\": 0.2377905547618866, \"sigma_obs\": 162.34576416015625, \"slope\": -0.09079325944185257, \"chain\": 0, \"draw\": 197}, {\"draws\": 197, \"mouse\": 2, \"mu_intercept_per_group\": 9.956884384155273, \"sigma_intercept_per_group\": 0.2377905547618866, \"sigma_obs\": 162.34576416015625, \"slope\": -0.09079325944185257, \"chain\": 0, \"draw\": 197}, {\"draws\": 197, \"mouse\": 3, \"mu_intercept_per_group\": 9.226908683776855, \"sigma_intercept_per_group\": 0.2377905547618866, \"sigma_obs\": 162.34576416015625, \"slope\": -0.09079325944185257, \"chain\": 0, \"draw\": 197}, {\"draws\": 197, \"mouse\": 4, \"mu_intercept_per_group\": 9.00545883178711, \"sigma_intercept_per_group\": 0.2377905547618866, \"sigma_obs\": 162.34576416015625, \"slope\": -0.09079325944185257, \"chain\": 0, \"draw\": 197}, {\"draws\": 197, \"mouse\": 5, \"mu_intercept_per_group\": 8.546092987060547, \"sigma_intercept_per_group\": 0.2377905547618866, \"sigma_obs\": 162.34576416015625, \"slope\": -0.09079325944185257, \"chain\": 0, \"draw\": 197}, {\"draws\": 197, \"mouse\": 6, \"mu_intercept_per_group\": 8.414193153381348, \"sigma_intercept_per_group\": 0.2377905547618866, \"sigma_obs\": 162.34576416015625, \"slope\": -0.09079325944185257, \"chain\": 0, \"draw\": 197}, {\"draws\": 197, \"mouse\": 7, \"mu_intercept_per_group\": 7.613941669464111, \"sigma_intercept_per_group\": 0.2377905547618866, \"sigma_obs\": 162.34576416015625, \"slope\": -0.09079325944185257, \"chain\": 0, \"draw\": 197}, {\"draws\": 198, \"mouse\": 0, \"mu_intercept_per_group\": 10.911436080932617, \"sigma_intercept_per_group\": 0.22706744074821472, \"sigma_obs\": 163.05221557617188, \"slope\": -0.07491739094257355, \"chain\": 0, \"draw\": 198}, {\"draws\": 198, \"mouse\": 1, \"mu_intercept_per_group\": 10.805643081665039, \"sigma_intercept_per_group\": 0.22706744074821472, \"sigma_obs\": 163.05221557617188, \"slope\": -0.07491739094257355, \"chain\": 0, \"draw\": 198}, {\"draws\": 198, \"mouse\": 2, \"mu_intercept_per_group\": 10.353530883789062, \"sigma_intercept_per_group\": 0.22706744074821472, \"sigma_obs\": 163.05221557617188, \"slope\": -0.07491739094257355, \"chain\": 0, \"draw\": 198}, {\"draws\": 198, \"mouse\": 3, \"mu_intercept_per_group\": 9.922028541564941, \"sigma_intercept_per_group\": 0.22706744074821472, \"sigma_obs\": 163.05221557617188, \"slope\": -0.07491739094257355, \"chain\": 0, \"draw\": 198}, {\"draws\": 198, \"mouse\": 4, \"mu_intercept_per_group\": 9.407150268554688, \"sigma_intercept_per_group\": 0.22706744074821472, \"sigma_obs\": 163.05221557617188, \"slope\": -0.07491739094257355, \"chain\": 0, \"draw\": 198}, {\"draws\": 198, \"mouse\": 5, \"mu_intercept_per_group\": 8.798450469970703, \"sigma_intercept_per_group\": 0.22706744074821472, \"sigma_obs\": 163.05221557617188, \"slope\": -0.07491739094257355, \"chain\": 0, \"draw\": 198}, {\"draws\": 198, \"mouse\": 6, \"mu_intercept_per_group\": 8.63098430633545, \"sigma_intercept_per_group\": 0.22706744074821472, \"sigma_obs\": 163.05221557617188, \"slope\": -0.07491739094257355, \"chain\": 0, \"draw\": 198}, {\"draws\": 198, \"mouse\": 7, \"mu_intercept_per_group\": 7.961634159088135, \"sigma_intercept_per_group\": 0.22706744074821472, \"sigma_obs\": 163.05221557617188, \"slope\": -0.07491739094257355, \"chain\": 0, \"draw\": 198}, {\"draws\": 199, \"mouse\": 0, \"mu_intercept_per_group\": 10.911858558654785, \"sigma_intercept_per_group\": 0.22642917931079865, \"sigma_obs\": 158.85316467285156, \"slope\": -0.07918258756399155, \"chain\": 0, \"draw\": 199}, {\"draws\": 199, \"mouse\": 1, \"mu_intercept_per_group\": 10.558164596557617, \"sigma_intercept_per_group\": 0.22642917931079865, \"sigma_obs\": 158.85316467285156, \"slope\": -0.07918258756399155, \"chain\": 0, \"draw\": 199}, {\"draws\": 199, \"mouse\": 2, \"mu_intercept_per_group\": 10.303736686706543, \"sigma_intercept_per_group\": 0.22642917931079865, \"sigma_obs\": 158.85316467285156, \"slope\": -0.07918258756399155, \"chain\": 0, \"draw\": 199}, {\"draws\": 199, \"mouse\": 3, \"mu_intercept_per_group\": 9.569894790649414, \"sigma_intercept_per_group\": 0.22642917931079865, \"sigma_obs\": 158.85316467285156, \"slope\": -0.07918258756399155, \"chain\": 0, \"draw\": 199}, {\"draws\": 199, \"mouse\": 4, \"mu_intercept_per_group\": 9.518318176269531, \"sigma_intercept_per_group\": 0.22642917931079865, \"sigma_obs\": 158.85316467285156, \"slope\": -0.07918258756399155, \"chain\": 0, \"draw\": 199}, {\"draws\": 199, \"mouse\": 5, \"mu_intercept_per_group\": 9.141979217529297, \"sigma_intercept_per_group\": 0.22642917931079865, \"sigma_obs\": 158.85316467285156, \"slope\": -0.07918258756399155, \"chain\": 0, \"draw\": 199}, {\"draws\": 199, \"mouse\": 6, \"mu_intercept_per_group\": 8.179068565368652, \"sigma_intercept_per_group\": 0.22642917931079865, \"sigma_obs\": 158.85316467285156, \"slope\": -0.07918258756399155, \"chain\": 0, \"draw\": 199}, {\"draws\": 199, \"mouse\": 7, \"mu_intercept_per_group\": 8.110771179199219, \"sigma_intercept_per_group\": 0.22642917931079865, \"sigma_obs\": 158.85316467285156, \"slope\": -0.07918258756399155, \"chain\": 0, \"draw\": 199}, {\"draws\": 200, \"mouse\": 0, \"mu_intercept_per_group\": 9.53984260559082, \"sigma_intercept_per_group\": 0.26652824878692627, \"sigma_obs\": 175.32070922851562, \"slope\": -0.07887633889913559, \"chain\": 1, \"draw\": 0}, {\"draws\": 200, \"mouse\": 1, \"mu_intercept_per_group\": 9.476383209228516, \"sigma_intercept_per_group\": 0.26652824878692627, \"sigma_obs\": 175.32070922851562, \"slope\": -0.07887633889913559, \"chain\": 1, \"draw\": 0}, {\"draws\": 200, \"mouse\": 2, \"mu_intercept_per_group\": 9.061407089233398, \"sigma_intercept_per_group\": 0.26652824878692627, \"sigma_obs\": 175.32070922851562, \"slope\": -0.07887633889913559, \"chain\": 1, \"draw\": 0}, {\"draws\": 200, \"mouse\": 3, \"mu_intercept_per_group\": 8.51129150390625, \"sigma_intercept_per_group\": 0.26652824878692627, \"sigma_obs\": 175.32070922851562, \"slope\": -0.07887633889913559, \"chain\": 1, \"draw\": 0}, {\"draws\": 200, \"mouse\": 4, \"mu_intercept_per_group\": 8.267457008361816, \"sigma_intercept_per_group\": 0.26652824878692627, \"sigma_obs\": 175.32070922851562, \"slope\": -0.07887633889913559, \"chain\": 1, \"draw\": 0}, {\"draws\": 200, \"mouse\": 5, \"mu_intercept_per_group\": 7.821758270263672, \"sigma_intercept_per_group\": 0.26652824878692627, \"sigma_obs\": 175.32070922851562, \"slope\": -0.07887633889913559, \"chain\": 1, \"draw\": 0}, {\"draws\": 200, \"mouse\": 6, \"mu_intercept_per_group\": 7.348052978515625, \"sigma_intercept_per_group\": 0.26652824878692627, \"sigma_obs\": 175.32070922851562, \"slope\": -0.07887633889913559, \"chain\": 1, \"draw\": 0}, {\"draws\": 200, \"mouse\": 7, \"mu_intercept_per_group\": 6.930202007293701, \"sigma_intercept_per_group\": 0.26652824878692627, \"sigma_obs\": 175.32070922851562, \"slope\": -0.07887633889913559, \"chain\": 1, \"draw\": 0}, {\"draws\": 201, \"mouse\": 0, \"mu_intercept_per_group\": 10.643444061279297, \"sigma_intercept_per_group\": 0.2238588035106659, \"sigma_obs\": 147.81854248046875, \"slope\": -0.08609172701835632, \"chain\": 1, \"draw\": 1}, {\"draws\": 201, \"mouse\": 1, \"mu_intercept_per_group\": 10.533331871032715, \"sigma_intercept_per_group\": 0.2238588035106659, \"sigma_obs\": 147.81854248046875, \"slope\": -0.08609172701835632, \"chain\": 1, \"draw\": 1}, {\"draws\": 201, \"mouse\": 2, \"mu_intercept_per_group\": 10.013813972473145, \"sigma_intercept_per_group\": 0.2238588035106659, \"sigma_obs\": 147.81854248046875, \"slope\": -0.08609172701835632, \"chain\": 1, \"draw\": 1}, {\"draws\": 201, \"mouse\": 3, \"mu_intercept_per_group\": 9.712846755981445, \"sigma_intercept_per_group\": 0.2238588035106659, \"sigma_obs\": 147.81854248046875, \"slope\": -0.08609172701835632, \"chain\": 1, \"draw\": 1}, {\"draws\": 201, \"mouse\": 4, \"mu_intercept_per_group\": 9.26323127746582, \"sigma_intercept_per_group\": 0.2238588035106659, \"sigma_obs\": 147.81854248046875, \"slope\": -0.08609172701835632, \"chain\": 1, \"draw\": 1}, {\"draws\": 201, \"mouse\": 5, \"mu_intercept_per_group\": 8.811277389526367, \"sigma_intercept_per_group\": 0.2238588035106659, \"sigma_obs\": 147.81854248046875, \"slope\": -0.08609172701835632, \"chain\": 1, \"draw\": 1}, {\"draws\": 201, \"mouse\": 6, \"mu_intercept_per_group\": 7.975843906402588, \"sigma_intercept_per_group\": 0.2238588035106659, \"sigma_obs\": 147.81854248046875, \"slope\": -0.08609172701835632, \"chain\": 1, \"draw\": 1}, {\"draws\": 201, \"mouse\": 7, \"mu_intercept_per_group\": 7.655252456665039, \"sigma_intercept_per_group\": 0.2238588035106659, \"sigma_obs\": 147.81854248046875, \"slope\": -0.08609172701835632, \"chain\": 1, \"draw\": 1}, {\"draws\": 202, \"mouse\": 0, \"mu_intercept_per_group\": 10.638249397277832, \"sigma_intercept_per_group\": 0.22292466461658478, \"sigma_obs\": 144.84375, \"slope\": -0.09184294939041138, \"chain\": 1, \"draw\": 2}, {\"draws\": 202, \"mouse\": 1, \"mu_intercept_per_group\": 10.613873481750488, \"sigma_intercept_per_group\": 0.22292466461658478, \"sigma_obs\": 144.84375, \"slope\": -0.09184294939041138, \"chain\": 1, \"draw\": 2}, {\"draws\": 202, \"mouse\": 2, \"mu_intercept_per_group\": 10.050358772277832, \"sigma_intercept_per_group\": 0.22292466461658478, \"sigma_obs\": 144.84375, \"slope\": -0.09184294939041138, \"chain\": 1, \"draw\": 2}, {\"draws\": 202, \"mouse\": 3, \"mu_intercept_per_group\": 9.443792343139648, \"sigma_intercept_per_group\": 0.22292466461658478, \"sigma_obs\": 144.84375, \"slope\": -0.09184294939041138, \"chain\": 1, \"draw\": 2}, {\"draws\": 202, \"mouse\": 4, \"mu_intercept_per_group\": 9.311197280883789, \"sigma_intercept_per_group\": 0.22292466461658478, \"sigma_obs\": 144.84375, \"slope\": -0.09184294939041138, \"chain\": 1, \"draw\": 2}, {\"draws\": 202, \"mouse\": 5, \"mu_intercept_per_group\": 8.676220893859863, \"sigma_intercept_per_group\": 0.22292466461658478, \"sigma_obs\": 144.84375, \"slope\": -0.09184294939041138, \"chain\": 1, \"draw\": 2}, {\"draws\": 202, \"mouse\": 6, \"mu_intercept_per_group\": 8.389147758483887, \"sigma_intercept_per_group\": 0.22292466461658478, \"sigma_obs\": 144.84375, \"slope\": -0.09184294939041138, \"chain\": 1, \"draw\": 2}, {\"draws\": 202, \"mouse\": 7, \"mu_intercept_per_group\": 7.856712341308594, \"sigma_intercept_per_group\": 0.22292466461658478, \"sigma_obs\": 144.84375, \"slope\": -0.09184294939041138, \"chain\": 1, \"draw\": 2}, {\"draws\": 203, \"mouse\": 0, \"mu_intercept_per_group\": 9.00733757019043, \"sigma_intercept_per_group\": 0.28596997261047363, \"sigma_obs\": 167.09295654296875, \"slope\": -0.061572276055812836, \"chain\": 1, \"draw\": 3}, {\"draws\": 203, \"mouse\": 1, \"mu_intercept_per_group\": 8.440794944763184, \"sigma_intercept_per_group\": 0.28596997261047363, \"sigma_obs\": 167.09295654296875, \"slope\": -0.061572276055812836, \"chain\": 1, \"draw\": 3}, {\"draws\": 203, \"mouse\": 2, \"mu_intercept_per_group\": 7.990480899810791, \"sigma_intercept_per_group\": 0.28596997261047363, \"sigma_obs\": 167.09295654296875, \"slope\": -0.061572276055812836, \"chain\": 1, \"draw\": 3}, {\"draws\": 203, \"mouse\": 3, \"mu_intercept_per_group\": 7.766578197479248, \"sigma_intercept_per_group\": 0.28596997261047363, \"sigma_obs\": 167.09295654296875, \"slope\": -0.061572276055812836, \"chain\": 1, \"draw\": 3}, {\"draws\": 203, \"mouse\": 4, \"mu_intercept_per_group\": 7.624654769897461, \"sigma_intercept_per_group\": 0.28596997261047363, \"sigma_obs\": 167.09295654296875, \"slope\": -0.061572276055812836, \"chain\": 1, \"draw\": 3}, {\"draws\": 203, \"mouse\": 5, \"mu_intercept_per_group\": 7.052796363830566, \"sigma_intercept_per_group\": 0.28596997261047363, \"sigma_obs\": 167.09295654296875, \"slope\": -0.061572276055812836, \"chain\": 1, \"draw\": 3}, {\"draws\": 203, \"mouse\": 6, \"mu_intercept_per_group\": 6.44877290725708, \"sigma_intercept_per_group\": 0.28596997261047363, \"sigma_obs\": 167.09295654296875, \"slope\": -0.061572276055812836, \"chain\": 1, \"draw\": 3}, {\"draws\": 203, \"mouse\": 7, \"mu_intercept_per_group\": 6.203943729400635, \"sigma_intercept_per_group\": 0.28596997261047363, \"sigma_obs\": 167.09295654296875, \"slope\": -0.061572276055812836, \"chain\": 1, \"draw\": 3}, {\"draws\": 204, \"mouse\": 0, \"mu_intercept_per_group\": 8.494970321655273, \"sigma_intercept_per_group\": 0.28720447421073914, \"sigma_obs\": 162.88870239257812, \"slope\": -0.06967322528362274, \"chain\": 1, \"draw\": 4}, {\"draws\": 204, \"mouse\": 1, \"mu_intercept_per_group\": 8.369220733642578, \"sigma_intercept_per_group\": 0.28720447421073914, \"sigma_obs\": 162.88870239257812, \"slope\": -0.06967322528362274, \"chain\": 1, \"draw\": 4}, {\"draws\": 204, \"mouse\": 2, \"mu_intercept_per_group\": 8.275580406188965, \"sigma_intercept_per_group\": 0.28720447421073914, \"sigma_obs\": 162.88870239257812, \"slope\": -0.06967322528362274, \"chain\": 1, \"draw\": 4}, {\"draws\": 204, \"mouse\": 3, \"mu_intercept_per_group\": 7.552180290222168, \"sigma_intercept_per_group\": 0.28720447421073914, \"sigma_obs\": 162.88870239257812, \"slope\": -0.06967322528362274, \"chain\": 1, \"draw\": 4}, {\"draws\": 204, \"mouse\": 4, \"mu_intercept_per_group\": 7.659979820251465, \"sigma_intercept_per_group\": 0.28720447421073914, \"sigma_obs\": 162.88870239257812, \"slope\": -0.06967322528362274, \"chain\": 1, \"draw\": 4}, {\"draws\": 204, \"mouse\": 5, \"mu_intercept_per_group\": 7.1724371910095215, \"sigma_intercept_per_group\": 0.28720447421073914, \"sigma_obs\": 162.88870239257812, \"slope\": -0.06967322528362274, \"chain\": 1, \"draw\": 4}, {\"draws\": 204, \"mouse\": 6, \"mu_intercept_per_group\": 6.467124938964844, \"sigma_intercept_per_group\": 0.28720447421073914, \"sigma_obs\": 162.88870239257812, \"slope\": -0.06967322528362274, \"chain\": 1, \"draw\": 4}, {\"draws\": 204, \"mouse\": 7, \"mu_intercept_per_group\": 6.169829845428467, \"sigma_intercept_per_group\": 0.28720447421073914, \"sigma_obs\": 162.88870239257812, \"slope\": -0.06967322528362274, \"chain\": 1, \"draw\": 4}, {\"draws\": 205, \"mouse\": 0, \"mu_intercept_per_group\": 9.0673246383667, \"sigma_intercept_per_group\": 0.2708650827407837, \"sigma_obs\": 155.96417236328125, \"slope\": -0.0751432552933693, \"chain\": 1, \"draw\": 5}, {\"draws\": 205, \"mouse\": 1, \"mu_intercept_per_group\": 8.721512794494629, \"sigma_intercept_per_group\": 0.2708650827407837, \"sigma_obs\": 155.96417236328125, \"slope\": -0.0751432552933693, \"chain\": 1, \"draw\": 5}, {\"draws\": 205, \"mouse\": 2, \"mu_intercept_per_group\": 8.197345733642578, \"sigma_intercept_per_group\": 0.2708650827407837, \"sigma_obs\": 155.96417236328125, \"slope\": -0.0751432552933693, \"chain\": 1, \"draw\": 5}, {\"draws\": 205, \"mouse\": 3, \"mu_intercept_per_group\": 7.852082252502441, \"sigma_intercept_per_group\": 0.2708650827407837, \"sigma_obs\": 155.96417236328125, \"slope\": -0.0751432552933693, \"chain\": 1, \"draw\": 5}, {\"draws\": 205, \"mouse\": 4, \"mu_intercept_per_group\": 7.981184959411621, \"sigma_intercept_per_group\": 0.2708650827407837, \"sigma_obs\": 155.96417236328125, \"slope\": -0.0751432552933693, \"chain\": 1, \"draw\": 5}, {\"draws\": 205, \"mouse\": 5, \"mu_intercept_per_group\": 7.398582935333252, \"sigma_intercept_per_group\": 0.2708650827407837, \"sigma_obs\": 155.96417236328125, \"slope\": -0.0751432552933693, \"chain\": 1, \"draw\": 5}, {\"draws\": 205, \"mouse\": 6, \"mu_intercept_per_group\": 7.066089630126953, \"sigma_intercept_per_group\": 0.2708650827407837, \"sigma_obs\": 155.96417236328125, \"slope\": -0.0751432552933693, \"chain\": 1, \"draw\": 5}, {\"draws\": 205, \"mouse\": 7, \"mu_intercept_per_group\": 6.675655841827393, \"sigma_intercept_per_group\": 0.2708650827407837, \"sigma_obs\": 155.96417236328125, \"slope\": -0.0751432552933693, \"chain\": 1, \"draw\": 5}, {\"draws\": 206, \"mouse\": 0, \"mu_intercept_per_group\": 9.225547790527344, \"sigma_intercept_per_group\": 0.2650328278541565, \"sigma_obs\": 152.61622619628906, \"slope\": -0.07392597943544388, \"chain\": 1, \"draw\": 6}, {\"draws\": 206, \"mouse\": 1, \"mu_intercept_per_group\": 8.750295639038086, \"sigma_intercept_per_group\": 0.2650328278541565, \"sigma_obs\": 152.61622619628906, \"slope\": -0.07392597943544388, \"chain\": 1, \"draw\": 6}, {\"draws\": 206, \"mouse\": 2, \"mu_intercept_per_group\": 8.800888061523438, \"sigma_intercept_per_group\": 0.2650328278541565, \"sigma_obs\": 152.61622619628906, \"slope\": -0.07392597943544388, \"chain\": 1, \"draw\": 6}, {\"draws\": 206, \"mouse\": 3, \"mu_intercept_per_group\": 8.280722618103027, \"sigma_intercept_per_group\": 0.2650328278541565, \"sigma_obs\": 152.61622619628906, \"slope\": -0.07392597943544388, \"chain\": 1, \"draw\": 6}, {\"draws\": 206, \"mouse\": 4, \"mu_intercept_per_group\": 7.657410621643066, \"sigma_intercept_per_group\": 0.2650328278541565, \"sigma_obs\": 152.61622619628906, \"slope\": -0.07392597943544388, \"chain\": 1, \"draw\": 6}, {\"draws\": 206, \"mouse\": 5, \"mu_intercept_per_group\": 7.3643012046813965, \"sigma_intercept_per_group\": 0.2650328278541565, \"sigma_obs\": 152.61622619628906, \"slope\": -0.07392597943544388, \"chain\": 1, \"draw\": 6}, {\"draws\": 206, \"mouse\": 6, \"mu_intercept_per_group\": 6.833577632904053, \"sigma_intercept_per_group\": 0.2650328278541565, \"sigma_obs\": 152.61622619628906, \"slope\": -0.07392597943544388, \"chain\": 1, \"draw\": 6}, {\"draws\": 206, \"mouse\": 7, \"mu_intercept_per_group\": 6.392580509185791, \"sigma_intercept_per_group\": 0.2650328278541565, \"sigma_obs\": 152.61622619628906, \"slope\": -0.07392597943544388, \"chain\": 1, \"draw\": 6}, {\"draws\": 207, \"mouse\": 0, \"mu_intercept_per_group\": 9.067222595214844, \"sigma_intercept_per_group\": 0.26426732540130615, \"sigma_obs\": 152.80401611328125, \"slope\": -0.07441011816263199, \"chain\": 1, \"draw\": 7}, {\"draws\": 207, \"mouse\": 1, \"mu_intercept_per_group\": 8.685667037963867, \"sigma_intercept_per_group\": 0.26426732540130615, \"sigma_obs\": 152.80401611328125, \"slope\": -0.07441011816263199, \"chain\": 1, \"draw\": 7}, {\"draws\": 207, \"mouse\": 2, \"mu_intercept_per_group\": 8.626333236694336, \"sigma_intercept_per_group\": 0.26426732540130615, \"sigma_obs\": 152.80401611328125, \"slope\": -0.07441011816263199, \"chain\": 1, \"draw\": 7}, {\"draws\": 207, \"mouse\": 3, \"mu_intercept_per_group\": 8.142875671386719, \"sigma_intercept_per_group\": 0.26426732540130615, \"sigma_obs\": 152.80401611328125, \"slope\": -0.07441011816263199, \"chain\": 1, \"draw\": 7}, {\"draws\": 207, \"mouse\": 4, \"mu_intercept_per_group\": 7.8534417152404785, \"sigma_intercept_per_group\": 0.26426732540130615, \"sigma_obs\": 152.80401611328125, \"slope\": -0.07441011816263199, \"chain\": 1, \"draw\": 7}, {\"draws\": 207, \"mouse\": 5, \"mu_intercept_per_group\": 7.602132320404053, \"sigma_intercept_per_group\": 0.26426732540130615, \"sigma_obs\": 152.80401611328125, \"slope\": -0.07441011816263199, \"chain\": 1, \"draw\": 7}, {\"draws\": 207, \"mouse\": 6, \"mu_intercept_per_group\": 6.925667762756348, \"sigma_intercept_per_group\": 0.26426732540130615, \"sigma_obs\": 152.80401611328125, \"slope\": -0.07441011816263199, \"chain\": 1, \"draw\": 7}, {\"draws\": 207, \"mouse\": 7, \"mu_intercept_per_group\": 6.40448522567749, \"sigma_intercept_per_group\": 0.26426732540130615, \"sigma_obs\": 152.80401611328125, \"slope\": -0.07441011816263199, \"chain\": 1, \"draw\": 7}, {\"draws\": 208, \"mouse\": 0, \"mu_intercept_per_group\": 8.423473358154297, \"sigma_intercept_per_group\": 0.2981353998184204, \"sigma_obs\": 164.99111938476562, \"slope\": -0.07203955948352814, \"chain\": 1, \"draw\": 8}, {\"draws\": 208, \"mouse\": 1, \"mu_intercept_per_group\": 8.130553245544434, \"sigma_intercept_per_group\": 0.2981353998184204, \"sigma_obs\": 164.99111938476562, \"slope\": -0.07203955948352814, \"chain\": 1, \"draw\": 8}, {\"draws\": 208, \"mouse\": 2, \"mu_intercept_per_group\": 8.061010360717773, \"sigma_intercept_per_group\": 0.2981353998184204, \"sigma_obs\": 164.99111938476562, \"slope\": -0.07203955948352814, \"chain\": 1, \"draw\": 8}, {\"draws\": 208, \"mouse\": 3, \"mu_intercept_per_group\": 7.470335960388184, \"sigma_intercept_per_group\": 0.2981353998184204, \"sigma_obs\": 164.99111938476562, \"slope\": -0.07203955948352814, \"chain\": 1, \"draw\": 8}, {\"draws\": 208, \"mouse\": 4, \"mu_intercept_per_group\": 7.282719612121582, \"sigma_intercept_per_group\": 0.2981353998184204, \"sigma_obs\": 164.99111938476562, \"slope\": -0.07203955948352814, \"chain\": 1, \"draw\": 8}, {\"draws\": 208, \"mouse\": 5, \"mu_intercept_per_group\": 7.1358323097229, \"sigma_intercept_per_group\": 0.2981353998184204, \"sigma_obs\": 164.99111938476562, \"slope\": -0.07203955948352814, \"chain\": 1, \"draw\": 8}, {\"draws\": 208, \"mouse\": 6, \"mu_intercept_per_group\": 6.309218883514404, \"sigma_intercept_per_group\": 0.2981353998184204, \"sigma_obs\": 164.99111938476562, \"slope\": -0.07203955948352814, \"chain\": 1, \"draw\": 8}, {\"draws\": 208, \"mouse\": 7, \"mu_intercept_per_group\": 6.039029121398926, \"sigma_intercept_per_group\": 0.2981353998184204, \"sigma_obs\": 164.99111938476562, \"slope\": -0.07203955948352814, \"chain\": 1, \"draw\": 8}, {\"draws\": 209, \"mouse\": 0, \"mu_intercept_per_group\": 8.486133575439453, \"sigma_intercept_per_group\": 0.2935279905796051, \"sigma_obs\": 165.76922607421875, \"slope\": -0.072627492249012, \"chain\": 1, \"draw\": 9}, {\"draws\": 209, \"mouse\": 1, \"mu_intercept_per_group\": 8.351999282836914, \"sigma_intercept_per_group\": 0.2935279905796051, \"sigma_obs\": 165.76922607421875, \"slope\": -0.072627492249012, \"chain\": 1, \"draw\": 9}, {\"draws\": 209, \"mouse\": 2, \"mu_intercept_per_group\": 7.906220436096191, \"sigma_intercept_per_group\": 0.2935279905796051, \"sigma_obs\": 165.76922607421875, \"slope\": -0.072627492249012, \"chain\": 1, \"draw\": 9}, {\"draws\": 209, \"mouse\": 3, \"mu_intercept_per_group\": 7.464179992675781, \"sigma_intercept_per_group\": 0.2935279905796051, \"sigma_obs\": 165.76922607421875, \"slope\": -0.072627492249012, \"chain\": 1, \"draw\": 9}, {\"draws\": 209, \"mouse\": 4, \"mu_intercept_per_group\": 7.425296306610107, \"sigma_intercept_per_group\": 0.2935279905796051, \"sigma_obs\": 165.76922607421875, \"slope\": -0.072627492249012, \"chain\": 1, \"draw\": 9}, {\"draws\": 209, \"mouse\": 5, \"mu_intercept_per_group\": 6.806064128875732, \"sigma_intercept_per_group\": 0.2935279905796051, \"sigma_obs\": 165.76922607421875, \"slope\": -0.072627492249012, \"chain\": 1, \"draw\": 9}, {\"draws\": 209, \"mouse\": 6, \"mu_intercept_per_group\": 6.4991865158081055, \"sigma_intercept_per_group\": 0.2935279905796051, \"sigma_obs\": 165.76922607421875, \"slope\": -0.072627492249012, \"chain\": 1, \"draw\": 9}, {\"draws\": 209, \"mouse\": 7, \"mu_intercept_per_group\": 6.146899223327637, \"sigma_intercept_per_group\": 0.2935279905796051, \"sigma_obs\": 165.76922607421875, \"slope\": -0.072627492249012, \"chain\": 1, \"draw\": 9}, {\"draws\": 210, \"mouse\": 0, \"mu_intercept_per_group\": 9.893180847167969, \"sigma_intercept_per_group\": 0.2602999210357666, \"sigma_obs\": 168.05934143066406, \"slope\": -0.0805349200963974, \"chain\": 1, \"draw\": 10}, {\"draws\": 210, \"mouse\": 1, \"mu_intercept_per_group\": 9.540558815002441, \"sigma_intercept_per_group\": 0.2602999210357666, \"sigma_obs\": 168.05934143066406, \"slope\": -0.0805349200963974, \"chain\": 1, \"draw\": 10}, {\"draws\": 210, \"mouse\": 2, \"mu_intercept_per_group\": 9.068760871887207, \"sigma_intercept_per_group\": 0.2602999210357666, \"sigma_obs\": 168.05934143066406, \"slope\": -0.0805349200963974, \"chain\": 1, \"draw\": 10}, {\"draws\": 210, \"mouse\": 3, \"mu_intercept_per_group\": 8.750154495239258, \"sigma_intercept_per_group\": 0.2602999210357666, \"sigma_obs\": 168.05934143066406, \"slope\": -0.0805349200963974, \"chain\": 1, \"draw\": 10}, {\"draws\": 210, \"mouse\": 4, \"mu_intercept_per_group\": 8.439169883728027, \"sigma_intercept_per_group\": 0.2602999210357666, \"sigma_obs\": 168.05934143066406, \"slope\": -0.0805349200963974, \"chain\": 1, \"draw\": 10}, {\"draws\": 210, \"mouse\": 5, \"mu_intercept_per_group\": 7.875215530395508, \"sigma_intercept_per_group\": 0.2602999210357666, \"sigma_obs\": 168.05934143066406, \"slope\": -0.0805349200963974, \"chain\": 1, \"draw\": 10}, {\"draws\": 210, \"mouse\": 6, \"mu_intercept_per_group\": 7.508004665374756, \"sigma_intercept_per_group\": 0.2602999210357666, \"sigma_obs\": 168.05934143066406, \"slope\": -0.0805349200963974, \"chain\": 1, \"draw\": 10}, {\"draws\": 210, \"mouse\": 7, \"mu_intercept_per_group\": 6.887652397155762, \"sigma_intercept_per_group\": 0.2602999210357666, \"sigma_obs\": 168.05934143066406, \"slope\": -0.0805349200963974, \"chain\": 1, \"draw\": 10}, {\"draws\": 211, \"mouse\": 0, \"mu_intercept_per_group\": 9.670361518859863, \"sigma_intercept_per_group\": 0.26288852095603943, \"sigma_obs\": 169.4735107421875, \"slope\": -0.08015573769807816, \"chain\": 1, \"draw\": 11}, {\"draws\": 211, \"mouse\": 1, \"mu_intercept_per_group\": 9.258430480957031, \"sigma_intercept_per_group\": 0.26288852095603943, \"sigma_obs\": 169.4735107421875, \"slope\": -0.08015573769807816, \"chain\": 1, \"draw\": 11}, {\"draws\": 211, \"mouse\": 2, \"mu_intercept_per_group\": 9.263687133789062, \"sigma_intercept_per_group\": 0.26288852095603943, \"sigma_obs\": 169.4735107421875, \"slope\": -0.08015573769807816, \"chain\": 1, \"draw\": 11}, {\"draws\": 211, \"mouse\": 3, \"mu_intercept_per_group\": 8.550195693969727, \"sigma_intercept_per_group\": 0.26288852095603943, \"sigma_obs\": 169.4735107421875, \"slope\": -0.08015573769807816, \"chain\": 1, \"draw\": 11}, {\"draws\": 211, \"mouse\": 4, \"mu_intercept_per_group\": 8.533559799194336, \"sigma_intercept_per_group\": 0.26288852095603943, \"sigma_obs\": 169.4735107421875, \"slope\": -0.08015573769807816, \"chain\": 1, \"draw\": 11}, {\"draws\": 211, \"mouse\": 5, \"mu_intercept_per_group\": 7.802779197692871, \"sigma_intercept_per_group\": 0.26288852095603943, \"sigma_obs\": 169.4735107421875, \"slope\": -0.08015573769807816, \"chain\": 1, \"draw\": 11}, {\"draws\": 211, \"mouse\": 6, \"mu_intercept_per_group\": 7.457581520080566, \"sigma_intercept_per_group\": 0.26288852095603943, \"sigma_obs\": 169.4735107421875, \"slope\": -0.08015573769807816, \"chain\": 1, \"draw\": 11}, {\"draws\": 211, \"mouse\": 7, \"mu_intercept_per_group\": 6.912327289581299, \"sigma_intercept_per_group\": 0.26288852095603943, \"sigma_obs\": 169.4735107421875, \"slope\": -0.08015573769807816, \"chain\": 1, \"draw\": 11}, {\"draws\": 212, \"mouse\": 0, \"mu_intercept_per_group\": 7.973079204559326, \"sigma_intercept_per_group\": 0.31769898533821106, \"sigma_obs\": 169.89822387695312, \"slope\": -0.07896188646554947, \"chain\": 1, \"draw\": 12}, {\"draws\": 212, \"mouse\": 1, \"mu_intercept_per_group\": 7.836396217346191, \"sigma_intercept_per_group\": 0.31769898533821106, \"sigma_obs\": 169.89822387695312, \"slope\": -0.07896188646554947, \"chain\": 1, \"draw\": 12}, {\"draws\": 212, \"mouse\": 2, \"mu_intercept_per_group\": 7.395638465881348, \"sigma_intercept_per_group\": 0.31769898533821106, \"sigma_obs\": 169.89822387695312, \"slope\": -0.07896188646554947, \"chain\": 1, \"draw\": 12}, {\"draws\": 212, \"mouse\": 3, \"mu_intercept_per_group\": 7.022419452667236, \"sigma_intercept_per_group\": 0.31769898533821106, \"sigma_obs\": 169.89822387695312, \"slope\": -0.07896188646554947, \"chain\": 1, \"draw\": 12}, {\"draws\": 212, \"mouse\": 4, \"mu_intercept_per_group\": 6.8831658363342285, \"sigma_intercept_per_group\": 0.31769898533821106, \"sigma_obs\": 169.89822387695312, \"slope\": -0.07896188646554947, \"chain\": 1, \"draw\": 12}, {\"draws\": 212, \"mouse\": 5, \"mu_intercept_per_group\": 6.551790237426758, \"sigma_intercept_per_group\": 0.31769898533821106, \"sigma_obs\": 169.89822387695312, \"slope\": -0.07896188646554947, \"chain\": 1, \"draw\": 12}, {\"draws\": 212, \"mouse\": 6, \"mu_intercept_per_group\": 6.01740837097168, \"sigma_intercept_per_group\": 0.31769898533821106, \"sigma_obs\": 169.89822387695312, \"slope\": -0.07896188646554947, \"chain\": 1, \"draw\": 12}, {\"draws\": 212, \"mouse\": 7, \"mu_intercept_per_group\": 5.733466148376465, \"sigma_intercept_per_group\": 0.31769898533821106, \"sigma_obs\": 169.89822387695312, \"slope\": -0.07896188646554947, \"chain\": 1, \"draw\": 12}, {\"draws\": 213, \"mouse\": 0, \"mu_intercept_per_group\": 7.999101161956787, \"sigma_intercept_per_group\": 0.3178567886352539, \"sigma_obs\": 169.8755340576172, \"slope\": -0.07898466289043427, \"chain\": 1, \"draw\": 13}, {\"draws\": 213, \"mouse\": 1, \"mu_intercept_per_group\": 7.5623459815979, \"sigma_intercept_per_group\": 0.3178567886352539, \"sigma_obs\": 169.8755340576172, \"slope\": -0.07898466289043427, \"chain\": 1, \"draw\": 13}, {\"draws\": 213, \"mouse\": 2, \"mu_intercept_per_group\": 7.58742094039917, \"sigma_intercept_per_group\": 0.3178567886352539, \"sigma_obs\": 169.8755340576172, \"slope\": -0.07898466289043427, \"chain\": 1, \"draw\": 13}, {\"draws\": 213, \"mouse\": 3, \"mu_intercept_per_group\": 7.213669300079346, \"sigma_intercept_per_group\": 0.3178567886352539, \"sigma_obs\": 169.8755340576172, \"slope\": -0.07898466289043427, \"chain\": 1, \"draw\": 13}, {\"draws\": 213, \"mouse\": 4, \"mu_intercept_per_group\": 6.87556791305542, \"sigma_intercept_per_group\": 0.3178567886352539, \"sigma_obs\": 169.8755340576172, \"slope\": -0.07898466289043427, \"chain\": 1, \"draw\": 13}, {\"draws\": 213, \"mouse\": 5, \"mu_intercept_per_group\": 6.355483055114746, \"sigma_intercept_per_group\": 0.3178567886352539, \"sigma_obs\": 169.8755340576172, \"slope\": -0.07898466289043427, \"chain\": 1, \"draw\": 13}, {\"draws\": 213, \"mouse\": 6, \"mu_intercept_per_group\": 6.134898662567139, \"sigma_intercept_per_group\": 0.3178567886352539, \"sigma_obs\": 169.8755340576172, \"slope\": -0.07898466289043427, \"chain\": 1, \"draw\": 13}, {\"draws\": 213, \"mouse\": 7, \"mu_intercept_per_group\": 5.610433578491211, \"sigma_intercept_per_group\": 0.3178567886352539, \"sigma_obs\": 169.8755340576172, \"slope\": -0.07898466289043427, \"chain\": 1, \"draw\": 13}, {\"draws\": 214, \"mouse\": 0, \"mu_intercept_per_group\": 8.552762031555176, \"sigma_intercept_per_group\": 0.29325467348098755, \"sigma_obs\": 167.0622100830078, \"slope\": -0.07651317119598389, \"chain\": 1, \"draw\": 14}, {\"draws\": 214, \"mouse\": 1, \"mu_intercept_per_group\": 8.562359809875488, \"sigma_intercept_per_group\": 0.29325467348098755, \"sigma_obs\": 167.0622100830078, \"slope\": -0.07651317119598389, \"chain\": 1, \"draw\": 14}, {\"draws\": 214, \"mouse\": 2, \"mu_intercept_per_group\": 8.076353073120117, \"sigma_intercept_per_group\": 0.29325467348098755, \"sigma_obs\": 167.0622100830078, \"slope\": -0.07651317119598389, \"chain\": 1, \"draw\": 14}, {\"draws\": 214, \"mouse\": 3, \"mu_intercept_per_group\": 7.655981063842773, \"sigma_intercept_per_group\": 0.29325467348098755, \"sigma_obs\": 167.0622100830078, \"slope\": -0.07651317119598389, \"chain\": 1, \"draw\": 14}, {\"draws\": 214, \"mouse\": 4, \"mu_intercept_per_group\": 7.461544036865234, \"sigma_intercept_per_group\": 0.29325467348098755, \"sigma_obs\": 167.0622100830078, \"slope\": -0.07651317119598389, \"chain\": 1, \"draw\": 14}, {\"draws\": 214, \"mouse\": 5, \"mu_intercept_per_group\": 6.818528652191162, \"sigma_intercept_per_group\": 0.29325467348098755, \"sigma_obs\": 167.0622100830078, \"slope\": -0.07651317119598389, \"chain\": 1, \"draw\": 14}, {\"draws\": 214, \"mouse\": 6, \"mu_intercept_per_group\": 6.605119705200195, \"sigma_intercept_per_group\": 0.29325467348098755, \"sigma_obs\": 167.0622100830078, \"slope\": -0.07651317119598389, \"chain\": 1, \"draw\": 14}, {\"draws\": 214, \"mouse\": 7, \"mu_intercept_per_group\": 5.944061756134033, \"sigma_intercept_per_group\": 0.29325467348098755, \"sigma_obs\": 167.0622100830078, \"slope\": -0.07651317119598389, \"chain\": 1, \"draw\": 14}, {\"draws\": 215, \"mouse\": 0, \"mu_intercept_per_group\": 8.601069450378418, \"sigma_intercept_per_group\": 0.2902737855911255, \"sigma_obs\": 167.10888671875, \"slope\": -0.07637671381235123, \"chain\": 1, \"draw\": 15}, {\"draws\": 215, \"mouse\": 1, \"mu_intercept_per_group\": 8.626971244812012, \"sigma_intercept_per_group\": 0.2902737855911255, \"sigma_obs\": 167.10888671875, \"slope\": -0.07637671381235123, \"chain\": 1, \"draw\": 15}, {\"draws\": 215, \"mouse\": 2, \"mu_intercept_per_group\": 7.985941410064697, \"sigma_intercept_per_group\": 0.2902737855911255, \"sigma_obs\": 167.10888671875, \"slope\": -0.07637671381235123, \"chain\": 1, \"draw\": 15}, {\"draws\": 215, \"mouse\": 3, \"mu_intercept_per_group\": 7.654144287109375, \"sigma_intercept_per_group\": 0.2902737855911255, \"sigma_obs\": 167.10888671875, \"slope\": -0.07637671381235123, \"chain\": 1, \"draw\": 15}, {\"draws\": 215, \"mouse\": 4, \"mu_intercept_per_group\": 7.40828800201416, \"sigma_intercept_per_group\": 0.2902737855911255, \"sigma_obs\": 167.10888671875, \"slope\": -0.07637671381235123, \"chain\": 1, \"draw\": 15}, {\"draws\": 215, \"mouse\": 5, \"mu_intercept_per_group\": 6.798896789550781, \"sigma_intercept_per_group\": 0.2902737855911255, \"sigma_obs\": 167.10888671875, \"slope\": -0.07637671381235123, \"chain\": 1, \"draw\": 15}, {\"draws\": 215, \"mouse\": 6, \"mu_intercept_per_group\": 6.68356990814209, \"sigma_intercept_per_group\": 0.2902737855911255, \"sigma_obs\": 167.10888671875, \"slope\": -0.07637671381235123, \"chain\": 1, \"draw\": 15}, {\"draws\": 215, \"mouse\": 7, \"mu_intercept_per_group\": 5.987796306610107, \"sigma_intercept_per_group\": 0.2902737855911255, \"sigma_obs\": 167.10888671875, \"slope\": -0.07637671381235123, \"chain\": 1, \"draw\": 15}, {\"draws\": 216, \"mouse\": 0, \"mu_intercept_per_group\": 10.963348388671875, \"sigma_intercept_per_group\": 0.22225476801395416, \"sigma_obs\": 159.7667236328125, \"slope\": -0.08522084355354309, \"chain\": 1, \"draw\": 16}, {\"draws\": 216, \"mouse\": 1, \"mu_intercept_per_group\": 10.591510772705078, \"sigma_intercept_per_group\": 0.22225476801395416, \"sigma_obs\": 159.7667236328125, \"slope\": -0.08522084355354309, \"chain\": 1, \"draw\": 16}, {\"draws\": 216, \"mouse\": 2, \"mu_intercept_per_group\": 10.725897789001465, \"sigma_intercept_per_group\": 0.22225476801395416, \"sigma_obs\": 159.7667236328125, \"slope\": -0.08522084355354309, \"chain\": 1, \"draw\": 16}, {\"draws\": 216, \"mouse\": 3, \"mu_intercept_per_group\": 9.699362754821777, \"sigma_intercept_per_group\": 0.22225476801395416, \"sigma_obs\": 159.7667236328125, \"slope\": -0.08522084355354309, \"chain\": 1, \"draw\": 16}, {\"draws\": 216, \"mouse\": 4, \"mu_intercept_per_group\": 9.71195125579834, \"sigma_intercept_per_group\": 0.22225476801395416, \"sigma_obs\": 159.7667236328125, \"slope\": -0.08522084355354309, \"chain\": 1, \"draw\": 16}, {\"draws\": 216, \"mouse\": 5, \"mu_intercept_per_group\": 9.321340560913086, \"sigma_intercept_per_group\": 0.22225476801395416, \"sigma_obs\": 159.7667236328125, \"slope\": -0.08522084355354309, \"chain\": 1, \"draw\": 16}, {\"draws\": 216, \"mouse\": 6, \"mu_intercept_per_group\": 8.682634353637695, \"sigma_intercept_per_group\": 0.22225476801395416, \"sigma_obs\": 159.7667236328125, \"slope\": -0.08522084355354309, \"chain\": 1, \"draw\": 16}, {\"draws\": 216, \"mouse\": 7, \"mu_intercept_per_group\": 8.075608253479004, \"sigma_intercept_per_group\": 0.22225476801395416, \"sigma_obs\": 159.7667236328125, \"slope\": -0.08522084355354309, \"chain\": 1, \"draw\": 16}, {\"draws\": 217, \"mouse\": 0, \"mu_intercept_per_group\": 11.014545440673828, \"sigma_intercept_per_group\": 0.22381862998008728, \"sigma_obs\": 164.5146484375, \"slope\": -0.06617056578397751, \"chain\": 1, \"draw\": 17}, {\"draws\": 217, \"mouse\": 1, \"mu_intercept_per_group\": 10.866835594177246, \"sigma_intercept_per_group\": 0.22381862998008728, \"sigma_obs\": 164.5146484375, \"slope\": -0.06617056578397751, \"chain\": 1, \"draw\": 17}, {\"draws\": 217, \"mouse\": 2, \"mu_intercept_per_group\": 10.300581932067871, \"sigma_intercept_per_group\": 0.22381862998008728, \"sigma_obs\": 164.5146484375, \"slope\": -0.06617056578397751, \"chain\": 1, \"draw\": 17}, {\"draws\": 217, \"mouse\": 3, \"mu_intercept_per_group\": 10.075753211975098, \"sigma_intercept_per_group\": 0.22381862998008728, \"sigma_obs\": 164.5146484375, \"slope\": -0.06617056578397751, \"chain\": 1, \"draw\": 17}, {\"draws\": 217, \"mouse\": 4, \"mu_intercept_per_group\": 9.489540100097656, \"sigma_intercept_per_group\": 0.22381862998008728, \"sigma_obs\": 164.5146484375, \"slope\": -0.06617056578397751, \"chain\": 1, \"draw\": 17}, {\"draws\": 217, \"mouse\": 5, \"mu_intercept_per_group\": 8.738486289978027, \"sigma_intercept_per_group\": 0.22381862998008728, \"sigma_obs\": 164.5146484375, \"slope\": -0.06617056578397751, \"chain\": 1, \"draw\": 17}, {\"draws\": 217, \"mouse\": 6, \"mu_intercept_per_group\": 8.532842636108398, \"sigma_intercept_per_group\": 0.22381862998008728, \"sigma_obs\": 164.5146484375, \"slope\": -0.06617056578397751, \"chain\": 1, \"draw\": 17}, {\"draws\": 217, \"mouse\": 7, \"mu_intercept_per_group\": 7.92553186416626, \"sigma_intercept_per_group\": 0.22381862998008728, \"sigma_obs\": 164.5146484375, \"slope\": -0.06617056578397751, \"chain\": 1, \"draw\": 17}, {\"draws\": 218, \"mouse\": 0, \"mu_intercept_per_group\": 11.47413444519043, \"sigma_intercept_per_group\": 0.22638826072216034, \"sigma_obs\": 179.26953125, \"slope\": -0.06331472098827362, \"chain\": 1, \"draw\": 18}, {\"draws\": 218, \"mouse\": 1, \"mu_intercept_per_group\": 10.86164379119873, \"sigma_intercept_per_group\": 0.22638826072216034, \"sigma_obs\": 179.26953125, \"slope\": -0.06331472098827362, \"chain\": 1, \"draw\": 18}, {\"draws\": 218, \"mouse\": 2, \"mu_intercept_per_group\": 10.757413864135742, \"sigma_intercept_per_group\": 0.22638826072216034, \"sigma_obs\": 179.26953125, \"slope\": -0.06331472098827362, \"chain\": 1, \"draw\": 18}, {\"draws\": 218, \"mouse\": 3, \"mu_intercept_per_group\": 9.789017677307129, \"sigma_intercept_per_group\": 0.22638826072216034, \"sigma_obs\": 179.26953125, \"slope\": -0.06331472098827362, \"chain\": 1, \"draw\": 18}, {\"draws\": 218, \"mouse\": 4, \"mu_intercept_per_group\": 9.934776306152344, \"sigma_intercept_per_group\": 0.22638826072216034, \"sigma_obs\": 179.26953125, \"slope\": -0.06331472098827362, \"chain\": 1, \"draw\": 18}, {\"draws\": 218, \"mouse\": 5, \"mu_intercept_per_group\": 9.397340774536133, \"sigma_intercept_per_group\": 0.22638826072216034, \"sigma_obs\": 179.26953125, \"slope\": -0.06331472098827362, \"chain\": 1, \"draw\": 18}, {\"draws\": 218, \"mouse\": 6, \"mu_intercept_per_group\": 8.846471786499023, \"sigma_intercept_per_group\": 0.22638826072216034, \"sigma_obs\": 179.26953125, \"slope\": -0.06331472098827362, \"chain\": 1, \"draw\": 18}, {\"draws\": 218, \"mouse\": 7, \"mu_intercept_per_group\": 8.332637786865234, \"sigma_intercept_per_group\": 0.22638826072216034, \"sigma_obs\": 179.26953125, \"slope\": -0.06331472098827362, \"chain\": 1, \"draw\": 18}, {\"draws\": 219, \"mouse\": 0, \"mu_intercept_per_group\": 10.346145629882812, \"sigma_intercept_per_group\": 0.23954477906227112, \"sigma_obs\": 161.2203826904297, \"slope\": -0.06049572303891182, \"chain\": 1, \"draw\": 19}, {\"draws\": 219, \"mouse\": 1, \"mu_intercept_per_group\": 9.717293739318848, \"sigma_intercept_per_group\": 0.23954477906227112, \"sigma_obs\": 161.2203826904297, \"slope\": -0.06049572303891182, \"chain\": 1, \"draw\": 19}, {\"draws\": 219, \"mouse\": 2, \"mu_intercept_per_group\": 9.4877290725708, \"sigma_intercept_per_group\": 0.23954477906227112, \"sigma_obs\": 161.2203826904297, \"slope\": -0.06049572303891182, \"chain\": 1, \"draw\": 19}, {\"draws\": 219, \"mouse\": 3, \"mu_intercept_per_group\": 9.040497779846191, \"sigma_intercept_per_group\": 0.23954477906227112, \"sigma_obs\": 161.2203826904297, \"slope\": -0.06049572303891182, \"chain\": 1, \"draw\": 19}, {\"draws\": 219, \"mouse\": 4, \"mu_intercept_per_group\": 9.009912490844727, \"sigma_intercept_per_group\": 0.23954477906227112, \"sigma_obs\": 161.2203826904297, \"slope\": -0.06049572303891182, \"chain\": 1, \"draw\": 19}, {\"draws\": 219, \"mouse\": 5, \"mu_intercept_per_group\": 8.512487411499023, \"sigma_intercept_per_group\": 0.23954477906227112, \"sigma_obs\": 161.2203826904297, \"slope\": -0.06049572303891182, \"chain\": 1, \"draw\": 19}, {\"draws\": 219, \"mouse\": 6, \"mu_intercept_per_group\": 7.796633720397949, \"sigma_intercept_per_group\": 0.23954477906227112, \"sigma_obs\": 161.2203826904297, \"slope\": -0.06049572303891182, \"chain\": 1, \"draw\": 19}, {\"draws\": 219, \"mouse\": 7, \"mu_intercept_per_group\": 7.5130438804626465, \"sigma_intercept_per_group\": 0.23954477906227112, \"sigma_obs\": 161.2203826904297, \"slope\": -0.06049572303891182, \"chain\": 1, \"draw\": 19}, {\"draws\": 220, \"mouse\": 0, \"mu_intercept_per_group\": 10.515423774719238, \"sigma_intercept_per_group\": 0.2323332130908966, \"sigma_obs\": 155.76329040527344, \"slope\": -0.06161078065633774, \"chain\": 1, \"draw\": 20}, {\"draws\": 220, \"mouse\": 1, \"mu_intercept_per_group\": 9.964056015014648, \"sigma_intercept_per_group\": 0.2323332130908966, \"sigma_obs\": 155.76329040527344, \"slope\": -0.06161078065633774, \"chain\": 1, \"draw\": 20}, {\"draws\": 220, \"mouse\": 2, \"mu_intercept_per_group\": 9.724641799926758, \"sigma_intercept_per_group\": 0.2323332130908966, \"sigma_obs\": 155.76329040527344, \"slope\": -0.06161078065633774, \"chain\": 1, \"draw\": 20}, {\"draws\": 220, \"mouse\": 3, \"mu_intercept_per_group\": 9.453821182250977, \"sigma_intercept_per_group\": 0.2323332130908966, \"sigma_obs\": 155.76329040527344, \"slope\": -0.06161078065633774, \"chain\": 1, \"draw\": 20}, {\"draws\": 220, \"mouse\": 4, \"mu_intercept_per_group\": 8.956320762634277, \"sigma_intercept_per_group\": 0.2323332130908966, \"sigma_obs\": 155.76329040527344, \"slope\": -0.06161078065633774, \"chain\": 1, \"draw\": 20}, {\"draws\": 220, \"mouse\": 5, \"mu_intercept_per_group\": 8.384092330932617, \"sigma_intercept_per_group\": 0.2323332130908966, \"sigma_obs\": 155.76329040527344, \"slope\": -0.06161078065633774, \"chain\": 1, \"draw\": 20}, {\"draws\": 220, \"mouse\": 6, \"mu_intercept_per_group\": 8.08166790008545, \"sigma_intercept_per_group\": 0.2323332130908966, \"sigma_obs\": 155.76329040527344, \"slope\": -0.06161078065633774, \"chain\": 1, \"draw\": 20}, {\"draws\": 220, \"mouse\": 7, \"mu_intercept_per_group\": 7.460705280303955, \"sigma_intercept_per_group\": 0.2323332130908966, \"sigma_obs\": 155.76329040527344, \"slope\": -0.06161078065633774, \"chain\": 1, \"draw\": 20}, {\"draws\": 221, \"mouse\": 0, \"mu_intercept_per_group\": 10.634040832519531, \"sigma_intercept_per_group\": 0.23062734305858612, \"sigma_obs\": 156.0670623779297, \"slope\": -0.06123007461428642, \"chain\": 1, \"draw\": 21}, {\"draws\": 221, \"mouse\": 1, \"mu_intercept_per_group\": 10.217379570007324, \"sigma_intercept_per_group\": 0.23062734305858612, \"sigma_obs\": 156.0670623779297, \"slope\": -0.06123007461428642, \"chain\": 1, \"draw\": 21}, {\"draws\": 221, \"mouse\": 2, \"mu_intercept_per_group\": 10.051005363464355, \"sigma_intercept_per_group\": 0.23062734305858612, \"sigma_obs\": 156.0670623779297, \"slope\": -0.06123007461428642, \"chain\": 1, \"draw\": 21}, {\"draws\": 221, \"mouse\": 3, \"mu_intercept_per_group\": 9.49742603302002, \"sigma_intercept_per_group\": 0.23062734305858612, \"sigma_obs\": 156.0670623779297, \"slope\": -0.06123007461428642, \"chain\": 1, \"draw\": 21}, {\"draws\": 221, \"mouse\": 4, \"mu_intercept_per_group\": 9.103635787963867, \"sigma_intercept_per_group\": 0.23062734305858612, \"sigma_obs\": 156.0670623779297, \"slope\": -0.06123007461428642, \"chain\": 1, \"draw\": 21}, {\"draws\": 221, \"mouse\": 5, \"mu_intercept_per_group\": 8.632837295532227, \"sigma_intercept_per_group\": 0.23062734305858612, \"sigma_obs\": 156.0670623779297, \"slope\": -0.06123007461428642, \"chain\": 1, \"draw\": 21}, {\"draws\": 221, \"mouse\": 6, \"mu_intercept_per_group\": 7.676592826843262, \"sigma_intercept_per_group\": 0.23062734305858612, \"sigma_obs\": 156.0670623779297, \"slope\": -0.06123007461428642, \"chain\": 1, \"draw\": 21}, {\"draws\": 221, \"mouse\": 7, \"mu_intercept_per_group\": 7.383272647857666, \"sigma_intercept_per_group\": 0.23062734305858612, \"sigma_obs\": 156.0670623779297, \"slope\": -0.06123007461428642, \"chain\": 1, \"draw\": 21}, {\"draws\": 222, \"mouse\": 0, \"mu_intercept_per_group\": 10.54057502746582, \"sigma_intercept_per_group\": 0.22865848243236542, \"sigma_obs\": 150.57403564453125, \"slope\": -0.06878364086151123, \"chain\": 1, \"draw\": 22}, {\"draws\": 222, \"mouse\": 1, \"mu_intercept_per_group\": 10.177375793457031, \"sigma_intercept_per_group\": 0.22865848243236542, \"sigma_obs\": 150.57403564453125, \"slope\": -0.06878364086151123, \"chain\": 1, \"draw\": 22}, {\"draws\": 222, \"mouse\": 2, \"mu_intercept_per_group\": 9.915014266967773, \"sigma_intercept_per_group\": 0.22865848243236542, \"sigma_obs\": 150.57403564453125, \"slope\": -0.06878364086151123, \"chain\": 1, \"draw\": 22}, {\"draws\": 222, \"mouse\": 3, \"mu_intercept_per_group\": 9.164777755737305, \"sigma_intercept_per_group\": 0.22865848243236542, \"sigma_obs\": 150.57403564453125, \"slope\": -0.06878364086151123, \"chain\": 1, \"draw\": 22}, {\"draws\": 222, \"mouse\": 4, \"mu_intercept_per_group\": 8.806466102600098, \"sigma_intercept_per_group\": 0.22865848243236542, \"sigma_obs\": 150.57403564453125, \"slope\": -0.06878364086151123, \"chain\": 1, \"draw\": 22}, {\"draws\": 222, \"mouse\": 5, \"mu_intercept_per_group\": 8.337839126586914, \"sigma_intercept_per_group\": 0.22865848243236542, \"sigma_obs\": 150.57403564453125, \"slope\": -0.06878364086151123, \"chain\": 1, \"draw\": 22}, {\"draws\": 222, \"mouse\": 6, \"mu_intercept_per_group\": 7.810216426849365, \"sigma_intercept_per_group\": 0.22865848243236542, \"sigma_obs\": 150.57403564453125, \"slope\": -0.06878364086151123, \"chain\": 1, \"draw\": 22}, {\"draws\": 222, \"mouse\": 7, \"mu_intercept_per_group\": 7.459445476531982, \"sigma_intercept_per_group\": 0.22865848243236542, \"sigma_obs\": 150.57403564453125, \"slope\": -0.06878364086151123, \"chain\": 1, \"draw\": 22}, {\"draws\": 223, \"mouse\": 0, \"mu_intercept_per_group\": 9.458843231201172, \"sigma_intercept_per_group\": 0.25818055868148804, \"sigma_obs\": 155.8154296875, \"slope\": -0.07251846790313721, \"chain\": 1, \"draw\": 23}, {\"draws\": 223, \"mouse\": 1, \"mu_intercept_per_group\": 9.304788589477539, \"sigma_intercept_per_group\": 0.25818055868148804, \"sigma_obs\": 155.8154296875, \"slope\": -0.07251846790313721, \"chain\": 1, \"draw\": 23}, {\"draws\": 223, \"mouse\": 2, \"mu_intercept_per_group\": 8.790209770202637, \"sigma_intercept_per_group\": 0.25818055868148804, \"sigma_obs\": 155.8154296875, \"slope\": -0.07251846790313721, \"chain\": 1, \"draw\": 23}, {\"draws\": 223, \"mouse\": 3, \"mu_intercept_per_group\": 8.573615074157715, \"sigma_intercept_per_group\": 0.25818055868148804, \"sigma_obs\": 155.8154296875, \"slope\": -0.07251846790313721, \"chain\": 1, \"draw\": 23}, {\"draws\": 223, \"mouse\": 4, \"mu_intercept_per_group\": 8.189006805419922, \"sigma_intercept_per_group\": 0.25818055868148804, \"sigma_obs\": 155.8154296875, \"slope\": -0.07251846790313721, \"chain\": 1, \"draw\": 23}, {\"draws\": 223, \"mouse\": 5, \"mu_intercept_per_group\": 7.985067844390869, \"sigma_intercept_per_group\": 0.25818055868148804, \"sigma_obs\": 155.8154296875, \"slope\": -0.07251846790313721, \"chain\": 1, \"draw\": 23}, {\"draws\": 223, \"mouse\": 6, \"mu_intercept_per_group\": 7.194474220275879, \"sigma_intercept_per_group\": 0.25818055868148804, \"sigma_obs\": 155.8154296875, \"slope\": -0.07251846790313721, \"chain\": 1, \"draw\": 23}, {\"draws\": 223, \"mouse\": 7, \"mu_intercept_per_group\": 6.926297664642334, \"sigma_intercept_per_group\": 0.25818055868148804, \"sigma_obs\": 155.8154296875, \"slope\": -0.07251846790313721, \"chain\": 1, \"draw\": 23}, {\"draws\": 224, \"mouse\": 0, \"mu_intercept_per_group\": 9.825448989868164, \"sigma_intercept_per_group\": 0.24918025732040405, \"sigma_obs\": 148.98558044433594, \"slope\": -0.07686817646026611, \"chain\": 1, \"draw\": 24}, {\"draws\": 224, \"mouse\": 1, \"mu_intercept_per_group\": 9.095338821411133, \"sigma_intercept_per_group\": 0.24918025732040405, \"sigma_obs\": 148.98558044433594, \"slope\": -0.07686817646026611, \"chain\": 1, \"draw\": 24}, {\"draws\": 224, \"mouse\": 2, \"mu_intercept_per_group\": 9.064371109008789, \"sigma_intercept_per_group\": 0.24918025732040405, \"sigma_obs\": 148.98558044433594, \"slope\": -0.07686817646026611, \"chain\": 1, \"draw\": 24}, {\"draws\": 224, \"mouse\": 3, \"mu_intercept_per_group\": 8.331624984741211, \"sigma_intercept_per_group\": 0.24918025732040405, \"sigma_obs\": 148.98558044433594, \"slope\": -0.07686817646026611, \"chain\": 1, \"draw\": 24}, {\"draws\": 224, \"mouse\": 4, \"mu_intercept_per_group\": 8.258512496948242, \"sigma_intercept_per_group\": 0.24918025732040405, \"sigma_obs\": 148.98558044433594, \"slope\": -0.07686817646026611, \"chain\": 1, \"draw\": 24}, {\"draws\": 224, \"mouse\": 5, \"mu_intercept_per_group\": 7.861319541931152, \"sigma_intercept_per_group\": 0.24918025732040405, \"sigma_obs\": 148.98558044433594, \"slope\": -0.07686817646026611, \"chain\": 1, \"draw\": 24}, {\"draws\": 224, \"mouse\": 6, \"mu_intercept_per_group\": 7.11163330078125, \"sigma_intercept_per_group\": 0.24918025732040405, \"sigma_obs\": 148.98558044433594, \"slope\": -0.07686817646026611, \"chain\": 1, \"draw\": 24}, {\"draws\": 224, \"mouse\": 7, \"mu_intercept_per_group\": 6.980116367340088, \"sigma_intercept_per_group\": 0.24918025732040405, \"sigma_obs\": 148.98558044433594, \"slope\": -0.07686817646026611, \"chain\": 1, \"draw\": 24}, {\"draws\": 225, \"mouse\": 0, \"mu_intercept_per_group\": 10.127419471740723, \"sigma_intercept_per_group\": 0.24531222879886627, \"sigma_obs\": 154.3313751220703, \"slope\": -0.07566844671964645, \"chain\": 1, \"draw\": 25}, {\"draws\": 225, \"mouse\": 1, \"mu_intercept_per_group\": 9.317757606506348, \"sigma_intercept_per_group\": 0.24531222879886627, \"sigma_obs\": 154.3313751220703, \"slope\": -0.07566844671964645, \"chain\": 1, \"draw\": 25}, {\"draws\": 225, \"mouse\": 2, \"mu_intercept_per_group\": 9.169636726379395, \"sigma_intercept_per_group\": 0.24531222879886627, \"sigma_obs\": 154.3313751220703, \"slope\": -0.07566844671964645, \"chain\": 1, \"draw\": 25}, {\"draws\": 225, \"mouse\": 3, \"mu_intercept_per_group\": 9.058475494384766, \"sigma_intercept_per_group\": 0.24531222879886627, \"sigma_obs\": 154.3313751220703, \"slope\": -0.07566844671964645, \"chain\": 1, \"draw\": 25}, {\"draws\": 225, \"mouse\": 4, \"mu_intercept_per_group\": 8.597349166870117, \"sigma_intercept_per_group\": 0.24531222879886627, \"sigma_obs\": 154.3313751220703, \"slope\": -0.07566844671964645, \"chain\": 1, \"draw\": 25}, {\"draws\": 225, \"mouse\": 5, \"mu_intercept_per_group\": 7.947408676147461, \"sigma_intercept_per_group\": 0.24531222879886627, \"sigma_obs\": 154.3313751220703, \"slope\": -0.07566844671964645, \"chain\": 1, \"draw\": 25}, {\"draws\": 225, \"mouse\": 6, \"mu_intercept_per_group\": 7.4791483879089355, \"sigma_intercept_per_group\": 0.24531222879886627, \"sigma_obs\": 154.3313751220703, \"slope\": -0.07566844671964645, \"chain\": 1, \"draw\": 25}, {\"draws\": 225, \"mouse\": 7, \"mu_intercept_per_group\": 7.388245105743408, \"sigma_intercept_per_group\": 0.24531222879886627, \"sigma_obs\": 154.3313751220703, \"slope\": -0.07566844671964645, \"chain\": 1, \"draw\": 25}, {\"draws\": 226, \"mouse\": 0, \"mu_intercept_per_group\": 9.79346752166748, \"sigma_intercept_per_group\": 0.2513720393180847, \"sigma_obs\": 151.02163696289062, \"slope\": -0.07868058234453201, \"chain\": 1, \"draw\": 26}, {\"draws\": 226, \"mouse\": 1, \"mu_intercept_per_group\": 9.125075340270996, \"sigma_intercept_per_group\": 0.2513720393180847, \"sigma_obs\": 151.02163696289062, \"slope\": -0.07868058234453201, \"chain\": 1, \"draw\": 26}, {\"draws\": 226, \"mouse\": 2, \"mu_intercept_per_group\": 9.030420303344727, \"sigma_intercept_per_group\": 0.2513720393180847, \"sigma_obs\": 151.02163696289062, \"slope\": -0.07868058234453201, \"chain\": 1, \"draw\": 26}, {\"draws\": 226, \"mouse\": 3, \"mu_intercept_per_group\": 8.755877494812012, \"sigma_intercept_per_group\": 0.2513720393180847, \"sigma_obs\": 151.02163696289062, \"slope\": -0.07868058234453201, \"chain\": 1, \"draw\": 26}, {\"draws\": 226, \"mouse\": 4, \"mu_intercept_per_group\": 8.531831741333008, \"sigma_intercept_per_group\": 0.2513720393180847, \"sigma_obs\": 151.02163696289062, \"slope\": -0.07868058234453201, \"chain\": 1, \"draw\": 26}, {\"draws\": 226, \"mouse\": 5, \"mu_intercept_per_group\": 7.698380947113037, \"sigma_intercept_per_group\": 0.2513720393180847, \"sigma_obs\": 151.02163696289062, \"slope\": -0.07868058234453201, \"chain\": 1, \"draw\": 26}, {\"draws\": 226, \"mouse\": 6, \"mu_intercept_per_group\": 7.398761749267578, \"sigma_intercept_per_group\": 0.2513720393180847, \"sigma_obs\": 151.02163696289062, \"slope\": -0.07868058234453201, \"chain\": 1, \"draw\": 26}, {\"draws\": 226, \"mouse\": 7, \"mu_intercept_per_group\": 6.85683536529541, \"sigma_intercept_per_group\": 0.2513720393180847, \"sigma_obs\": 151.02163696289062, \"slope\": -0.07868058234453201, \"chain\": 1, \"draw\": 26}, {\"draws\": 227, \"mouse\": 0, \"mu_intercept_per_group\": 8.71868896484375, \"sigma_intercept_per_group\": 0.28326451778411865, \"sigma_obs\": 160.70321655273438, \"slope\": -0.06654755026102066, \"chain\": 1, \"draw\": 27}, {\"draws\": 227, \"mouse\": 1, \"mu_intercept_per_group\": 8.515172004699707, \"sigma_intercept_per_group\": 0.28326451778411865, \"sigma_obs\": 160.70321655273438, \"slope\": -0.06654755026102066, \"chain\": 1, \"draw\": 27}, {\"draws\": 227, \"mouse\": 2, \"mu_intercept_per_group\": 8.060184478759766, \"sigma_intercept_per_group\": 0.28326451778411865, \"sigma_obs\": 160.70321655273438, \"slope\": -0.06654755026102066, \"chain\": 1, \"draw\": 27}, {\"draws\": 227, \"mouse\": 3, \"mu_intercept_per_group\": 7.701967716217041, \"sigma_intercept_per_group\": 0.28326451778411865, \"sigma_obs\": 160.70321655273438, \"slope\": -0.06654755026102066, \"chain\": 1, \"draw\": 27}, {\"draws\": 227, \"mouse\": 4, \"mu_intercept_per_group\": 7.53495454788208, \"sigma_intercept_per_group\": 0.28326451778411865, \"sigma_obs\": 160.70321655273438, \"slope\": -0.06654755026102066, \"chain\": 1, \"draw\": 27}, {\"draws\": 227, \"mouse\": 5, \"mu_intercept_per_group\": 7.428536415100098, \"sigma_intercept_per_group\": 0.28326451778411865, \"sigma_obs\": 160.70321655273438, \"slope\": -0.06654755026102066, \"chain\": 1, \"draw\": 27}, {\"draws\": 227, \"mouse\": 6, \"mu_intercept_per_group\": 6.624223232269287, \"sigma_intercept_per_group\": 0.28326451778411865, \"sigma_obs\": 160.70321655273438, \"slope\": -0.06654755026102066, \"chain\": 1, \"draw\": 27}, {\"draws\": 227, \"mouse\": 7, \"mu_intercept_per_group\": 6.153936386108398, \"sigma_intercept_per_group\": 0.28326451778411865, \"sigma_obs\": 160.70321655273438, \"slope\": -0.06654755026102066, \"chain\": 1, \"draw\": 27}, {\"draws\": 228, \"mouse\": 0, \"mu_intercept_per_group\": 8.841858863830566, \"sigma_intercept_per_group\": 0.2785813510417938, \"sigma_obs\": 163.4812469482422, \"slope\": -0.06100156530737877, \"chain\": 1, \"draw\": 28}, {\"draws\": 228, \"mouse\": 1, \"mu_intercept_per_group\": 8.452402114868164, \"sigma_intercept_per_group\": 0.2785813510417938, \"sigma_obs\": 163.4812469482422, \"slope\": -0.06100156530737877, \"chain\": 1, \"draw\": 28}, {\"draws\": 228, \"mouse\": 2, \"mu_intercept_per_group\": 8.27042007446289, \"sigma_intercept_per_group\": 0.2785813510417938, \"sigma_obs\": 163.4812469482422, \"slope\": -0.06100156530737877, \"chain\": 1, \"draw\": 28}, {\"draws\": 228, \"mouse\": 3, \"mu_intercept_per_group\": 7.629507064819336, \"sigma_intercept_per_group\": 0.2785813510417938, \"sigma_obs\": 163.4812469482422, \"slope\": -0.06100156530737877, \"chain\": 1, \"draw\": 28}, {\"draws\": 228, \"mouse\": 4, \"mu_intercept_per_group\": 7.540476322174072, \"sigma_intercept_per_group\": 0.2785813510417938, \"sigma_obs\": 163.4812469482422, \"slope\": -0.06100156530737877, \"chain\": 1, \"draw\": 28}, {\"draws\": 228, \"mouse\": 5, \"mu_intercept_per_group\": 7.458775997161865, \"sigma_intercept_per_group\": 0.2785813510417938, \"sigma_obs\": 163.4812469482422, \"slope\": -0.06100156530737877, \"chain\": 1, \"draw\": 28}, {\"draws\": 228, \"mouse\": 6, \"mu_intercept_per_group\": 6.533994674682617, \"sigma_intercept_per_group\": 0.2785813510417938, \"sigma_obs\": 163.4812469482422, \"slope\": -0.06100156530737877, \"chain\": 1, \"draw\": 28}, {\"draws\": 228, \"mouse\": 7, \"mu_intercept_per_group\": 6.3370680809021, \"sigma_intercept_per_group\": 0.2785813510417938, \"sigma_obs\": 163.4812469482422, \"slope\": -0.06100156530737877, \"chain\": 1, \"draw\": 28}, {\"draws\": 229, \"mouse\": 0, \"mu_intercept_per_group\": 8.69003677368164, \"sigma_intercept_per_group\": 0.2773396968841553, \"sigma_obs\": 161.0260772705078, \"slope\": -0.04621662199497223, \"chain\": 1, \"draw\": 29}, {\"draws\": 229, \"mouse\": 1, \"mu_intercept_per_group\": 8.346334457397461, \"sigma_intercept_per_group\": 0.2773396968841553, \"sigma_obs\": 161.0260772705078, \"slope\": -0.04621662199497223, \"chain\": 1, \"draw\": 29}, {\"draws\": 229, \"mouse\": 2, \"mu_intercept_per_group\": 8.224455833435059, \"sigma_intercept_per_group\": 0.2773396968841553, \"sigma_obs\": 161.0260772705078, \"slope\": -0.04621662199497223, \"chain\": 1, \"draw\": 29}, {\"draws\": 229, \"mouse\": 3, \"mu_intercept_per_group\": 7.76099967956543, \"sigma_intercept_per_group\": 0.2773396968841553, \"sigma_obs\": 161.0260772705078, \"slope\": -0.04621662199497223, \"chain\": 1, \"draw\": 29}, {\"draws\": 229, \"mouse\": 4, \"mu_intercept_per_group\": 7.438860893249512, \"sigma_intercept_per_group\": 0.2773396968841553, \"sigma_obs\": 161.0260772705078, \"slope\": -0.04621662199497223, \"chain\": 1, \"draw\": 29}, {\"draws\": 229, \"mouse\": 5, \"mu_intercept_per_group\": 6.673213958740234, \"sigma_intercept_per_group\": 0.2773396968841553, \"sigma_obs\": 161.0260772705078, \"slope\": -0.04621662199497223, \"chain\": 1, \"draw\": 29}, {\"draws\": 229, \"mouse\": 6, \"mu_intercept_per_group\": 6.875527381896973, \"sigma_intercept_per_group\": 0.2773396968841553, \"sigma_obs\": 161.0260772705078, \"slope\": -0.04621662199497223, \"chain\": 1, \"draw\": 29}, {\"draws\": 229, \"mouse\": 7, \"mu_intercept_per_group\": 6.053366184234619, \"sigma_intercept_per_group\": 0.2773396968841553, \"sigma_obs\": 161.0260772705078, \"slope\": -0.04621662199497223, \"chain\": 1, \"draw\": 29}, {\"draws\": 230, \"mouse\": 0, \"mu_intercept_per_group\": 8.781039237976074, \"sigma_intercept_per_group\": 0.2820492386817932, \"sigma_obs\": 161.2143096923828, \"slope\": -0.04625174030661583, \"chain\": 1, \"draw\": 30}, {\"draws\": 230, \"mouse\": 1, \"mu_intercept_per_group\": 8.341839790344238, \"sigma_intercept_per_group\": 0.2820492386817932, \"sigma_obs\": 161.2143096923828, \"slope\": -0.04625174030661583, \"chain\": 1, \"draw\": 30}, {\"draws\": 230, \"mouse\": 2, \"mu_intercept_per_group\": 8.237029075622559, \"sigma_intercept_per_group\": 0.2820492386817932, \"sigma_obs\": 161.2143096923828, \"slope\": -0.04625174030661583, \"chain\": 1, \"draw\": 30}, {\"draws\": 230, \"mouse\": 3, \"mu_intercept_per_group\": 7.703880786895752, \"sigma_intercept_per_group\": 0.2820492386817932, \"sigma_obs\": 161.2143096923828, \"slope\": -0.04625174030661583, \"chain\": 1, \"draw\": 30}, {\"draws\": 230, \"mouse\": 4, \"mu_intercept_per_group\": 7.569944858551025, \"sigma_intercept_per_group\": 0.2820492386817932, \"sigma_obs\": 161.2143096923828, \"slope\": -0.04625174030661583, \"chain\": 1, \"draw\": 30}, {\"draws\": 230, \"mouse\": 5, \"mu_intercept_per_group\": 6.644527435302734, \"sigma_intercept_per_group\": 0.2820492386817932, \"sigma_obs\": 161.2143096923828, \"slope\": -0.04625174030661583, \"chain\": 1, \"draw\": 30}, {\"draws\": 230, \"mouse\": 6, \"mu_intercept_per_group\": 6.8647332191467285, \"sigma_intercept_per_group\": 0.2820492386817932, \"sigma_obs\": 161.2143096923828, \"slope\": -0.04625174030661583, \"chain\": 1, \"draw\": 30}, {\"draws\": 230, \"mouse\": 7, \"mu_intercept_per_group\": 6.098525524139404, \"sigma_intercept_per_group\": 0.2820492386817932, \"sigma_obs\": 161.2143096923828, \"slope\": -0.04625174030661583, \"chain\": 1, \"draw\": 30}, {\"draws\": 231, \"mouse\": 0, \"mu_intercept_per_group\": 9.062759399414062, \"sigma_intercept_per_group\": 0.25762954354286194, \"sigma_obs\": 145.4346466064453, \"slope\": -0.05507680028676987, \"chain\": 1, \"draw\": 31}, {\"draws\": 231, \"mouse\": 1, \"mu_intercept_per_group\": 8.689879417419434, \"sigma_intercept_per_group\": 0.25762954354286194, \"sigma_obs\": 145.4346466064453, \"slope\": -0.05507680028676987, \"chain\": 1, \"draw\": 31}, {\"draws\": 231, \"mouse\": 2, \"mu_intercept_per_group\": 8.19955062866211, \"sigma_intercept_per_group\": 0.25762954354286194, \"sigma_obs\": 145.4346466064453, \"slope\": -0.05507680028676987, \"chain\": 1, \"draw\": 31}, {\"draws\": 231, \"mouse\": 3, \"mu_intercept_per_group\": 7.855125427246094, \"sigma_intercept_per_group\": 0.25762954354286194, \"sigma_obs\": 145.4346466064453, \"slope\": -0.05507680028676987, \"chain\": 1, \"draw\": 31}, {\"draws\": 231, \"mouse\": 4, \"mu_intercept_per_group\": 7.550840377807617, \"sigma_intercept_per_group\": 0.25762954354286194, \"sigma_obs\": 145.4346466064453, \"slope\": -0.05507680028676987, \"chain\": 1, \"draw\": 31}, {\"draws\": 231, \"mouse\": 5, \"mu_intercept_per_group\": 7.466890811920166, \"sigma_intercept_per_group\": 0.25762954354286194, \"sigma_obs\": 145.4346466064453, \"slope\": -0.05507680028676987, \"chain\": 1, \"draw\": 31}, {\"draws\": 231, \"mouse\": 6, \"mu_intercept_per_group\": 7.0746259689331055, \"sigma_intercept_per_group\": 0.25762954354286194, \"sigma_obs\": 145.4346466064453, \"slope\": -0.05507680028676987, \"chain\": 1, \"draw\": 31}, {\"draws\": 231, \"mouse\": 7, \"mu_intercept_per_group\": 6.433014392852783, \"sigma_intercept_per_group\": 0.25762954354286194, \"sigma_obs\": 145.4346466064453, \"slope\": -0.05507680028676987, \"chain\": 1, \"draw\": 31}, {\"draws\": 232, \"mouse\": 0, \"mu_intercept_per_group\": 9.180309295654297, \"sigma_intercept_per_group\": 0.2553204596042633, \"sigma_obs\": 146.67892456054688, \"slope\": -0.05631576478481293, \"chain\": 1, \"draw\": 32}, {\"draws\": 232, \"mouse\": 1, \"mu_intercept_per_group\": 8.858088493347168, \"sigma_intercept_per_group\": 0.2553204596042633, \"sigma_obs\": 146.67892456054688, \"slope\": -0.05631576478481293, \"chain\": 1, \"draw\": 32}, {\"draws\": 232, \"mouse\": 2, \"mu_intercept_per_group\": 8.853445053100586, \"sigma_intercept_per_group\": 0.2553204596042633, \"sigma_obs\": 146.67892456054688, \"slope\": -0.05631576478481293, \"chain\": 1, \"draw\": 32}, {\"draws\": 232, \"mouse\": 3, \"mu_intercept_per_group\": 8.103565216064453, \"sigma_intercept_per_group\": 0.2553204596042633, \"sigma_obs\": 146.67892456054688, \"slope\": -0.05631576478481293, \"chain\": 1, \"draw\": 32}, {\"draws\": 232, \"mouse\": 4, \"mu_intercept_per_group\": 8.108006477355957, \"sigma_intercept_per_group\": 0.2553204596042633, \"sigma_obs\": 146.67892456054688, \"slope\": -0.05631576478481293, \"chain\": 1, \"draw\": 32}, {\"draws\": 232, \"mouse\": 5, \"mu_intercept_per_group\": 7.122224807739258, \"sigma_intercept_per_group\": 0.2553204596042633, \"sigma_obs\": 146.67892456054688, \"slope\": -0.05631576478481293, \"chain\": 1, \"draw\": 32}, {\"draws\": 232, \"mouse\": 6, \"mu_intercept_per_group\": 6.7018351554870605, \"sigma_intercept_per_group\": 0.2553204596042633, \"sigma_obs\": 146.67892456054688, \"slope\": -0.05631576478481293, \"chain\": 1, \"draw\": 32}, {\"draws\": 232, \"mouse\": 7, \"mu_intercept_per_group\": 6.419288635253906, \"sigma_intercept_per_group\": 0.2553204596042633, \"sigma_obs\": 146.67892456054688, \"slope\": -0.05631576478481293, \"chain\": 1, \"draw\": 32}, {\"draws\": 233, \"mouse\": 0, \"mu_intercept_per_group\": 8.998129844665527, \"sigma_intercept_per_group\": 0.2677971124649048, \"sigma_obs\": 147.9902801513672, \"slope\": -0.08832066506147385, \"chain\": 1, \"draw\": 33}, {\"draws\": 233, \"mouse\": 1, \"mu_intercept_per_group\": 8.923541069030762, \"sigma_intercept_per_group\": 0.2677971124649048, \"sigma_obs\": 147.9902801513672, \"slope\": -0.08832066506147385, \"chain\": 1, \"draw\": 33}, {\"draws\": 233, \"mouse\": 2, \"mu_intercept_per_group\": 8.449797630310059, \"sigma_intercept_per_group\": 0.2677971124649048, \"sigma_obs\": 147.9902801513672, \"slope\": -0.08832066506147385, \"chain\": 1, \"draw\": 33}, {\"draws\": 233, \"mouse\": 3, \"mu_intercept_per_group\": 7.938240051269531, \"sigma_intercept_per_group\": 0.2677971124649048, \"sigma_obs\": 147.9902801513672, \"slope\": -0.08832066506147385, \"chain\": 1, \"draw\": 33}, {\"draws\": 233, \"mouse\": 4, \"mu_intercept_per_group\": 7.716010570526123, \"sigma_intercept_per_group\": 0.2677971124649048, \"sigma_obs\": 147.9902801513672, \"slope\": -0.08832066506147385, \"chain\": 1, \"draw\": 33}, {\"draws\": 233, \"mouse\": 5, \"mu_intercept_per_group\": 7.157975673675537, \"sigma_intercept_per_group\": 0.2677971124649048, \"sigma_obs\": 147.9902801513672, \"slope\": -0.08832066506147385, \"chain\": 1, \"draw\": 33}, {\"draws\": 233, \"mouse\": 6, \"mu_intercept_per_group\": 6.657237529754639, \"sigma_intercept_per_group\": 0.2677971124649048, \"sigma_obs\": 147.9902801513672, \"slope\": -0.08832066506147385, \"chain\": 1, \"draw\": 33}, {\"draws\": 233, \"mouse\": 7, \"mu_intercept_per_group\": 6.296994209289551, \"sigma_intercept_per_group\": 0.2677971124649048, \"sigma_obs\": 147.9902801513672, \"slope\": -0.08832066506147385, \"chain\": 1, \"draw\": 33}, {\"draws\": 234, \"mouse\": 0, \"mu_intercept_per_group\": 8.6344633102417, \"sigma_intercept_per_group\": 0.2801504135131836, \"sigma_obs\": 150.66990661621094, \"slope\": -0.08772820234298706, \"chain\": 1, \"draw\": 34}, {\"draws\": 234, \"mouse\": 1, \"mu_intercept_per_group\": 8.550627708435059, \"sigma_intercept_per_group\": 0.2801504135131836, \"sigma_obs\": 150.66990661621094, \"slope\": -0.08772820234298706, \"chain\": 1, \"draw\": 34}, {\"draws\": 234, \"mouse\": 2, \"mu_intercept_per_group\": 8.050573348999023, \"sigma_intercept_per_group\": 0.2801504135131836, \"sigma_obs\": 150.66990661621094, \"slope\": -0.08772820234298706, \"chain\": 1, \"draw\": 34}, {\"draws\": 234, \"mouse\": 3, \"mu_intercept_per_group\": 7.5999040603637695, \"sigma_intercept_per_group\": 0.2801504135131836, \"sigma_obs\": 150.66990661621094, \"slope\": -0.08772820234298706, \"chain\": 1, \"draw\": 34}, {\"draws\": 234, \"mouse\": 4, \"mu_intercept_per_group\": 7.552123069763184, \"sigma_intercept_per_group\": 0.2801504135131836, \"sigma_obs\": 150.66990661621094, \"slope\": -0.08772820234298706, \"chain\": 1, \"draw\": 34}, {\"draws\": 234, \"mouse\": 5, \"mu_intercept_per_group\": 7.012725830078125, \"sigma_intercept_per_group\": 0.2801504135131836, \"sigma_obs\": 150.66990661621094, \"slope\": -0.08772820234298706, \"chain\": 1, \"draw\": 34}, {\"draws\": 234, \"mouse\": 6, \"mu_intercept_per_group\": 6.7669477462768555, \"sigma_intercept_per_group\": 0.2801504135131836, \"sigma_obs\": 150.66990661621094, \"slope\": -0.08772820234298706, \"chain\": 1, \"draw\": 34}, {\"draws\": 234, \"mouse\": 7, \"mu_intercept_per_group\": 6.437361240386963, \"sigma_intercept_per_group\": 0.2801504135131836, \"sigma_obs\": 150.66990661621094, \"slope\": -0.08772820234298706, \"chain\": 1, \"draw\": 34}, {\"draws\": 235, \"mouse\": 0, \"mu_intercept_per_group\": 8.605868339538574, \"sigma_intercept_per_group\": 0.27493804693222046, \"sigma_obs\": 150.6305389404297, \"slope\": -0.08810555189847946, \"chain\": 1, \"draw\": 35}, {\"draws\": 235, \"mouse\": 1, \"mu_intercept_per_group\": 8.543766975402832, \"sigma_intercept_per_group\": 0.27493804693222046, \"sigma_obs\": 150.6305389404297, \"slope\": -0.08810555189847946, \"chain\": 1, \"draw\": 35}, {\"draws\": 235, \"mouse\": 2, \"mu_intercept_per_group\": 8.006176948547363, \"sigma_intercept_per_group\": 0.27493804693222046, \"sigma_obs\": 150.6305389404297, \"slope\": -0.08810555189847946, \"chain\": 1, \"draw\": 35}, {\"draws\": 235, \"mouse\": 3, \"mu_intercept_per_group\": 7.526795387268066, \"sigma_intercept_per_group\": 0.27493804693222046, \"sigma_obs\": 150.6305389404297, \"slope\": -0.08810555189847946, \"chain\": 1, \"draw\": 35}, {\"draws\": 235, \"mouse\": 4, \"mu_intercept_per_group\": 7.501816749572754, \"sigma_intercept_per_group\": 0.27493804693222046, \"sigma_obs\": 150.6305389404297, \"slope\": -0.08810555189847946, \"chain\": 1, \"draw\": 35}, {\"draws\": 235, \"mouse\": 5, \"mu_intercept_per_group\": 7.017492294311523, \"sigma_intercept_per_group\": 0.27493804693222046, \"sigma_obs\": 150.6305389404297, \"slope\": -0.08810555189847946, \"chain\": 1, \"draw\": 35}, {\"draws\": 235, \"mouse\": 6, \"mu_intercept_per_group\": 6.748496055603027, \"sigma_intercept_per_group\": 0.27493804693222046, \"sigma_obs\": 150.6305389404297, \"slope\": -0.08810555189847946, \"chain\": 1, \"draw\": 35}, {\"draws\": 235, \"mouse\": 7, \"mu_intercept_per_group\": 6.471675395965576, \"sigma_intercept_per_group\": 0.27493804693222046, \"sigma_obs\": 150.6305389404297, \"slope\": -0.08810555189847946, \"chain\": 1, \"draw\": 35}, {\"draws\": 236, \"mouse\": 0, \"mu_intercept_per_group\": 7.933002471923828, \"sigma_intercept_per_group\": 0.3135190010070801, \"sigma_obs\": 155.17222595214844, \"slope\": -0.08912640064954758, \"chain\": 1, \"draw\": 36}, {\"draws\": 236, \"mouse\": 1, \"mu_intercept_per_group\": 7.597813606262207, \"sigma_intercept_per_group\": 0.3135190010070801, \"sigma_obs\": 155.17222595214844, \"slope\": -0.08912640064954758, \"chain\": 1, \"draw\": 36}, {\"draws\": 236, \"mouse\": 2, \"mu_intercept_per_group\": 7.613993167877197, \"sigma_intercept_per_group\": 0.3135190010070801, \"sigma_obs\": 155.17222595214844, \"slope\": -0.08912640064954758, \"chain\": 1, \"draw\": 36}, {\"draws\": 236, \"mouse\": 3, \"mu_intercept_per_group\": 7.040347099304199, \"sigma_intercept_per_group\": 0.3135190010070801, \"sigma_obs\": 155.17222595214844, \"slope\": -0.08912640064954758, \"chain\": 1, \"draw\": 36}, {\"draws\": 236, \"mouse\": 4, \"mu_intercept_per_group\": 7.0646538734436035, \"sigma_intercept_per_group\": 0.3135190010070801, \"sigma_obs\": 155.17222595214844, \"slope\": -0.08912640064954758, \"chain\": 1, \"draw\": 36}, {\"draws\": 236, \"mouse\": 5, \"mu_intercept_per_group\": 6.39491081237793, \"sigma_intercept_per_group\": 0.3135190010070801, \"sigma_obs\": 155.17222595214844, \"slope\": -0.08912640064954758, \"chain\": 1, \"draw\": 36}, {\"draws\": 236, \"mouse\": 6, \"mu_intercept_per_group\": 6.206068992614746, \"sigma_intercept_per_group\": 0.3135190010070801, \"sigma_obs\": 155.17222595214844, \"slope\": -0.08912640064954758, \"chain\": 1, \"draw\": 36}, {\"draws\": 236, \"mouse\": 7, \"mu_intercept_per_group\": 5.973605155944824, \"sigma_intercept_per_group\": 0.3135190010070801, \"sigma_obs\": 155.17222595214844, \"slope\": -0.08912640064954758, \"chain\": 1, \"draw\": 36}, {\"draws\": 237, \"mouse\": 0, \"mu_intercept_per_group\": 11.376399040222168, \"sigma_intercept_per_group\": 0.2138083279132843, \"sigma_obs\": 149.62632751464844, \"slope\": -0.059252284467220306, \"chain\": 1, \"draw\": 37}, {\"draws\": 237, \"mouse\": 1, \"mu_intercept_per_group\": 10.761676788330078, \"sigma_intercept_per_group\": 0.2138083279132843, \"sigma_obs\": 149.62632751464844, \"slope\": -0.059252284467220306, \"chain\": 1, \"draw\": 37}, {\"draws\": 237, \"mouse\": 2, \"mu_intercept_per_group\": 10.44596004486084, \"sigma_intercept_per_group\": 0.2138083279132843, \"sigma_obs\": 149.62632751464844, \"slope\": -0.059252284467220306, \"chain\": 1, \"draw\": 37}, {\"draws\": 237, \"mouse\": 3, \"mu_intercept_per_group\": 9.799818992614746, \"sigma_intercept_per_group\": 0.2138083279132843, \"sigma_obs\": 149.62632751464844, \"slope\": -0.059252284467220306, \"chain\": 1, \"draw\": 37}, {\"draws\": 237, \"mouse\": 4, \"mu_intercept_per_group\": 9.842781066894531, \"sigma_intercept_per_group\": 0.2138083279132843, \"sigma_obs\": 149.62632751464844, \"slope\": -0.059252284467220306, \"chain\": 1, \"draw\": 37}, {\"draws\": 237, \"mouse\": 5, \"mu_intercept_per_group\": 8.890080451965332, \"sigma_intercept_per_group\": 0.2138083279132843, \"sigma_obs\": 149.62632751464844, \"slope\": -0.059252284467220306, \"chain\": 1, \"draw\": 37}, {\"draws\": 237, \"mouse\": 6, \"mu_intercept_per_group\": 8.592794418334961, \"sigma_intercept_per_group\": 0.2138083279132843, \"sigma_obs\": 149.62632751464844, \"slope\": -0.059252284467220306, \"chain\": 1, \"draw\": 37}, {\"draws\": 237, \"mouse\": 7, \"mu_intercept_per_group\": 8.019195556640625, \"sigma_intercept_per_group\": 0.2138083279132843, \"sigma_obs\": 149.62632751464844, \"slope\": -0.059252284467220306, \"chain\": 1, \"draw\": 37}, {\"draws\": 238, \"mouse\": 0, \"mu_intercept_per_group\": 9.080038070678711, \"sigma_intercept_per_group\": 0.27045971155166626, \"sigma_obs\": 145.77157592773438, \"slope\": -0.07992443442344666, \"chain\": 1, \"draw\": 38}, {\"draws\": 238, \"mouse\": 1, \"mu_intercept_per_group\": 8.456670761108398, \"sigma_intercept_per_group\": 0.27045971155166626, \"sigma_obs\": 145.77157592773438, \"slope\": -0.07992443442344666, \"chain\": 1, \"draw\": 38}, {\"draws\": 238, \"mouse\": 2, \"mu_intercept_per_group\": 8.242877960205078, \"sigma_intercept_per_group\": 0.27045971155166626, \"sigma_obs\": 145.77157592773438, \"slope\": -0.07992443442344666, \"chain\": 1, \"draw\": 38}, {\"draws\": 238, \"mouse\": 3, \"mu_intercept_per_group\": 7.818202972412109, \"sigma_intercept_per_group\": 0.27045971155166626, \"sigma_obs\": 145.77157592773438, \"slope\": -0.07992443442344666, \"chain\": 1, \"draw\": 38}, {\"draws\": 238, \"mouse\": 4, \"mu_intercept_per_group\": 7.478865146636963, \"sigma_intercept_per_group\": 0.27045971155166626, \"sigma_obs\": 145.77157592773438, \"slope\": -0.07992443442344666, \"chain\": 1, \"draw\": 38}, {\"draws\": 238, \"mouse\": 5, \"mu_intercept_per_group\": 7.274409770965576, \"sigma_intercept_per_group\": 0.27045971155166626, \"sigma_obs\": 145.77157592773438, \"slope\": -0.07992443442344666, \"chain\": 1, \"draw\": 38}, {\"draws\": 238, \"mouse\": 6, \"mu_intercept_per_group\": 6.8466033935546875, \"sigma_intercept_per_group\": 0.27045971155166626, \"sigma_obs\": 145.77157592773438, \"slope\": -0.07992443442344666, \"chain\": 1, \"draw\": 38}, {\"draws\": 238, \"mouse\": 7, \"mu_intercept_per_group\": 6.415567398071289, \"sigma_intercept_per_group\": 0.27045971155166626, \"sigma_obs\": 145.77157592773438, \"slope\": -0.07992443442344666, \"chain\": 1, \"draw\": 38}, {\"draws\": 239, \"mouse\": 0, \"mu_intercept_per_group\": 8.954042434692383, \"sigma_intercept_per_group\": 0.26771482825279236, \"sigma_obs\": 145.90635681152344, \"slope\": -0.07981240004301071, \"chain\": 1, \"draw\": 39}, {\"draws\": 239, \"mouse\": 1, \"mu_intercept_per_group\": 8.53111457824707, \"sigma_intercept_per_group\": 0.26771482825279236, \"sigma_obs\": 145.90635681152344, \"slope\": -0.07981240004301071, \"chain\": 1, \"draw\": 39}, {\"draws\": 239, \"mouse\": 2, \"mu_intercept_per_group\": 8.278386116027832, \"sigma_intercept_per_group\": 0.26771482825279236, \"sigma_obs\": 145.90635681152344, \"slope\": -0.07981240004301071, \"chain\": 1, \"draw\": 39}, {\"draws\": 239, \"mouse\": 3, \"mu_intercept_per_group\": 7.746144771575928, \"sigma_intercept_per_group\": 0.26771482825279236, \"sigma_obs\": 145.90635681152344, \"slope\": -0.07981240004301071, \"chain\": 1, \"draw\": 39}, {\"draws\": 239, \"mouse\": 4, \"mu_intercept_per_group\": 7.606442451477051, \"sigma_intercept_per_group\": 0.26771482825279236, \"sigma_obs\": 145.90635681152344, \"slope\": -0.07981240004301071, \"chain\": 1, \"draw\": 39}, {\"draws\": 239, \"mouse\": 5, \"mu_intercept_per_group\": 7.237203598022461, \"sigma_intercept_per_group\": 0.26771482825279236, \"sigma_obs\": 145.90635681152344, \"slope\": -0.07981240004301071, \"chain\": 1, \"draw\": 39}, {\"draws\": 239, \"mouse\": 6, \"mu_intercept_per_group\": 6.912465572357178, \"sigma_intercept_per_group\": 0.26771482825279236, \"sigma_obs\": 145.90635681152344, \"slope\": -0.07981240004301071, \"chain\": 1, \"draw\": 39}, {\"draws\": 239, \"mouse\": 7, \"mu_intercept_per_group\": 6.263345241546631, \"sigma_intercept_per_group\": 0.26771482825279236, \"sigma_obs\": 145.90635681152344, \"slope\": -0.07981240004301071, \"chain\": 1, \"draw\": 39}, {\"draws\": 240, \"mouse\": 0, \"mu_intercept_per_group\": 11.671688079833984, \"sigma_intercept_per_group\": 0.22080327570438385, \"sigma_obs\": 174.1724853515625, \"slope\": -0.08935824036598206, \"chain\": 1, \"draw\": 40}, {\"draws\": 240, \"mouse\": 1, \"mu_intercept_per_group\": 11.156180381774902, \"sigma_intercept_per_group\": 0.22080327570438385, \"sigma_obs\": 174.1724853515625, \"slope\": -0.08935824036598206, \"chain\": 1, \"draw\": 40}, {\"draws\": 240, \"mouse\": 2, \"mu_intercept_per_group\": 10.869266510009766, \"sigma_intercept_per_group\": 0.22080327570438385, \"sigma_obs\": 174.1724853515625, \"slope\": -0.08935824036598206, \"chain\": 1, \"draw\": 40}, {\"draws\": 240, \"mouse\": 3, \"mu_intercept_per_group\": 10.211894989013672, \"sigma_intercept_per_group\": 0.22080327570438385, \"sigma_obs\": 174.1724853515625, \"slope\": -0.08935824036598206, \"chain\": 1, \"draw\": 40}, {\"draws\": 240, \"mouse\": 4, \"mu_intercept_per_group\": 10.01382064819336, \"sigma_intercept_per_group\": 0.22080327570438385, \"sigma_obs\": 174.1724853515625, \"slope\": -0.08935824036598206, \"chain\": 1, \"draw\": 40}, {\"draws\": 240, \"mouse\": 5, \"mu_intercept_per_group\": 9.697656631469727, \"sigma_intercept_per_group\": 0.22080327570438385, \"sigma_obs\": 174.1724853515625, \"slope\": -0.08935824036598206, \"chain\": 1, \"draw\": 40}, {\"draws\": 240, \"mouse\": 6, \"mu_intercept_per_group\": 8.986573219299316, \"sigma_intercept_per_group\": 0.22080327570438385, \"sigma_obs\": 174.1724853515625, \"slope\": -0.08935824036598206, \"chain\": 1, \"draw\": 40}, {\"draws\": 240, \"mouse\": 7, \"mu_intercept_per_group\": 8.607321739196777, \"sigma_intercept_per_group\": 0.22080327570438385, \"sigma_obs\": 174.1724853515625, \"slope\": -0.08935824036598206, \"chain\": 1, \"draw\": 40}, {\"draws\": 241, \"mouse\": 0, \"mu_intercept_per_group\": 11.581680297851562, \"sigma_intercept_per_group\": 0.22413179278373718, \"sigma_obs\": 174.31846618652344, \"slope\": -0.09079337120056152, \"chain\": 1, \"draw\": 41}, {\"draws\": 241, \"mouse\": 1, \"mu_intercept_per_group\": 11.259088516235352, \"sigma_intercept_per_group\": 0.22413179278373718, \"sigma_obs\": 174.31846618652344, \"slope\": -0.09079337120056152, \"chain\": 1, \"draw\": 41}, {\"draws\": 241, \"mouse\": 2, \"mu_intercept_per_group\": 10.962069511413574, \"sigma_intercept_per_group\": 0.22413179278373718, \"sigma_obs\": 174.31846618652344, \"slope\": -0.09079337120056152, \"chain\": 1, \"draw\": 41}, {\"draws\": 241, \"mouse\": 3, \"mu_intercept_per_group\": 10.39748477935791, \"sigma_intercept_per_group\": 0.22413179278373718, \"sigma_obs\": 174.31846618652344, \"slope\": -0.09079337120056152, \"chain\": 1, \"draw\": 41}, {\"draws\": 241, \"mouse\": 4, \"mu_intercept_per_group\": 10.085598945617676, \"sigma_intercept_per_group\": 0.22413179278373718, \"sigma_obs\": 174.31846618652344, \"slope\": -0.09079337120056152, \"chain\": 1, \"draw\": 41}, {\"draws\": 241, \"mouse\": 5, \"mu_intercept_per_group\": 9.51535415649414, \"sigma_intercept_per_group\": 0.22413179278373718, \"sigma_obs\": 174.31846618652344, \"slope\": -0.09079337120056152, \"chain\": 1, \"draw\": 41}, {\"draws\": 241, \"mouse\": 6, \"mu_intercept_per_group\": 8.60656452178955, \"sigma_intercept_per_group\": 0.22413179278373718, \"sigma_obs\": 174.31846618652344, \"slope\": -0.09079337120056152, \"chain\": 1, \"draw\": 41}, {\"draws\": 241, \"mouse\": 7, \"mu_intercept_per_group\": 8.276723861694336, \"sigma_intercept_per_group\": 0.22413179278373718, \"sigma_obs\": 174.31846618652344, \"slope\": -0.09079337120056152, \"chain\": 1, \"draw\": 41}, {\"draws\": 242, \"mouse\": 0, \"mu_intercept_per_group\": 10.27645492553711, \"sigma_intercept_per_group\": 0.24423100054264069, \"sigma_obs\": 167.94078063964844, \"slope\": -0.03882848843932152, \"chain\": 1, \"draw\": 42}, {\"draws\": 242, \"mouse\": 1, \"mu_intercept_per_group\": 9.655223846435547, \"sigma_intercept_per_group\": 0.24423100054264069, \"sigma_obs\": 167.94078063964844, \"slope\": -0.03882848843932152, \"chain\": 1, \"draw\": 42}, {\"draws\": 242, \"mouse\": 2, \"mu_intercept_per_group\": 9.45633316040039, \"sigma_intercept_per_group\": 0.24423100054264069, \"sigma_obs\": 167.94078063964844, \"slope\": -0.03882848843932152, \"chain\": 1, \"draw\": 42}, {\"draws\": 242, \"mouse\": 3, \"mu_intercept_per_group\": 8.784198760986328, \"sigma_intercept_per_group\": 0.24423100054264069, \"sigma_obs\": 167.94078063964844, \"slope\": -0.03882848843932152, \"chain\": 1, \"draw\": 42}, {\"draws\": 242, \"mouse\": 4, \"mu_intercept_per_group\": 8.679813385009766, \"sigma_intercept_per_group\": 0.24423100054264069, \"sigma_obs\": 167.94078063964844, \"slope\": -0.03882848843932152, \"chain\": 1, \"draw\": 42}, {\"draws\": 242, \"mouse\": 5, \"mu_intercept_per_group\": 8.195432662963867, \"sigma_intercept_per_group\": 0.24423100054264069, \"sigma_obs\": 167.94078063964844, \"slope\": -0.03882848843932152, \"chain\": 1, \"draw\": 42}, {\"draws\": 242, \"mouse\": 6, \"mu_intercept_per_group\": 7.484354019165039, \"sigma_intercept_per_group\": 0.24423100054264069, \"sigma_obs\": 167.94078063964844, \"slope\": -0.03882848843932152, \"chain\": 1, \"draw\": 42}, {\"draws\": 242, \"mouse\": 7, \"mu_intercept_per_group\": 7.247424125671387, \"sigma_intercept_per_group\": 0.24423100054264069, \"sigma_obs\": 167.94078063964844, \"slope\": -0.03882848843932152, \"chain\": 1, \"draw\": 42}, {\"draws\": 243, \"mouse\": 0, \"mu_intercept_per_group\": 8.244597434997559, \"sigma_intercept_per_group\": 0.3073592185974121, \"sigma_obs\": 162.59576416015625, \"slope\": -0.10392486304044724, \"chain\": 1, \"draw\": 43}, {\"draws\": 243, \"mouse\": 1, \"mu_intercept_per_group\": 8.060002326965332, \"sigma_intercept_per_group\": 0.3073592185974121, \"sigma_obs\": 162.59576416015625, \"slope\": -0.10392486304044724, \"chain\": 1, \"draw\": 43}, {\"draws\": 243, \"mouse\": 2, \"mu_intercept_per_group\": 7.792906761169434, \"sigma_intercept_per_group\": 0.3073592185974121, \"sigma_obs\": 162.59576416015625, \"slope\": -0.10392486304044724, \"chain\": 1, \"draw\": 43}, {\"draws\": 243, \"mouse\": 3, \"mu_intercept_per_group\": 7.265129089355469, \"sigma_intercept_per_group\": 0.3073592185974121, \"sigma_obs\": 162.59576416015625, \"slope\": -0.10392486304044724, \"chain\": 1, \"draw\": 43}, {\"draws\": 243, \"mouse\": 4, \"mu_intercept_per_group\": 7.1128644943237305, \"sigma_intercept_per_group\": 0.3073592185974121, \"sigma_obs\": 162.59576416015625, \"slope\": -0.10392486304044724, \"chain\": 1, \"draw\": 43}, {\"draws\": 243, \"mouse\": 5, \"mu_intercept_per_group\": 6.7278947830200195, \"sigma_intercept_per_group\": 0.3073592185974121, \"sigma_obs\": 162.59576416015625, \"slope\": -0.10392486304044724, \"chain\": 1, \"draw\": 43}, {\"draws\": 243, \"mouse\": 6, \"mu_intercept_per_group\": 6.233462810516357, \"sigma_intercept_per_group\": 0.3073592185974121, \"sigma_obs\": 162.59576416015625, \"slope\": -0.10392486304044724, \"chain\": 1, \"draw\": 43}, {\"draws\": 243, \"mouse\": 7, \"mu_intercept_per_group\": 5.769969463348389, \"sigma_intercept_per_group\": 0.3073592185974121, \"sigma_obs\": 162.59576416015625, \"slope\": -0.10392486304044724, \"chain\": 1, \"draw\": 43}, {\"draws\": 244, \"mouse\": 0, \"mu_intercept_per_group\": 8.274232864379883, \"sigma_intercept_per_group\": 0.2973051369190216, \"sigma_obs\": 157.42579650878906, \"slope\": -0.08660989254713058, \"chain\": 1, \"draw\": 44}, {\"draws\": 244, \"mouse\": 1, \"mu_intercept_per_group\": 7.933197498321533, \"sigma_intercept_per_group\": 0.2973051369190216, \"sigma_obs\": 157.42579650878906, \"slope\": -0.08660989254713058, \"chain\": 1, \"draw\": 44}, {\"draws\": 244, \"mouse\": 2, \"mu_intercept_per_group\": 7.721458911895752, \"sigma_intercept_per_group\": 0.2973051369190216, \"sigma_obs\": 157.42579650878906, \"slope\": -0.08660989254713058, \"chain\": 1, \"draw\": 44}, {\"draws\": 244, \"mouse\": 3, \"mu_intercept_per_group\": 7.334635257720947, \"sigma_intercept_per_group\": 0.2973051369190216, \"sigma_obs\": 157.42579650878906, \"slope\": -0.08660989254713058, \"chain\": 1, \"draw\": 44}, {\"draws\": 244, \"mouse\": 4, \"mu_intercept_per_group\": 7.088204860687256, \"sigma_intercept_per_group\": 0.2973051369190216, \"sigma_obs\": 157.42579650878906, \"slope\": -0.08660989254713058, \"chain\": 1, \"draw\": 44}, {\"draws\": 244, \"mouse\": 5, \"mu_intercept_per_group\": 6.715694427490234, \"sigma_intercept_per_group\": 0.2973051369190216, \"sigma_obs\": 157.42579650878906, \"slope\": -0.08660989254713058, \"chain\": 1, \"draw\": 44}, {\"draws\": 244, \"mouse\": 6, \"mu_intercept_per_group\": 5.8859453201293945, \"sigma_intercept_per_group\": 0.2973051369190216, \"sigma_obs\": 157.42579650878906, \"slope\": -0.08660989254713058, \"chain\": 1, \"draw\": 44}, {\"draws\": 244, \"mouse\": 7, \"mu_intercept_per_group\": 5.961085796356201, \"sigma_intercept_per_group\": 0.2973051369190216, \"sigma_obs\": 157.42579650878906, \"slope\": -0.08660989254713058, \"chain\": 1, \"draw\": 44}, {\"draws\": 245, \"mouse\": 0, \"mu_intercept_per_group\": 8.290590286254883, \"sigma_intercept_per_group\": 0.29855313897132874, \"sigma_obs\": 156.97506713867188, \"slope\": -0.08723408728837967, \"chain\": 1, \"draw\": 45}, {\"draws\": 245, \"mouse\": 1, \"mu_intercept_per_group\": 7.943575382232666, \"sigma_intercept_per_group\": 0.29855313897132874, \"sigma_obs\": 156.97506713867188, \"slope\": -0.08723408728837967, \"chain\": 1, \"draw\": 45}, {\"draws\": 245, \"mouse\": 2, \"mu_intercept_per_group\": 7.77508544921875, \"sigma_intercept_per_group\": 0.29855313897132874, \"sigma_obs\": 156.97506713867188, \"slope\": -0.08723408728837967, \"chain\": 1, \"draw\": 45}, {\"draws\": 245, \"mouse\": 3, \"mu_intercept_per_group\": 7.31040620803833, \"sigma_intercept_per_group\": 0.29855313897132874, \"sigma_obs\": 156.97506713867188, \"slope\": -0.08723408728837967, \"chain\": 1, \"draw\": 45}, {\"draws\": 245, \"mouse\": 4, \"mu_intercept_per_group\": 7.373466491699219, \"sigma_intercept_per_group\": 0.29855313897132874, \"sigma_obs\": 156.97506713867188, \"slope\": -0.08723408728837967, \"chain\": 1, \"draw\": 45}, {\"draws\": 245, \"mouse\": 5, \"mu_intercept_per_group\": 6.77968168258667, \"sigma_intercept_per_group\": 0.29855313897132874, \"sigma_obs\": 156.97506713867188, \"slope\": -0.08723408728837967, \"chain\": 1, \"draw\": 45}, {\"draws\": 245, \"mouse\": 6, \"mu_intercept_per_group\": 6.151970863342285, \"sigma_intercept_per_group\": 0.29855313897132874, \"sigma_obs\": 156.97506713867188, \"slope\": -0.08723408728837967, \"chain\": 1, \"draw\": 45}, {\"draws\": 245, \"mouse\": 7, \"mu_intercept_per_group\": 5.908337116241455, \"sigma_intercept_per_group\": 0.29855313897132874, \"sigma_obs\": 156.97506713867188, \"slope\": -0.08723408728837967, \"chain\": 1, \"draw\": 45}, {\"draws\": 246, \"mouse\": 0, \"mu_intercept_per_group\": 8.227225303649902, \"sigma_intercept_per_group\": 0.2996709942817688, \"sigma_obs\": 156.50271606445312, \"slope\": -0.08595529943704605, \"chain\": 1, \"draw\": 46}, {\"draws\": 246, \"mouse\": 1, \"mu_intercept_per_group\": 8.01594066619873, \"sigma_intercept_per_group\": 0.2996709942817688, \"sigma_obs\": 156.50271606445312, \"slope\": -0.08595529943704605, \"chain\": 1, \"draw\": 46}, {\"draws\": 246, \"mouse\": 2, \"mu_intercept_per_group\": 7.705348491668701, \"sigma_intercept_per_group\": 0.2996709942817688, \"sigma_obs\": 156.50271606445312, \"slope\": -0.08595529943704605, \"chain\": 1, \"draw\": 46}, {\"draws\": 246, \"mouse\": 3, \"mu_intercept_per_group\": 7.338446140289307, \"sigma_intercept_per_group\": 0.2996709942817688, \"sigma_obs\": 156.50271606445312, \"slope\": -0.08595529943704605, \"chain\": 1, \"draw\": 46}, {\"draws\": 246, \"mouse\": 4, \"mu_intercept_per_group\": 6.795342922210693, \"sigma_intercept_per_group\": 0.2996709942817688, \"sigma_obs\": 156.50271606445312, \"slope\": -0.08595529943704605, \"chain\": 1, \"draw\": 46}, {\"draws\": 246, \"mouse\": 5, \"mu_intercept_per_group\": 6.720563888549805, \"sigma_intercept_per_group\": 0.2996709942817688, \"sigma_obs\": 156.50271606445312, \"slope\": -0.08595529943704605, \"chain\": 1, \"draw\": 46}, {\"draws\": 246, \"mouse\": 6, \"mu_intercept_per_group\": 6.487117767333984, \"sigma_intercept_per_group\": 0.2996709942817688, \"sigma_obs\": 156.50271606445312, \"slope\": -0.08595529943704605, \"chain\": 1, \"draw\": 46}, {\"draws\": 246, \"mouse\": 7, \"mu_intercept_per_group\": 6.0156402587890625, \"sigma_intercept_per_group\": 0.2996709942817688, \"sigma_obs\": 156.50271606445312, \"slope\": -0.08595529943704605, \"chain\": 1, \"draw\": 46}, {\"draws\": 247, \"mouse\": 0, \"mu_intercept_per_group\": 8.159951210021973, \"sigma_intercept_per_group\": 0.30612605810165405, \"sigma_obs\": 160.6882781982422, \"slope\": -0.0849291980266571, \"chain\": 1, \"draw\": 47}, {\"draws\": 247, \"mouse\": 1, \"mu_intercept_per_group\": 7.79959774017334, \"sigma_intercept_per_group\": 0.30612605810165405, \"sigma_obs\": 160.6882781982422, \"slope\": -0.0849291980266571, \"chain\": 1, \"draw\": 47}, {\"draws\": 247, \"mouse\": 2, \"mu_intercept_per_group\": 7.62238073348999, \"sigma_intercept_per_group\": 0.30612605810165405, \"sigma_obs\": 160.6882781982422, \"slope\": -0.0849291980266571, \"chain\": 1, \"draw\": 47}, {\"draws\": 247, \"mouse\": 3, \"mu_intercept_per_group\": 7.23602294921875, \"sigma_intercept_per_group\": 0.30612605810165405, \"sigma_obs\": 160.6882781982422, \"slope\": -0.0849291980266571, \"chain\": 1, \"draw\": 47}, {\"draws\": 247, \"mouse\": 4, \"mu_intercept_per_group\": 6.82275390625, \"sigma_intercept_per_group\": 0.30612605810165405, \"sigma_obs\": 160.6882781982422, \"slope\": -0.0849291980266571, \"chain\": 1, \"draw\": 47}, {\"draws\": 247, \"mouse\": 5, \"mu_intercept_per_group\": 6.6843581199646, \"sigma_intercept_per_group\": 0.30612605810165405, \"sigma_obs\": 160.6882781982422, \"slope\": -0.0849291980266571, \"chain\": 1, \"draw\": 47}, {\"draws\": 247, \"mouse\": 6, \"mu_intercept_per_group\": 6.237144947052002, \"sigma_intercept_per_group\": 0.30612605810165405, \"sigma_obs\": 160.6882781982422, \"slope\": -0.0849291980266571, \"chain\": 1, \"draw\": 47}, {\"draws\": 247, \"mouse\": 7, \"mu_intercept_per_group\": 6.2038092613220215, \"sigma_intercept_per_group\": 0.30612605810165405, \"sigma_obs\": 160.6882781982422, \"slope\": -0.0849291980266571, \"chain\": 1, \"draw\": 47}, {\"draws\": 248, \"mouse\": 0, \"mu_intercept_per_group\": 8.177654266357422, \"sigma_intercept_per_group\": 0.3026373088359833, \"sigma_obs\": 160.0225830078125, \"slope\": -0.08633187413215637, \"chain\": 1, \"draw\": 48}, {\"draws\": 248, \"mouse\": 1, \"mu_intercept_per_group\": 7.971785068511963, \"sigma_intercept_per_group\": 0.3026373088359833, \"sigma_obs\": 160.0225830078125, \"slope\": -0.08633187413215637, \"chain\": 1, \"draw\": 48}, {\"draws\": 248, \"mouse\": 2, \"mu_intercept_per_group\": 7.540954113006592, \"sigma_intercept_per_group\": 0.3026373088359833, \"sigma_obs\": 160.0225830078125, \"slope\": -0.08633187413215637, \"chain\": 1, \"draw\": 48}, {\"draws\": 248, \"mouse\": 3, \"mu_intercept_per_group\": 7.153018474578857, \"sigma_intercept_per_group\": 0.3026373088359833, \"sigma_obs\": 160.0225830078125, \"slope\": -0.08633187413215637, \"chain\": 1, \"draw\": 48}, {\"draws\": 248, \"mouse\": 4, \"mu_intercept_per_group\": 7.331822872161865, \"sigma_intercept_per_group\": 0.3026373088359833, \"sigma_obs\": 160.0225830078125, \"slope\": -0.08633187413215637, \"chain\": 1, \"draw\": 48}, {\"draws\": 248, \"mouse\": 5, \"mu_intercept_per_group\": 6.517466068267822, \"sigma_intercept_per_group\": 0.3026373088359833, \"sigma_obs\": 160.0225830078125, \"slope\": -0.08633187413215637, \"chain\": 1, \"draw\": 48}, {\"draws\": 248, \"mouse\": 6, \"mu_intercept_per_group\": 6.263089179992676, \"sigma_intercept_per_group\": 0.3026373088359833, \"sigma_obs\": 160.0225830078125, \"slope\": -0.08633187413215637, \"chain\": 1, \"draw\": 48}, {\"draws\": 248, \"mouse\": 7, \"mu_intercept_per_group\": 5.820173263549805, \"sigma_intercept_per_group\": 0.3026373088359833, \"sigma_obs\": 160.0225830078125, \"slope\": -0.08633187413215637, \"chain\": 1, \"draw\": 48}, {\"draws\": 249, \"mouse\": 0, \"mu_intercept_per_group\": 8.094420433044434, \"sigma_intercept_per_group\": 0.3060338795185089, \"sigma_obs\": 158.46702575683594, \"slope\": -0.08709418773651123, \"chain\": 1, \"draw\": 49}, {\"draws\": 249, \"mouse\": 1, \"mu_intercept_per_group\": 7.809699535369873, \"sigma_intercept_per_group\": 0.3060338795185089, \"sigma_obs\": 158.46702575683594, \"slope\": -0.08709418773651123, \"chain\": 1, \"draw\": 49}, {\"draws\": 249, \"mouse\": 2, \"mu_intercept_per_group\": 7.4493513107299805, \"sigma_intercept_per_group\": 0.3060338795185089, \"sigma_obs\": 158.46702575683594, \"slope\": -0.08709418773651123, \"chain\": 1, \"draw\": 49}, {\"draws\": 249, \"mouse\": 3, \"mu_intercept_per_group\": 7.299236297607422, \"sigma_intercept_per_group\": 0.3060338795185089, \"sigma_obs\": 158.46702575683594, \"slope\": -0.08709418773651123, \"chain\": 1, \"draw\": 49}, {\"draws\": 249, \"mouse\": 4, \"mu_intercept_per_group\": 6.890037536621094, \"sigma_intercept_per_group\": 0.3060338795185089, \"sigma_obs\": 158.46702575683594, \"slope\": -0.08709418773651123, \"chain\": 1, \"draw\": 49}, {\"draws\": 249, \"mouse\": 5, \"mu_intercept_per_group\": 6.8199052810668945, \"sigma_intercept_per_group\": 0.3060338795185089, \"sigma_obs\": 158.46702575683594, \"slope\": -0.08709418773651123, \"chain\": 1, \"draw\": 49}, {\"draws\": 249, \"mouse\": 6, \"mu_intercept_per_group\": 6.148198127746582, \"sigma_intercept_per_group\": 0.3060338795185089, \"sigma_obs\": 158.46702575683594, \"slope\": -0.08709418773651123, \"chain\": 1, \"draw\": 49}, {\"draws\": 249, \"mouse\": 7, \"mu_intercept_per_group\": 5.9907097816467285, \"sigma_intercept_per_group\": 0.3060338795185089, \"sigma_obs\": 158.46702575683594, \"slope\": -0.08709418773651123, \"chain\": 1, \"draw\": 49}, {\"draws\": 250, \"mouse\": 0, \"mu_intercept_per_group\": 9.06493091583252, \"sigma_intercept_per_group\": 0.277823805809021, \"sigma_obs\": 168.39585876464844, \"slope\": -0.06511856615543365, \"chain\": 1, \"draw\": 50}, {\"draws\": 250, \"mouse\": 1, \"mu_intercept_per_group\": 8.681916236877441, \"sigma_intercept_per_group\": 0.277823805809021, \"sigma_obs\": 168.39585876464844, \"slope\": -0.06511856615543365, \"chain\": 1, \"draw\": 50}, {\"draws\": 250, \"mouse\": 2, \"mu_intercept_per_group\": 8.511932373046875, \"sigma_intercept_per_group\": 0.277823805809021, \"sigma_obs\": 168.39585876464844, \"slope\": -0.06511856615543365, \"chain\": 1, \"draw\": 50}, {\"draws\": 250, \"mouse\": 3, \"mu_intercept_per_group\": 7.758650302886963, \"sigma_intercept_per_group\": 0.277823805809021, \"sigma_obs\": 168.39585876464844, \"slope\": -0.06511856615543365, \"chain\": 1, \"draw\": 50}, {\"draws\": 250, \"mouse\": 4, \"mu_intercept_per_group\": 7.874857425689697, \"sigma_intercept_per_group\": 0.277823805809021, \"sigma_obs\": 168.39585876464844, \"slope\": -0.06511856615543365, \"chain\": 1, \"draw\": 50}, {\"draws\": 250, \"mouse\": 5, \"mu_intercept_per_group\": 7.573592185974121, \"sigma_intercept_per_group\": 0.277823805809021, \"sigma_obs\": 168.39585876464844, \"slope\": -0.06511856615543365, \"chain\": 1, \"draw\": 50}, {\"draws\": 250, \"mouse\": 6, \"mu_intercept_per_group\": 7.119711399078369, \"sigma_intercept_per_group\": 0.277823805809021, \"sigma_obs\": 168.39585876464844, \"slope\": -0.06511856615543365, \"chain\": 1, \"draw\": 50}, {\"draws\": 250, \"mouse\": 7, \"mu_intercept_per_group\": 6.513888835906982, \"sigma_intercept_per_group\": 0.277823805809021, \"sigma_obs\": 168.39585876464844, \"slope\": -0.06511856615543365, \"chain\": 1, \"draw\": 50}, {\"draws\": 251, \"mouse\": 0, \"mu_intercept_per_group\": 9.034850120544434, \"sigma_intercept_per_group\": 0.2764764130115509, \"sigma_obs\": 167.8928985595703, \"slope\": -0.0654631108045578, \"chain\": 1, \"draw\": 51}, {\"draws\": 251, \"mouse\": 1, \"mu_intercept_per_group\": 8.74507999420166, \"sigma_intercept_per_group\": 0.2764764130115509, \"sigma_obs\": 167.8928985595703, \"slope\": -0.0654631108045578, \"chain\": 1, \"draw\": 51}, {\"draws\": 251, \"mouse\": 2, \"mu_intercept_per_group\": 8.423884391784668, \"sigma_intercept_per_group\": 0.2764764130115509, \"sigma_obs\": 167.8928985595703, \"slope\": -0.0654631108045578, \"chain\": 1, \"draw\": 51}, {\"draws\": 251, \"mouse\": 3, \"mu_intercept_per_group\": 8.269222259521484, \"sigma_intercept_per_group\": 0.2764764130115509, \"sigma_obs\": 167.8928985595703, \"slope\": -0.0654631108045578, \"chain\": 1, \"draw\": 51}, {\"draws\": 251, \"mouse\": 4, \"mu_intercept_per_group\": 7.769878387451172, \"sigma_intercept_per_group\": 0.2764764130115509, \"sigma_obs\": 167.8928985595703, \"slope\": -0.0654631108045578, \"chain\": 1, \"draw\": 51}, {\"draws\": 251, \"mouse\": 5, \"mu_intercept_per_group\": 7.115993976593018, \"sigma_intercept_per_group\": 0.2764764130115509, \"sigma_obs\": 167.8928985595703, \"slope\": -0.0654631108045578, \"chain\": 1, \"draw\": 51}, {\"draws\": 251, \"mouse\": 6, \"mu_intercept_per_group\": 6.888887405395508, \"sigma_intercept_per_group\": 0.2764764130115509, \"sigma_obs\": 167.8928985595703, \"slope\": -0.0654631108045578, \"chain\": 1, \"draw\": 51}, {\"draws\": 251, \"mouse\": 7, \"mu_intercept_per_group\": 6.6933207511901855, \"sigma_intercept_per_group\": 0.2764764130115509, \"sigma_obs\": 167.8928985595703, \"slope\": -0.0654631108045578, \"chain\": 1, \"draw\": 51}, {\"draws\": 252, \"mouse\": 0, \"mu_intercept_per_group\": 8.900541305541992, \"sigma_intercept_per_group\": 0.2877068519592285, \"sigma_obs\": 175.93011474609375, \"slope\": -0.07829075306653976, \"chain\": 1, \"draw\": 52}, {\"draws\": 252, \"mouse\": 1, \"mu_intercept_per_group\": 8.679576873779297, \"sigma_intercept_per_group\": 0.2877068519592285, \"sigma_obs\": 175.93011474609375, \"slope\": -0.07829075306653976, \"chain\": 1, \"draw\": 52}, {\"draws\": 252, \"mouse\": 2, \"mu_intercept_per_group\": 8.351469039916992, \"sigma_intercept_per_group\": 0.2877068519592285, \"sigma_obs\": 175.93011474609375, \"slope\": -0.07829075306653976, \"chain\": 1, \"draw\": 52}, {\"draws\": 252, \"mouse\": 3, \"mu_intercept_per_group\": 7.9090070724487305, \"sigma_intercept_per_group\": 0.2877068519592285, \"sigma_obs\": 175.93011474609375, \"slope\": -0.07829075306653976, \"chain\": 1, \"draw\": 52}, {\"draws\": 252, \"mouse\": 4, \"mu_intercept_per_group\": 7.846373558044434, \"sigma_intercept_per_group\": 0.2877068519592285, \"sigma_obs\": 175.93011474609375, \"slope\": -0.07829075306653976, \"chain\": 1, \"draw\": 52}, {\"draws\": 252, \"mouse\": 5, \"mu_intercept_per_group\": 7.146698951721191, \"sigma_intercept_per_group\": 0.2877068519592285, \"sigma_obs\": 175.93011474609375, \"slope\": -0.07829075306653976, \"chain\": 1, \"draw\": 52}, {\"draws\": 252, \"mouse\": 6, \"mu_intercept_per_group\": 6.931885719299316, \"sigma_intercept_per_group\": 0.2877068519592285, \"sigma_obs\": 175.93011474609375, \"slope\": -0.07829075306653976, \"chain\": 1, \"draw\": 52}, {\"draws\": 252, \"mouse\": 7, \"mu_intercept_per_group\": 6.539978981018066, \"sigma_intercept_per_group\": 0.2877068519592285, \"sigma_obs\": 175.93011474609375, \"slope\": -0.07829075306653976, \"chain\": 1, \"draw\": 52}, {\"draws\": 253, \"mouse\": 0, \"mu_intercept_per_group\": 9.327873229980469, \"sigma_intercept_per_group\": 0.2715878486633301, \"sigma_obs\": 171.99972534179688, \"slope\": -0.06574154645204544, \"chain\": 1, \"draw\": 53}, {\"draws\": 253, \"mouse\": 1, \"mu_intercept_per_group\": 9.002174377441406, \"sigma_intercept_per_group\": 0.2715878486633301, \"sigma_obs\": 171.99972534179688, \"slope\": -0.06574154645204544, \"chain\": 1, \"draw\": 53}, {\"draws\": 253, \"mouse\": 2, \"mu_intercept_per_group\": 8.659621238708496, \"sigma_intercept_per_group\": 0.2715878486633301, \"sigma_obs\": 171.99972534179688, \"slope\": -0.06574154645204544, \"chain\": 1, \"draw\": 53}, {\"draws\": 253, \"mouse\": 3, \"mu_intercept_per_group\": 8.094517707824707, \"sigma_intercept_per_group\": 0.2715878486633301, \"sigma_obs\": 171.99972534179688, \"slope\": -0.06574154645204544, \"chain\": 1, \"draw\": 53}, {\"draws\": 253, \"mouse\": 4, \"mu_intercept_per_group\": 8.053909301757812, \"sigma_intercept_per_group\": 0.2715878486633301, \"sigma_obs\": 171.99972534179688, \"slope\": -0.06574154645204544, \"chain\": 1, \"draw\": 53}, {\"draws\": 253, \"mouse\": 5, \"mu_intercept_per_group\": 7.7112531661987305, \"sigma_intercept_per_group\": 0.2715878486633301, \"sigma_obs\": 171.99972534179688, \"slope\": -0.06574154645204544, \"chain\": 1, \"draw\": 53}, {\"draws\": 253, \"mouse\": 6, \"mu_intercept_per_group\": 7.097691535949707, \"sigma_intercept_per_group\": 0.2715878486633301, \"sigma_obs\": 171.99972534179688, \"slope\": -0.06574154645204544, \"chain\": 1, \"draw\": 53}, {\"draws\": 253, \"mouse\": 7, \"mu_intercept_per_group\": 6.7858381271362305, \"sigma_intercept_per_group\": 0.2715878486633301, \"sigma_obs\": 171.99972534179688, \"slope\": -0.06574154645204544, \"chain\": 1, \"draw\": 53}, {\"draws\": 254, \"mouse\": 0, \"mu_intercept_per_group\": 9.37540054321289, \"sigma_intercept_per_group\": 0.27641206979751587, \"sigma_obs\": 182.62191772460938, \"slope\": -0.07228416204452515, \"chain\": 1, \"draw\": 54}, {\"draws\": 254, \"mouse\": 1, \"mu_intercept_per_group\": 8.908437728881836, \"sigma_intercept_per_group\": 0.27641206979751587, \"sigma_obs\": 182.62191772460938, \"slope\": -0.07228416204452515, \"chain\": 1, \"draw\": 54}, {\"draws\": 254, \"mouse\": 2, \"mu_intercept_per_group\": 8.830245018005371, \"sigma_intercept_per_group\": 0.27641206979751587, \"sigma_obs\": 182.62191772460938, \"slope\": -0.07228416204452515, \"chain\": 1, \"draw\": 54}, {\"draws\": 254, \"mouse\": 3, \"mu_intercept_per_group\": 8.378334999084473, \"sigma_intercept_per_group\": 0.27641206979751587, \"sigma_obs\": 182.62191772460938, \"slope\": -0.07228416204452515, \"chain\": 1, \"draw\": 54}, {\"draws\": 254, \"mouse\": 4, \"mu_intercept_per_group\": 8.071457862854004, \"sigma_intercept_per_group\": 0.27641206979751587, \"sigma_obs\": 182.62191772460938, \"slope\": -0.07228416204452515, \"chain\": 1, \"draw\": 54}, {\"draws\": 254, \"mouse\": 5, \"mu_intercept_per_group\": 7.918947696685791, \"sigma_intercept_per_group\": 0.27641206979751587, \"sigma_obs\": 182.62191772460938, \"slope\": -0.07228416204452515, \"chain\": 1, \"draw\": 54}, {\"draws\": 254, \"mouse\": 6, \"mu_intercept_per_group\": 7.287697792053223, \"sigma_intercept_per_group\": 0.27641206979751587, \"sigma_obs\": 182.62191772460938, \"slope\": -0.07228416204452515, \"chain\": 1, \"draw\": 54}, {\"draws\": 254, \"mouse\": 7, \"mu_intercept_per_group\": 6.749755382537842, \"sigma_intercept_per_group\": 0.27641206979751587, \"sigma_obs\": 182.62191772460938, \"slope\": -0.07228416204452515, \"chain\": 1, \"draw\": 54}, {\"draws\": 255, \"mouse\": 0, \"mu_intercept_per_group\": 9.085494995117188, \"sigma_intercept_per_group\": 0.2848949432373047, \"sigma_obs\": 184.3424072265625, \"slope\": -0.07186765968799591, \"chain\": 1, \"draw\": 55}, {\"draws\": 255, \"mouse\": 1, \"mu_intercept_per_group\": 9.035956382751465, \"sigma_intercept_per_group\": 0.2848949432373047, \"sigma_obs\": 184.3424072265625, \"slope\": -0.07186765968799591, \"chain\": 1, \"draw\": 55}, {\"draws\": 255, \"mouse\": 2, \"mu_intercept_per_group\": 8.716079711914062, \"sigma_intercept_per_group\": 0.2848949432373047, \"sigma_obs\": 184.3424072265625, \"slope\": -0.07186765968799591, \"chain\": 1, \"draw\": 55}, {\"draws\": 255, \"mouse\": 3, \"mu_intercept_per_group\": 8.181090354919434, \"sigma_intercept_per_group\": 0.2848949432373047, \"sigma_obs\": 184.3424072265625, \"slope\": -0.07186765968799591, \"chain\": 1, \"draw\": 55}, {\"draws\": 255, \"mouse\": 4, \"mu_intercept_per_group\": 8.060739517211914, \"sigma_intercept_per_group\": 0.2848949432373047, \"sigma_obs\": 184.3424072265625, \"slope\": -0.07186765968799591, \"chain\": 1, \"draw\": 55}, {\"draws\": 255, \"mouse\": 5, \"mu_intercept_per_group\": 7.204378128051758, \"sigma_intercept_per_group\": 0.2848949432373047, \"sigma_obs\": 184.3424072265625, \"slope\": -0.07186765968799591, \"chain\": 1, \"draw\": 55}, {\"draws\": 255, \"mouse\": 6, \"mu_intercept_per_group\": 7.090000152587891, \"sigma_intercept_per_group\": 0.2848949432373047, \"sigma_obs\": 184.3424072265625, \"slope\": -0.07186765968799591, \"chain\": 1, \"draw\": 55}, {\"draws\": 255, \"mouse\": 7, \"mu_intercept_per_group\": 6.836429595947266, \"sigma_intercept_per_group\": 0.2848949432373047, \"sigma_obs\": 184.3424072265625, \"slope\": -0.07186765968799591, \"chain\": 1, \"draw\": 55}, {\"draws\": 256, \"mouse\": 0, \"mu_intercept_per_group\": 9.365687370300293, \"sigma_intercept_per_group\": 0.281911164522171, \"sigma_obs\": 182.87069702148438, \"slope\": -0.07383251935243607, \"chain\": 1, \"draw\": 56}, {\"draws\": 256, \"mouse\": 1, \"mu_intercept_per_group\": 8.784880638122559, \"sigma_intercept_per_group\": 0.281911164522171, \"sigma_obs\": 182.87069702148438, \"slope\": -0.07383251935243607, \"chain\": 1, \"draw\": 56}, {\"draws\": 256, \"mouse\": 2, \"mu_intercept_per_group\": 8.635092735290527, \"sigma_intercept_per_group\": 0.281911164522171, \"sigma_obs\": 182.87069702148438, \"slope\": -0.07383251935243607, \"chain\": 1, \"draw\": 56}, {\"draws\": 256, \"mouse\": 3, \"mu_intercept_per_group\": 8.290351867675781, \"sigma_intercept_per_group\": 0.281911164522171, \"sigma_obs\": 182.87069702148438, \"slope\": -0.07383251935243607, \"chain\": 1, \"draw\": 56}, {\"draws\": 256, \"mouse\": 4, \"mu_intercept_per_group\": 7.810214996337891, \"sigma_intercept_per_group\": 0.281911164522171, \"sigma_obs\": 182.87069702148438, \"slope\": -0.07383251935243607, \"chain\": 1, \"draw\": 56}, {\"draws\": 256, \"mouse\": 5, \"mu_intercept_per_group\": 7.5558857917785645, \"sigma_intercept_per_group\": 0.281911164522171, \"sigma_obs\": 182.87069702148438, \"slope\": -0.07383251935243607, \"chain\": 1, \"draw\": 56}, {\"draws\": 256, \"mouse\": 6, \"mu_intercept_per_group\": 7.366140842437744, \"sigma_intercept_per_group\": 0.281911164522171, \"sigma_obs\": 182.87069702148438, \"slope\": -0.07383251935243607, \"chain\": 1, \"draw\": 56}, {\"draws\": 256, \"mouse\": 7, \"mu_intercept_per_group\": 6.965289115905762, \"sigma_intercept_per_group\": 0.281911164522171, \"sigma_obs\": 182.87069702148438, \"slope\": -0.07383251935243607, \"chain\": 1, \"draw\": 56}, {\"draws\": 257, \"mouse\": 0, \"mu_intercept_per_group\": 9.619043350219727, \"sigma_intercept_per_group\": 0.2643488645553589, \"sigma_obs\": 177.36001586914062, \"slope\": -0.08307892829179764, \"chain\": 1, \"draw\": 57}, {\"draws\": 257, \"mouse\": 1, \"mu_intercept_per_group\": 9.444560050964355, \"sigma_intercept_per_group\": 0.2643488645553589, \"sigma_obs\": 177.36001586914062, \"slope\": -0.08307892829179764, \"chain\": 1, \"draw\": 57}, {\"draws\": 257, \"mouse\": 2, \"mu_intercept_per_group\": 9.390192985534668, \"sigma_intercept_per_group\": 0.2643488645553589, \"sigma_obs\": 177.36001586914062, \"slope\": -0.08307892829179764, \"chain\": 1, \"draw\": 57}, {\"draws\": 257, \"mouse\": 3, \"mu_intercept_per_group\": 8.896937370300293, \"sigma_intercept_per_group\": 0.2643488645553589, \"sigma_obs\": 177.36001586914062, \"slope\": -0.08307892829179764, \"chain\": 1, \"draw\": 57}, {\"draws\": 257, \"mouse\": 4, \"mu_intercept_per_group\": 8.516958236694336, \"sigma_intercept_per_group\": 0.2643488645553589, \"sigma_obs\": 177.36001586914062, \"slope\": -0.08307892829179764, \"chain\": 1, \"draw\": 57}, {\"draws\": 257, \"mouse\": 5, \"mu_intercept_per_group\": 8.152235984802246, \"sigma_intercept_per_group\": 0.2643488645553589, \"sigma_obs\": 177.36001586914062, \"slope\": -0.08307892829179764, \"chain\": 1, \"draw\": 57}, {\"draws\": 257, \"mouse\": 6, \"mu_intercept_per_group\": 7.33491849899292, \"sigma_intercept_per_group\": 0.2643488645553589, \"sigma_obs\": 177.36001586914062, \"slope\": -0.08307892829179764, \"chain\": 1, \"draw\": 57}, {\"draws\": 257, \"mouse\": 7, \"mu_intercept_per_group\": 6.864623546600342, \"sigma_intercept_per_group\": 0.2643488645553589, \"sigma_obs\": 177.36001586914062, \"slope\": -0.08307892829179764, \"chain\": 1, \"draw\": 57}, {\"draws\": 258, \"mouse\": 0, \"mu_intercept_per_group\": 9.86734676361084, \"sigma_intercept_per_group\": 0.26889896392822266, \"sigma_obs\": 178.86727905273438, \"slope\": -0.08268053829669952, \"chain\": 1, \"draw\": 58}, {\"draws\": 258, \"mouse\": 1, \"mu_intercept_per_group\": 9.372197151184082, \"sigma_intercept_per_group\": 0.26889896392822266, \"sigma_obs\": 178.86727905273438, \"slope\": -0.08268053829669952, \"chain\": 1, \"draw\": 58}, {\"draws\": 258, \"mouse\": 2, \"mu_intercept_per_group\": 8.924455642700195, \"sigma_intercept_per_group\": 0.26889896392822266, \"sigma_obs\": 178.86727905273438, \"slope\": -0.08268053829669952, \"chain\": 1, \"draw\": 58}, {\"draws\": 258, \"mouse\": 3, \"mu_intercept_per_group\": 8.437430381774902, \"sigma_intercept_per_group\": 0.26889896392822266, \"sigma_obs\": 178.86727905273438, \"slope\": -0.08268053829669952, \"chain\": 1, \"draw\": 58}, {\"draws\": 258, \"mouse\": 4, \"mu_intercept_per_group\": 8.366097450256348, \"sigma_intercept_per_group\": 0.26889896392822266, \"sigma_obs\": 178.86727905273438, \"slope\": -0.08268053829669952, \"chain\": 1, \"draw\": 58}, {\"draws\": 258, \"mouse\": 5, \"mu_intercept_per_group\": 7.9064483642578125, \"sigma_intercept_per_group\": 0.26889896392822266, \"sigma_obs\": 178.86727905273438, \"slope\": -0.08268053829669952, \"chain\": 1, \"draw\": 58}, {\"draws\": 258, \"mouse\": 6, \"mu_intercept_per_group\": 7.512410640716553, \"sigma_intercept_per_group\": 0.26889896392822266, \"sigma_obs\": 178.86727905273438, \"slope\": -0.08268053829669952, \"chain\": 1, \"draw\": 58}, {\"draws\": 258, \"mouse\": 7, \"mu_intercept_per_group\": 6.96994686126709, \"sigma_intercept_per_group\": 0.26889896392822266, \"sigma_obs\": 178.86727905273438, \"slope\": -0.08268053829669952, \"chain\": 1, \"draw\": 58}, {\"draws\": 259, \"mouse\": 0, \"mu_intercept_per_group\": 11.362706184387207, \"sigma_intercept_per_group\": 0.21926116943359375, \"sigma_obs\": 164.52210998535156, \"slope\": -0.03588814660906792, \"chain\": 1, \"draw\": 59}, {\"draws\": 259, \"mouse\": 1, \"mu_intercept_per_group\": 10.595719337463379, \"sigma_intercept_per_group\": 0.21926116943359375, \"sigma_obs\": 164.52210998535156, \"slope\": -0.03588814660906792, \"chain\": 1, \"draw\": 59}, {\"draws\": 259, \"mouse\": 2, \"mu_intercept_per_group\": 10.580804824829102, \"sigma_intercept_per_group\": 0.21926116943359375, \"sigma_obs\": 164.52210998535156, \"slope\": -0.03588814660906792, \"chain\": 1, \"draw\": 59}, {\"draws\": 259, \"mouse\": 3, \"mu_intercept_per_group\": 9.939305305480957, \"sigma_intercept_per_group\": 0.21926116943359375, \"sigma_obs\": 164.52210998535156, \"slope\": -0.03588814660906792, \"chain\": 1, \"draw\": 59}, {\"draws\": 259, \"mouse\": 4, \"mu_intercept_per_group\": 9.463397026062012, \"sigma_intercept_per_group\": 0.21926116943359375, \"sigma_obs\": 164.52210998535156, \"slope\": -0.03588814660906792, \"chain\": 1, \"draw\": 59}, {\"draws\": 259, \"mouse\": 5, \"mu_intercept_per_group\": 8.87991714477539, \"sigma_intercept_per_group\": 0.21926116943359375, \"sigma_obs\": 164.52210998535156, \"slope\": -0.03588814660906792, \"chain\": 1, \"draw\": 59}, {\"draws\": 259, \"mouse\": 6, \"mu_intercept_per_group\": 8.354853630065918, \"sigma_intercept_per_group\": 0.21926116943359375, \"sigma_obs\": 164.52210998535156, \"slope\": -0.03588814660906792, \"chain\": 1, \"draw\": 59}, {\"draws\": 259, \"mouse\": 7, \"mu_intercept_per_group\": 8.143126487731934, \"sigma_intercept_per_group\": 0.21926116943359375, \"sigma_obs\": 164.52210998535156, \"slope\": -0.03588814660906792, \"chain\": 1, \"draw\": 59}, {\"draws\": 260, \"mouse\": 0, \"mu_intercept_per_group\": 12.536582946777344, \"sigma_intercept_per_group\": 0.20311963558197021, \"sigma_obs\": 183.15081787109375, \"slope\": -0.04642743617296219, \"chain\": 1, \"draw\": 60}, {\"draws\": 260, \"mouse\": 1, \"mu_intercept_per_group\": 12.404708862304688, \"sigma_intercept_per_group\": 0.20311963558197021, \"sigma_obs\": 183.15081787109375, \"slope\": -0.04642743617296219, \"chain\": 1, \"draw\": 60}, {\"draws\": 260, \"mouse\": 2, \"mu_intercept_per_group\": 11.718205451965332, \"sigma_intercept_per_group\": 0.20311963558197021, \"sigma_obs\": 183.15081787109375, \"slope\": -0.04642743617296219, \"chain\": 1, \"draw\": 60}, {\"draws\": 260, \"mouse\": 3, \"mu_intercept_per_group\": 11.263333320617676, \"sigma_intercept_per_group\": 0.20311963558197021, \"sigma_obs\": 183.15081787109375, \"slope\": -0.04642743617296219, \"chain\": 1, \"draw\": 60}, {\"draws\": 260, \"mouse\": 4, \"mu_intercept_per_group\": 10.730533599853516, \"sigma_intercept_per_group\": 0.20311963558197021, \"sigma_obs\": 183.15081787109375, \"slope\": -0.04642743617296219, \"chain\": 1, \"draw\": 60}, {\"draws\": 260, \"mouse\": 5, \"mu_intercept_per_group\": 10.447331428527832, \"sigma_intercept_per_group\": 0.20311963558197021, \"sigma_obs\": 183.15081787109375, \"slope\": -0.04642743617296219, \"chain\": 1, \"draw\": 60}, {\"draws\": 260, \"mouse\": 6, \"mu_intercept_per_group\": 9.61367130279541, \"sigma_intercept_per_group\": 0.20311963558197021, \"sigma_obs\": 183.15081787109375, \"slope\": -0.04642743617296219, \"chain\": 1, \"draw\": 60}, {\"draws\": 260, \"mouse\": 7, \"mu_intercept_per_group\": 9.366307258605957, \"sigma_intercept_per_group\": 0.20311963558197021, \"sigma_obs\": 183.15081787109375, \"slope\": -0.04642743617296219, \"chain\": 1, \"draw\": 60}, {\"draws\": 261, \"mouse\": 0, \"mu_intercept_per_group\": 12.495116233825684, \"sigma_intercept_per_group\": 0.20675860345363617, \"sigma_obs\": 181.50875854492188, \"slope\": -0.04682363569736481, \"chain\": 1, \"draw\": 61}, {\"draws\": 261, \"mouse\": 1, \"mu_intercept_per_group\": 11.661664009094238, \"sigma_intercept_per_group\": 0.20675860345363617, \"sigma_obs\": 181.50875854492188, \"slope\": -0.04682363569736481, \"chain\": 1, \"draw\": 61}, {\"draws\": 261, \"mouse\": 2, \"mu_intercept_per_group\": 11.814748764038086, \"sigma_intercept_per_group\": 0.20675860345363617, \"sigma_obs\": 181.50875854492188, \"slope\": -0.04682363569736481, \"chain\": 1, \"draw\": 61}, {\"draws\": 261, \"mouse\": 3, \"mu_intercept_per_group\": 10.908892631530762, \"sigma_intercept_per_group\": 0.20675860345363617, \"sigma_obs\": 181.50875854492188, \"slope\": -0.04682363569736481, \"chain\": 1, \"draw\": 61}, {\"draws\": 261, \"mouse\": 4, \"mu_intercept_per_group\": 10.839127540588379, \"sigma_intercept_per_group\": 0.20675860345363617, \"sigma_obs\": 181.50875854492188, \"slope\": -0.04682363569736481, \"chain\": 1, \"draw\": 61}, {\"draws\": 261, \"mouse\": 5, \"mu_intercept_per_group\": 10.045977592468262, \"sigma_intercept_per_group\": 0.20675860345363617, \"sigma_obs\": 181.50875854492188, \"slope\": -0.04682363569736481, \"chain\": 1, \"draw\": 61}, {\"draws\": 261, \"mouse\": 6, \"mu_intercept_per_group\": 9.591887474060059, \"sigma_intercept_per_group\": 0.20675860345363617, \"sigma_obs\": 181.50875854492188, \"slope\": -0.04682363569736481, \"chain\": 1, \"draw\": 61}, {\"draws\": 261, \"mouse\": 7, \"mu_intercept_per_group\": 8.91333293914795, \"sigma_intercept_per_group\": 0.20675860345363617, \"sigma_obs\": 181.50875854492188, \"slope\": -0.04682363569736481, \"chain\": 1, \"draw\": 61}, {\"draws\": 262, \"mouse\": 0, \"mu_intercept_per_group\": 12.588187217712402, \"sigma_intercept_per_group\": 0.20602037012577057, \"sigma_obs\": 180.99978637695312, \"slope\": -0.046907711774110794, \"chain\": 1, \"draw\": 62}, {\"draws\": 262, \"mouse\": 1, \"mu_intercept_per_group\": 12.02862548828125, \"sigma_intercept_per_group\": 0.20602037012577057, \"sigma_obs\": 180.99978637695312, \"slope\": -0.046907711774110794, \"chain\": 1, \"draw\": 62}, {\"draws\": 262, \"mouse\": 2, \"mu_intercept_per_group\": 11.467535018920898, \"sigma_intercept_per_group\": 0.20602037012577057, \"sigma_obs\": 180.99978637695312, \"slope\": -0.046907711774110794, \"chain\": 1, \"draw\": 62}, {\"draws\": 262, \"mouse\": 3, \"mu_intercept_per_group\": 10.980742454528809, \"sigma_intercept_per_group\": 0.20602037012577057, \"sigma_obs\": 180.99978637695312, \"slope\": -0.046907711774110794, \"chain\": 1, \"draw\": 62}, {\"draws\": 262, \"mouse\": 4, \"mu_intercept_per_group\": 10.971883773803711, \"sigma_intercept_per_group\": 0.20602037012577057, \"sigma_obs\": 180.99978637695312, \"slope\": -0.046907711774110794, \"chain\": 1, \"draw\": 62}, {\"draws\": 262, \"mouse\": 5, \"mu_intercept_per_group\": 10.0648193359375, \"sigma_intercept_per_group\": 0.20602037012577057, \"sigma_obs\": 180.99978637695312, \"slope\": -0.046907711774110794, \"chain\": 1, \"draw\": 62}, {\"draws\": 262, \"mouse\": 6, \"mu_intercept_per_group\": 9.475364685058594, \"sigma_intercept_per_group\": 0.20602037012577057, \"sigma_obs\": 180.99978637695312, \"slope\": -0.046907711774110794, \"chain\": 1, \"draw\": 62}, {\"draws\": 262, \"mouse\": 7, \"mu_intercept_per_group\": 9.00442123413086, \"sigma_intercept_per_group\": 0.20602037012577057, \"sigma_obs\": 180.99978637695312, \"slope\": -0.046907711774110794, \"chain\": 1, \"draw\": 62}, {\"draws\": 263, \"mouse\": 0, \"mu_intercept_per_group\": 11.915135383605957, \"sigma_intercept_per_group\": 0.2233959436416626, \"sigma_obs\": 192.22727966308594, \"slope\": -0.07067390531301498, \"chain\": 1, \"draw\": 63}, {\"draws\": 263, \"mouse\": 1, \"mu_intercept_per_group\": 11.243053436279297, \"sigma_intercept_per_group\": 0.2233959436416626, \"sigma_obs\": 192.22727966308594, \"slope\": -0.07067390531301498, \"chain\": 1, \"draw\": 63}, {\"draws\": 263, \"mouse\": 2, \"mu_intercept_per_group\": 11.291340827941895, \"sigma_intercept_per_group\": 0.2233959436416626, \"sigma_obs\": 192.22727966308594, \"slope\": -0.07067390531301498, \"chain\": 1, \"draw\": 63}, {\"draws\": 263, \"mouse\": 3, \"mu_intercept_per_group\": 10.174832344055176, \"sigma_intercept_per_group\": 0.2233959436416626, \"sigma_obs\": 192.22727966308594, \"slope\": -0.07067390531301498, \"chain\": 1, \"draw\": 63}, {\"draws\": 263, \"mouse\": 4, \"mu_intercept_per_group\": 10.233746528625488, \"sigma_intercept_per_group\": 0.2233959436416626, \"sigma_obs\": 192.22727966308594, \"slope\": -0.07067390531301498, \"chain\": 1, \"draw\": 63}, {\"draws\": 263, \"mouse\": 5, \"mu_intercept_per_group\": 9.854655265808105, \"sigma_intercept_per_group\": 0.2233959436416626, \"sigma_obs\": 192.22727966308594, \"slope\": -0.07067390531301498, \"chain\": 1, \"draw\": 63}, {\"draws\": 263, \"mouse\": 6, \"mu_intercept_per_group\": 9.246499061584473, \"sigma_intercept_per_group\": 0.2233959436416626, \"sigma_obs\": 192.22727966308594, \"slope\": -0.07067390531301498, \"chain\": 1, \"draw\": 63}, {\"draws\": 263, \"mouse\": 7, \"mu_intercept_per_group\": 8.481893539428711, \"sigma_intercept_per_group\": 0.2233959436416626, \"sigma_obs\": 192.22727966308594, \"slope\": -0.07067390531301498, \"chain\": 1, \"draw\": 63}, {\"draws\": 264, \"mouse\": 0, \"mu_intercept_per_group\": 11.963971138000488, \"sigma_intercept_per_group\": 0.22422392666339874, \"sigma_obs\": 192.276611328125, \"slope\": -0.07076191902160645, \"chain\": 1, \"draw\": 64}, {\"draws\": 264, \"mouse\": 1, \"mu_intercept_per_group\": 11.240931510925293, \"sigma_intercept_per_group\": 0.22422392666339874, \"sigma_obs\": 192.276611328125, \"slope\": -0.07076191902160645, \"chain\": 1, \"draw\": 64}, {\"draws\": 264, \"mouse\": 2, \"mu_intercept_per_group\": 11.291754722595215, \"sigma_intercept_per_group\": 0.22422392666339874, \"sigma_obs\": 192.276611328125, \"slope\": -0.07076191902160645, \"chain\": 1, \"draw\": 64}, {\"draws\": 264, \"mouse\": 3, \"mu_intercept_per_group\": 10.113141059875488, \"sigma_intercept_per_group\": 0.22422392666339874, \"sigma_obs\": 192.276611328125, \"slope\": -0.07076191902160645, \"chain\": 1, \"draw\": 64}, {\"draws\": 264, \"mouse\": 4, \"mu_intercept_per_group\": 10.198851585388184, \"sigma_intercept_per_group\": 0.22422392666339874, \"sigma_obs\": 192.276611328125, \"slope\": -0.07076191902160645, \"chain\": 1, \"draw\": 64}, {\"draws\": 264, \"mouse\": 5, \"mu_intercept_per_group\": 9.968305587768555, \"sigma_intercept_per_group\": 0.22422392666339874, \"sigma_obs\": 192.276611328125, \"slope\": -0.07076191902160645, \"chain\": 1, \"draw\": 64}, {\"draws\": 264, \"mouse\": 6, \"mu_intercept_per_group\": 9.303313255310059, \"sigma_intercept_per_group\": 0.22422392666339874, \"sigma_obs\": 192.276611328125, \"slope\": -0.07076191902160645, \"chain\": 1, \"draw\": 64}, {\"draws\": 264, \"mouse\": 7, \"mu_intercept_per_group\": 8.484146118164062, \"sigma_intercept_per_group\": 0.22422392666339874, \"sigma_obs\": 192.276611328125, \"slope\": -0.07076191902160645, \"chain\": 1, \"draw\": 64}, {\"draws\": 265, \"mouse\": 0, \"mu_intercept_per_group\": 13.747886657714844, \"sigma_intercept_per_group\": 0.18359112739562988, \"sigma_obs\": 168.3919219970703, \"slope\": -0.08526390790939331, \"chain\": 1, \"draw\": 65}, {\"draws\": 265, \"mouse\": 1, \"mu_intercept_per_group\": 13.100323677062988, \"sigma_intercept_per_group\": 0.18359112739562988, \"sigma_obs\": 168.3919219970703, \"slope\": -0.08526390790939331, \"chain\": 1, \"draw\": 65}, {\"draws\": 265, \"mouse\": 2, \"mu_intercept_per_group\": 12.893837928771973, \"sigma_intercept_per_group\": 0.18359112739562988, \"sigma_obs\": 168.3919219970703, \"slope\": -0.08526390790939331, \"chain\": 1, \"draw\": 65}, {\"draws\": 265, \"mouse\": 3, \"mu_intercept_per_group\": 12.31835651397705, \"sigma_intercept_per_group\": 0.18359112739562988, \"sigma_obs\": 168.3919219970703, \"slope\": -0.08526390790939331, \"chain\": 1, \"draw\": 65}, {\"draws\": 265, \"mouse\": 4, \"mu_intercept_per_group\": 11.824544906616211, \"sigma_intercept_per_group\": 0.18359112739562988, \"sigma_obs\": 168.3919219970703, \"slope\": -0.08526390790939331, \"chain\": 1, \"draw\": 65}, {\"draws\": 265, \"mouse\": 5, \"mu_intercept_per_group\": 11.537144660949707, \"sigma_intercept_per_group\": 0.18359112739562988, \"sigma_obs\": 168.3919219970703, \"slope\": -0.08526390790939331, \"chain\": 1, \"draw\": 65}, {\"draws\": 265, \"mouse\": 6, \"mu_intercept_per_group\": 10.843310356140137, \"sigma_intercept_per_group\": 0.18359112739562988, \"sigma_obs\": 168.3919219970703, \"slope\": -0.08526390790939331, \"chain\": 1, \"draw\": 65}, {\"draws\": 265, \"mouse\": 7, \"mu_intercept_per_group\": 10.314022064208984, \"sigma_intercept_per_group\": 0.18359112739562988, \"sigma_obs\": 168.3919219970703, \"slope\": -0.08526390790939331, \"chain\": 1, \"draw\": 65}, {\"draws\": 266, \"mouse\": 0, \"mu_intercept_per_group\": 13.883459091186523, \"sigma_intercept_per_group\": 0.18118704855442047, \"sigma_obs\": 168.69329833984375, \"slope\": -0.08636504411697388, \"chain\": 1, \"draw\": 66}, {\"draws\": 266, \"mouse\": 1, \"mu_intercept_per_group\": 13.444437980651855, \"sigma_intercept_per_group\": 0.18118704855442047, \"sigma_obs\": 168.69329833984375, \"slope\": -0.08636504411697388, \"chain\": 1, \"draw\": 66}, {\"draws\": 266, \"mouse\": 2, \"mu_intercept_per_group\": 13.005571365356445, \"sigma_intercept_per_group\": 0.18118704855442047, \"sigma_obs\": 168.69329833984375, \"slope\": -0.08636504411697388, \"chain\": 1, \"draw\": 66}, {\"draws\": 266, \"mouse\": 3, \"mu_intercept_per_group\": 12.50775146484375, \"sigma_intercept_per_group\": 0.18118704855442047, \"sigma_obs\": 168.69329833984375, \"slope\": -0.08636504411697388, \"chain\": 1, \"draw\": 66}, {\"draws\": 266, \"mouse\": 4, \"mu_intercept_per_group\": 11.724592208862305, \"sigma_intercept_per_group\": 0.18118704855442047, \"sigma_obs\": 168.69329833984375, \"slope\": -0.08636504411697388, \"chain\": 1, \"draw\": 66}, {\"draws\": 266, \"mouse\": 5, \"mu_intercept_per_group\": 11.676307678222656, \"sigma_intercept_per_group\": 0.18118704855442047, \"sigma_obs\": 168.69329833984375, \"slope\": -0.08636504411697388, \"chain\": 1, \"draw\": 66}, {\"draws\": 266, \"mouse\": 6, \"mu_intercept_per_group\": 11.018671989440918, \"sigma_intercept_per_group\": 0.18118704855442047, \"sigma_obs\": 168.69329833984375, \"slope\": -0.08636504411697388, \"chain\": 1, \"draw\": 66}, {\"draws\": 266, \"mouse\": 7, \"mu_intercept_per_group\": 10.286566734313965, \"sigma_intercept_per_group\": 0.18118704855442047, \"sigma_obs\": 168.69329833984375, \"slope\": -0.08636504411697388, \"chain\": 1, \"draw\": 66}, {\"draws\": 267, \"mouse\": 0, \"mu_intercept_per_group\": 14.270333290100098, \"sigma_intercept_per_group\": 0.1816544234752655, \"sigma_obs\": 170.0301513671875, \"slope\": -0.08874461054801941, \"chain\": 1, \"draw\": 67}, {\"draws\": 267, \"mouse\": 1, \"mu_intercept_per_group\": 13.650616645812988, \"sigma_intercept_per_group\": 0.1816544234752655, \"sigma_obs\": 170.0301513671875, \"slope\": -0.08874461054801941, \"chain\": 1, \"draw\": 67}, {\"draws\": 267, \"mouse\": 2, \"mu_intercept_per_group\": 13.208481788635254, \"sigma_intercept_per_group\": 0.1816544234752655, \"sigma_obs\": 170.0301513671875, \"slope\": -0.08874461054801941, \"chain\": 1, \"draw\": 67}, {\"draws\": 267, \"mouse\": 3, \"mu_intercept_per_group\": 12.269460678100586, \"sigma_intercept_per_group\": 0.1816544234752655, \"sigma_obs\": 170.0301513671875, \"slope\": -0.08874461054801941, \"chain\": 1, \"draw\": 67}, {\"draws\": 267, \"mouse\": 4, \"mu_intercept_per_group\": 12.364483833312988, \"sigma_intercept_per_group\": 0.1816544234752655, \"sigma_obs\": 170.0301513671875, \"slope\": -0.08874461054801941, \"chain\": 1, \"draw\": 67}, {\"draws\": 267, \"mouse\": 5, \"mu_intercept_per_group\": 11.634489059448242, \"sigma_intercept_per_group\": 0.1816544234752655, \"sigma_obs\": 170.0301513671875, \"slope\": -0.08874461054801941, \"chain\": 1, \"draw\": 67}, {\"draws\": 267, \"mouse\": 6, \"mu_intercept_per_group\": 10.786369323730469, \"sigma_intercept_per_group\": 0.1816544234752655, \"sigma_obs\": 170.0301513671875, \"slope\": -0.08874461054801941, \"chain\": 1, \"draw\": 67}, {\"draws\": 267, \"mouse\": 7, \"mu_intercept_per_group\": 9.980602264404297, \"sigma_intercept_per_group\": 0.1816544234752655, \"sigma_obs\": 170.0301513671875, \"slope\": -0.08874461054801941, \"chain\": 1, \"draw\": 67}, {\"draws\": 268, \"mouse\": 0, \"mu_intercept_per_group\": 13.906664848327637, \"sigma_intercept_per_group\": 0.18589472770690918, \"sigma_obs\": 178.67352294921875, \"slope\": -0.06080049276351929, \"chain\": 1, \"draw\": 68}, {\"draws\": 268, \"mouse\": 1, \"mu_intercept_per_group\": 13.11266040802002, \"sigma_intercept_per_group\": 0.18589472770690918, \"sigma_obs\": 178.67352294921875, \"slope\": -0.06080049276351929, \"chain\": 1, \"draw\": 68}, {\"draws\": 268, \"mouse\": 2, \"mu_intercept_per_group\": 12.875127792358398, \"sigma_intercept_per_group\": 0.18589472770690918, \"sigma_obs\": 178.67352294921875, \"slope\": -0.06080049276351929, \"chain\": 1, \"draw\": 68}, {\"draws\": 268, \"mouse\": 3, \"mu_intercept_per_group\": 12.36202335357666, \"sigma_intercept_per_group\": 0.18589472770690918, \"sigma_obs\": 178.67352294921875, \"slope\": -0.06080049276351929, \"chain\": 1, \"draw\": 68}, {\"draws\": 268, \"mouse\": 4, \"mu_intercept_per_group\": 11.768362998962402, \"sigma_intercept_per_group\": 0.18589472770690918, \"sigma_obs\": 178.67352294921875, \"slope\": -0.06080049276351929, \"chain\": 1, \"draw\": 68}, {\"draws\": 268, \"mouse\": 5, \"mu_intercept_per_group\": 11.31446647644043, \"sigma_intercept_per_group\": 0.18589472770690918, \"sigma_obs\": 178.67352294921875, \"slope\": -0.06080049276351929, \"chain\": 1, \"draw\": 68}, {\"draws\": 268, \"mouse\": 6, \"mu_intercept_per_group\": 10.609794616699219, \"sigma_intercept_per_group\": 0.18589472770690918, \"sigma_obs\": 178.67352294921875, \"slope\": -0.06080049276351929, \"chain\": 1, \"draw\": 68}, {\"draws\": 268, \"mouse\": 7, \"mu_intercept_per_group\": 10.20462703704834, \"sigma_intercept_per_group\": 0.18589472770690918, \"sigma_obs\": 178.67352294921875, \"slope\": -0.06080049276351929, \"chain\": 1, \"draw\": 68}, {\"draws\": 269, \"mouse\": 0, \"mu_intercept_per_group\": 13.893438339233398, \"sigma_intercept_per_group\": 0.18366485834121704, \"sigma_obs\": 180.28424072265625, \"slope\": -0.06255704164505005, \"chain\": 1, \"draw\": 69}, {\"draws\": 269, \"mouse\": 1, \"mu_intercept_per_group\": 13.605257034301758, \"sigma_intercept_per_group\": 0.18366485834121704, \"sigma_obs\": 180.28424072265625, \"slope\": -0.06255704164505005, \"chain\": 1, \"draw\": 69}, {\"draws\": 269, \"mouse\": 2, \"mu_intercept_per_group\": 13.12439250946045, \"sigma_intercept_per_group\": 0.18366485834121704, \"sigma_obs\": 180.28424072265625, \"slope\": -0.06255704164505005, \"chain\": 1, \"draw\": 69}, {\"draws\": 269, \"mouse\": 3, \"mu_intercept_per_group\": 12.247550964355469, \"sigma_intercept_per_group\": 0.18366485834121704, \"sigma_obs\": 180.28424072265625, \"slope\": -0.06255704164505005, \"chain\": 1, \"draw\": 69}, {\"draws\": 269, \"mouse\": 4, \"mu_intercept_per_group\": 12.199721336364746, \"sigma_intercept_per_group\": 0.18366485834121704, \"sigma_obs\": 180.28424072265625, \"slope\": -0.06255704164505005, \"chain\": 1, \"draw\": 69}, {\"draws\": 269, \"mouse\": 5, \"mu_intercept_per_group\": 11.340720176696777, \"sigma_intercept_per_group\": 0.18366485834121704, \"sigma_obs\": 180.28424072265625, \"slope\": -0.06255704164505005, \"chain\": 1, \"draw\": 69}, {\"draws\": 269, \"mouse\": 6, \"mu_intercept_per_group\": 10.738554954528809, \"sigma_intercept_per_group\": 0.18366485834121704, \"sigma_obs\": 180.28424072265625, \"slope\": -0.06255704164505005, \"chain\": 1, \"draw\": 69}, {\"draws\": 269, \"mouse\": 7, \"mu_intercept_per_group\": 9.974769592285156, \"sigma_intercept_per_group\": 0.18366485834121704, \"sigma_obs\": 180.28424072265625, \"slope\": -0.06255704164505005, \"chain\": 1, \"draw\": 69}, {\"draws\": 270, \"mouse\": 0, \"mu_intercept_per_group\": 14.028482437133789, \"sigma_intercept_per_group\": 0.1843125820159912, \"sigma_obs\": 187.94256591796875, \"slope\": -0.06195991858839989, \"chain\": 1, \"draw\": 70}, {\"draws\": 270, \"mouse\": 1, \"mu_intercept_per_group\": 13.824867248535156, \"sigma_intercept_per_group\": 0.1843125820159912, \"sigma_obs\": 187.94256591796875, \"slope\": -0.06195991858839989, \"chain\": 1, \"draw\": 70}, {\"draws\": 270, \"mouse\": 2, \"mu_intercept_per_group\": 13.312899589538574, \"sigma_intercept_per_group\": 0.1843125820159912, \"sigma_obs\": 187.94256591796875, \"slope\": -0.06195991858839989, \"chain\": 1, \"draw\": 70}, {\"draws\": 270, \"mouse\": 3, \"mu_intercept_per_group\": 12.413568496704102, \"sigma_intercept_per_group\": 0.1843125820159912, \"sigma_obs\": 187.94256591796875, \"slope\": -0.06195991858839989, \"chain\": 1, \"draw\": 70}, {\"draws\": 270, \"mouse\": 4, \"mu_intercept_per_group\": 12.352392196655273, \"sigma_intercept_per_group\": 0.1843125820159912, \"sigma_obs\": 187.94256591796875, \"slope\": -0.06195991858839989, \"chain\": 1, \"draw\": 70}, {\"draws\": 270, \"mouse\": 5, \"mu_intercept_per_group\": 11.625724792480469, \"sigma_intercept_per_group\": 0.1843125820159912, \"sigma_obs\": 187.94256591796875, \"slope\": -0.06195991858839989, \"chain\": 1, \"draw\": 70}, {\"draws\": 270, \"mouse\": 6, \"mu_intercept_per_group\": 10.736714363098145, \"sigma_intercept_per_group\": 0.1843125820159912, \"sigma_obs\": 187.94256591796875, \"slope\": -0.06195991858839989, \"chain\": 1, \"draw\": 70}, {\"draws\": 270, \"mouse\": 7, \"mu_intercept_per_group\": 10.647855758666992, \"sigma_intercept_per_group\": 0.1843125820159912, \"sigma_obs\": 187.94256591796875, \"slope\": -0.06195991858839989, \"chain\": 1, \"draw\": 70}, {\"draws\": 271, \"mouse\": 0, \"mu_intercept_per_group\": 15.096702575683594, \"sigma_intercept_per_group\": 0.16627278923988342, \"sigma_obs\": 160.31747436523438, \"slope\": -0.09078148007392883, \"chain\": 1, \"draw\": 71}, {\"draws\": 271, \"mouse\": 1, \"mu_intercept_per_group\": 14.608909606933594, \"sigma_intercept_per_group\": 0.16627278923988342, \"sigma_obs\": 160.31747436523438, \"slope\": -0.09078148007392883, \"chain\": 1, \"draw\": 71}, {\"draws\": 271, \"mouse\": 2, \"mu_intercept_per_group\": 13.875463485717773, \"sigma_intercept_per_group\": 0.16627278923988342, \"sigma_obs\": 160.31747436523438, \"slope\": -0.09078148007392883, \"chain\": 1, \"draw\": 71}, {\"draws\": 271, \"mouse\": 3, \"mu_intercept_per_group\": 13.26345443725586, \"sigma_intercept_per_group\": 0.16627278923988342, \"sigma_obs\": 160.31747436523438, \"slope\": -0.09078148007392883, \"chain\": 1, \"draw\": 71}, {\"draws\": 271, \"mouse\": 4, \"mu_intercept_per_group\": 12.696471214294434, \"sigma_intercept_per_group\": 0.16627278923988342, \"sigma_obs\": 160.31747436523438, \"slope\": -0.09078148007392883, \"chain\": 1, \"draw\": 71}, {\"draws\": 271, \"mouse\": 5, \"mu_intercept_per_group\": 12.319963455200195, \"sigma_intercept_per_group\": 0.16627278923988342, \"sigma_obs\": 160.31747436523438, \"slope\": -0.09078148007392883, \"chain\": 1, \"draw\": 71}, {\"draws\": 271, \"mouse\": 6, \"mu_intercept_per_group\": 11.042283058166504, \"sigma_intercept_per_group\": 0.16627278923988342, \"sigma_obs\": 160.31747436523438, \"slope\": -0.09078148007392883, \"chain\": 1, \"draw\": 71}, {\"draws\": 271, \"mouse\": 7, \"mu_intercept_per_group\": 10.344144821166992, \"sigma_intercept_per_group\": 0.16627278923988342, \"sigma_obs\": 160.31747436523438, \"slope\": -0.09078148007392883, \"chain\": 1, \"draw\": 71}, {\"draws\": 272, \"mouse\": 0, \"mu_intercept_per_group\": 13.39078140258789, \"sigma_intercept_per_group\": 0.18611982464790344, \"sigma_obs\": 162.82138061523438, \"slope\": -0.07937028259038925, \"chain\": 1, \"draw\": 72}, {\"draws\": 272, \"mouse\": 1, \"mu_intercept_per_group\": 13.457091331481934, \"sigma_intercept_per_group\": 0.18611982464790344, \"sigma_obs\": 162.82138061523438, \"slope\": -0.07937028259038925, \"chain\": 1, \"draw\": 72}, {\"draws\": 272, \"mouse\": 2, \"mu_intercept_per_group\": 12.569717407226562, \"sigma_intercept_per_group\": 0.18611982464790344, \"sigma_obs\": 162.82138061523438, \"slope\": -0.07937028259038925, \"chain\": 1, \"draw\": 72}, {\"draws\": 272, \"mouse\": 3, \"mu_intercept_per_group\": 12.173370361328125, \"sigma_intercept_per_group\": 0.18611982464790344, \"sigma_obs\": 162.82138061523438, \"slope\": -0.07937028259038925, \"chain\": 1, \"draw\": 72}, {\"draws\": 272, \"mouse\": 4, \"mu_intercept_per_group\": 11.841873168945312, \"sigma_intercept_per_group\": 0.18611982464790344, \"sigma_obs\": 162.82138061523438, \"slope\": -0.07937028259038925, \"chain\": 1, \"draw\": 72}, {\"draws\": 272, \"mouse\": 5, \"mu_intercept_per_group\": 11.079113006591797, \"sigma_intercept_per_group\": 0.18611982464790344, \"sigma_obs\": 162.82138061523438, \"slope\": -0.07937028259038925, \"chain\": 1, \"draw\": 72}, {\"draws\": 272, \"mouse\": 6, \"mu_intercept_per_group\": 10.258938789367676, \"sigma_intercept_per_group\": 0.18611982464790344, \"sigma_obs\": 162.82138061523438, \"slope\": -0.07937028259038925, \"chain\": 1, \"draw\": 72}, {\"draws\": 272, \"mouse\": 7, \"mu_intercept_per_group\": 10.084123611450195, \"sigma_intercept_per_group\": 0.18611982464790344, \"sigma_obs\": 162.82138061523438, \"slope\": -0.07937028259038925, \"chain\": 1, \"draw\": 72}, {\"draws\": 273, \"mouse\": 0, \"mu_intercept_per_group\": 13.945594787597656, \"sigma_intercept_per_group\": 0.17332059144973755, \"sigma_obs\": 160.24012756347656, \"slope\": -0.07844862341880798, \"chain\": 1, \"draw\": 73}, {\"draws\": 273, \"mouse\": 1, \"mu_intercept_per_group\": 14.012626647949219, \"sigma_intercept_per_group\": 0.17332059144973755, \"sigma_obs\": 160.24012756347656, \"slope\": -0.07844862341880798, \"chain\": 1, \"draw\": 73}, {\"draws\": 273, \"mouse\": 2, \"mu_intercept_per_group\": 13.275485038757324, \"sigma_intercept_per_group\": 0.17332059144973755, \"sigma_obs\": 160.24012756347656, \"slope\": -0.07844862341880798, \"chain\": 1, \"draw\": 73}, {\"draws\": 273, \"mouse\": 3, \"mu_intercept_per_group\": 12.631742477416992, \"sigma_intercept_per_group\": 0.17332059144973755, \"sigma_obs\": 160.24012756347656, \"slope\": -0.07844862341880798, \"chain\": 1, \"draw\": 73}, {\"draws\": 273, \"mouse\": 4, \"mu_intercept_per_group\": 11.913870811462402, \"sigma_intercept_per_group\": 0.17332059144973755, \"sigma_obs\": 160.24012756347656, \"slope\": -0.07844862341880798, \"chain\": 1, \"draw\": 73}, {\"draws\": 273, \"mouse\": 5, \"mu_intercept_per_group\": 11.33776569366455, \"sigma_intercept_per_group\": 0.17332059144973755, \"sigma_obs\": 160.24012756347656, \"slope\": -0.07844862341880798, \"chain\": 1, \"draw\": 73}, {\"draws\": 273, \"mouse\": 6, \"mu_intercept_per_group\": 10.95383358001709, \"sigma_intercept_per_group\": 0.17332059144973755, \"sigma_obs\": 160.24012756347656, \"slope\": -0.07844862341880798, \"chain\": 1, \"draw\": 73}, {\"draws\": 273, \"mouse\": 7, \"mu_intercept_per_group\": 10.082966804504395, \"sigma_intercept_per_group\": 0.17332059144973755, \"sigma_obs\": 160.24012756347656, \"slope\": -0.07844862341880798, \"chain\": 1, \"draw\": 73}, {\"draws\": 274, \"mouse\": 0, \"mu_intercept_per_group\": 13.244973182678223, \"sigma_intercept_per_group\": 0.17568862438201904, \"sigma_obs\": 154.1225128173828, \"slope\": -0.04943570867180824, \"chain\": 1, \"draw\": 74}, {\"draws\": 274, \"mouse\": 1, \"mu_intercept_per_group\": 13.451159477233887, \"sigma_intercept_per_group\": 0.17568862438201904, \"sigma_obs\": 154.1225128173828, \"slope\": -0.04943570867180824, \"chain\": 1, \"draw\": 74}, {\"draws\": 274, \"mouse\": 2, \"mu_intercept_per_group\": 12.773608207702637, \"sigma_intercept_per_group\": 0.17568862438201904, \"sigma_obs\": 154.1225128173828, \"slope\": -0.04943570867180824, \"chain\": 1, \"draw\": 74}, {\"draws\": 274, \"mouse\": 3, \"mu_intercept_per_group\": 11.631560325622559, \"sigma_intercept_per_group\": 0.17568862438201904, \"sigma_obs\": 154.1225128173828, \"slope\": -0.04943570867180824, \"chain\": 1, \"draw\": 74}, {\"draws\": 274, \"mouse\": 4, \"mu_intercept_per_group\": 11.559688568115234, \"sigma_intercept_per_group\": 0.17568862438201904, \"sigma_obs\": 154.1225128173828, \"slope\": -0.04943570867180824, \"chain\": 1, \"draw\": 74}, {\"draws\": 274, \"mouse\": 5, \"mu_intercept_per_group\": 11.023323059082031, \"sigma_intercept_per_group\": 0.17568862438201904, \"sigma_obs\": 154.1225128173828, \"slope\": -0.04943570867180824, \"chain\": 1, \"draw\": 74}, {\"draws\": 274, \"mouse\": 6, \"mu_intercept_per_group\": 9.977683067321777, \"sigma_intercept_per_group\": 0.17568862438201904, \"sigma_obs\": 154.1225128173828, \"slope\": -0.04943570867180824, \"chain\": 1, \"draw\": 74}, {\"draws\": 274, \"mouse\": 7, \"mu_intercept_per_group\": 9.491470336914062, \"sigma_intercept_per_group\": 0.17568862438201904, \"sigma_obs\": 154.1225128173828, \"slope\": -0.04943570867180824, \"chain\": 1, \"draw\": 74}, {\"draws\": 275, \"mouse\": 0, \"mu_intercept_per_group\": 13.795119285583496, \"sigma_intercept_per_group\": 0.1796749085187912, \"sigma_obs\": 155.24053955078125, \"slope\": -0.0468255914747715, \"chain\": 1, \"draw\": 75}, {\"draws\": 275, \"mouse\": 1, \"mu_intercept_per_group\": 12.557745933532715, \"sigma_intercept_per_group\": 0.1796749085187912, \"sigma_obs\": 155.24053955078125, \"slope\": -0.0468255914747715, \"chain\": 1, \"draw\": 75}, {\"draws\": 275, \"mouse\": 2, \"mu_intercept_per_group\": 12.5525541305542, \"sigma_intercept_per_group\": 0.1796749085187912, \"sigma_obs\": 155.24053955078125, \"slope\": -0.0468255914747715, \"chain\": 1, \"draw\": 75}, {\"draws\": 275, \"mouse\": 3, \"mu_intercept_per_group\": 11.94640064239502, \"sigma_intercept_per_group\": 0.1796749085187912, \"sigma_obs\": 155.24053955078125, \"slope\": -0.0468255914747715, \"chain\": 1, \"draw\": 75}, {\"draws\": 275, \"mouse\": 4, \"mu_intercept_per_group\": 11.541899681091309, \"sigma_intercept_per_group\": 0.1796749085187912, \"sigma_obs\": 155.24053955078125, \"slope\": -0.0468255914747715, \"chain\": 1, \"draw\": 75}, {\"draws\": 275, \"mouse\": 5, \"mu_intercept_per_group\": 11.105936050415039, \"sigma_intercept_per_group\": 0.1796749085187912, \"sigma_obs\": 155.24053955078125, \"slope\": -0.0468255914747715, \"chain\": 1, \"draw\": 75}, {\"draws\": 275, \"mouse\": 6, \"mu_intercept_per_group\": 10.572806358337402, \"sigma_intercept_per_group\": 0.1796749085187912, \"sigma_obs\": 155.24053955078125, \"slope\": -0.0468255914747715, \"chain\": 1, \"draw\": 75}, {\"draws\": 275, \"mouse\": 7, \"mu_intercept_per_group\": 9.39113998413086, \"sigma_intercept_per_group\": 0.1796749085187912, \"sigma_obs\": 155.24053955078125, \"slope\": -0.0468255914747715, \"chain\": 1, \"draw\": 75}, {\"draws\": 276, \"mouse\": 0, \"mu_intercept_per_group\": 13.626147270202637, \"sigma_intercept_per_group\": 0.17821630835533142, \"sigma_obs\": 154.58251953125, \"slope\": -0.0468759760260582, \"chain\": 1, \"draw\": 76}, {\"draws\": 276, \"mouse\": 1, \"mu_intercept_per_group\": 12.8501615524292, \"sigma_intercept_per_group\": 0.17821630835533142, \"sigma_obs\": 154.58251953125, \"slope\": -0.0468759760260582, \"chain\": 1, \"draw\": 76}, {\"draws\": 276, \"mouse\": 2, \"mu_intercept_per_group\": 12.504575729370117, \"sigma_intercept_per_group\": 0.17821630835533142, \"sigma_obs\": 154.58251953125, \"slope\": -0.0468759760260582, \"chain\": 1, \"draw\": 76}, {\"draws\": 276, \"mouse\": 3, \"mu_intercept_per_group\": 12.270326614379883, \"sigma_intercept_per_group\": 0.17821630835533142, \"sigma_obs\": 154.58251953125, \"slope\": -0.0468759760260582, \"chain\": 1, \"draw\": 76}, {\"draws\": 276, \"mouse\": 4, \"mu_intercept_per_group\": 11.686993598937988, \"sigma_intercept_per_group\": 0.17821630835533142, \"sigma_obs\": 154.58251953125, \"slope\": -0.0468759760260582, \"chain\": 1, \"draw\": 76}, {\"draws\": 276, \"mouse\": 5, \"mu_intercept_per_group\": 10.812193870544434, \"sigma_intercept_per_group\": 0.17821630835533142, \"sigma_obs\": 154.58251953125, \"slope\": -0.0468759760260582, \"chain\": 1, \"draw\": 76}, {\"draws\": 276, \"mouse\": 6, \"mu_intercept_per_group\": 10.574665069580078, \"sigma_intercept_per_group\": 0.17821630835533142, \"sigma_obs\": 154.58251953125, \"slope\": -0.0468759760260582, \"chain\": 1, \"draw\": 76}, {\"draws\": 276, \"mouse\": 7, \"mu_intercept_per_group\": 9.942620277404785, \"sigma_intercept_per_group\": 0.17821630835533142, \"sigma_obs\": 154.58251953125, \"slope\": -0.0468759760260582, \"chain\": 1, \"draw\": 76}, {\"draws\": 277, \"mouse\": 0, \"mu_intercept_per_group\": 10.893963813781738, \"sigma_intercept_per_group\": 0.2358262538909912, \"sigma_obs\": 164.8993377685547, \"slope\": -0.09769861400127411, \"chain\": 1, \"draw\": 77}, {\"draws\": 277, \"mouse\": 1, \"mu_intercept_per_group\": 10.39931583404541, \"sigma_intercept_per_group\": 0.2358262538909912, \"sigma_obs\": 164.8993377685547, \"slope\": -0.09769861400127411, \"chain\": 1, \"draw\": 77}, {\"draws\": 277, \"mouse\": 2, \"mu_intercept_per_group\": 10.051054000854492, \"sigma_intercept_per_group\": 0.2358262538909912, \"sigma_obs\": 164.8993377685547, \"slope\": -0.09769861400127411, \"chain\": 1, \"draw\": 77}, {\"draws\": 277, \"mouse\": 3, \"mu_intercept_per_group\": 9.96043586730957, \"sigma_intercept_per_group\": 0.2358262538909912, \"sigma_obs\": 164.8993377685547, \"slope\": -0.09769861400127411, \"chain\": 1, \"draw\": 77}, {\"draws\": 277, \"mouse\": 4, \"mu_intercept_per_group\": 9.384839057922363, \"sigma_intercept_per_group\": 0.2358262538909912, \"sigma_obs\": 164.8993377685547, \"slope\": -0.09769861400127411, \"chain\": 1, \"draw\": 77}, {\"draws\": 277, \"mouse\": 5, \"mu_intercept_per_group\": 9.223207473754883, \"sigma_intercept_per_group\": 0.2358262538909912, \"sigma_obs\": 164.8993377685547, \"slope\": -0.09769861400127411, \"chain\": 1, \"draw\": 77}, {\"draws\": 277, \"mouse\": 6, \"mu_intercept_per_group\": 8.24203109741211, \"sigma_intercept_per_group\": 0.2358262538909912, \"sigma_obs\": 164.8993377685547, \"slope\": -0.09769861400127411, \"chain\": 1, \"draw\": 77}, {\"draws\": 277, \"mouse\": 7, \"mu_intercept_per_group\": 7.864625453948975, \"sigma_intercept_per_group\": 0.2358262538909912, \"sigma_obs\": 164.8993377685547, \"slope\": -0.09769861400127411, \"chain\": 1, \"draw\": 77}, {\"draws\": 278, \"mouse\": 0, \"mu_intercept_per_group\": 11.002288818359375, \"sigma_intercept_per_group\": 0.22959396243095398, \"sigma_obs\": 164.89816284179688, \"slope\": -0.09846997261047363, \"chain\": 1, \"draw\": 78}, {\"draws\": 278, \"mouse\": 1, \"mu_intercept_per_group\": 10.447009086608887, \"sigma_intercept_per_group\": 0.22959396243095398, \"sigma_obs\": 164.89816284179688, \"slope\": -0.09846997261047363, \"chain\": 1, \"draw\": 78}, {\"draws\": 278, \"mouse\": 2, \"mu_intercept_per_group\": 9.996681213378906, \"sigma_intercept_per_group\": 0.22959396243095398, \"sigma_obs\": 164.89816284179688, \"slope\": -0.09846997261047363, \"chain\": 1, \"draw\": 78}, {\"draws\": 278, \"mouse\": 3, \"mu_intercept_per_group\": 9.80187702178955, \"sigma_intercept_per_group\": 0.22959396243095398, \"sigma_obs\": 164.89816284179688, \"slope\": -0.09846997261047363, \"chain\": 1, \"draw\": 78}, {\"draws\": 278, \"mouse\": 4, \"mu_intercept_per_group\": 9.416247367858887, \"sigma_intercept_per_group\": 0.22959396243095398, \"sigma_obs\": 164.89816284179688, \"slope\": -0.09846997261047363, \"chain\": 1, \"draw\": 78}, {\"draws\": 278, \"mouse\": 5, \"mu_intercept_per_group\": 9.241677284240723, \"sigma_intercept_per_group\": 0.22959396243095398, \"sigma_obs\": 164.89816284179688, \"slope\": -0.09846997261047363, \"chain\": 1, \"draw\": 78}, {\"draws\": 278, \"mouse\": 6, \"mu_intercept_per_group\": 8.36453914642334, \"sigma_intercept_per_group\": 0.22959396243095398, \"sigma_obs\": 164.89816284179688, \"slope\": -0.09846997261047363, \"chain\": 1, \"draw\": 78}, {\"draws\": 278, \"mouse\": 7, \"mu_intercept_per_group\": 7.976189136505127, \"sigma_intercept_per_group\": 0.22959396243095398, \"sigma_obs\": 164.89816284179688, \"slope\": -0.09846997261047363, \"chain\": 1, \"draw\": 78}, {\"draws\": 279, \"mouse\": 0, \"mu_intercept_per_group\": 9.593973159790039, \"sigma_intercept_per_group\": 0.26130208373069763, \"sigma_obs\": 173.64358520507812, \"slope\": -0.08201796561479568, \"chain\": 1, \"draw\": 79}, {\"draws\": 279, \"mouse\": 1, \"mu_intercept_per_group\": 9.235185623168945, \"sigma_intercept_per_group\": 0.26130208373069763, \"sigma_obs\": 173.64358520507812, \"slope\": -0.08201796561479568, \"chain\": 1, \"draw\": 79}, {\"draws\": 279, \"mouse\": 2, \"mu_intercept_per_group\": 9.165855407714844, \"sigma_intercept_per_group\": 0.26130208373069763, \"sigma_obs\": 173.64358520507812, \"slope\": -0.08201796561479568, \"chain\": 1, \"draw\": 79}, {\"draws\": 279, \"mouse\": 3, \"mu_intercept_per_group\": 8.869417190551758, \"sigma_intercept_per_group\": 0.26130208373069763, \"sigma_obs\": 173.64358520507812, \"slope\": -0.08201796561479568, \"chain\": 1, \"draw\": 79}, {\"draws\": 279, \"mouse\": 4, \"mu_intercept_per_group\": 8.634356498718262, \"sigma_intercept_per_group\": 0.26130208373069763, \"sigma_obs\": 173.64358520507812, \"slope\": -0.08201796561479568, \"chain\": 1, \"draw\": 79}, {\"draws\": 279, \"mouse\": 5, \"mu_intercept_per_group\": 7.797507286071777, \"sigma_intercept_per_group\": 0.26130208373069763, \"sigma_obs\": 173.64358520507812, \"slope\": -0.08201796561479568, \"chain\": 1, \"draw\": 79}, {\"draws\": 279, \"mouse\": 6, \"mu_intercept_per_group\": 7.4325032234191895, \"sigma_intercept_per_group\": 0.26130208373069763, \"sigma_obs\": 173.64358520507812, \"slope\": -0.08201796561479568, \"chain\": 1, \"draw\": 79}, {\"draws\": 279, \"mouse\": 7, \"mu_intercept_per_group\": 7.076809406280518, \"sigma_intercept_per_group\": 0.26130208373069763, \"sigma_obs\": 173.64358520507812, \"slope\": -0.08201796561479568, \"chain\": 1, \"draw\": 79}, {\"draws\": 280, \"mouse\": 0, \"mu_intercept_per_group\": 9.18665885925293, \"sigma_intercept_per_group\": 0.27786606550216675, \"sigma_obs\": 173.4302520751953, \"slope\": -0.08196693658828735, \"chain\": 1, \"draw\": 80}, {\"draws\": 280, \"mouse\": 1, \"mu_intercept_per_group\": 8.869138717651367, \"sigma_intercept_per_group\": 0.27786606550216675, \"sigma_obs\": 173.4302520751953, \"slope\": -0.08196693658828735, \"chain\": 1, \"draw\": 80}, {\"draws\": 280, \"mouse\": 2, \"mu_intercept_per_group\": 8.6944580078125, \"sigma_intercept_per_group\": 0.27786606550216675, \"sigma_obs\": 173.4302520751953, \"slope\": -0.08196693658828735, \"chain\": 1, \"draw\": 80}, {\"draws\": 280, \"mouse\": 3, \"mu_intercept_per_group\": 8.343393325805664, \"sigma_intercept_per_group\": 0.27786606550216675, \"sigma_obs\": 173.4302520751953, \"slope\": -0.08196693658828735, \"chain\": 1, \"draw\": 80}, {\"draws\": 280, \"mouse\": 4, \"mu_intercept_per_group\": 8.158573150634766, \"sigma_intercept_per_group\": 0.27786606550216675, \"sigma_obs\": 173.4302520751953, \"slope\": -0.08196693658828735, \"chain\": 1, \"draw\": 80}, {\"draws\": 280, \"mouse\": 5, \"mu_intercept_per_group\": 7.6462178230285645, \"sigma_intercept_per_group\": 0.27786606550216675, \"sigma_obs\": 173.4302520751953, \"slope\": -0.08196693658828735, \"chain\": 1, \"draw\": 80}, {\"draws\": 280, \"mouse\": 6, \"mu_intercept_per_group\": 7.218209743499756, \"sigma_intercept_per_group\": 0.27786606550216675, \"sigma_obs\": 173.4302520751953, \"slope\": -0.08196693658828735, \"chain\": 1, \"draw\": 80}, {\"draws\": 280, \"mouse\": 7, \"mu_intercept_per_group\": 6.881120204925537, \"sigma_intercept_per_group\": 0.27786606550216675, \"sigma_obs\": 173.4302520751953, \"slope\": -0.08196693658828735, \"chain\": 1, \"draw\": 80}, {\"draws\": 281, \"mouse\": 0, \"mu_intercept_per_group\": 9.527448654174805, \"sigma_intercept_per_group\": 0.27342334389686584, \"sigma_obs\": 172.30238342285156, \"slope\": -0.08203194290399551, \"chain\": 1, \"draw\": 81}, {\"draws\": 281, \"mouse\": 1, \"mu_intercept_per_group\": 9.104144096374512, \"sigma_intercept_per_group\": 0.27342334389686584, \"sigma_obs\": 172.30238342285156, \"slope\": -0.08203194290399551, \"chain\": 1, \"draw\": 81}, {\"draws\": 281, \"mouse\": 2, \"mu_intercept_per_group\": 8.956316947937012, \"sigma_intercept_per_group\": 0.27342334389686584, \"sigma_obs\": 172.30238342285156, \"slope\": -0.08203194290399551, \"chain\": 1, \"draw\": 81}, {\"draws\": 281, \"mouse\": 3, \"mu_intercept_per_group\": 8.367551803588867, \"sigma_intercept_per_group\": 0.27342334389686584, \"sigma_obs\": 172.30238342285156, \"slope\": -0.08203194290399551, \"chain\": 1, \"draw\": 81}, {\"draws\": 281, \"mouse\": 4, \"mu_intercept_per_group\": 7.830291271209717, \"sigma_intercept_per_group\": 0.27342334389686584, \"sigma_obs\": 172.30238342285156, \"slope\": -0.08203194290399551, \"chain\": 1, \"draw\": 81}, {\"draws\": 281, \"mouse\": 5, \"mu_intercept_per_group\": 7.680187702178955, \"sigma_intercept_per_group\": 0.27342334389686584, \"sigma_obs\": 172.30238342285156, \"slope\": -0.08203194290399551, \"chain\": 1, \"draw\": 81}, {\"draws\": 281, \"mouse\": 6, \"mu_intercept_per_group\": 7.067836284637451, \"sigma_intercept_per_group\": 0.27342334389686584, \"sigma_obs\": 172.30238342285156, \"slope\": -0.08203194290399551, \"chain\": 1, \"draw\": 81}, {\"draws\": 281, \"mouse\": 7, \"mu_intercept_per_group\": 6.974819183349609, \"sigma_intercept_per_group\": 0.27342334389686584, \"sigma_obs\": 172.30238342285156, \"slope\": -0.08203194290399551, \"chain\": 1, \"draw\": 81}, {\"draws\": 282, \"mouse\": 0, \"mu_intercept_per_group\": 7.401383399963379, \"sigma_intercept_per_group\": 0.344040185213089, \"sigma_obs\": 175.17721557617188, \"slope\": -0.08445810526609421, \"chain\": 1, \"draw\": 82}, {\"draws\": 282, \"mouse\": 1, \"mu_intercept_per_group\": 7.21136474609375, \"sigma_intercept_per_group\": 0.344040185213089, \"sigma_obs\": 175.17721557617188, \"slope\": -0.08445810526609421, \"chain\": 1, \"draw\": 82}, {\"draws\": 282, \"mouse\": 2, \"mu_intercept_per_group\": 6.979137420654297, \"sigma_intercept_per_group\": 0.344040185213089, \"sigma_obs\": 175.17721557617188, \"slope\": -0.08445810526609421, \"chain\": 1, \"draw\": 82}, {\"draws\": 282, \"mouse\": 3, \"mu_intercept_per_group\": 6.831587791442871, \"sigma_intercept_per_group\": 0.344040185213089, \"sigma_obs\": 175.17721557617188, \"slope\": -0.08445810526609421, \"chain\": 1, \"draw\": 82}, {\"draws\": 282, \"mouse\": 4, \"mu_intercept_per_group\": 6.3876447677612305, \"sigma_intercept_per_group\": 0.344040185213089, \"sigma_obs\": 175.17721557617188, \"slope\": -0.08445810526609421, \"chain\": 1, \"draw\": 82}, {\"draws\": 282, \"mouse\": 5, \"mu_intercept_per_group\": 6.133861064910889, \"sigma_intercept_per_group\": 0.344040185213089, \"sigma_obs\": 175.17721557617188, \"slope\": -0.08445810526609421, \"chain\": 1, \"draw\": 82}, {\"draws\": 282, \"mouse\": 6, \"mu_intercept_per_group\": 5.620956897735596, \"sigma_intercept_per_group\": 0.344040185213089, \"sigma_obs\": 175.17721557617188, \"slope\": -0.08445810526609421, \"chain\": 1, \"draw\": 82}, {\"draws\": 282, \"mouse\": 7, \"mu_intercept_per_group\": 5.582183361053467, \"sigma_intercept_per_group\": 0.344040185213089, \"sigma_obs\": 175.17721557617188, \"slope\": -0.08445810526609421, \"chain\": 1, \"draw\": 82}, {\"draws\": 283, \"mouse\": 0, \"mu_intercept_per_group\": 7.64672327041626, \"sigma_intercept_per_group\": 0.3351297378540039, \"sigma_obs\": 171.35890197753906, \"slope\": -0.08539842814207077, \"chain\": 1, \"draw\": 83}, {\"draws\": 283, \"mouse\": 1, \"mu_intercept_per_group\": 7.409386157989502, \"sigma_intercept_per_group\": 0.3351297378540039, \"sigma_obs\": 171.35890197753906, \"slope\": -0.08539842814207077, \"chain\": 1, \"draw\": 83}, {\"draws\": 283, \"mouse\": 2, \"mu_intercept_per_group\": 7.178930282592773, \"sigma_intercept_per_group\": 0.3351297378540039, \"sigma_obs\": 171.35890197753906, \"slope\": -0.08539842814207077, \"chain\": 1, \"draw\": 83}, {\"draws\": 283, \"mouse\": 3, \"mu_intercept_per_group\": 6.981323719024658, \"sigma_intercept_per_group\": 0.3351297378540039, \"sigma_obs\": 171.35890197753906, \"slope\": -0.08539842814207077, \"chain\": 1, \"draw\": 83}, {\"draws\": 283, \"mouse\": 4, \"mu_intercept_per_group\": 6.576877593994141, \"sigma_intercept_per_group\": 0.3351297378540039, \"sigma_obs\": 171.35890197753906, \"slope\": -0.08539842814207077, \"chain\": 1, \"draw\": 83}, {\"draws\": 283, \"mouse\": 5, \"mu_intercept_per_group\": 6.42155122756958, \"sigma_intercept_per_group\": 0.3351297378540039, \"sigma_obs\": 171.35890197753906, \"slope\": -0.08539842814207077, \"chain\": 1, \"draw\": 83}, {\"draws\": 283, \"mouse\": 6, \"mu_intercept_per_group\": 5.982708930969238, \"sigma_intercept_per_group\": 0.3351297378540039, \"sigma_obs\": 171.35890197753906, \"slope\": -0.08539842814207077, \"chain\": 1, \"draw\": 83}, {\"draws\": 283, \"mouse\": 7, \"mu_intercept_per_group\": 5.331269264221191, \"sigma_intercept_per_group\": 0.3351297378540039, \"sigma_obs\": 171.35890197753906, \"slope\": -0.08539842814207077, \"chain\": 1, \"draw\": 83}, {\"draws\": 284, \"mouse\": 0, \"mu_intercept_per_group\": 4.715513706207275, \"sigma_intercept_per_group\": 0.536857545375824, \"sigma_obs\": 165.03244018554688, \"slope\": -0.055721595883369446, \"chain\": 1, \"draw\": 84}, {\"draws\": 284, \"mouse\": 1, \"mu_intercept_per_group\": 4.453851222991943, \"sigma_intercept_per_group\": 0.536857545375824, \"sigma_obs\": 165.03244018554688, \"slope\": -0.055721595883369446, \"chain\": 1, \"draw\": 84}, {\"draws\": 284, \"mouse\": 2, \"mu_intercept_per_group\": 4.3555755615234375, \"sigma_intercept_per_group\": 0.536857545375824, \"sigma_obs\": 165.03244018554688, \"slope\": -0.055721595883369446, \"chain\": 1, \"draw\": 84}, {\"draws\": 284, \"mouse\": 3, \"mu_intercept_per_group\": 4.082845687866211, \"sigma_intercept_per_group\": 0.536857545375824, \"sigma_obs\": 165.03244018554688, \"slope\": -0.055721595883369446, \"chain\": 1, \"draw\": 84}, {\"draws\": 284, \"mouse\": 4, \"mu_intercept_per_group\": 4.096060276031494, \"sigma_intercept_per_group\": 0.536857545375824, \"sigma_obs\": 165.03244018554688, \"slope\": -0.055721595883369446, \"chain\": 1, \"draw\": 84}, {\"draws\": 284, \"mouse\": 5, \"mu_intercept_per_group\": 3.6768581867218018, \"sigma_intercept_per_group\": 0.536857545375824, \"sigma_obs\": 165.03244018554688, \"slope\": -0.055721595883369446, \"chain\": 1, \"draw\": 84}, {\"draws\": 284, \"mouse\": 6, \"mu_intercept_per_group\": 3.4941883087158203, \"sigma_intercept_per_group\": 0.536857545375824, \"sigma_obs\": 165.03244018554688, \"slope\": -0.055721595883369446, \"chain\": 1, \"draw\": 84}, {\"draws\": 284, \"mouse\": 7, \"mu_intercept_per_group\": 3.4312925338745117, \"sigma_intercept_per_group\": 0.536857545375824, \"sigma_obs\": 165.03244018554688, \"slope\": -0.055721595883369446, \"chain\": 1, \"draw\": 84}, {\"draws\": 285, \"mouse\": 0, \"mu_intercept_per_group\": 4.570064544677734, \"sigma_intercept_per_group\": 0.5354076027870178, \"sigma_obs\": 165.09185791015625, \"slope\": -0.055585939437150955, \"chain\": 1, \"draw\": 85}, {\"draws\": 285, \"mouse\": 1, \"mu_intercept_per_group\": 4.4252753257751465, \"sigma_intercept_per_group\": 0.5354076027870178, \"sigma_obs\": 165.09185791015625, \"slope\": -0.055585939437150955, \"chain\": 1, \"draw\": 85}, {\"draws\": 285, \"mouse\": 2, \"mu_intercept_per_group\": 4.4018731117248535, \"sigma_intercept_per_group\": 0.5354076027870178, \"sigma_obs\": 165.09185791015625, \"slope\": -0.055585939437150955, \"chain\": 1, \"draw\": 85}, {\"draws\": 285, \"mouse\": 3, \"mu_intercept_per_group\": 4.178603172302246, \"sigma_intercept_per_group\": 0.5354076027870178, \"sigma_obs\": 165.09185791015625, \"slope\": -0.055585939437150955, \"chain\": 1, \"draw\": 85}, {\"draws\": 285, \"mouse\": 4, \"mu_intercept_per_group\": 4.047457695007324, \"sigma_intercept_per_group\": 0.5354076027870178, \"sigma_obs\": 165.09185791015625, \"slope\": -0.055585939437150955, \"chain\": 1, \"draw\": 85}, {\"draws\": 285, \"mouse\": 5, \"mu_intercept_per_group\": 3.679347276687622, \"sigma_intercept_per_group\": 0.5354076027870178, \"sigma_obs\": 165.09185791015625, \"slope\": -0.055585939437150955, \"chain\": 1, \"draw\": 85}, {\"draws\": 285, \"mouse\": 6, \"mu_intercept_per_group\": 3.4914543628692627, \"sigma_intercept_per_group\": 0.5354076027870178, \"sigma_obs\": 165.09185791015625, \"slope\": -0.055585939437150955, \"chain\": 1, \"draw\": 85}, {\"draws\": 285, \"mouse\": 7, \"mu_intercept_per_group\": 3.380805253982544, \"sigma_intercept_per_group\": 0.5354076027870178, \"sigma_obs\": 165.09185791015625, \"slope\": -0.055585939437150955, \"chain\": 1, \"draw\": 85}, {\"draws\": 286, \"mouse\": 0, \"mu_intercept_per_group\": 5.672654151916504, \"sigma_intercept_per_group\": 0.4409211575984955, \"sigma_obs\": 170.3754119873047, \"slope\": -0.04902396351099014, \"chain\": 1, \"draw\": 86}, {\"draws\": 286, \"mouse\": 1, \"mu_intercept_per_group\": 5.534390926361084, \"sigma_intercept_per_group\": 0.4409211575984955, \"sigma_obs\": 170.3754119873047, \"slope\": -0.04902396351099014, \"chain\": 1, \"draw\": 86}, {\"draws\": 286, \"mouse\": 2, \"mu_intercept_per_group\": 5.21840763092041, \"sigma_intercept_per_group\": 0.4409211575984955, \"sigma_obs\": 170.3754119873047, \"slope\": -0.04902396351099014, \"chain\": 1, \"draw\": 86}, {\"draws\": 286, \"mouse\": 3, \"mu_intercept_per_group\": 4.938225746154785, \"sigma_intercept_per_group\": 0.4409211575984955, \"sigma_obs\": 170.3754119873047, \"slope\": -0.04902396351099014, \"chain\": 1, \"draw\": 86}, {\"draws\": 286, \"mouse\": 4, \"mu_intercept_per_group\": 4.81564474105835, \"sigma_intercept_per_group\": 0.4409211575984955, \"sigma_obs\": 170.3754119873047, \"slope\": -0.04902396351099014, \"chain\": 1, \"draw\": 86}, {\"draws\": 286, \"mouse\": 5, \"mu_intercept_per_group\": 4.644794940948486, \"sigma_intercept_per_group\": 0.4409211575984955, \"sigma_obs\": 170.3754119873047, \"slope\": -0.04902396351099014, \"chain\": 1, \"draw\": 86}, {\"draws\": 286, \"mouse\": 6, \"mu_intercept_per_group\": 4.3318023681640625, \"sigma_intercept_per_group\": 0.4409211575984955, \"sigma_obs\": 170.3754119873047, \"slope\": -0.04902396351099014, \"chain\": 1, \"draw\": 86}, {\"draws\": 286, \"mouse\": 7, \"mu_intercept_per_group\": 4.152503967285156, \"sigma_intercept_per_group\": 0.4409211575984955, \"sigma_obs\": 170.3754119873047, \"slope\": -0.04902396351099014, \"chain\": 1, \"draw\": 86}, {\"draws\": 287, \"mouse\": 0, \"mu_intercept_per_group\": 5.6700286865234375, \"sigma_intercept_per_group\": 0.44275856018066406, \"sigma_obs\": 170.4322052001953, \"slope\": -0.048896413296461105, \"chain\": 1, \"draw\": 87}, {\"draws\": 287, \"mouse\": 1, \"mu_intercept_per_group\": 5.414867401123047, \"sigma_intercept_per_group\": 0.44275856018066406, \"sigma_obs\": 170.4322052001953, \"slope\": -0.048896413296461105, \"chain\": 1, \"draw\": 87}, {\"draws\": 287, \"mouse\": 2, \"mu_intercept_per_group\": 5.332643032073975, \"sigma_intercept_per_group\": 0.44275856018066406, \"sigma_obs\": 170.4322052001953, \"slope\": -0.048896413296461105, \"chain\": 1, \"draw\": 87}, {\"draws\": 287, \"mouse\": 3, \"mu_intercept_per_group\": 4.995340824127197, \"sigma_intercept_per_group\": 0.44275856018066406, \"sigma_obs\": 170.4322052001953, \"slope\": -0.048896413296461105, \"chain\": 1, \"draw\": 87}, {\"draws\": 287, \"mouse\": 4, \"mu_intercept_per_group\": 4.900432109832764, \"sigma_intercept_per_group\": 0.44275856018066406, \"sigma_obs\": 170.4322052001953, \"slope\": -0.048896413296461105, \"chain\": 1, \"draw\": 87}, {\"draws\": 287, \"mouse\": 5, \"mu_intercept_per_group\": 4.594041347503662, \"sigma_intercept_per_group\": 0.44275856018066406, \"sigma_obs\": 170.4322052001953, \"slope\": -0.048896413296461105, \"chain\": 1, \"draw\": 87}, {\"draws\": 287, \"mouse\": 6, \"mu_intercept_per_group\": 4.329372406005859, \"sigma_intercept_per_group\": 0.44275856018066406, \"sigma_obs\": 170.4322052001953, \"slope\": -0.048896413296461105, \"chain\": 1, \"draw\": 87}, {\"draws\": 287, \"mouse\": 7, \"mu_intercept_per_group\": 4.13552713394165, \"sigma_intercept_per_group\": 0.44275856018066406, \"sigma_obs\": 170.4322052001953, \"slope\": -0.048896413296461105, \"chain\": 1, \"draw\": 87}, {\"draws\": 288, \"mouse\": 0, \"mu_intercept_per_group\": 5.659270286560059, \"sigma_intercept_per_group\": 0.4415890574455261, \"sigma_obs\": 170.34364318847656, \"slope\": -0.04801535606384277, \"chain\": 1, \"draw\": 88}, {\"draws\": 288, \"mouse\": 1, \"mu_intercept_per_group\": 5.506867408752441, \"sigma_intercept_per_group\": 0.4415890574455261, \"sigma_obs\": 170.34364318847656, \"slope\": -0.04801535606384277, \"chain\": 1, \"draw\": 88}, {\"draws\": 288, \"mouse\": 2, \"mu_intercept_per_group\": 5.2741522789001465, \"sigma_intercept_per_group\": 0.4415890574455261, \"sigma_obs\": 170.34364318847656, \"slope\": -0.04801535606384277, \"chain\": 1, \"draw\": 88}, {\"draws\": 288, \"mouse\": 3, \"mu_intercept_per_group\": 4.967618465423584, \"sigma_intercept_per_group\": 0.4415890574455261, \"sigma_obs\": 170.34364318847656, \"slope\": -0.04801535606384277, \"chain\": 1, \"draw\": 88}, {\"draws\": 288, \"mouse\": 4, \"mu_intercept_per_group\": 4.777606964111328, \"sigma_intercept_per_group\": 0.4415890574455261, \"sigma_obs\": 170.34364318847656, \"slope\": -0.04801535606384277, \"chain\": 1, \"draw\": 88}, {\"draws\": 288, \"mouse\": 5, \"mu_intercept_per_group\": 4.572078704833984, \"sigma_intercept_per_group\": 0.4415890574455261, \"sigma_obs\": 170.34364318847656, \"slope\": -0.04801535606384277, \"chain\": 1, \"draw\": 88}, {\"draws\": 288, \"mouse\": 6, \"mu_intercept_per_group\": 4.284364223480225, \"sigma_intercept_per_group\": 0.4415890574455261, \"sigma_obs\": 170.34364318847656, \"slope\": -0.04801535606384277, \"chain\": 1, \"draw\": 88}, {\"draws\": 288, \"mouse\": 7, \"mu_intercept_per_group\": 4.202385902404785, \"sigma_intercept_per_group\": 0.4415890574455261, \"sigma_obs\": 170.34364318847656, \"slope\": -0.04801535606384277, \"chain\": 1, \"draw\": 88}, {\"draws\": 289, \"mouse\": 0, \"mu_intercept_per_group\": 6.101051330566406, \"sigma_intercept_per_group\": 0.4136672019958496, \"sigma_obs\": 173.39337158203125, \"slope\": -0.04685010761022568, \"chain\": 1, \"draw\": 89}, {\"draws\": 289, \"mouse\": 1, \"mu_intercept_per_group\": 5.844546318054199, \"sigma_intercept_per_group\": 0.4136672019958496, \"sigma_obs\": 173.39337158203125, \"slope\": -0.04685010761022568, \"chain\": 1, \"draw\": 89}, {\"draws\": 289, \"mouse\": 2, \"mu_intercept_per_group\": 5.723720073699951, \"sigma_intercept_per_group\": 0.4136672019958496, \"sigma_obs\": 173.39337158203125, \"slope\": -0.04685010761022568, \"chain\": 1, \"draw\": 89}, {\"draws\": 289, \"mouse\": 3, \"mu_intercept_per_group\": 5.309369087219238, \"sigma_intercept_per_group\": 0.4136672019958496, \"sigma_obs\": 173.39337158203125, \"slope\": -0.04685010761022568, \"chain\": 1, \"draw\": 89}, {\"draws\": 289, \"mouse\": 4, \"mu_intercept_per_group\": 5.119515419006348, \"sigma_intercept_per_group\": 0.4136672019958496, \"sigma_obs\": 173.39337158203125, \"slope\": -0.04685010761022568, \"chain\": 1, \"draw\": 89}, {\"draws\": 289, \"mouse\": 5, \"mu_intercept_per_group\": 5.0675950050354, \"sigma_intercept_per_group\": 0.4136672019958496, \"sigma_obs\": 173.39337158203125, \"slope\": -0.04685010761022568, \"chain\": 1, \"draw\": 89}, {\"draws\": 289, \"mouse\": 6, \"mu_intercept_per_group\": 4.608969211578369, \"sigma_intercept_per_group\": 0.4136672019958496, \"sigma_obs\": 173.39337158203125, \"slope\": -0.04685010761022568, \"chain\": 1, \"draw\": 89}, {\"draws\": 289, \"mouse\": 7, \"mu_intercept_per_group\": 4.431392192840576, \"sigma_intercept_per_group\": 0.4136672019958496, \"sigma_obs\": 173.39337158203125, \"slope\": -0.04685010761022568, \"chain\": 1, \"draw\": 89}, {\"draws\": 290, \"mouse\": 0, \"mu_intercept_per_group\": 5.990025043487549, \"sigma_intercept_per_group\": 0.4185987710952759, \"sigma_obs\": 173.30245971679688, \"slope\": -0.047566723078489304, \"chain\": 1, \"draw\": 90}, {\"draws\": 290, \"mouse\": 1, \"mu_intercept_per_group\": 5.725117206573486, \"sigma_intercept_per_group\": 0.4185987710952759, \"sigma_obs\": 173.30245971679688, \"slope\": -0.047566723078489304, \"chain\": 1, \"draw\": 90}, {\"draws\": 290, \"mouse\": 2, \"mu_intercept_per_group\": 5.561583995819092, \"sigma_intercept_per_group\": 0.4185987710952759, \"sigma_obs\": 173.30245971679688, \"slope\": -0.047566723078489304, \"chain\": 1, \"draw\": 90}, {\"draws\": 290, \"mouse\": 3, \"mu_intercept_per_group\": 5.504540920257568, \"sigma_intercept_per_group\": 0.4185987710952759, \"sigma_obs\": 173.30245971679688, \"slope\": -0.047566723078489304, \"chain\": 1, \"draw\": 90}, {\"draws\": 290, \"mouse\": 4, \"mu_intercept_per_group\": 5.137509822845459, \"sigma_intercept_per_group\": 0.4185987710952759, \"sigma_obs\": 173.30245971679688, \"slope\": -0.047566723078489304, \"chain\": 1, \"draw\": 90}, {\"draws\": 290, \"mouse\": 5, \"mu_intercept_per_group\": 5.04243278503418, \"sigma_intercept_per_group\": 0.4185987710952759, \"sigma_obs\": 173.30245971679688, \"slope\": -0.047566723078489304, \"chain\": 1, \"draw\": 90}, {\"draws\": 290, \"mouse\": 6, \"mu_intercept_per_group\": 4.380519390106201, \"sigma_intercept_per_group\": 0.4185987710952759, \"sigma_obs\": 173.30245971679688, \"slope\": -0.047566723078489304, \"chain\": 1, \"draw\": 90}, {\"draws\": 290, \"mouse\": 7, \"mu_intercept_per_group\": 4.518290042877197, \"sigma_intercept_per_group\": 0.4185987710952759, \"sigma_obs\": 173.30245971679688, \"slope\": -0.047566723078489304, \"chain\": 1, \"draw\": 90}, {\"draws\": 291, \"mouse\": 0, \"mu_intercept_per_group\": 5.992208957672119, \"sigma_intercept_per_group\": 0.4185014069080353, \"sigma_obs\": 173.21240234375, \"slope\": -0.04824943467974663, \"chain\": 1, \"draw\": 91}, {\"draws\": 291, \"mouse\": 1, \"mu_intercept_per_group\": 5.848598003387451, \"sigma_intercept_per_group\": 0.4185014069080353, \"sigma_obs\": 173.21240234375, \"slope\": -0.04824943467974663, \"chain\": 1, \"draw\": 91}, {\"draws\": 291, \"mouse\": 2, \"mu_intercept_per_group\": 5.740513324737549, \"sigma_intercept_per_group\": 0.4185014069080353, \"sigma_obs\": 173.21240234375, \"slope\": -0.04824943467974663, \"chain\": 1, \"draw\": 91}, {\"draws\": 291, \"mouse\": 3, \"mu_intercept_per_group\": 5.108473777770996, \"sigma_intercept_per_group\": 0.4185014069080353, \"sigma_obs\": 173.21240234375, \"slope\": -0.04824943467974663, \"chain\": 1, \"draw\": 91}, {\"draws\": 291, \"mouse\": 4, \"mu_intercept_per_group\": 5.238846302032471, \"sigma_intercept_per_group\": 0.4185014069080353, \"sigma_obs\": 173.21240234375, \"slope\": -0.04824943467974663, \"chain\": 1, \"draw\": 91}, {\"draws\": 291, \"mouse\": 5, \"mu_intercept_per_group\": 4.771239280700684, \"sigma_intercept_per_group\": 0.4185014069080353, \"sigma_obs\": 173.21240234375, \"slope\": -0.04824943467974663, \"chain\": 1, \"draw\": 91}, {\"draws\": 291, \"mouse\": 6, \"mu_intercept_per_group\": 4.669162273406982, \"sigma_intercept_per_group\": 0.4185014069080353, \"sigma_obs\": 173.21240234375, \"slope\": -0.04824943467974663, \"chain\": 1, \"draw\": 91}, {\"draws\": 291, \"mouse\": 7, \"mu_intercept_per_group\": 4.365772247314453, \"sigma_intercept_per_group\": 0.4185014069080353, \"sigma_obs\": 173.21240234375, \"slope\": -0.04824943467974663, \"chain\": 1, \"draw\": 91}, {\"draws\": 292, \"mouse\": 0, \"mu_intercept_per_group\": 5.319715976715088, \"sigma_intercept_per_group\": 0.46042600274086, \"sigma_obs\": 172.54434204101562, \"slope\": -0.04454372450709343, \"chain\": 1, \"draw\": 92}, {\"draws\": 292, \"mouse\": 1, \"mu_intercept_per_group\": 5.1476216316223145, \"sigma_intercept_per_group\": 0.46042600274086, \"sigma_obs\": 172.54434204101562, \"slope\": -0.04454372450709343, \"chain\": 1, \"draw\": 92}, {\"draws\": 292, \"mouse\": 2, \"mu_intercept_per_group\": 5.108654499053955, \"sigma_intercept_per_group\": 0.46042600274086, \"sigma_obs\": 172.54434204101562, \"slope\": -0.04454372450709343, \"chain\": 1, \"draw\": 92}, {\"draws\": 292, \"mouse\": 3, \"mu_intercept_per_group\": 4.992055416107178, \"sigma_intercept_per_group\": 0.46042600274086, \"sigma_obs\": 172.54434204101562, \"slope\": -0.04454372450709343, \"chain\": 1, \"draw\": 92}, {\"draws\": 292, \"mouse\": 4, \"mu_intercept_per_group\": 4.644301891326904, \"sigma_intercept_per_group\": 0.46042600274086, \"sigma_obs\": 172.54434204101562, \"slope\": -0.04454372450709343, \"chain\": 1, \"draw\": 92}, {\"draws\": 292, \"mouse\": 5, \"mu_intercept_per_group\": 4.346001148223877, \"sigma_intercept_per_group\": 0.46042600274086, \"sigma_obs\": 172.54434204101562, \"slope\": -0.04454372450709343, \"chain\": 1, \"draw\": 92}, {\"draws\": 292, \"mouse\": 6, \"mu_intercept_per_group\": 4.320974826812744, \"sigma_intercept_per_group\": 0.46042600274086, \"sigma_obs\": 172.54434204101562, \"slope\": -0.04454372450709343, \"chain\": 1, \"draw\": 92}, {\"draws\": 292, \"mouse\": 7, \"mu_intercept_per_group\": 3.9426310062408447, \"sigma_intercept_per_group\": 0.46042600274086, \"sigma_obs\": 172.54434204101562, \"slope\": -0.04454372450709343, \"chain\": 1, \"draw\": 92}, {\"draws\": 293, \"mouse\": 0, \"mu_intercept_per_group\": 5.4274163246154785, \"sigma_intercept_per_group\": 0.45735228061676025, \"sigma_obs\": 172.8715362548828, \"slope\": -0.04484879970550537, \"chain\": 1, \"draw\": 93}, {\"draws\": 293, \"mouse\": 1, \"mu_intercept_per_group\": 5.212273120880127, \"sigma_intercept_per_group\": 0.45735228061676025, \"sigma_obs\": 172.8715362548828, \"slope\": -0.04484879970550537, \"chain\": 1, \"draw\": 93}, {\"draws\": 293, \"mouse\": 2, \"mu_intercept_per_group\": 5.118312835693359, \"sigma_intercept_per_group\": 0.45735228061676025, \"sigma_obs\": 172.8715362548828, \"slope\": -0.04484879970550537, \"chain\": 1, \"draw\": 93}, {\"draws\": 293, \"mouse\": 3, \"mu_intercept_per_group\": 4.82464599609375, \"sigma_intercept_per_group\": 0.45735228061676025, \"sigma_obs\": 172.8715362548828, \"slope\": -0.04484879970550537, \"chain\": 1, \"draw\": 93}, {\"draws\": 293, \"mouse\": 4, \"mu_intercept_per_group\": 4.562198162078857, \"sigma_intercept_per_group\": 0.45735228061676025, \"sigma_obs\": 172.8715362548828, \"slope\": -0.04484879970550537, \"chain\": 1, \"draw\": 93}, {\"draws\": 293, \"mouse\": 5, \"mu_intercept_per_group\": 4.416219711303711, \"sigma_intercept_per_group\": 0.45735228061676025, \"sigma_obs\": 172.8715362548828, \"slope\": -0.04484879970550537, \"chain\": 1, \"draw\": 93}, {\"draws\": 293, \"mouse\": 6, \"mu_intercept_per_group\": 4.136592864990234, \"sigma_intercept_per_group\": 0.45735228061676025, \"sigma_obs\": 172.8715362548828, \"slope\": -0.04484879970550537, \"chain\": 1, \"draw\": 93}, {\"draws\": 293, \"mouse\": 7, \"mu_intercept_per_group\": 4.049530506134033, \"sigma_intercept_per_group\": 0.45735228061676025, \"sigma_obs\": 172.8715362548828, \"slope\": -0.04484879970550537, \"chain\": 1, \"draw\": 93}, {\"draws\": 294, \"mouse\": 0, \"mu_intercept_per_group\": 5.429105758666992, \"sigma_intercept_per_group\": 0.46111443638801575, \"sigma_obs\": 172.77915954589844, \"slope\": -0.04512603208422661, \"chain\": 1, \"draw\": 94}, {\"draws\": 294, \"mouse\": 1, \"mu_intercept_per_group\": 5.237331867218018, \"sigma_intercept_per_group\": 0.46111443638801575, \"sigma_obs\": 172.77915954589844, \"slope\": -0.04512603208422661, \"chain\": 1, \"draw\": 94}, {\"draws\": 294, \"mouse\": 2, \"mu_intercept_per_group\": 5.108198642730713, \"sigma_intercept_per_group\": 0.46111443638801575, \"sigma_obs\": 172.77915954589844, \"slope\": -0.04512603208422661, \"chain\": 1, \"draw\": 94}, {\"draws\": 294, \"mouse\": 3, \"mu_intercept_per_group\": 4.840840816497803, \"sigma_intercept_per_group\": 0.46111443638801575, \"sigma_obs\": 172.77915954589844, \"slope\": -0.04512603208422661, \"chain\": 1, \"draw\": 94}, {\"draws\": 294, \"mouse\": 4, \"mu_intercept_per_group\": 4.592223167419434, \"sigma_intercept_per_group\": 0.46111443638801575, \"sigma_obs\": 172.77915954589844, \"slope\": -0.04512603208422661, \"chain\": 1, \"draw\": 94}, {\"draws\": 294, \"mouse\": 5, \"mu_intercept_per_group\": 4.457422256469727, \"sigma_intercept_per_group\": 0.46111443638801575, \"sigma_obs\": 172.77915954589844, \"slope\": -0.04512603208422661, \"chain\": 1, \"draw\": 94}, {\"draws\": 294, \"mouse\": 6, \"mu_intercept_per_group\": 4.1063923835754395, \"sigma_intercept_per_group\": 0.46111443638801575, \"sigma_obs\": 172.77915954589844, \"slope\": -0.04512603208422661, \"chain\": 1, \"draw\": 94}, {\"draws\": 294, \"mouse\": 7, \"mu_intercept_per_group\": 4.0366435050964355, \"sigma_intercept_per_group\": 0.46111443638801575, \"sigma_obs\": 172.77915954589844, \"slope\": -0.04512603208422661, \"chain\": 1, \"draw\": 94}, {\"draws\": 295, \"mouse\": 0, \"mu_intercept_per_group\": 4.028386116027832, \"sigma_intercept_per_group\": 0.619312047958374, \"sigma_obs\": 158.4661102294922, \"slope\": -0.0832962617278099, \"chain\": 1, \"draw\": 95}, {\"draws\": 295, \"mouse\": 1, \"mu_intercept_per_group\": 3.878962993621826, \"sigma_intercept_per_group\": 0.619312047958374, \"sigma_obs\": 158.4661102294922, \"slope\": -0.0832962617278099, \"chain\": 1, \"draw\": 95}, {\"draws\": 295, \"mouse\": 2, \"mu_intercept_per_group\": 3.78114652633667, \"sigma_intercept_per_group\": 0.619312047958374, \"sigma_obs\": 158.4661102294922, \"slope\": -0.0832962617278099, \"chain\": 1, \"draw\": 95}, {\"draws\": 295, \"mouse\": 3, \"mu_intercept_per_group\": 3.569723129272461, \"sigma_intercept_per_group\": 0.619312047958374, \"sigma_obs\": 158.4661102294922, \"slope\": -0.0832962617278099, \"chain\": 1, \"draw\": 95}, {\"draws\": 295, \"mouse\": 4, \"mu_intercept_per_group\": 3.3823251724243164, \"sigma_intercept_per_group\": 0.619312047958374, \"sigma_obs\": 158.4661102294922, \"slope\": -0.0832962617278099, \"chain\": 1, \"draw\": 95}, {\"draws\": 295, \"mouse\": 5, \"mu_intercept_per_group\": 3.3388826847076416, \"sigma_intercept_per_group\": 0.619312047958374, \"sigma_obs\": 158.4661102294922, \"slope\": -0.0832962617278099, \"chain\": 1, \"draw\": 95}, {\"draws\": 295, \"mouse\": 6, \"mu_intercept_per_group\": 3.0279734134674072, \"sigma_intercept_per_group\": 0.619312047958374, \"sigma_obs\": 158.4661102294922, \"slope\": -0.0832962617278099, \"chain\": 1, \"draw\": 95}, {\"draws\": 295, \"mouse\": 7, \"mu_intercept_per_group\": 2.8555867671966553, \"sigma_intercept_per_group\": 0.619312047958374, \"sigma_obs\": 158.4661102294922, \"slope\": -0.0832962617278099, \"chain\": 1, \"draw\": 95}, {\"draws\": 296, \"mouse\": 0, \"mu_intercept_per_group\": 3.9574391841888428, \"sigma_intercept_per_group\": 0.6205828189849854, \"sigma_obs\": 158.48153686523438, \"slope\": -0.08340895175933838, \"chain\": 1, \"draw\": 96}, {\"draws\": 296, \"mouse\": 1, \"mu_intercept_per_group\": 3.8031487464904785, \"sigma_intercept_per_group\": 0.6205828189849854, \"sigma_obs\": 158.48153686523438, \"slope\": -0.08340895175933838, \"chain\": 1, \"draw\": 96}, {\"draws\": 296, \"mouse\": 2, \"mu_intercept_per_group\": 3.811739444732666, \"sigma_intercept_per_group\": 0.6205828189849854, \"sigma_obs\": 158.48153686523438, \"slope\": -0.08340895175933838, \"chain\": 1, \"draw\": 96}, {\"draws\": 296, \"mouse\": 3, \"mu_intercept_per_group\": 3.5936460494995117, \"sigma_intercept_per_group\": 0.6205828189849854, \"sigma_obs\": 158.48153686523438, \"slope\": -0.08340895175933838, \"chain\": 1, \"draw\": 96}, {\"draws\": 296, \"mouse\": 4, \"mu_intercept_per_group\": 3.4185707569122314, \"sigma_intercept_per_group\": 0.6205828189849854, \"sigma_obs\": 158.48153686523438, \"slope\": -0.08340895175933838, \"chain\": 1, \"draw\": 96}, {\"draws\": 296, \"mouse\": 5, \"mu_intercept_per_group\": 3.279602289199829, \"sigma_intercept_per_group\": 0.6205828189849854, \"sigma_obs\": 158.48153686523438, \"slope\": -0.08340895175933838, \"chain\": 1, \"draw\": 96}, {\"draws\": 296, \"mouse\": 6, \"mu_intercept_per_group\": 2.997244119644165, \"sigma_intercept_per_group\": 0.6205828189849854, \"sigma_obs\": 158.48153686523438, \"slope\": -0.08340895175933838, \"chain\": 1, \"draw\": 96}, {\"draws\": 296, \"mouse\": 7, \"mu_intercept_per_group\": 2.8907926082611084, \"sigma_intercept_per_group\": 0.6205828189849854, \"sigma_obs\": 158.48153686523438, \"slope\": -0.08340895175933838, \"chain\": 1, \"draw\": 96}, {\"draws\": 297, \"mouse\": 0, \"mu_intercept_per_group\": 6.8202972412109375, \"sigma_intercept_per_group\": 0.3842340409755707, \"sigma_obs\": 176.0359344482422, \"slope\": -0.08133875578641891, \"chain\": 1, \"draw\": 97}, {\"draws\": 297, \"mouse\": 1, \"mu_intercept_per_group\": 6.378407955169678, \"sigma_intercept_per_group\": 0.3842340409755707, \"sigma_obs\": 176.0359344482422, \"slope\": -0.08133875578641891, \"chain\": 1, \"draw\": 97}, {\"draws\": 297, \"mouse\": 2, \"mu_intercept_per_group\": 6.395968437194824, \"sigma_intercept_per_group\": 0.3842340409755707, \"sigma_obs\": 176.0359344482422, \"slope\": -0.08133875578641891, \"chain\": 1, \"draw\": 97}, {\"draws\": 297, \"mouse\": 3, \"mu_intercept_per_group\": 6.063174247741699, \"sigma_intercept_per_group\": 0.3842340409755707, \"sigma_obs\": 176.0359344482422, \"slope\": -0.08133875578641891, \"chain\": 1, \"draw\": 97}, {\"draws\": 297, \"mouse\": 4, \"mu_intercept_per_group\": 5.864990234375, \"sigma_intercept_per_group\": 0.3842340409755707, \"sigma_obs\": 176.0359344482422, \"slope\": -0.08133875578641891, \"chain\": 1, \"draw\": 97}, {\"draws\": 297, \"mouse\": 5, \"mu_intercept_per_group\": 5.619534015655518, \"sigma_intercept_per_group\": 0.3842340409755707, \"sigma_obs\": 176.0359344482422, \"slope\": -0.08133875578641891, \"chain\": 1, \"draw\": 97}, {\"draws\": 297, \"mouse\": 6, \"mu_intercept_per_group\": 5.060976505279541, \"sigma_intercept_per_group\": 0.3842340409755707, \"sigma_obs\": 176.0359344482422, \"slope\": -0.08133875578641891, \"chain\": 1, \"draw\": 97}, {\"draws\": 297, \"mouse\": 7, \"mu_intercept_per_group\": 4.7826385498046875, \"sigma_intercept_per_group\": 0.3842340409755707, \"sigma_obs\": 176.0359344482422, \"slope\": -0.08133875578641891, \"chain\": 1, \"draw\": 97}, {\"draws\": 298, \"mouse\": 0, \"mu_intercept_per_group\": 6.8200225830078125, \"sigma_intercept_per_group\": 0.37987691164016724, \"sigma_obs\": 176.44906616210938, \"slope\": -0.08062463998794556, \"chain\": 1, \"draw\": 98}, {\"draws\": 298, \"mouse\": 1, \"mu_intercept_per_group\": 6.743011474609375, \"sigma_intercept_per_group\": 0.37987691164016724, \"sigma_obs\": 176.44906616210938, \"slope\": -0.08062463998794556, \"chain\": 1, \"draw\": 98}, {\"draws\": 298, \"mouse\": 2, \"mu_intercept_per_group\": 6.368788242340088, \"sigma_intercept_per_group\": 0.37987691164016724, \"sigma_obs\": 176.44906616210938, \"slope\": -0.08062463998794556, \"chain\": 1, \"draw\": 98}, {\"draws\": 298, \"mouse\": 3, \"mu_intercept_per_group\": 6.132348537445068, \"sigma_intercept_per_group\": 0.37987691164016724, \"sigma_obs\": 176.44906616210938, \"slope\": -0.08062463998794556, \"chain\": 1, \"draw\": 98}, {\"draws\": 298, \"mouse\": 4, \"mu_intercept_per_group\": 5.80518913269043, \"sigma_intercept_per_group\": 0.37987691164016724, \"sigma_obs\": 176.44906616210938, \"slope\": -0.08062463998794556, \"chain\": 1, \"draw\": 98}, {\"draws\": 298, \"mouse\": 5, \"mu_intercept_per_group\": 5.614851951599121, \"sigma_intercept_per_group\": 0.37987691164016724, \"sigma_obs\": 176.44906616210938, \"slope\": -0.08062463998794556, \"chain\": 1, \"draw\": 98}, {\"draws\": 298, \"mouse\": 6, \"mu_intercept_per_group\": 5.081448078155518, \"sigma_intercept_per_group\": 0.37987691164016724, \"sigma_obs\": 176.44906616210938, \"slope\": -0.08062463998794556, \"chain\": 1, \"draw\": 98}, {\"draws\": 298, \"mouse\": 7, \"mu_intercept_per_group\": 4.957766056060791, \"sigma_intercept_per_group\": 0.37987691164016724, \"sigma_obs\": 176.44906616210938, \"slope\": -0.08062463998794556, \"chain\": 1, \"draw\": 98}, {\"draws\": 299, \"mouse\": 0, \"mu_intercept_per_group\": 6.908786296844482, \"sigma_intercept_per_group\": 0.3805985152721405, \"sigma_obs\": 176.0757293701172, \"slope\": -0.08132810145616531, \"chain\": 1, \"draw\": 99}, {\"draws\": 299, \"mouse\": 1, \"mu_intercept_per_group\": 6.506435871124268, \"sigma_intercept_per_group\": 0.3805985152721405, \"sigma_obs\": 176.0757293701172, \"slope\": -0.08132810145616531, \"chain\": 1, \"draw\": 99}, {\"draws\": 299, \"mouse\": 2, \"mu_intercept_per_group\": 6.5132904052734375, \"sigma_intercept_per_group\": 0.3805985152721405, \"sigma_obs\": 176.0757293701172, \"slope\": -0.08132810145616531, \"chain\": 1, \"draw\": 99}, {\"draws\": 299, \"mouse\": 3, \"mu_intercept_per_group\": 6.104393482208252, \"sigma_intercept_per_group\": 0.3805985152721405, \"sigma_obs\": 176.0757293701172, \"slope\": -0.08132810145616531, \"chain\": 1, \"draw\": 99}, {\"draws\": 299, \"mouse\": 4, \"mu_intercept_per_group\": 5.902710914611816, \"sigma_intercept_per_group\": 0.3805985152721405, \"sigma_obs\": 176.0757293701172, \"slope\": -0.08132810145616531, \"chain\": 1, \"draw\": 99}, {\"draws\": 299, \"mouse\": 5, \"mu_intercept_per_group\": 5.493561744689941, \"sigma_intercept_per_group\": 0.3805985152721405, \"sigma_obs\": 176.0757293701172, \"slope\": -0.08132810145616531, \"chain\": 1, \"draw\": 99}, {\"draws\": 299, \"mouse\": 6, \"mu_intercept_per_group\": 5.2088141441345215, \"sigma_intercept_per_group\": 0.3805985152721405, \"sigma_obs\": 176.0757293701172, \"slope\": -0.08132810145616531, \"chain\": 1, \"draw\": 99}, {\"draws\": 299, \"mouse\": 7, \"mu_intercept_per_group\": 5.081500053405762, \"sigma_intercept_per_group\": 0.3805985152721405, \"sigma_obs\": 176.0757293701172, \"slope\": -0.08132810145616531, \"chain\": 1, \"draw\": 99}, {\"draws\": 300, \"mouse\": 0, \"mu_intercept_per_group\": 9.265935897827148, \"sigma_intercept_per_group\": 0.26300832629203796, \"sigma_obs\": 153.27391052246094, \"slope\": -0.08506026864051819, \"chain\": 1, \"draw\": 100}, {\"draws\": 300, \"mouse\": 1, \"mu_intercept_per_group\": 9.08882999420166, \"sigma_intercept_per_group\": 0.26300832629203796, \"sigma_obs\": 153.27391052246094, \"slope\": -0.08506026864051819, \"chain\": 1, \"draw\": 100}, {\"draws\": 300, \"mouse\": 2, \"mu_intercept_per_group\": 8.760603904724121, \"sigma_intercept_per_group\": 0.26300832629203796, \"sigma_obs\": 153.27391052246094, \"slope\": -0.08506026864051819, \"chain\": 1, \"draw\": 100}, {\"draws\": 300, \"mouse\": 3, \"mu_intercept_per_group\": 8.160492897033691, \"sigma_intercept_per_group\": 0.26300832629203796, \"sigma_obs\": 153.27391052246094, \"slope\": -0.08506026864051819, \"chain\": 1, \"draw\": 100}, {\"draws\": 300, \"mouse\": 4, \"mu_intercept_per_group\": 8.059999465942383, \"sigma_intercept_per_group\": 0.26300832629203796, \"sigma_obs\": 153.27391052246094, \"slope\": -0.08506026864051819, \"chain\": 1, \"draw\": 100}, {\"draws\": 300, \"mouse\": 5, \"mu_intercept_per_group\": 7.707486152648926, \"sigma_intercept_per_group\": 0.26300832629203796, \"sigma_obs\": 153.27391052246094, \"slope\": -0.08506026864051819, \"chain\": 1, \"draw\": 100}, {\"draws\": 300, \"mouse\": 6, \"mu_intercept_per_group\": 7.120778560638428, \"sigma_intercept_per_group\": 0.26300832629203796, \"sigma_obs\": 153.27391052246094, \"slope\": -0.08506026864051819, \"chain\": 1, \"draw\": 100}, {\"draws\": 300, \"mouse\": 7, \"mu_intercept_per_group\": 6.702258110046387, \"sigma_intercept_per_group\": 0.26300832629203796, \"sigma_obs\": 153.27391052246094, \"slope\": -0.08506026864051819, \"chain\": 1, \"draw\": 100}, {\"draws\": 301, \"mouse\": 0, \"mu_intercept_per_group\": 8.594613075256348, \"sigma_intercept_per_group\": 0.28993532061576843, \"sigma_obs\": 160.53480529785156, \"slope\": -0.07177071273326874, \"chain\": 1, \"draw\": 101}, {\"draws\": 301, \"mouse\": 1, \"mu_intercept_per_group\": 8.398406028747559, \"sigma_intercept_per_group\": 0.28993532061576843, \"sigma_obs\": 160.53480529785156, \"slope\": -0.07177071273326874, \"chain\": 1, \"draw\": 101}, {\"draws\": 301, \"mouse\": 2, \"mu_intercept_per_group\": 7.9446001052856445, \"sigma_intercept_per_group\": 0.28993532061576843, \"sigma_obs\": 160.53480529785156, \"slope\": -0.07177071273326874, \"chain\": 1, \"draw\": 101}, {\"draws\": 301, \"mouse\": 3, \"mu_intercept_per_group\": 7.61775541305542, \"sigma_intercept_per_group\": 0.28993532061576843, \"sigma_obs\": 160.53480529785156, \"slope\": -0.07177071273326874, \"chain\": 1, \"draw\": 101}, {\"draws\": 301, \"mouse\": 4, \"mu_intercept_per_group\": 7.33897066116333, \"sigma_intercept_per_group\": 0.28993532061576843, \"sigma_obs\": 160.53480529785156, \"slope\": -0.07177071273326874, \"chain\": 1, \"draw\": 101}, {\"draws\": 301, \"mouse\": 5, \"mu_intercept_per_group\": 6.984589576721191, \"sigma_intercept_per_group\": 0.28993532061576843, \"sigma_obs\": 160.53480529785156, \"slope\": -0.07177071273326874, \"chain\": 1, \"draw\": 101}, {\"draws\": 301, \"mouse\": 6, \"mu_intercept_per_group\": 6.451938629150391, \"sigma_intercept_per_group\": 0.28993532061576843, \"sigma_obs\": 160.53480529785156, \"slope\": -0.07177071273326874, \"chain\": 1, \"draw\": 101}, {\"draws\": 301, \"mouse\": 7, \"mu_intercept_per_group\": 6.384490013122559, \"sigma_intercept_per_group\": 0.28993532061576843, \"sigma_obs\": 160.53480529785156, \"slope\": -0.07177071273326874, \"chain\": 1, \"draw\": 101}, {\"draws\": 302, \"mouse\": 0, \"mu_intercept_per_group\": 8.51406192779541, \"sigma_intercept_per_group\": 0.28831747174263, \"sigma_obs\": 160.74920654296875, \"slope\": -0.0731537714600563, \"chain\": 1, \"draw\": 102}, {\"draws\": 302, \"mouse\": 1, \"mu_intercept_per_group\": 8.382046699523926, \"sigma_intercept_per_group\": 0.28831747174263, \"sigma_obs\": 160.74920654296875, \"slope\": -0.0731537714600563, \"chain\": 1, \"draw\": 102}, {\"draws\": 302, \"mouse\": 2, \"mu_intercept_per_group\": 7.993638515472412, \"sigma_intercept_per_group\": 0.28831747174263, \"sigma_obs\": 160.74920654296875, \"slope\": -0.0731537714600563, \"chain\": 1, \"draw\": 102}, {\"draws\": 302, \"mouse\": 3, \"mu_intercept_per_group\": 7.452841758728027, \"sigma_intercept_per_group\": 0.28831747174263, \"sigma_obs\": 160.74920654296875, \"slope\": -0.0731537714600563, \"chain\": 1, \"draw\": 102}, {\"draws\": 302, \"mouse\": 4, \"mu_intercept_per_group\": 7.727978229522705, \"sigma_intercept_per_group\": 0.28831747174263, \"sigma_obs\": 160.74920654296875, \"slope\": -0.0731537714600563, \"chain\": 1, \"draw\": 102}, {\"draws\": 302, \"mouse\": 5, \"mu_intercept_per_group\": 7.05873441696167, \"sigma_intercept_per_group\": 0.28831747174263, \"sigma_obs\": 160.74920654296875, \"slope\": -0.0731537714600563, \"chain\": 1, \"draw\": 102}, {\"draws\": 302, \"mouse\": 6, \"mu_intercept_per_group\": 6.486367702484131, \"sigma_intercept_per_group\": 0.28831747174263, \"sigma_obs\": 160.74920654296875, \"slope\": -0.0731537714600563, \"chain\": 1, \"draw\": 102}, {\"draws\": 302, \"mouse\": 7, \"mu_intercept_per_group\": 6.230035781860352, \"sigma_intercept_per_group\": 0.28831747174263, \"sigma_obs\": 160.74920654296875, \"slope\": -0.0731537714600563, \"chain\": 1, \"draw\": 102}, {\"draws\": 303, \"mouse\": 0, \"mu_intercept_per_group\": 8.68400764465332, \"sigma_intercept_per_group\": 0.2913022041320801, \"sigma_obs\": 162.1910858154297, \"slope\": -0.07336097955703735, \"chain\": 1, \"draw\": 103}, {\"draws\": 303, \"mouse\": 1, \"mu_intercept_per_group\": 8.167867660522461, \"sigma_intercept_per_group\": 0.2913022041320801, \"sigma_obs\": 162.1910858154297, \"slope\": -0.07336097955703735, \"chain\": 1, \"draw\": 103}, {\"draws\": 303, \"mouse\": 2, \"mu_intercept_per_group\": 8.121818542480469, \"sigma_intercept_per_group\": 0.2913022041320801, \"sigma_obs\": 162.1910858154297, \"slope\": -0.07336097955703735, \"chain\": 1, \"draw\": 103}, {\"draws\": 303, \"mouse\": 3, \"mu_intercept_per_group\": 7.562943458557129, \"sigma_intercept_per_group\": 0.2913022041320801, \"sigma_obs\": 162.1910858154297, \"slope\": -0.07336097955703735, \"chain\": 1, \"draw\": 103}, {\"draws\": 303, \"mouse\": 4, \"mu_intercept_per_group\": 7.156359672546387, \"sigma_intercept_per_group\": 0.2913022041320801, \"sigma_obs\": 162.1910858154297, \"slope\": -0.07336097955703735, \"chain\": 1, \"draw\": 103}, {\"draws\": 303, \"mouse\": 5, \"mu_intercept_per_group\": 6.735377788543701, \"sigma_intercept_per_group\": 0.2913022041320801, \"sigma_obs\": 162.1910858154297, \"slope\": -0.07336097955703735, \"chain\": 1, \"draw\": 103}, {\"draws\": 303, \"mouse\": 6, \"mu_intercept_per_group\": 6.700687408447266, \"sigma_intercept_per_group\": 0.2913022041320801, \"sigma_obs\": 162.1910858154297, \"slope\": -0.07336097955703735, \"chain\": 1, \"draw\": 103}, {\"draws\": 303, \"mouse\": 7, \"mu_intercept_per_group\": 6.230829238891602, \"sigma_intercept_per_group\": 0.2913022041320801, \"sigma_obs\": 162.1910858154297, \"slope\": -0.07336097955703735, \"chain\": 1, \"draw\": 103}, {\"draws\": 304, \"mouse\": 0, \"mu_intercept_per_group\": 8.618915557861328, \"sigma_intercept_per_group\": 0.2836470901966095, \"sigma_obs\": 160.25869750976562, \"slope\": -0.07801639288663864, \"chain\": 1, \"draw\": 104}, {\"draws\": 304, \"mouse\": 1, \"mu_intercept_per_group\": 8.530861854553223, \"sigma_intercept_per_group\": 0.2836470901966095, \"sigma_obs\": 160.25869750976562, \"slope\": -0.07801639288663864, \"chain\": 1, \"draw\": 104}, {\"draws\": 304, \"mouse\": 2, \"mu_intercept_per_group\": 8.34668254852295, \"sigma_intercept_per_group\": 0.2836470901966095, \"sigma_obs\": 160.25869750976562, \"slope\": -0.07801639288663864, \"chain\": 1, \"draw\": 104}, {\"draws\": 304, \"mouse\": 3, \"mu_intercept_per_group\": 7.754578590393066, \"sigma_intercept_per_group\": 0.2836470901966095, \"sigma_obs\": 160.25869750976562, \"slope\": -0.07801639288663864, \"chain\": 1, \"draw\": 104}, {\"draws\": 304, \"mouse\": 4, \"mu_intercept_per_group\": 7.3545684814453125, \"sigma_intercept_per_group\": 0.2836470901966095, \"sigma_obs\": 160.25869750976562, \"slope\": -0.07801639288663864, \"chain\": 1, \"draw\": 104}, {\"draws\": 304, \"mouse\": 5, \"mu_intercept_per_group\": 6.864177703857422, \"sigma_intercept_per_group\": 0.2836470901966095, \"sigma_obs\": 160.25869750976562, \"slope\": -0.07801639288663864, \"chain\": 1, \"draw\": 104}, {\"draws\": 304, \"mouse\": 6, \"mu_intercept_per_group\": 6.6343207359313965, \"sigma_intercept_per_group\": 0.2836470901966095, \"sigma_obs\": 160.25869750976562, \"slope\": -0.07801639288663864, \"chain\": 1, \"draw\": 104}, {\"draws\": 304, \"mouse\": 7, \"mu_intercept_per_group\": 6.4514007568359375, \"sigma_intercept_per_group\": 0.2836470901966095, \"sigma_obs\": 160.25869750976562, \"slope\": -0.07801639288663864, \"chain\": 1, \"draw\": 104}, {\"draws\": 305, \"mouse\": 0, \"mu_intercept_per_group\": 8.59100341796875, \"sigma_intercept_per_group\": 0.28153425455093384, \"sigma_obs\": 157.24319458007812, \"slope\": -0.08088455349206924, \"chain\": 1, \"draw\": 105}, {\"draws\": 305, \"mouse\": 1, \"mu_intercept_per_group\": 8.43571662902832, \"sigma_intercept_per_group\": 0.28153425455093384, \"sigma_obs\": 157.24319458007812, \"slope\": -0.08088455349206924, \"chain\": 1, \"draw\": 105}, {\"draws\": 305, \"mouse\": 2, \"mu_intercept_per_group\": 8.300762176513672, \"sigma_intercept_per_group\": 0.28153425455093384, \"sigma_obs\": 157.24319458007812, \"slope\": -0.08088455349206924, \"chain\": 1, \"draw\": 105}, {\"draws\": 305, \"mouse\": 3, \"mu_intercept_per_group\": 7.6436028480529785, \"sigma_intercept_per_group\": 0.28153425455093384, \"sigma_obs\": 157.24319458007812, \"slope\": -0.08088455349206924, \"chain\": 1, \"draw\": 105}, {\"draws\": 305, \"mouse\": 4, \"mu_intercept_per_group\": 7.5204010009765625, \"sigma_intercept_per_group\": 0.28153425455093384, \"sigma_obs\": 157.24319458007812, \"slope\": -0.08088455349206924, \"chain\": 1, \"draw\": 105}, {\"draws\": 305, \"mouse\": 5, \"mu_intercept_per_group\": 7.295720100402832, \"sigma_intercept_per_group\": 0.28153425455093384, \"sigma_obs\": 157.24319458007812, \"slope\": -0.08088455349206924, \"chain\": 1, \"draw\": 105}, {\"draws\": 305, \"mouse\": 6, \"mu_intercept_per_group\": 6.612118244171143, \"sigma_intercept_per_group\": 0.28153425455093384, \"sigma_obs\": 157.24319458007812, \"slope\": -0.08088455349206924, \"chain\": 1, \"draw\": 105}, {\"draws\": 305, \"mouse\": 7, \"mu_intercept_per_group\": 6.121010780334473, \"sigma_intercept_per_group\": 0.28153425455093384, \"sigma_obs\": 157.24319458007812, \"slope\": -0.08088455349206924, \"chain\": 1, \"draw\": 105}, {\"draws\": 306, \"mouse\": 0, \"mu_intercept_per_group\": 7.962194919586182, \"sigma_intercept_per_group\": 0.30099916458129883, \"sigma_obs\": 155.31649780273438, \"slope\": -0.07043297588825226, \"chain\": 1, \"draw\": 106}, {\"draws\": 306, \"mouse\": 1, \"mu_intercept_per_group\": 7.875107765197754, \"sigma_intercept_per_group\": 0.30099916458129883, \"sigma_obs\": 155.31649780273438, \"slope\": -0.07043297588825226, \"chain\": 1, \"draw\": 106}, {\"draws\": 306, \"mouse\": 2, \"mu_intercept_per_group\": 7.670370101928711, \"sigma_intercept_per_group\": 0.30099916458129883, \"sigma_obs\": 155.31649780273438, \"slope\": -0.07043297588825226, \"chain\": 1, \"draw\": 106}, {\"draws\": 306, \"mouse\": 3, \"mu_intercept_per_group\": 7.323633670806885, \"sigma_intercept_per_group\": 0.30099916458129883, \"sigma_obs\": 155.31649780273438, \"slope\": -0.07043297588825226, \"chain\": 1, \"draw\": 106}, {\"draws\": 306, \"mouse\": 4, \"mu_intercept_per_group\": 7.034640789031982, \"sigma_intercept_per_group\": 0.30099916458129883, \"sigma_obs\": 155.31649780273438, \"slope\": -0.07043297588825226, \"chain\": 1, \"draw\": 106}, {\"draws\": 306, \"mouse\": 5, \"mu_intercept_per_group\": 6.549246788024902, \"sigma_intercept_per_group\": 0.30099916458129883, \"sigma_obs\": 155.31649780273438, \"slope\": -0.07043297588825226, \"chain\": 1, \"draw\": 106}, {\"draws\": 306, \"mouse\": 6, \"mu_intercept_per_group\": 6.470900058746338, \"sigma_intercept_per_group\": 0.30099916458129883, \"sigma_obs\": 155.31649780273438, \"slope\": -0.07043297588825226, \"chain\": 1, \"draw\": 106}, {\"draws\": 306, \"mouse\": 7, \"mu_intercept_per_group\": 5.848280429840088, \"sigma_intercept_per_group\": 0.30099916458129883, \"sigma_obs\": 155.31649780273438, \"slope\": -0.07043297588825226, \"chain\": 1, \"draw\": 106}, {\"draws\": 307, \"mouse\": 0, \"mu_intercept_per_group\": 7.944667816162109, \"sigma_intercept_per_group\": 0.30935436487197876, \"sigma_obs\": 159.0700225830078, \"slope\": -0.0732017382979393, \"chain\": 1, \"draw\": 107}, {\"draws\": 307, \"mouse\": 1, \"mu_intercept_per_group\": 7.856377124786377, \"sigma_intercept_per_group\": 0.30935436487197876, \"sigma_obs\": 159.0700225830078, \"slope\": -0.0732017382979393, \"chain\": 1, \"draw\": 107}, {\"draws\": 307, \"mouse\": 2, \"mu_intercept_per_group\": 7.5200676918029785, \"sigma_intercept_per_group\": 0.30935436487197876, \"sigma_obs\": 159.0700225830078, \"slope\": -0.0732017382979393, \"chain\": 1, \"draw\": 107}, {\"draws\": 307, \"mouse\": 3, \"mu_intercept_per_group\": 7.101002216339111, \"sigma_intercept_per_group\": 0.30935436487197876, \"sigma_obs\": 159.0700225830078, \"slope\": -0.0732017382979393, \"chain\": 1, \"draw\": 107}, {\"draws\": 307, \"mouse\": 4, \"mu_intercept_per_group\": 6.916648864746094, \"sigma_intercept_per_group\": 0.30935436487197876, \"sigma_obs\": 159.0700225830078, \"slope\": -0.0732017382979393, \"chain\": 1, \"draw\": 107}, {\"draws\": 307, \"mouse\": 5, \"mu_intercept_per_group\": 6.377735137939453, \"sigma_intercept_per_group\": 0.30935436487197876, \"sigma_obs\": 159.0700225830078, \"slope\": -0.0732017382979393, \"chain\": 1, \"draw\": 107}, {\"draws\": 307, \"mouse\": 6, \"mu_intercept_per_group\": 6.293815612792969, \"sigma_intercept_per_group\": 0.30935436487197876, \"sigma_obs\": 159.0700225830078, \"slope\": -0.0732017382979393, \"chain\": 1, \"draw\": 107}, {\"draws\": 307, \"mouse\": 7, \"mu_intercept_per_group\": 5.906498432159424, \"sigma_intercept_per_group\": 0.30935436487197876, \"sigma_obs\": 159.0700225830078, \"slope\": -0.0732017382979393, \"chain\": 1, \"draw\": 107}, {\"draws\": 308, \"mouse\": 0, \"mu_intercept_per_group\": 8.162857055664062, \"sigma_intercept_per_group\": 0.31116336584091187, \"sigma_obs\": 164.49261474609375, \"slope\": -0.07500658929347992, \"chain\": 1, \"draw\": 108}, {\"draws\": 308, \"mouse\": 1, \"mu_intercept_per_group\": 7.808631896972656, \"sigma_intercept_per_group\": 0.31116336584091187, \"sigma_obs\": 164.49261474609375, \"slope\": -0.07500658929347992, \"chain\": 1, \"draw\": 108}, {\"draws\": 308, \"mouse\": 2, \"mu_intercept_per_group\": 7.509790897369385, \"sigma_intercept_per_group\": 0.31116336584091187, \"sigma_obs\": 164.49261474609375, \"slope\": -0.07500658929347992, \"chain\": 1, \"draw\": 108}, {\"draws\": 308, \"mouse\": 3, \"mu_intercept_per_group\": 7.138992786407471, \"sigma_intercept_per_group\": 0.31116336584091187, \"sigma_obs\": 164.49261474609375, \"slope\": -0.07500658929347992, \"chain\": 1, \"draw\": 108}, {\"draws\": 308, \"mouse\": 4, \"mu_intercept_per_group\": 7.056379318237305, \"sigma_intercept_per_group\": 0.31116336584091187, \"sigma_obs\": 164.49261474609375, \"slope\": -0.07500658929347992, \"chain\": 1, \"draw\": 108}, {\"draws\": 308, \"mouse\": 5, \"mu_intercept_per_group\": 6.475204944610596, \"sigma_intercept_per_group\": 0.31116336584091187, \"sigma_obs\": 164.49261474609375, \"slope\": -0.07500658929347992, \"chain\": 1, \"draw\": 108}, {\"draws\": 308, \"mouse\": 6, \"mu_intercept_per_group\": 6.19773530960083, \"sigma_intercept_per_group\": 0.31116336584091187, \"sigma_obs\": 164.49261474609375, \"slope\": -0.07500658929347992, \"chain\": 1, \"draw\": 108}, {\"draws\": 308, \"mouse\": 7, \"mu_intercept_per_group\": 6.17958402633667, \"sigma_intercept_per_group\": 0.31116336584091187, \"sigma_obs\": 164.49261474609375, \"slope\": -0.07500658929347992, \"chain\": 1, \"draw\": 108}, {\"draws\": 309, \"mouse\": 0, \"mu_intercept_per_group\": 9.176798820495605, \"sigma_intercept_per_group\": 0.2790316641330719, \"sigma_obs\": 174.02877807617188, \"slope\": -0.07604584842920303, \"chain\": 1, \"draw\": 109}, {\"draws\": 309, \"mouse\": 1, \"mu_intercept_per_group\": 8.872303009033203, \"sigma_intercept_per_group\": 0.2790316641330719, \"sigma_obs\": 174.02877807617188, \"slope\": -0.07604584842920303, \"chain\": 1, \"draw\": 109}, {\"draws\": 309, \"mouse\": 2, \"mu_intercept_per_group\": 8.49106502532959, \"sigma_intercept_per_group\": 0.2790316641330719, \"sigma_obs\": 174.02877807617188, \"slope\": -0.07604584842920303, \"chain\": 1, \"draw\": 109}, {\"draws\": 309, \"mouse\": 3, \"mu_intercept_per_group\": 8.186064720153809, \"sigma_intercept_per_group\": 0.2790316641330719, \"sigma_obs\": 174.02877807617188, \"slope\": -0.07604584842920303, \"chain\": 1, \"draw\": 109}, {\"draws\": 309, \"mouse\": 4, \"mu_intercept_per_group\": 7.857297897338867, \"sigma_intercept_per_group\": 0.2790316641330719, \"sigma_obs\": 174.02877807617188, \"slope\": -0.07604584842920303, \"chain\": 1, \"draw\": 109}, {\"draws\": 309, \"mouse\": 5, \"mu_intercept_per_group\": 7.324443817138672, \"sigma_intercept_per_group\": 0.2790316641330719, \"sigma_obs\": 174.02877807617188, \"slope\": -0.07604584842920303, \"chain\": 1, \"draw\": 109}, {\"draws\": 309, \"mouse\": 6, \"mu_intercept_per_group\": 7.018901824951172, \"sigma_intercept_per_group\": 0.2790316641330719, \"sigma_obs\": 174.02877807617188, \"slope\": -0.07604584842920303, \"chain\": 1, \"draw\": 109}, {\"draws\": 309, \"mouse\": 7, \"mu_intercept_per_group\": 6.350771427154541, \"sigma_intercept_per_group\": 0.2790316641330719, \"sigma_obs\": 174.02877807617188, \"slope\": -0.07604584842920303, \"chain\": 1, \"draw\": 109}, {\"draws\": 310, \"mouse\": 0, \"mu_intercept_per_group\": 10.678116798400879, \"sigma_intercept_per_group\": 0.2375306785106659, \"sigma_obs\": 174.1528778076172, \"slope\": -0.07178036123514175, \"chain\": 1, \"draw\": 110}, {\"draws\": 310, \"mouse\": 1, \"mu_intercept_per_group\": 10.469687461853027, \"sigma_intercept_per_group\": 0.2375306785106659, \"sigma_obs\": 174.1528778076172, \"slope\": -0.07178036123514175, \"chain\": 1, \"draw\": 110}, {\"draws\": 310, \"mouse\": 2, \"mu_intercept_per_group\": 9.973668098449707, \"sigma_intercept_per_group\": 0.2375306785106659, \"sigma_obs\": 174.1528778076172, \"slope\": -0.07178036123514175, \"chain\": 1, \"draw\": 110}, {\"draws\": 310, \"mouse\": 3, \"mu_intercept_per_group\": 9.482088088989258, \"sigma_intercept_per_group\": 0.2375306785106659, \"sigma_obs\": 174.1528778076172, \"slope\": -0.07178036123514175, \"chain\": 1, \"draw\": 110}, {\"draws\": 310, \"mouse\": 4, \"mu_intercept_per_group\": 9.32860279083252, \"sigma_intercept_per_group\": 0.2375306785106659, \"sigma_obs\": 174.1528778076172, \"slope\": -0.07178036123514175, \"chain\": 1, \"draw\": 110}, {\"draws\": 310, \"mouse\": 5, \"mu_intercept_per_group\": 8.59566593170166, \"sigma_intercept_per_group\": 0.2375306785106659, \"sigma_obs\": 174.1528778076172, \"slope\": -0.07178036123514175, \"chain\": 1, \"draw\": 110}, {\"draws\": 310, \"mouse\": 6, \"mu_intercept_per_group\": 8.136205673217773, \"sigma_intercept_per_group\": 0.2375306785106659, \"sigma_obs\": 174.1528778076172, \"slope\": -0.07178036123514175, \"chain\": 1, \"draw\": 110}, {\"draws\": 310, \"mouse\": 7, \"mu_intercept_per_group\": 7.965078830718994, \"sigma_intercept_per_group\": 0.2375306785106659, \"sigma_obs\": 174.1528778076172, \"slope\": -0.07178036123514175, \"chain\": 1, \"draw\": 110}, {\"draws\": 311, \"mouse\": 0, \"mu_intercept_per_group\": 10.48883056640625, \"sigma_intercept_per_group\": 0.2398228794336319, \"sigma_obs\": 174.64834594726562, \"slope\": -0.07201818376779556, \"chain\": 1, \"draw\": 111}, {\"draws\": 311, \"mouse\": 1, \"mu_intercept_per_group\": 10.422074317932129, \"sigma_intercept_per_group\": 0.2398228794336319, \"sigma_obs\": 174.64834594726562, \"slope\": -0.07201818376779556, \"chain\": 1, \"draw\": 111}, {\"draws\": 311, \"mouse\": 2, \"mu_intercept_per_group\": 9.95513916015625, \"sigma_intercept_per_group\": 0.2398228794336319, \"sigma_obs\": 174.64834594726562, \"slope\": -0.07201818376779556, \"chain\": 1, \"draw\": 111}, {\"draws\": 311, \"mouse\": 3, \"mu_intercept_per_group\": 9.795519828796387, \"sigma_intercept_per_group\": 0.2398228794336319, \"sigma_obs\": 174.64834594726562, \"slope\": -0.07201818376779556, \"chain\": 1, \"draw\": 111}, {\"draws\": 311, \"mouse\": 4, \"mu_intercept_per_group\": 9.257383346557617, \"sigma_intercept_per_group\": 0.2398228794336319, \"sigma_obs\": 174.64834594726562, \"slope\": -0.07201818376779556, \"chain\": 1, \"draw\": 111}, {\"draws\": 311, \"mouse\": 5, \"mu_intercept_per_group\": 8.408991813659668, \"sigma_intercept_per_group\": 0.2398228794336319, \"sigma_obs\": 174.64834594726562, \"slope\": -0.07201818376779556, \"chain\": 1, \"draw\": 111}, {\"draws\": 311, \"mouse\": 6, \"mu_intercept_per_group\": 8.2291898727417, \"sigma_intercept_per_group\": 0.2398228794336319, \"sigma_obs\": 174.64834594726562, \"slope\": -0.07201818376779556, \"chain\": 1, \"draw\": 111}, {\"draws\": 311, \"mouse\": 7, \"mu_intercept_per_group\": 7.876227855682373, \"sigma_intercept_per_group\": 0.2398228794336319, \"sigma_obs\": 174.64834594726562, \"slope\": -0.07201818376779556, \"chain\": 1, \"draw\": 111}, {\"draws\": 312, \"mouse\": 0, \"mu_intercept_per_group\": 11.702799797058105, \"sigma_intercept_per_group\": 0.2158365249633789, \"sigma_obs\": 161.71206665039062, \"slope\": -0.05380988493561745, \"chain\": 1, \"draw\": 112}, {\"draws\": 312, \"mouse\": 1, \"mu_intercept_per_group\": 11.118124961853027, \"sigma_intercept_per_group\": 0.2158365249633789, \"sigma_obs\": 161.71206665039062, \"slope\": -0.05380988493561745, \"chain\": 1, \"draw\": 112}, {\"draws\": 312, \"mouse\": 2, \"mu_intercept_per_group\": 10.604883193969727, \"sigma_intercept_per_group\": 0.2158365249633789, \"sigma_obs\": 161.71206665039062, \"slope\": -0.05380988493561745, \"chain\": 1, \"draw\": 112}, {\"draws\": 312, \"mouse\": 3, \"mu_intercept_per_group\": 9.815505027770996, \"sigma_intercept_per_group\": 0.2158365249633789, \"sigma_obs\": 161.71206665039062, \"slope\": -0.05380988493561745, \"chain\": 1, \"draw\": 112}, {\"draws\": 312, \"mouse\": 4, \"mu_intercept_per_group\": 9.729244232177734, \"sigma_intercept_per_group\": 0.2158365249633789, \"sigma_obs\": 161.71206665039062, \"slope\": -0.05380988493561745, \"chain\": 1, \"draw\": 112}, {\"draws\": 312, \"mouse\": 5, \"mu_intercept_per_group\": 9.031647682189941, \"sigma_intercept_per_group\": 0.2158365249633789, \"sigma_obs\": 161.71206665039062, \"slope\": -0.05380988493561745, \"chain\": 1, \"draw\": 112}, {\"draws\": 312, \"mouse\": 6, \"mu_intercept_per_group\": 8.434587478637695, \"sigma_intercept_per_group\": 0.2158365249633789, \"sigma_obs\": 161.71206665039062, \"slope\": -0.05380988493561745, \"chain\": 1, \"draw\": 112}, {\"draws\": 312, \"mouse\": 7, \"mu_intercept_per_group\": 8.15789794921875, \"sigma_intercept_per_group\": 0.2158365249633789, \"sigma_obs\": 161.71206665039062, \"slope\": -0.05380988493561745, \"chain\": 1, \"draw\": 112}, {\"draws\": 313, \"mouse\": 0, \"mu_intercept_per_group\": 10.766546249389648, \"sigma_intercept_per_group\": 0.23327064514160156, \"sigma_obs\": 171.26609802246094, \"slope\": -0.08058919757604599, \"chain\": 1, \"draw\": 113}, {\"draws\": 313, \"mouse\": 1, \"mu_intercept_per_group\": 10.700377464294434, \"sigma_intercept_per_group\": 0.23327064514160156, \"sigma_obs\": 171.26609802246094, \"slope\": -0.08058919757604599, \"chain\": 1, \"draw\": 113}, {\"draws\": 313, \"mouse\": 2, \"mu_intercept_per_group\": 10.505799293518066, \"sigma_intercept_per_group\": 0.23327064514160156, \"sigma_obs\": 171.26609802246094, \"slope\": -0.08058919757604599, \"chain\": 1, \"draw\": 113}, {\"draws\": 313, \"mouse\": 3, \"mu_intercept_per_group\": 9.35368537902832, \"sigma_intercept_per_group\": 0.23327064514160156, \"sigma_obs\": 171.26609802246094, \"slope\": -0.08058919757604599, \"chain\": 1, \"draw\": 113}, {\"draws\": 313, \"mouse\": 4, \"mu_intercept_per_group\": 9.321737289428711, \"sigma_intercept_per_group\": 0.23327064514160156, \"sigma_obs\": 171.26609802246094, \"slope\": -0.08058919757604599, \"chain\": 1, \"draw\": 113}, {\"draws\": 313, \"mouse\": 5, \"mu_intercept_per_group\": 8.919281005859375, \"sigma_intercept_per_group\": 0.23327064514160156, \"sigma_obs\": 171.26609802246094, \"slope\": -0.08058919757604599, \"chain\": 1, \"draw\": 113}, {\"draws\": 313, \"mouse\": 6, \"mu_intercept_per_group\": 8.200143814086914, \"sigma_intercept_per_group\": 0.23327064514160156, \"sigma_obs\": 171.26609802246094, \"slope\": -0.08058919757604599, \"chain\": 1, \"draw\": 113}, {\"draws\": 313, \"mouse\": 7, \"mu_intercept_per_group\": 7.896308898925781, \"sigma_intercept_per_group\": 0.23327064514160156, \"sigma_obs\": 171.26609802246094, \"slope\": -0.08058919757604599, \"chain\": 1, \"draw\": 113}, {\"draws\": 314, \"mouse\": 0, \"mu_intercept_per_group\": 10.837868690490723, \"sigma_intercept_per_group\": 0.23367838561534882, \"sigma_obs\": 173.49708557128906, \"slope\": -0.07901433110237122, \"chain\": 1, \"draw\": 114}, {\"draws\": 314, \"mouse\": 1, \"mu_intercept_per_group\": 10.595802307128906, \"sigma_intercept_per_group\": 0.23367838561534882, \"sigma_obs\": 173.49708557128906, \"slope\": -0.07901433110237122, \"chain\": 1, \"draw\": 114}, {\"draws\": 314, \"mouse\": 2, \"mu_intercept_per_group\": 10.051959037780762, \"sigma_intercept_per_group\": 0.23367838561534882, \"sigma_obs\": 173.49708557128906, \"slope\": -0.07901433110237122, \"chain\": 1, \"draw\": 114}, {\"draws\": 314, \"mouse\": 3, \"mu_intercept_per_group\": 10.062582015991211, \"sigma_intercept_per_group\": 0.23367838561534882, \"sigma_obs\": 173.49708557128906, \"slope\": -0.07901433110237122, \"chain\": 1, \"draw\": 114}, {\"draws\": 314, \"mouse\": 4, \"mu_intercept_per_group\": 9.577305793762207, \"sigma_intercept_per_group\": 0.23367838561534882, \"sigma_obs\": 173.49708557128906, \"slope\": -0.07901433110237122, \"chain\": 1, \"draw\": 114}, {\"draws\": 314, \"mouse\": 5, \"mu_intercept_per_group\": 9.033132553100586, \"sigma_intercept_per_group\": 0.23367838561534882, \"sigma_obs\": 173.49708557128906, \"slope\": -0.07901433110237122, \"chain\": 1, \"draw\": 114}, {\"draws\": 314, \"mouse\": 6, \"mu_intercept_per_group\": 8.354674339294434, \"sigma_intercept_per_group\": 0.23367838561534882, \"sigma_obs\": 173.49708557128906, \"slope\": -0.07901433110237122, \"chain\": 1, \"draw\": 114}, {\"draws\": 314, \"mouse\": 7, \"mu_intercept_per_group\": 8.234735488891602, \"sigma_intercept_per_group\": 0.23367838561534882, \"sigma_obs\": 173.49708557128906, \"slope\": -0.07901433110237122, \"chain\": 1, \"draw\": 114}, {\"draws\": 315, \"mouse\": 0, \"mu_intercept_per_group\": 11.34645938873291, \"sigma_intercept_per_group\": 0.22817882895469666, \"sigma_obs\": 172.06838989257812, \"slope\": -0.07825843244791031, \"chain\": 1, \"draw\": 115}, {\"draws\": 315, \"mouse\": 1, \"mu_intercept_per_group\": 10.807294845581055, \"sigma_intercept_per_group\": 0.22817882895469666, \"sigma_obs\": 172.06838989257812, \"slope\": -0.07825843244791031, \"chain\": 1, \"draw\": 115}, {\"draws\": 315, \"mouse\": 2, \"mu_intercept_per_group\": 10.724336624145508, \"sigma_intercept_per_group\": 0.22817882895469666, \"sigma_obs\": 172.06838989257812, \"slope\": -0.07825843244791031, \"chain\": 1, \"draw\": 115}, {\"draws\": 315, \"mouse\": 3, \"mu_intercept_per_group\": 9.86283016204834, \"sigma_intercept_per_group\": 0.22817882895469666, \"sigma_obs\": 172.06838989257812, \"slope\": -0.07825843244791031, \"chain\": 1, \"draw\": 115}, {\"draws\": 315, \"mouse\": 4, \"mu_intercept_per_group\": 9.799553871154785, \"sigma_intercept_per_group\": 0.22817882895469666, \"sigma_obs\": 172.06838989257812, \"slope\": -0.07825843244791031, \"chain\": 1, \"draw\": 115}, {\"draws\": 315, \"mouse\": 5, \"mu_intercept_per_group\": 8.961922645568848, \"sigma_intercept_per_group\": 0.22817882895469666, \"sigma_obs\": 172.06838989257812, \"slope\": -0.07825843244791031, \"chain\": 1, \"draw\": 115}, {\"draws\": 315, \"mouse\": 6, \"mu_intercept_per_group\": 8.082850456237793, \"sigma_intercept_per_group\": 0.22817882895469666, \"sigma_obs\": 172.06838989257812, \"slope\": -0.07825843244791031, \"chain\": 1, \"draw\": 115}, {\"draws\": 315, \"mouse\": 7, \"mu_intercept_per_group\": 8.069154739379883, \"sigma_intercept_per_group\": 0.22817882895469666, \"sigma_obs\": 172.06838989257812, \"slope\": -0.07825843244791031, \"chain\": 1, \"draw\": 115}, {\"draws\": 316, \"mouse\": 0, \"mu_intercept_per_group\": 10.850715637207031, \"sigma_intercept_per_group\": 0.23592528700828552, \"sigma_obs\": 173.3868408203125, \"slope\": -0.07891055941581726, \"chain\": 1, \"draw\": 116}, {\"draws\": 316, \"mouse\": 1, \"mu_intercept_per_group\": 10.445403099060059, \"sigma_intercept_per_group\": 0.23592528700828552, \"sigma_obs\": 173.3868408203125, \"slope\": -0.07891055941581726, \"chain\": 1, \"draw\": 116}, {\"draws\": 316, \"mouse\": 2, \"mu_intercept_per_group\": 10.083162307739258, \"sigma_intercept_per_group\": 0.23592528700828552, \"sigma_obs\": 173.3868408203125, \"slope\": -0.07891055941581726, \"chain\": 1, \"draw\": 116}, {\"draws\": 316, \"mouse\": 3, \"mu_intercept_per_group\": 9.74562931060791, \"sigma_intercept_per_group\": 0.23592528700828552, \"sigma_obs\": 173.3868408203125, \"slope\": -0.07891055941581726, \"chain\": 1, \"draw\": 116}, {\"draws\": 316, \"mouse\": 4, \"mu_intercept_per_group\": 9.301839828491211, \"sigma_intercept_per_group\": 0.23592528700828552, \"sigma_obs\": 173.3868408203125, \"slope\": -0.07891055941581726, \"chain\": 1, \"draw\": 116}, {\"draws\": 316, \"mouse\": 5, \"mu_intercept_per_group\": 9.21347713470459, \"sigma_intercept_per_group\": 0.23592528700828552, \"sigma_obs\": 173.3868408203125, \"slope\": -0.07891055941581726, \"chain\": 1, \"draw\": 116}, {\"draws\": 316, \"mouse\": 6, \"mu_intercept_per_group\": 8.755645751953125, \"sigma_intercept_per_group\": 0.23592528700828552, \"sigma_obs\": 173.3868408203125, \"slope\": -0.07891055941581726, \"chain\": 1, \"draw\": 116}, {\"draws\": 316, \"mouse\": 7, \"mu_intercept_per_group\": 8.13627815246582, \"sigma_intercept_per_group\": 0.23592528700828552, \"sigma_obs\": 173.3868408203125, \"slope\": -0.07891055941581726, \"chain\": 1, \"draw\": 116}, {\"draws\": 317, \"mouse\": 0, \"mu_intercept_per_group\": 11.04190731048584, \"sigma_intercept_per_group\": 0.23305661976337433, \"sigma_obs\": 173.3969268798828, \"slope\": -0.07837662100791931, \"chain\": 1, \"draw\": 117}, {\"draws\": 317, \"mouse\": 1, \"mu_intercept_per_group\": 10.334501266479492, \"sigma_intercept_per_group\": 0.23305661976337433, \"sigma_obs\": 173.3969268798828, \"slope\": -0.07837662100791931, \"chain\": 1, \"draw\": 117}, {\"draws\": 317, \"mouse\": 2, \"mu_intercept_per_group\": 10.147135734558105, \"sigma_intercept_per_group\": 0.23305661976337433, \"sigma_obs\": 173.3969268798828, \"slope\": -0.07837662100791931, \"chain\": 1, \"draw\": 117}, {\"draws\": 317, \"mouse\": 3, \"mu_intercept_per_group\": 9.733022689819336, \"sigma_intercept_per_group\": 0.23305661976337433, \"sigma_obs\": 173.3969268798828, \"slope\": -0.07837662100791931, \"chain\": 1, \"draw\": 117}, {\"draws\": 317, \"mouse\": 4, \"mu_intercept_per_group\": 9.180787086486816, \"sigma_intercept_per_group\": 0.23305661976337433, \"sigma_obs\": 173.3969268798828, \"slope\": -0.07837662100791931, \"chain\": 1, \"draw\": 117}, {\"draws\": 317, \"mouse\": 5, \"mu_intercept_per_group\": 9.184407234191895, \"sigma_intercept_per_group\": 0.23305661976337433, \"sigma_obs\": 173.3969268798828, \"slope\": -0.07837662100791931, \"chain\": 1, \"draw\": 117}, {\"draws\": 317, \"mouse\": 6, \"mu_intercept_per_group\": 8.604838371276855, \"sigma_intercept_per_group\": 0.23305661976337433, \"sigma_obs\": 173.3969268798828, \"slope\": -0.07837662100791931, \"chain\": 1, \"draw\": 117}, {\"draws\": 317, \"mouse\": 7, \"mu_intercept_per_group\": 8.296968460083008, \"sigma_intercept_per_group\": 0.23305661976337433, \"sigma_obs\": 173.3969268798828, \"slope\": -0.07837662100791931, \"chain\": 1, \"draw\": 117}, {\"draws\": 318, \"mouse\": 0, \"mu_intercept_per_group\": 16.770580291748047, \"sigma_intercept_per_group\": 0.14417333900928497, \"sigma_obs\": 153.46551513671875, \"slope\": -0.057405877858400345, \"chain\": 1, \"draw\": 118}, {\"draws\": 318, \"mouse\": 1, \"mu_intercept_per_group\": 15.882125854492188, \"sigma_intercept_per_group\": 0.14417333900928497, \"sigma_obs\": 153.46551513671875, \"slope\": -0.057405877858400345, \"chain\": 1, \"draw\": 118}, {\"draws\": 318, \"mouse\": 2, \"mu_intercept_per_group\": 15.440028190612793, \"sigma_intercept_per_group\": 0.14417333900928497, \"sigma_obs\": 153.46551513671875, \"slope\": -0.057405877858400345, \"chain\": 1, \"draw\": 118}, {\"draws\": 318, \"mouse\": 3, \"mu_intercept_per_group\": 14.829164505004883, \"sigma_intercept_per_group\": 0.14417333900928497, \"sigma_obs\": 153.46551513671875, \"slope\": -0.057405877858400345, \"chain\": 1, \"draw\": 118}, {\"draws\": 318, \"mouse\": 4, \"mu_intercept_per_group\": 14.384394645690918, \"sigma_intercept_per_group\": 0.14417333900928497, \"sigma_obs\": 153.46551513671875, \"slope\": -0.057405877858400345, \"chain\": 1, \"draw\": 118}, {\"draws\": 318, \"mouse\": 5, \"mu_intercept_per_group\": 12.891270637512207, \"sigma_intercept_per_group\": 0.14417333900928497, \"sigma_obs\": 153.46551513671875, \"slope\": -0.057405877858400345, \"chain\": 1, \"draw\": 118}, {\"draws\": 318, \"mouse\": 6, \"mu_intercept_per_group\": 12.641969680786133, \"sigma_intercept_per_group\": 0.14417333900928497, \"sigma_obs\": 153.46551513671875, \"slope\": -0.057405877858400345, \"chain\": 1, \"draw\": 118}, {\"draws\": 318, \"mouse\": 7, \"mu_intercept_per_group\": 11.638373374938965, \"sigma_intercept_per_group\": 0.14417333900928497, \"sigma_obs\": 153.46551513671875, \"slope\": -0.057405877858400345, \"chain\": 1, \"draw\": 118}, {\"draws\": 319, \"mouse\": 0, \"mu_intercept_per_group\": 16.17043113708496, \"sigma_intercept_per_group\": 0.14777909219264984, \"sigma_obs\": 157.05735778808594, \"slope\": -0.056278426200151443, \"chain\": 1, \"draw\": 119}, {\"draws\": 319, \"mouse\": 1, \"mu_intercept_per_group\": 15.851078033447266, \"sigma_intercept_per_group\": 0.14777909219264984, \"sigma_obs\": 157.05735778808594, \"slope\": -0.056278426200151443, \"chain\": 1, \"draw\": 119}, {\"draws\": 319, \"mouse\": 2, \"mu_intercept_per_group\": 15.465611457824707, \"sigma_intercept_per_group\": 0.14777909219264984, \"sigma_obs\": 157.05735778808594, \"slope\": -0.056278426200151443, \"chain\": 1, \"draw\": 119}, {\"draws\": 319, \"mouse\": 3, \"mu_intercept_per_group\": 14.165689468383789, \"sigma_intercept_per_group\": 0.14777909219264984, \"sigma_obs\": 157.05735778808594, \"slope\": -0.056278426200151443, \"chain\": 1, \"draw\": 119}, {\"draws\": 319, \"mouse\": 4, \"mu_intercept_per_group\": 13.76467514038086, \"sigma_intercept_per_group\": 0.14777909219264984, \"sigma_obs\": 157.05735778808594, \"slope\": -0.056278426200151443, \"chain\": 1, \"draw\": 119}, {\"draws\": 319, \"mouse\": 5, \"mu_intercept_per_group\": 13.741378784179688, \"sigma_intercept_per_group\": 0.14777909219264984, \"sigma_obs\": 157.05735778808594, \"slope\": -0.056278426200151443, \"chain\": 1, \"draw\": 119}, {\"draws\": 319, \"mouse\": 6, \"mu_intercept_per_group\": 12.261517524719238, \"sigma_intercept_per_group\": 0.14777909219264984, \"sigma_obs\": 157.05735778808594, \"slope\": -0.056278426200151443, \"chain\": 1, \"draw\": 119}, {\"draws\": 319, \"mouse\": 7, \"mu_intercept_per_group\": 11.9080171585083, \"sigma_intercept_per_group\": 0.14777909219264984, \"sigma_obs\": 157.05735778808594, \"slope\": -0.056278426200151443, \"chain\": 1, \"draw\": 119}, {\"draws\": 320, \"mouse\": 0, \"mu_intercept_per_group\": 15.34424877166748, \"sigma_intercept_per_group\": 0.1606471985578537, \"sigma_obs\": 159.46783447265625, \"slope\": -0.05009012669324875, \"chain\": 1, \"draw\": 120}, {\"draws\": 320, \"mouse\": 1, \"mu_intercept_per_group\": 14.52429485321045, \"sigma_intercept_per_group\": 0.1606471985578537, \"sigma_obs\": 159.46783447265625, \"slope\": -0.05009012669324875, \"chain\": 1, \"draw\": 120}, {\"draws\": 320, \"mouse\": 2, \"mu_intercept_per_group\": 13.797504425048828, \"sigma_intercept_per_group\": 0.1606471985578537, \"sigma_obs\": 159.46783447265625, \"slope\": -0.05009012669324875, \"chain\": 1, \"draw\": 120}, {\"draws\": 320, \"mouse\": 3, \"mu_intercept_per_group\": 13.431388854980469, \"sigma_intercept_per_group\": 0.1606471985578537, \"sigma_obs\": 159.46783447265625, \"slope\": -0.05009012669324875, \"chain\": 1, \"draw\": 120}, {\"draws\": 320, \"mouse\": 4, \"mu_intercept_per_group\": 12.882678031921387, \"sigma_intercept_per_group\": 0.1606471985578537, \"sigma_obs\": 159.46783447265625, \"slope\": -0.05009012669324875, \"chain\": 1, \"draw\": 120}, {\"draws\": 320, \"mouse\": 5, \"mu_intercept_per_group\": 12.832834243774414, \"sigma_intercept_per_group\": 0.1606471985578537, \"sigma_obs\": 159.46783447265625, \"slope\": -0.05009012669324875, \"chain\": 1, \"draw\": 120}, {\"draws\": 320, \"mouse\": 6, \"mu_intercept_per_group\": 11.322030067443848, \"sigma_intercept_per_group\": 0.1606471985578537, \"sigma_obs\": 159.46783447265625, \"slope\": -0.05009012669324875, \"chain\": 1, \"draw\": 120}, {\"draws\": 320, \"mouse\": 7, \"mu_intercept_per_group\": 10.96519660949707, \"sigma_intercept_per_group\": 0.1606471985578537, \"sigma_obs\": 159.46783447265625, \"slope\": -0.05009012669324875, \"chain\": 1, \"draw\": 120}, {\"draws\": 321, \"mouse\": 0, \"mu_intercept_per_group\": 15.189675331115723, \"sigma_intercept_per_group\": 0.1593732088804245, \"sigma_obs\": 159.014892578125, \"slope\": -0.0513169951736927, \"chain\": 1, \"draw\": 121}, {\"draws\": 321, \"mouse\": 1, \"mu_intercept_per_group\": 14.970671653747559, \"sigma_intercept_per_group\": 0.1593732088804245, \"sigma_obs\": 159.014892578125, \"slope\": -0.0513169951736927, \"chain\": 1, \"draw\": 121}, {\"draws\": 321, \"mouse\": 2, \"mu_intercept_per_group\": 14.37467098236084, \"sigma_intercept_per_group\": 0.1593732088804245, \"sigma_obs\": 159.014892578125, \"slope\": -0.0513169951736927, \"chain\": 1, \"draw\": 121}, {\"draws\": 321, \"mouse\": 3, \"mu_intercept_per_group\": 13.499411582946777, \"sigma_intercept_per_group\": 0.1593732088804245, \"sigma_obs\": 159.014892578125, \"slope\": -0.0513169951736927, \"chain\": 1, \"draw\": 121}, {\"draws\": 321, \"mouse\": 4, \"mu_intercept_per_group\": 12.731709480285645, \"sigma_intercept_per_group\": 0.1593732088804245, \"sigma_obs\": 159.014892578125, \"slope\": -0.0513169951736927, \"chain\": 1, \"draw\": 121}, {\"draws\": 321, \"mouse\": 5, \"mu_intercept_per_group\": 12.545930862426758, \"sigma_intercept_per_group\": 0.1593732088804245, \"sigma_obs\": 159.014892578125, \"slope\": -0.0513169951736927, \"chain\": 1, \"draw\": 121}, {\"draws\": 321, \"mouse\": 6, \"mu_intercept_per_group\": 11.799272537231445, \"sigma_intercept_per_group\": 0.1593732088804245, \"sigma_obs\": 159.014892578125, \"slope\": -0.0513169951736927, \"chain\": 1, \"draw\": 121}, {\"draws\": 321, \"mouse\": 7, \"mu_intercept_per_group\": 10.753277778625488, \"sigma_intercept_per_group\": 0.1593732088804245, \"sigma_obs\": 159.014892578125, \"slope\": -0.0513169951736927, \"chain\": 1, \"draw\": 121}, {\"draws\": 322, \"mouse\": 0, \"mu_intercept_per_group\": 15.694360733032227, \"sigma_intercept_per_group\": 0.15706978738307953, \"sigma_obs\": 160.123046875, \"slope\": -0.05313824862241745, \"chain\": 1, \"draw\": 122}, {\"draws\": 322, \"mouse\": 1, \"mu_intercept_per_group\": 14.808052062988281, \"sigma_intercept_per_group\": 0.15706978738307953, \"sigma_obs\": 160.123046875, \"slope\": -0.05313824862241745, \"chain\": 1, \"draw\": 122}, {\"draws\": 322, \"mouse\": 2, \"mu_intercept_per_group\": 14.702786445617676, \"sigma_intercept_per_group\": 0.15706978738307953, \"sigma_obs\": 160.123046875, \"slope\": -0.05313824862241745, \"chain\": 1, \"draw\": 122}, {\"draws\": 322, \"mouse\": 3, \"mu_intercept_per_group\": 13.787023544311523, \"sigma_intercept_per_group\": 0.15706978738307953, \"sigma_obs\": 160.123046875, \"slope\": -0.05313824862241745, \"chain\": 1, \"draw\": 122}, {\"draws\": 322, \"mouse\": 4, \"mu_intercept_per_group\": 13.391928672790527, \"sigma_intercept_per_group\": 0.15706978738307953, \"sigma_obs\": 160.123046875, \"slope\": -0.05313824862241745, \"chain\": 1, \"draw\": 122}, {\"draws\": 322, \"mouse\": 5, \"mu_intercept_per_group\": 12.565986633300781, \"sigma_intercept_per_group\": 0.15706978738307953, \"sigma_obs\": 160.123046875, \"slope\": -0.05313824862241745, \"chain\": 1, \"draw\": 122}, {\"draws\": 322, \"mouse\": 6, \"mu_intercept_per_group\": 11.799367904663086, \"sigma_intercept_per_group\": 0.15706978738307953, \"sigma_obs\": 160.123046875, \"slope\": -0.05313824862241745, \"chain\": 1, \"draw\": 122}, {\"draws\": 322, \"mouse\": 7, \"mu_intercept_per_group\": 10.932510375976562, \"sigma_intercept_per_group\": 0.15706978738307953, \"sigma_obs\": 160.123046875, \"slope\": -0.05313824862241745, \"chain\": 1, \"draw\": 122}, {\"draws\": 323, \"mouse\": 0, \"mu_intercept_per_group\": 15.925909042358398, \"sigma_intercept_per_group\": 0.15468576550483704, \"sigma_obs\": 161.04627990722656, \"slope\": -0.05068126320838928, \"chain\": 1, \"draw\": 123}, {\"draws\": 323, \"mouse\": 1, \"mu_intercept_per_group\": 15.352365493774414, \"sigma_intercept_per_group\": 0.15468576550483704, \"sigma_obs\": 161.04627990722656, \"slope\": -0.05068126320838928, \"chain\": 1, \"draw\": 123}, {\"draws\": 323, \"mouse\": 2, \"mu_intercept_per_group\": 14.911664962768555, \"sigma_intercept_per_group\": 0.15468576550483704, \"sigma_obs\": 161.04627990722656, \"slope\": -0.05068126320838928, \"chain\": 1, \"draw\": 123}, {\"draws\": 323, \"mouse\": 3, \"mu_intercept_per_group\": 13.931422233581543, \"sigma_intercept_per_group\": 0.15468576550483704, \"sigma_obs\": 161.04627990722656, \"slope\": -0.05068126320838928, \"chain\": 1, \"draw\": 123}, {\"draws\": 323, \"mouse\": 4, \"mu_intercept_per_group\": 13.629022598266602, \"sigma_intercept_per_group\": 0.15468576550483704, \"sigma_obs\": 161.04627990722656, \"slope\": -0.05068126320838928, \"chain\": 1, \"draw\": 123}, {\"draws\": 323, \"mouse\": 5, \"mu_intercept_per_group\": 12.886873245239258, \"sigma_intercept_per_group\": 0.15468576550483704, \"sigma_obs\": 161.04627990722656, \"slope\": -0.05068126320838928, \"chain\": 1, \"draw\": 123}, {\"draws\": 323, \"mouse\": 6, \"mu_intercept_per_group\": 12.026055335998535, \"sigma_intercept_per_group\": 0.15468576550483704, \"sigma_obs\": 161.04627990722656, \"slope\": -0.05068126320838928, \"chain\": 1, \"draw\": 123}, {\"draws\": 323, \"mouse\": 7, \"mu_intercept_per_group\": 10.768105506896973, \"sigma_intercept_per_group\": 0.15468576550483704, \"sigma_obs\": 161.04627990722656, \"slope\": -0.05068126320838928, \"chain\": 1, \"draw\": 123}, {\"draws\": 324, \"mouse\": 0, \"mu_intercept_per_group\": 15.827095031738281, \"sigma_intercept_per_group\": 0.15350660681724548, \"sigma_obs\": 152.85809326171875, \"slope\": -0.05384153127670288, \"chain\": 1, \"draw\": 124}, {\"draws\": 324, \"mouse\": 1, \"mu_intercept_per_group\": 15.503687858581543, \"sigma_intercept_per_group\": 0.15350660681724548, \"sigma_obs\": 152.85809326171875, \"slope\": -0.05384153127670288, \"chain\": 1, \"draw\": 124}, {\"draws\": 324, \"mouse\": 2, \"mu_intercept_per_group\": 14.642535209655762, \"sigma_intercept_per_group\": 0.15350660681724548, \"sigma_obs\": 152.85809326171875, \"slope\": -0.05384153127670288, \"chain\": 1, \"draw\": 124}, {\"draws\": 324, \"mouse\": 3, \"mu_intercept_per_group\": 14.08343505859375, \"sigma_intercept_per_group\": 0.15350660681724548, \"sigma_obs\": 152.85809326171875, \"slope\": -0.05384153127670288, \"chain\": 1, \"draw\": 124}, {\"draws\": 324, \"mouse\": 4, \"mu_intercept_per_group\": 13.528157234191895, \"sigma_intercept_per_group\": 0.15350660681724548, \"sigma_obs\": 152.85809326171875, \"slope\": -0.05384153127670288, \"chain\": 1, \"draw\": 124}, {\"draws\": 324, \"mouse\": 5, \"mu_intercept_per_group\": 12.818432807922363, \"sigma_intercept_per_group\": 0.15350660681724548, \"sigma_obs\": 152.85809326171875, \"slope\": -0.05384153127670288, \"chain\": 1, \"draw\": 124}, {\"draws\": 324, \"mouse\": 6, \"mu_intercept_per_group\": 11.773069381713867, \"sigma_intercept_per_group\": 0.15350660681724548, \"sigma_obs\": 152.85809326171875, \"slope\": -0.05384153127670288, \"chain\": 1, \"draw\": 124}, {\"draws\": 324, \"mouse\": 7, \"mu_intercept_per_group\": 11.144231796264648, \"sigma_intercept_per_group\": 0.15350660681724548, \"sigma_obs\": 152.85809326171875, \"slope\": -0.05384153127670288, \"chain\": 1, \"draw\": 124}, {\"draws\": 325, \"mouse\": 0, \"mu_intercept_per_group\": 9.408387184143066, \"sigma_intercept_per_group\": 0.27176061272621155, \"sigma_obs\": 170.604736328125, \"slope\": -0.08956550061702728, \"chain\": 1, \"draw\": 125}, {\"draws\": 325, \"mouse\": 1, \"mu_intercept_per_group\": 9.133434295654297, \"sigma_intercept_per_group\": 0.27176061272621155, \"sigma_obs\": 170.604736328125, \"slope\": -0.08956550061702728, \"chain\": 1, \"draw\": 125}, {\"draws\": 325, \"mouse\": 2, \"mu_intercept_per_group\": 8.865482330322266, \"sigma_intercept_per_group\": 0.27176061272621155, \"sigma_obs\": 170.604736328125, \"slope\": -0.08956550061702728, \"chain\": 1, \"draw\": 125}, {\"draws\": 325, \"mouse\": 3, \"mu_intercept_per_group\": 8.51900577545166, \"sigma_intercept_per_group\": 0.27176061272621155, \"sigma_obs\": 170.604736328125, \"slope\": -0.08956550061702728, \"chain\": 1, \"draw\": 125}, {\"draws\": 325, \"mouse\": 4, \"mu_intercept_per_group\": 8.291192054748535, \"sigma_intercept_per_group\": 0.27176061272621155, \"sigma_obs\": 170.604736328125, \"slope\": -0.08956550061702728, \"chain\": 1, \"draw\": 125}, {\"draws\": 325, \"mouse\": 5, \"mu_intercept_per_group\": 7.8700785636901855, \"sigma_intercept_per_group\": 0.27176061272621155, \"sigma_obs\": 170.604736328125, \"slope\": -0.08956550061702728, \"chain\": 1, \"draw\": 125}, {\"draws\": 325, \"mouse\": 6, \"mu_intercept_per_group\": 7.140909194946289, \"sigma_intercept_per_group\": 0.27176061272621155, \"sigma_obs\": 170.604736328125, \"slope\": -0.08956550061702728, \"chain\": 1, \"draw\": 125}, {\"draws\": 325, \"mouse\": 7, \"mu_intercept_per_group\": 6.887386322021484, \"sigma_intercept_per_group\": 0.27176061272621155, \"sigma_obs\": 170.604736328125, \"slope\": -0.08956550061702728, \"chain\": 1, \"draw\": 125}, {\"draws\": 326, \"mouse\": 0, \"mu_intercept_per_group\": 10.281269073486328, \"sigma_intercept_per_group\": 0.2399130016565323, \"sigma_obs\": 162.24932861328125, \"slope\": -0.06206934526562691, \"chain\": 1, \"draw\": 126}, {\"draws\": 326, \"mouse\": 1, \"mu_intercept_per_group\": 9.972044944763184, \"sigma_intercept_per_group\": 0.2399130016565323, \"sigma_obs\": 162.24932861328125, \"slope\": -0.06206934526562691, \"chain\": 1, \"draw\": 126}, {\"draws\": 326, \"mouse\": 2, \"mu_intercept_per_group\": 9.674508094787598, \"sigma_intercept_per_group\": 0.2399130016565323, \"sigma_obs\": 162.24932861328125, \"slope\": -0.06206934526562691, \"chain\": 1, \"draw\": 126}, {\"draws\": 326, \"mouse\": 3, \"mu_intercept_per_group\": 9.36139965057373, \"sigma_intercept_per_group\": 0.2399130016565323, \"sigma_obs\": 162.24932861328125, \"slope\": -0.06206934526562691, \"chain\": 1, \"draw\": 126}, {\"draws\": 326, \"mouse\": 4, \"mu_intercept_per_group\": 8.90007209777832, \"sigma_intercept_per_group\": 0.2399130016565323, \"sigma_obs\": 162.24932861328125, \"slope\": -0.06206934526562691, \"chain\": 1, \"draw\": 126}, {\"draws\": 326, \"mouse\": 5, \"mu_intercept_per_group\": 8.476293563842773, \"sigma_intercept_per_group\": 0.2399130016565323, \"sigma_obs\": 162.24932861328125, \"slope\": -0.06206934526562691, \"chain\": 1, \"draw\": 126}, {\"draws\": 326, \"mouse\": 6, \"mu_intercept_per_group\": 7.9016265869140625, \"sigma_intercept_per_group\": 0.2399130016565323, \"sigma_obs\": 162.24932861328125, \"slope\": -0.06206934526562691, \"chain\": 1, \"draw\": 126}, {\"draws\": 326, \"mouse\": 7, \"mu_intercept_per_group\": 7.625044345855713, \"sigma_intercept_per_group\": 0.2399130016565323, \"sigma_obs\": 162.24932861328125, \"slope\": -0.06206934526562691, \"chain\": 1, \"draw\": 126}, {\"draws\": 327, \"mouse\": 0, \"mu_intercept_per_group\": 10.510644912719727, \"sigma_intercept_per_group\": 0.23473769426345825, \"sigma_obs\": 160.68460083007812, \"slope\": -0.06397884339094162, \"chain\": 1, \"draw\": 127}, {\"draws\": 327, \"mouse\": 1, \"mu_intercept_per_group\": 10.033650398254395, \"sigma_intercept_per_group\": 0.23473769426345825, \"sigma_obs\": 160.68460083007812, \"slope\": -0.06397884339094162, \"chain\": 1, \"draw\": 127}, {\"draws\": 327, \"mouse\": 2, \"mu_intercept_per_group\": 10.217759132385254, \"sigma_intercept_per_group\": 0.23473769426345825, \"sigma_obs\": 160.68460083007812, \"slope\": -0.06397884339094162, \"chain\": 1, \"draw\": 127}, {\"draws\": 327, \"mouse\": 3, \"mu_intercept_per_group\": 9.433279991149902, \"sigma_intercept_per_group\": 0.23473769426345825, \"sigma_obs\": 160.68460083007812, \"slope\": -0.06397884339094162, \"chain\": 1, \"draw\": 127}, {\"draws\": 327, \"mouse\": 4, \"mu_intercept_per_group\": 8.931092262268066, \"sigma_intercept_per_group\": 0.23473769426345825, \"sigma_obs\": 160.68460083007812, \"slope\": -0.06397884339094162, \"chain\": 1, \"draw\": 127}, {\"draws\": 327, \"mouse\": 5, \"mu_intercept_per_group\": 8.458796501159668, \"sigma_intercept_per_group\": 0.23473769426345825, \"sigma_obs\": 160.68460083007812, \"slope\": -0.06397884339094162, \"chain\": 1, \"draw\": 127}, {\"draws\": 327, \"mouse\": 6, \"mu_intercept_per_group\": 7.982583045959473, \"sigma_intercept_per_group\": 0.23473769426345825, \"sigma_obs\": 160.68460083007812, \"slope\": -0.06397884339094162, \"chain\": 1, \"draw\": 127}, {\"draws\": 327, \"mouse\": 7, \"mu_intercept_per_group\": 7.473209381103516, \"sigma_intercept_per_group\": 0.23473769426345825, \"sigma_obs\": 160.68460083007812, \"slope\": -0.06397884339094162, \"chain\": 1, \"draw\": 127}, {\"draws\": 328, \"mouse\": 0, \"mu_intercept_per_group\": 7.373150825500488, \"sigma_intercept_per_group\": 0.34458377957344055, \"sigma_obs\": 169.89846801757812, \"slope\": -0.07703413814306259, \"chain\": 1, \"draw\": 128}, {\"draws\": 328, \"mouse\": 1, \"mu_intercept_per_group\": 6.927382469177246, \"sigma_intercept_per_group\": 0.34458377957344055, \"sigma_obs\": 169.89846801757812, \"slope\": -0.07703413814306259, \"chain\": 1, \"draw\": 128}, {\"draws\": 328, \"mouse\": 2, \"mu_intercept_per_group\": 7.055446147918701, \"sigma_intercept_per_group\": 0.34458377957344055, \"sigma_obs\": 169.89846801757812, \"slope\": -0.07703413814306259, \"chain\": 1, \"draw\": 128}, {\"draws\": 328, \"mouse\": 3, \"mu_intercept_per_group\": 6.73510217666626, \"sigma_intercept_per_group\": 0.34458377957344055, \"sigma_obs\": 169.89846801757812, \"slope\": -0.07703413814306259, \"chain\": 1, \"draw\": 128}, {\"draws\": 328, \"mouse\": 4, \"mu_intercept_per_group\": 6.36006498336792, \"sigma_intercept_per_group\": 0.34458377957344055, \"sigma_obs\": 169.89846801757812, \"slope\": -0.07703413814306259, \"chain\": 1, \"draw\": 128}, {\"draws\": 328, \"mouse\": 5, \"mu_intercept_per_group\": 6.017430305480957, \"sigma_intercept_per_group\": 0.34458377957344055, \"sigma_obs\": 169.89846801757812, \"slope\": -0.07703413814306259, \"chain\": 1, \"draw\": 128}, {\"draws\": 328, \"mouse\": 6, \"mu_intercept_per_group\": 5.573692321777344, \"sigma_intercept_per_group\": 0.34458377957344055, \"sigma_obs\": 169.89846801757812, \"slope\": -0.07703413814306259, \"chain\": 1, \"draw\": 128}, {\"draws\": 328, \"mouse\": 7, \"mu_intercept_per_group\": 5.238526821136475, \"sigma_intercept_per_group\": 0.34458377957344055, \"sigma_obs\": 169.89846801757812, \"slope\": -0.07703413814306259, \"chain\": 1, \"draw\": 128}, {\"draws\": 329, \"mouse\": 0, \"mu_intercept_per_group\": 7.921493053436279, \"sigma_intercept_per_group\": 0.31421759724617004, \"sigma_obs\": 170.3084716796875, \"slope\": -0.07521364092826843, \"chain\": 1, \"draw\": 129}, {\"draws\": 329, \"mouse\": 1, \"mu_intercept_per_group\": 8.041868209838867, \"sigma_intercept_per_group\": 0.31421759724617004, \"sigma_obs\": 170.3084716796875, \"slope\": -0.07521364092826843, \"chain\": 1, \"draw\": 129}, {\"draws\": 329, \"mouse\": 2, \"mu_intercept_per_group\": 7.464046478271484, \"sigma_intercept_per_group\": 0.31421759724617004, \"sigma_obs\": 170.3084716796875, \"slope\": -0.07521364092826843, \"chain\": 1, \"draw\": 129}, {\"draws\": 329, \"mouse\": 3, \"mu_intercept_per_group\": 7.009417533874512, \"sigma_intercept_per_group\": 0.31421759724617004, \"sigma_obs\": 170.3084716796875, \"slope\": -0.07521364092826843, \"chain\": 1, \"draw\": 129}, {\"draws\": 329, \"mouse\": 4, \"mu_intercept_per_group\": 7.073853015899658, \"sigma_intercept_per_group\": 0.31421759724617004, \"sigma_obs\": 170.3084716796875, \"slope\": -0.07521364092826843, \"chain\": 1, \"draw\": 129}, {\"draws\": 329, \"mouse\": 5, \"mu_intercept_per_group\": 6.394463539123535, \"sigma_intercept_per_group\": 0.31421759724617004, \"sigma_obs\": 170.3084716796875, \"slope\": -0.07521364092826843, \"chain\": 1, \"draw\": 129}, {\"draws\": 329, \"mouse\": 6, \"mu_intercept_per_group\": 6.099450588226318, \"sigma_intercept_per_group\": 0.31421759724617004, \"sigma_obs\": 170.3084716796875, \"slope\": -0.07521364092826843, \"chain\": 1, \"draw\": 129}, {\"draws\": 329, \"mouse\": 7, \"mu_intercept_per_group\": 5.695169925689697, \"sigma_intercept_per_group\": 0.31421759724617004, \"sigma_obs\": 170.3084716796875, \"slope\": -0.07521364092826843, \"chain\": 1, \"draw\": 129}, {\"draws\": 330, \"mouse\": 0, \"mu_intercept_per_group\": 11.21947193145752, \"sigma_intercept_per_group\": 0.22048981487751007, \"sigma_obs\": 152.5137176513672, \"slope\": -0.06007429212331772, \"chain\": 1, \"draw\": 130}, {\"draws\": 330, \"mouse\": 1, \"mu_intercept_per_group\": 10.558117866516113, \"sigma_intercept_per_group\": 0.22048981487751007, \"sigma_obs\": 152.5137176513672, \"slope\": -0.06007429212331772, \"chain\": 1, \"draw\": 130}, {\"draws\": 330, \"mouse\": 2, \"mu_intercept_per_group\": 9.837838172912598, \"sigma_intercept_per_group\": 0.22048981487751007, \"sigma_obs\": 152.5137176513672, \"slope\": -0.06007429212331772, \"chain\": 1, \"draw\": 130}, {\"draws\": 330, \"mouse\": 3, \"mu_intercept_per_group\": 9.570450782775879, \"sigma_intercept_per_group\": 0.22048981487751007, \"sigma_obs\": 152.5137176513672, \"slope\": -0.06007429212331772, \"chain\": 1, \"draw\": 130}, {\"draws\": 330, \"mouse\": 4, \"mu_intercept_per_group\": 9.285428047180176, \"sigma_intercept_per_group\": 0.22048981487751007, \"sigma_obs\": 152.5137176513672, \"slope\": -0.06007429212331772, \"chain\": 1, \"draw\": 130}, {\"draws\": 330, \"mouse\": 5, \"mu_intercept_per_group\": 9.035961151123047, \"sigma_intercept_per_group\": 0.22048981487751007, \"sigma_obs\": 152.5137176513672, \"slope\": -0.06007429212331772, \"chain\": 1, \"draw\": 130}, {\"draws\": 330, \"mouse\": 6, \"mu_intercept_per_group\": 8.294501304626465, \"sigma_intercept_per_group\": 0.22048981487751007, \"sigma_obs\": 152.5137176513672, \"slope\": -0.06007429212331772, \"chain\": 1, \"draw\": 130}, {\"draws\": 330, \"mouse\": 7, \"mu_intercept_per_group\": 7.957327365875244, \"sigma_intercept_per_group\": 0.22048981487751007, \"sigma_obs\": 152.5137176513672, \"slope\": -0.06007429212331772, \"chain\": 1, \"draw\": 130}, {\"draws\": 331, \"mouse\": 0, \"mu_intercept_per_group\": 11.096458435058594, \"sigma_intercept_per_group\": 0.21853949129581451, \"sigma_obs\": 150.38194274902344, \"slope\": -0.05392603203654289, \"chain\": 1, \"draw\": 131}, {\"draws\": 331, \"mouse\": 1, \"mu_intercept_per_group\": 10.48686408996582, \"sigma_intercept_per_group\": 0.21853949129581451, \"sigma_obs\": 150.38194274902344, \"slope\": -0.05392603203654289, \"chain\": 1, \"draw\": 131}, {\"draws\": 331, \"mouse\": 2, \"mu_intercept_per_group\": 10.1087064743042, \"sigma_intercept_per_group\": 0.21853949129581451, \"sigma_obs\": 150.38194274902344, \"slope\": -0.05392603203654289, \"chain\": 1, \"draw\": 131}, {\"draws\": 331, \"mouse\": 3, \"mu_intercept_per_group\": 9.909090995788574, \"sigma_intercept_per_group\": 0.21853949129581451, \"sigma_obs\": 150.38194274902344, \"slope\": -0.05392603203654289, \"chain\": 1, \"draw\": 131}, {\"draws\": 331, \"mouse\": 4, \"mu_intercept_per_group\": 9.439805030822754, \"sigma_intercept_per_group\": 0.21853949129581451, \"sigma_obs\": 150.38194274902344, \"slope\": -0.05392603203654289, \"chain\": 1, \"draw\": 131}, {\"draws\": 331, \"mouse\": 5, \"mu_intercept_per_group\": 8.666594505310059, \"sigma_intercept_per_group\": 0.21853949129581451, \"sigma_obs\": 150.38194274902344, \"slope\": -0.05392603203654289, \"chain\": 1, \"draw\": 131}, {\"draws\": 331, \"mouse\": 6, \"mu_intercept_per_group\": 8.20567798614502, \"sigma_intercept_per_group\": 0.21853949129581451, \"sigma_obs\": 150.38194274902344, \"slope\": -0.05392603203654289, \"chain\": 1, \"draw\": 131}, {\"draws\": 331, \"mouse\": 7, \"mu_intercept_per_group\": 7.714743614196777, \"sigma_intercept_per_group\": 0.21853949129581451, \"sigma_obs\": 150.38194274902344, \"slope\": -0.05392603203654289, \"chain\": 1, \"draw\": 131}, {\"draws\": 332, \"mouse\": 0, \"mu_intercept_per_group\": 9.473085403442383, \"sigma_intercept_per_group\": 0.25182807445526123, \"sigma_obs\": 153.08326721191406, \"slope\": -0.05210374295711517, \"chain\": 1, \"draw\": 132}, {\"draws\": 332, \"mouse\": 1, \"mu_intercept_per_group\": 8.940279006958008, \"sigma_intercept_per_group\": 0.25182807445526123, \"sigma_obs\": 153.08326721191406, \"slope\": -0.05210374295711517, \"chain\": 1, \"draw\": 132}, {\"draws\": 332, \"mouse\": 2, \"mu_intercept_per_group\": 8.936208724975586, \"sigma_intercept_per_group\": 0.25182807445526123, \"sigma_obs\": 153.08326721191406, \"slope\": -0.05210374295711517, \"chain\": 1, \"draw\": 132}, {\"draws\": 332, \"mouse\": 3, \"mu_intercept_per_group\": 8.139130592346191, \"sigma_intercept_per_group\": 0.25182807445526123, \"sigma_obs\": 153.08326721191406, \"slope\": -0.05210374295711517, \"chain\": 1, \"draw\": 132}, {\"draws\": 332, \"mouse\": 4, \"mu_intercept_per_group\": 8.040388107299805, \"sigma_intercept_per_group\": 0.25182807445526123, \"sigma_obs\": 153.08326721191406, \"slope\": -0.05210374295711517, \"chain\": 1, \"draw\": 132}, {\"draws\": 332, \"mouse\": 5, \"mu_intercept_per_group\": 7.828639030456543, \"sigma_intercept_per_group\": 0.25182807445526123, \"sigma_obs\": 153.08326721191406, \"slope\": -0.05210374295711517, \"chain\": 1, \"draw\": 132}, {\"draws\": 332, \"mouse\": 6, \"mu_intercept_per_group\": 7.2899017333984375, \"sigma_intercept_per_group\": 0.25182807445526123, \"sigma_obs\": 153.08326721191406, \"slope\": -0.05210374295711517, \"chain\": 1, \"draw\": 132}, {\"draws\": 332, \"mouse\": 7, \"mu_intercept_per_group\": 6.8154754638671875, \"sigma_intercept_per_group\": 0.25182807445526123, \"sigma_obs\": 153.08326721191406, \"slope\": -0.05210374295711517, \"chain\": 1, \"draw\": 132}, {\"draws\": 333, \"mouse\": 0, \"mu_intercept_per_group\": 12.127752304077148, \"sigma_intercept_per_group\": 0.2043202966451645, \"sigma_obs\": 155.0799102783203, \"slope\": -0.08655300736427307, \"chain\": 1, \"draw\": 133}, {\"draws\": 333, \"mouse\": 1, \"mu_intercept_per_group\": 11.606366157531738, \"sigma_intercept_per_group\": 0.2043202966451645, \"sigma_obs\": 155.0799102783203, \"slope\": -0.08655300736427307, \"chain\": 1, \"draw\": 133}, {\"draws\": 333, \"mouse\": 2, \"mu_intercept_per_group\": 11.352798461914062, \"sigma_intercept_per_group\": 0.2043202966451645, \"sigma_obs\": 155.0799102783203, \"slope\": -0.08655300736427307, \"chain\": 1, \"draw\": 133}, {\"draws\": 333, \"mouse\": 3, \"mu_intercept_per_group\": 10.5421142578125, \"sigma_intercept_per_group\": 0.2043202966451645, \"sigma_obs\": 155.0799102783203, \"slope\": -0.08655300736427307, \"chain\": 1, \"draw\": 133}, {\"draws\": 333, \"mouse\": 4, \"mu_intercept_per_group\": 10.384035110473633, \"sigma_intercept_per_group\": 0.2043202966451645, \"sigma_obs\": 155.0799102783203, \"slope\": -0.08655300736427307, \"chain\": 1, \"draw\": 133}, {\"draws\": 333, \"mouse\": 5, \"mu_intercept_per_group\": 9.476370811462402, \"sigma_intercept_per_group\": 0.2043202966451645, \"sigma_obs\": 155.0799102783203, \"slope\": -0.08655300736427307, \"chain\": 1, \"draw\": 133}, {\"draws\": 333, \"mouse\": 6, \"mu_intercept_per_group\": 9.231121063232422, \"sigma_intercept_per_group\": 0.2043202966451645, \"sigma_obs\": 155.0799102783203, \"slope\": -0.08655300736427307, \"chain\": 1, \"draw\": 133}, {\"draws\": 333, \"mouse\": 7, \"mu_intercept_per_group\": 8.342130661010742, \"sigma_intercept_per_group\": 0.2043202966451645, \"sigma_obs\": 155.0799102783203, \"slope\": -0.08655300736427307, \"chain\": 1, \"draw\": 133}, {\"draws\": 334, \"mouse\": 0, \"mu_intercept_per_group\": 12.10377311706543, \"sigma_intercept_per_group\": 0.20470386743545532, \"sigma_obs\": 155.55419921875, \"slope\": -0.08511039614677429, \"chain\": 1, \"draw\": 134}, {\"draws\": 334, \"mouse\": 1, \"mu_intercept_per_group\": 11.636536598205566, \"sigma_intercept_per_group\": 0.20470386743545532, \"sigma_obs\": 155.55419921875, \"slope\": -0.08511039614677429, \"chain\": 1, \"draw\": 134}, {\"draws\": 334, \"mouse\": 2, \"mu_intercept_per_group\": 11.350112915039062, \"sigma_intercept_per_group\": 0.20470386743545532, \"sigma_obs\": 155.55419921875, \"slope\": -0.08511039614677429, \"chain\": 1, \"draw\": 134}, {\"draws\": 334, \"mouse\": 3, \"mu_intercept_per_group\": 11.023005485534668, \"sigma_intercept_per_group\": 0.20470386743545532, \"sigma_obs\": 155.55419921875, \"slope\": -0.08511039614677429, \"chain\": 1, \"draw\": 134}, {\"draws\": 334, \"mouse\": 4, \"mu_intercept_per_group\": 10.381104469299316, \"sigma_intercept_per_group\": 0.20470386743545532, \"sigma_obs\": 155.55419921875, \"slope\": -0.08511039614677429, \"chain\": 1, \"draw\": 134}, {\"draws\": 334, \"mouse\": 5, \"mu_intercept_per_group\": 10.206209182739258, \"sigma_intercept_per_group\": 0.20470386743545532, \"sigma_obs\": 155.55419921875, \"slope\": -0.08511039614677429, \"chain\": 1, \"draw\": 134}, {\"draws\": 334, \"mouse\": 6, \"mu_intercept_per_group\": 8.887248992919922, \"sigma_intercept_per_group\": 0.20470386743545532, \"sigma_obs\": 155.55419921875, \"slope\": -0.08511039614677429, \"chain\": 1, \"draw\": 134}, {\"draws\": 334, \"mouse\": 7, \"mu_intercept_per_group\": 8.901321411132812, \"sigma_intercept_per_group\": 0.20470386743545532, \"sigma_obs\": 155.55419921875, \"slope\": -0.08511039614677429, \"chain\": 1, \"draw\": 134}, {\"draws\": 335, \"mouse\": 0, \"mu_intercept_per_group\": 13.441845893859863, \"sigma_intercept_per_group\": 0.1899876892566681, \"sigma_obs\": 177.4834442138672, \"slope\": -0.07970269024372101, \"chain\": 1, \"draw\": 135}, {\"draws\": 335, \"mouse\": 1, \"mu_intercept_per_group\": 13.075321197509766, \"sigma_intercept_per_group\": 0.1899876892566681, \"sigma_obs\": 177.4834442138672, \"slope\": -0.07970269024372101, \"chain\": 1, \"draw\": 135}, {\"draws\": 335, \"mouse\": 2, \"mu_intercept_per_group\": 12.745505332946777, \"sigma_intercept_per_group\": 0.1899876892566681, \"sigma_obs\": 177.4834442138672, \"slope\": -0.07970269024372101, \"chain\": 1, \"draw\": 135}, {\"draws\": 335, \"mouse\": 3, \"mu_intercept_per_group\": 11.770061492919922, \"sigma_intercept_per_group\": 0.1899876892566681, \"sigma_obs\": 177.4834442138672, \"slope\": -0.07970269024372101, \"chain\": 1, \"draw\": 135}, {\"draws\": 335, \"mouse\": 4, \"mu_intercept_per_group\": 11.531907081604004, \"sigma_intercept_per_group\": 0.1899876892566681, \"sigma_obs\": 177.4834442138672, \"slope\": -0.07970269024372101, \"chain\": 1, \"draw\": 135}, {\"draws\": 335, \"mouse\": 5, \"mu_intercept_per_group\": 10.88163948059082, \"sigma_intercept_per_group\": 0.1899876892566681, \"sigma_obs\": 177.4834442138672, \"slope\": -0.07970269024372101, \"chain\": 1, \"draw\": 135}, {\"draws\": 335, \"mouse\": 6, \"mu_intercept_per_group\": 10.67474365234375, \"sigma_intercept_per_group\": 0.1899876892566681, \"sigma_obs\": 177.4834442138672, \"slope\": -0.07970269024372101, \"chain\": 1, \"draw\": 135}, {\"draws\": 335, \"mouse\": 7, \"mu_intercept_per_group\": 9.897164344787598, \"sigma_intercept_per_group\": 0.1899876892566681, \"sigma_obs\": 177.4834442138672, \"slope\": -0.07970269024372101, \"chain\": 1, \"draw\": 135}, {\"draws\": 336, \"mouse\": 0, \"mu_intercept_per_group\": 12.41444206237793, \"sigma_intercept_per_group\": 0.19725078344345093, \"sigma_obs\": 155.15528869628906, \"slope\": -0.05370074138045311, \"chain\": 1, \"draw\": 136}, {\"draws\": 336, \"mouse\": 1, \"mu_intercept_per_group\": 11.862929344177246, \"sigma_intercept_per_group\": 0.19725078344345093, \"sigma_obs\": 155.15528869628906, \"slope\": -0.05370074138045311, \"chain\": 1, \"draw\": 136}, {\"draws\": 336, \"mouse\": 2, \"mu_intercept_per_group\": 11.949828147888184, \"sigma_intercept_per_group\": 0.19725078344345093, \"sigma_obs\": 155.15528869628906, \"slope\": -0.05370074138045311, \"chain\": 1, \"draw\": 136}, {\"draws\": 336, \"mouse\": 3, \"mu_intercept_per_group\": 10.814494132995605, \"sigma_intercept_per_group\": 0.19725078344345093, \"sigma_obs\": 155.15528869628906, \"slope\": -0.05370074138045311, \"chain\": 1, \"draw\": 136}, {\"draws\": 336, \"mouse\": 4, \"mu_intercept_per_group\": 10.647953033447266, \"sigma_intercept_per_group\": 0.19725078344345093, \"sigma_obs\": 155.15528869628906, \"slope\": -0.05370074138045311, \"chain\": 1, \"draw\": 136}, {\"draws\": 336, \"mouse\": 5, \"mu_intercept_per_group\": 10.054688453674316, \"sigma_intercept_per_group\": 0.19725078344345093, \"sigma_obs\": 155.15528869628906, \"slope\": -0.05370074138045311, \"chain\": 1, \"draw\": 136}, {\"draws\": 336, \"mouse\": 6, \"mu_intercept_per_group\": 9.065808296203613, \"sigma_intercept_per_group\": 0.19725078344345093, \"sigma_obs\": 155.15528869628906, \"slope\": -0.05370074138045311, \"chain\": 1, \"draw\": 136}, {\"draws\": 336, \"mouse\": 7, \"mu_intercept_per_group\": 8.804388999938965, \"sigma_intercept_per_group\": 0.19725078344345093, \"sigma_obs\": 155.15528869628906, \"slope\": -0.05370074138045311, \"chain\": 1, \"draw\": 136}, {\"draws\": 337, \"mouse\": 0, \"mu_intercept_per_group\": 18.505447387695312, \"sigma_intercept_per_group\": 0.13502278923988342, \"sigma_obs\": 165.69004821777344, \"slope\": -0.07365454733371735, \"chain\": 1, \"draw\": 137}, {\"draws\": 337, \"mouse\": 1, \"mu_intercept_per_group\": 17.751380920410156, \"sigma_intercept_per_group\": 0.13502278923988342, \"sigma_obs\": 165.69004821777344, \"slope\": -0.07365454733371735, \"chain\": 1, \"draw\": 137}, {\"draws\": 337, \"mouse\": 2, \"mu_intercept_per_group\": 17.305015563964844, \"sigma_intercept_per_group\": 0.13502278923988342, \"sigma_obs\": 165.69004821777344, \"slope\": -0.07365454733371735, \"chain\": 1, \"draw\": 137}, {\"draws\": 337, \"mouse\": 3, \"mu_intercept_per_group\": 16.315906524658203, \"sigma_intercept_per_group\": 0.13502278923988342, \"sigma_obs\": 165.69004821777344, \"slope\": -0.07365454733371735, \"chain\": 1, \"draw\": 137}, {\"draws\": 337, \"mouse\": 4, \"mu_intercept_per_group\": 15.77881145477295, \"sigma_intercept_per_group\": 0.13502278923988342, \"sigma_obs\": 165.69004821777344, \"slope\": -0.07365454733371735, \"chain\": 1, \"draw\": 137}, {\"draws\": 337, \"mouse\": 5, \"mu_intercept_per_group\": 15.005559921264648, \"sigma_intercept_per_group\": 0.13502278923988342, \"sigma_obs\": 165.69004821777344, \"slope\": -0.07365454733371735, \"chain\": 1, \"draw\": 137}, {\"draws\": 337, \"mouse\": 6, \"mu_intercept_per_group\": 14.290993690490723, \"sigma_intercept_per_group\": 0.13502278923988342, \"sigma_obs\": 165.69004821777344, \"slope\": -0.07365454733371735, \"chain\": 1, \"draw\": 137}, {\"draws\": 337, \"mouse\": 7, \"mu_intercept_per_group\": 13.415780067443848, \"sigma_intercept_per_group\": 0.13502278923988342, \"sigma_obs\": 165.69004821777344, \"slope\": -0.07365454733371735, \"chain\": 1, \"draw\": 137}, {\"draws\": 338, \"mouse\": 0, \"mu_intercept_per_group\": 18.30200958251953, \"sigma_intercept_per_group\": 0.13538281619548798, \"sigma_obs\": 164.841796875, \"slope\": -0.07140546292066574, \"chain\": 1, \"draw\": 138}, {\"draws\": 338, \"mouse\": 1, \"mu_intercept_per_group\": 17.7263126373291, \"sigma_intercept_per_group\": 0.13538281619548798, \"sigma_obs\": 164.841796875, \"slope\": -0.07140546292066574, \"chain\": 1, \"draw\": 138}, {\"draws\": 338, \"mouse\": 2, \"mu_intercept_per_group\": 17.371986389160156, \"sigma_intercept_per_group\": 0.13538281619548798, \"sigma_obs\": 164.841796875, \"slope\": -0.07140546292066574, \"chain\": 1, \"draw\": 138}, {\"draws\": 338, \"mouse\": 3, \"mu_intercept_per_group\": 16.121580123901367, \"sigma_intercept_per_group\": 0.13538281619548798, \"sigma_obs\": 164.841796875, \"slope\": -0.07140546292066574, \"chain\": 1, \"draw\": 138}, {\"draws\": 338, \"mouse\": 4, \"mu_intercept_per_group\": 15.526695251464844, \"sigma_intercept_per_group\": 0.13538281619548798, \"sigma_obs\": 164.841796875, \"slope\": -0.07140546292066574, \"chain\": 1, \"draw\": 138}, {\"draws\": 338, \"mouse\": 5, \"mu_intercept_per_group\": 14.899713516235352, \"sigma_intercept_per_group\": 0.13538281619548798, \"sigma_obs\": 164.841796875, \"slope\": -0.07140546292066574, \"chain\": 1, \"draw\": 138}, {\"draws\": 338, \"mouse\": 6, \"mu_intercept_per_group\": 14.37073802947998, \"sigma_intercept_per_group\": 0.13538281619548798, \"sigma_obs\": 164.841796875, \"slope\": -0.07140546292066574, \"chain\": 1, \"draw\": 138}, {\"draws\": 338, \"mouse\": 7, \"mu_intercept_per_group\": 12.9745512008667, \"sigma_intercept_per_group\": 0.13538281619548798, \"sigma_obs\": 164.841796875, \"slope\": -0.07140546292066574, \"chain\": 1, \"draw\": 138}, {\"draws\": 339, \"mouse\": 0, \"mu_intercept_per_group\": 17.998292922973633, \"sigma_intercept_per_group\": 0.13600488007068634, \"sigma_obs\": 165.51702880859375, \"slope\": -0.07043982297182083, \"chain\": 1, \"draw\": 139}, {\"draws\": 339, \"mouse\": 1, \"mu_intercept_per_group\": 17.566978454589844, \"sigma_intercept_per_group\": 0.13600488007068634, \"sigma_obs\": 165.51702880859375, \"slope\": -0.07043982297182083, \"chain\": 1, \"draw\": 139}, {\"draws\": 339, \"mouse\": 2, \"mu_intercept_per_group\": 17.385770797729492, \"sigma_intercept_per_group\": 0.13600488007068634, \"sigma_obs\": 165.51702880859375, \"slope\": -0.07043982297182083, \"chain\": 1, \"draw\": 139}, {\"draws\": 339, \"mouse\": 3, \"mu_intercept_per_group\": 16.432720184326172, \"sigma_intercept_per_group\": 0.13600488007068634, \"sigma_obs\": 165.51702880859375, \"slope\": -0.07043982297182083, \"chain\": 1, \"draw\": 139}, {\"draws\": 339, \"mouse\": 4, \"mu_intercept_per_group\": 15.24980354309082, \"sigma_intercept_per_group\": 0.13600488007068634, \"sigma_obs\": 165.51702880859375, \"slope\": -0.07043982297182083, \"chain\": 1, \"draw\": 139}, {\"draws\": 339, \"mouse\": 5, \"mu_intercept_per_group\": 14.900594711303711, \"sigma_intercept_per_group\": 0.13600488007068634, \"sigma_obs\": 165.51702880859375, \"slope\": -0.07043982297182083, \"chain\": 1, \"draw\": 139}, {\"draws\": 339, \"mouse\": 6, \"mu_intercept_per_group\": 14.512385368347168, \"sigma_intercept_per_group\": 0.13600488007068634, \"sigma_obs\": 165.51702880859375, \"slope\": -0.07043982297182083, \"chain\": 1, \"draw\": 139}, {\"draws\": 339, \"mouse\": 7, \"mu_intercept_per_group\": 12.915326118469238, \"sigma_intercept_per_group\": 0.13600488007068634, \"sigma_obs\": 165.51702880859375, \"slope\": -0.07043982297182083, \"chain\": 1, \"draw\": 139}, {\"draws\": 340, \"mouse\": 0, \"mu_intercept_per_group\": 17.275949478149414, \"sigma_intercept_per_group\": 0.14494416117668152, \"sigma_obs\": 151.78741455078125, \"slope\": -0.11669866740703583, \"chain\": 1, \"draw\": 140}, {\"draws\": 340, \"mouse\": 1, \"mu_intercept_per_group\": 16.846471786499023, \"sigma_intercept_per_group\": 0.14494416117668152, \"sigma_obs\": 151.78741455078125, \"slope\": -0.11669866740703583, \"chain\": 1, \"draw\": 140}, {\"draws\": 340, \"mouse\": 2, \"mu_intercept_per_group\": 15.855709075927734, \"sigma_intercept_per_group\": 0.14494416117668152, \"sigma_obs\": 151.78741455078125, \"slope\": -0.11669866740703583, \"chain\": 1, \"draw\": 140}, {\"draws\": 340, \"mouse\": 3, \"mu_intercept_per_group\": 15.775542259216309, \"sigma_intercept_per_group\": 0.14494416117668152, \"sigma_obs\": 151.78741455078125, \"slope\": -0.11669866740703583, \"chain\": 1, \"draw\": 140}, {\"draws\": 340, \"mouse\": 4, \"mu_intercept_per_group\": 14.424738883972168, \"sigma_intercept_per_group\": 0.14494416117668152, \"sigma_obs\": 151.78741455078125, \"slope\": -0.11669866740703583, \"chain\": 1, \"draw\": 140}, {\"draws\": 340, \"mouse\": 5, \"mu_intercept_per_group\": 14.331585884094238, \"sigma_intercept_per_group\": 0.14494416117668152, \"sigma_obs\": 151.78741455078125, \"slope\": -0.11669866740703583, \"chain\": 1, \"draw\": 140}, {\"draws\": 340, \"mouse\": 6, \"mu_intercept_per_group\": 12.793912887573242, \"sigma_intercept_per_group\": 0.14494416117668152, \"sigma_obs\": 151.78741455078125, \"slope\": -0.11669866740703583, \"chain\": 1, \"draw\": 140}, {\"draws\": 340, \"mouse\": 7, \"mu_intercept_per_group\": 12.898554801940918, \"sigma_intercept_per_group\": 0.14494416117668152, \"sigma_obs\": 151.78741455078125, \"slope\": -0.11669866740703583, \"chain\": 1, \"draw\": 140}, {\"draws\": 341, \"mouse\": 0, \"mu_intercept_per_group\": 16.48061752319336, \"sigma_intercept_per_group\": 0.1455998420715332, \"sigma_obs\": 143.22154235839844, \"slope\": -0.09648195654153824, \"chain\": 1, \"draw\": 141}, {\"draws\": 341, \"mouse\": 1, \"mu_intercept_per_group\": 15.946072578430176, \"sigma_intercept_per_group\": 0.1455998420715332, \"sigma_obs\": 143.22154235839844, \"slope\": -0.09648195654153824, \"chain\": 1, \"draw\": 141}, {\"draws\": 341, \"mouse\": 2, \"mu_intercept_per_group\": 15.087169647216797, \"sigma_intercept_per_group\": 0.1455998420715332, \"sigma_obs\": 143.22154235839844, \"slope\": -0.09648195654153824, \"chain\": 1, \"draw\": 141}, {\"draws\": 341, \"mouse\": 3, \"mu_intercept_per_group\": 14.048775672912598, \"sigma_intercept_per_group\": 0.1455998420715332, \"sigma_obs\": 143.22154235839844, \"slope\": -0.09648195654153824, \"chain\": 1, \"draw\": 141}, {\"draws\": 341, \"mouse\": 4, \"mu_intercept_per_group\": 14.270246505737305, \"sigma_intercept_per_group\": 0.1455998420715332, \"sigma_obs\": 143.22154235839844, \"slope\": -0.09648195654153824, \"chain\": 1, \"draw\": 141}, {\"draws\": 341, \"mouse\": 5, \"mu_intercept_per_group\": 13.49478530883789, \"sigma_intercept_per_group\": 0.1455998420715332, \"sigma_obs\": 143.22154235839844, \"slope\": -0.09648195654153824, \"chain\": 1, \"draw\": 141}, {\"draws\": 341, \"mouse\": 6, \"mu_intercept_per_group\": 11.829320907592773, \"sigma_intercept_per_group\": 0.1455998420715332, \"sigma_obs\": 143.22154235839844, \"slope\": -0.09648195654153824, \"chain\": 1, \"draw\": 141}, {\"draws\": 341, \"mouse\": 7, \"mu_intercept_per_group\": 11.932937622070312, \"sigma_intercept_per_group\": 0.1455998420715332, \"sigma_obs\": 143.22154235839844, \"slope\": -0.09648195654153824, \"chain\": 1, \"draw\": 141}, {\"draws\": 342, \"mouse\": 0, \"mu_intercept_per_group\": 17.97147560119629, \"sigma_intercept_per_group\": 0.14462924003601074, \"sigma_obs\": 174.20338439941406, \"slope\": -0.0865984633564949, \"chain\": 1, \"draw\": 142}, {\"draws\": 342, \"mouse\": 1, \"mu_intercept_per_group\": 17.181867599487305, \"sigma_intercept_per_group\": 0.14462924003601074, \"sigma_obs\": 174.20338439941406, \"slope\": -0.0865984633564949, \"chain\": 1, \"draw\": 142}, {\"draws\": 342, \"mouse\": 2, \"mu_intercept_per_group\": 16.157163619995117, \"sigma_intercept_per_group\": 0.14462924003601074, \"sigma_obs\": 174.20338439941406, \"slope\": -0.0865984633564949, \"chain\": 1, \"draw\": 142}, {\"draws\": 342, \"mouse\": 3, \"mu_intercept_per_group\": 15.518007278442383, \"sigma_intercept_per_group\": 0.14462924003601074, \"sigma_obs\": 174.20338439941406, \"slope\": -0.0865984633564949, \"chain\": 1, \"draw\": 142}, {\"draws\": 342, \"mouse\": 4, \"mu_intercept_per_group\": 15.65256118774414, \"sigma_intercept_per_group\": 0.14462924003601074, \"sigma_obs\": 174.20338439941406, \"slope\": -0.0865984633564949, \"chain\": 1, \"draw\": 142}, {\"draws\": 342, \"mouse\": 5, \"mu_intercept_per_group\": 14.405366897583008, \"sigma_intercept_per_group\": 0.14462924003601074, \"sigma_obs\": 174.20338439941406, \"slope\": -0.0865984633564949, \"chain\": 1, \"draw\": 142}, {\"draws\": 342, \"mouse\": 6, \"mu_intercept_per_group\": 13.661773681640625, \"sigma_intercept_per_group\": 0.14462924003601074, \"sigma_obs\": 174.20338439941406, \"slope\": -0.0865984633564949, \"chain\": 1, \"draw\": 142}, {\"draws\": 342, \"mouse\": 7, \"mu_intercept_per_group\": 12.4917573928833, \"sigma_intercept_per_group\": 0.14462924003601074, \"sigma_obs\": 174.20338439941406, \"slope\": -0.0865984633564949, \"chain\": 1, \"draw\": 142}, {\"draws\": 343, \"mouse\": 0, \"mu_intercept_per_group\": 17.289283752441406, \"sigma_intercept_per_group\": 0.1454659253358841, \"sigma_obs\": 159.36703491210938, \"slope\": -0.09491939097642899, \"chain\": 1, \"draw\": 143}, {\"draws\": 343, \"mouse\": 1, \"mu_intercept_per_group\": 16.34754753112793, \"sigma_intercept_per_group\": 0.1454659253358841, \"sigma_obs\": 159.36703491210938, \"slope\": -0.09491939097642899, \"chain\": 1, \"draw\": 143}, {\"draws\": 343, \"mouse\": 2, \"mu_intercept_per_group\": 16.159305572509766, \"sigma_intercept_per_group\": 0.1454659253358841, \"sigma_obs\": 159.36703491210938, \"slope\": -0.09491939097642899, \"chain\": 1, \"draw\": 143}, {\"draws\": 343, \"mouse\": 3, \"mu_intercept_per_group\": 15.045979499816895, \"sigma_intercept_per_group\": 0.1454659253358841, \"sigma_obs\": 159.36703491210938, \"slope\": -0.09491939097642899, \"chain\": 1, \"draw\": 143}, {\"draws\": 343, \"mouse\": 4, \"mu_intercept_per_group\": 14.631945610046387, \"sigma_intercept_per_group\": 0.1454659253358841, \"sigma_obs\": 159.36703491210938, \"slope\": -0.09491939097642899, \"chain\": 1, \"draw\": 143}, {\"draws\": 343, \"mouse\": 5, \"mu_intercept_per_group\": 13.531033515930176, \"sigma_intercept_per_group\": 0.1454659253358841, \"sigma_obs\": 159.36703491210938, \"slope\": -0.09491939097642899, \"chain\": 1, \"draw\": 143}, {\"draws\": 343, \"mouse\": 6, \"mu_intercept_per_group\": 12.897286415100098, \"sigma_intercept_per_group\": 0.1454659253358841, \"sigma_obs\": 159.36703491210938, \"slope\": -0.09491939097642899, \"chain\": 1, \"draw\": 143}, {\"draws\": 343, \"mouse\": 7, \"mu_intercept_per_group\": 12.617756843566895, \"sigma_intercept_per_group\": 0.1454659253358841, \"sigma_obs\": 159.36703491210938, \"slope\": -0.09491939097642899, \"chain\": 1, \"draw\": 143}, {\"draws\": 344, \"mouse\": 0, \"mu_intercept_per_group\": 19.532682418823242, \"sigma_intercept_per_group\": 0.13014483451843262, \"sigma_obs\": 162.75531005859375, \"slope\": -0.07885666191577911, \"chain\": 1, \"draw\": 144}, {\"draws\": 344, \"mouse\": 1, \"mu_intercept_per_group\": 18.1824893951416, \"sigma_intercept_per_group\": 0.13014483451843262, \"sigma_obs\": 162.75531005859375, \"slope\": -0.07885666191577911, \"chain\": 1, \"draw\": 144}, {\"draws\": 344, \"mouse\": 2, \"mu_intercept_per_group\": 17.985395431518555, \"sigma_intercept_per_group\": 0.13014483451843262, \"sigma_obs\": 162.75531005859375, \"slope\": -0.07885666191577911, \"chain\": 1, \"draw\": 144}, {\"draws\": 344, \"mouse\": 3, \"mu_intercept_per_group\": 16.683738708496094, \"sigma_intercept_per_group\": 0.13014483451843262, \"sigma_obs\": 162.75531005859375, \"slope\": -0.07885666191577911, \"chain\": 1, \"draw\": 144}, {\"draws\": 344, \"mouse\": 4, \"mu_intercept_per_group\": 16.291452407836914, \"sigma_intercept_per_group\": 0.13014483451843262, \"sigma_obs\": 162.75531005859375, \"slope\": -0.07885666191577911, \"chain\": 1, \"draw\": 144}, {\"draws\": 344, \"mouse\": 5, \"mu_intercept_per_group\": 15.75429916381836, \"sigma_intercept_per_group\": 0.13014483451843262, \"sigma_obs\": 162.75531005859375, \"slope\": -0.07885666191577911, \"chain\": 1, \"draw\": 144}, {\"draws\": 344, \"mouse\": 6, \"mu_intercept_per_group\": 14.84218978881836, \"sigma_intercept_per_group\": 0.13014483451843262, \"sigma_obs\": 162.75531005859375, \"slope\": -0.07885666191577911, \"chain\": 1, \"draw\": 144}, {\"draws\": 344, \"mouse\": 7, \"mu_intercept_per_group\": 13.536919593811035, \"sigma_intercept_per_group\": 0.13014483451843262, \"sigma_obs\": 162.75531005859375, \"slope\": -0.07885666191577911, \"chain\": 1, \"draw\": 144}, {\"draws\": 345, \"mouse\": 0, \"mu_intercept_per_group\": 14.86822509765625, \"sigma_intercept_per_group\": 0.17114496231079102, \"sigma_obs\": 161.9282684326172, \"slope\": -0.08196969330310822, \"chain\": 1, \"draw\": 145}, {\"draws\": 345, \"mouse\": 1, \"mu_intercept_per_group\": 13.870624542236328, \"sigma_intercept_per_group\": 0.17114496231079102, \"sigma_obs\": 161.9282684326172, \"slope\": -0.08196969330310822, \"chain\": 1, \"draw\": 145}, {\"draws\": 345, \"mouse\": 2, \"mu_intercept_per_group\": 13.476757049560547, \"sigma_intercept_per_group\": 0.17114496231079102, \"sigma_obs\": 161.9282684326172, \"slope\": -0.08196969330310822, \"chain\": 1, \"draw\": 145}, {\"draws\": 345, \"mouse\": 3, \"mu_intercept_per_group\": 13.011031150817871, \"sigma_intercept_per_group\": 0.17114496231079102, \"sigma_obs\": 161.9282684326172, \"slope\": -0.08196969330310822, \"chain\": 1, \"draw\": 145}, {\"draws\": 345, \"mouse\": 4, \"mu_intercept_per_group\": 12.47912311553955, \"sigma_intercept_per_group\": 0.17114496231079102, \"sigma_obs\": 161.9282684326172, \"slope\": -0.08196969330310822, \"chain\": 1, \"draw\": 145}, {\"draws\": 345, \"mouse\": 5, \"mu_intercept_per_group\": 11.966933250427246, \"sigma_intercept_per_group\": 0.17114496231079102, \"sigma_obs\": 161.9282684326172, \"slope\": -0.08196969330310822, \"chain\": 1, \"draw\": 145}, {\"draws\": 345, \"mouse\": 6, \"mu_intercept_per_group\": 11.338459014892578, \"sigma_intercept_per_group\": 0.17114496231079102, \"sigma_obs\": 161.9282684326172, \"slope\": -0.08196969330310822, \"chain\": 1, \"draw\": 145}, {\"draws\": 345, \"mouse\": 7, \"mu_intercept_per_group\": 9.672046661376953, \"sigma_intercept_per_group\": 0.17114496231079102, \"sigma_obs\": 161.9282684326172, \"slope\": -0.08196969330310822, \"chain\": 1, \"draw\": 145}, {\"draws\": 346, \"mouse\": 0, \"mu_intercept_per_group\": 14.056516647338867, \"sigma_intercept_per_group\": 0.1736849695444107, \"sigma_obs\": 163.4583282470703, \"slope\": -0.08352431654930115, \"chain\": 1, \"draw\": 146}, {\"draws\": 346, \"mouse\": 1, \"mu_intercept_per_group\": 14.09541130065918, \"sigma_intercept_per_group\": 0.1736849695444107, \"sigma_obs\": 163.4583282470703, \"slope\": -0.08352431654930115, \"chain\": 1, \"draw\": 146}, {\"draws\": 346, \"mouse\": 2, \"mu_intercept_per_group\": 13.688119888305664, \"sigma_intercept_per_group\": 0.1736849695444107, \"sigma_obs\": 163.4583282470703, \"slope\": -0.08352431654930115, \"chain\": 1, \"draw\": 146}, {\"draws\": 346, \"mouse\": 3, \"mu_intercept_per_group\": 12.64637279510498, \"sigma_intercept_per_group\": 0.1736849695444107, \"sigma_obs\": 163.4583282470703, \"slope\": -0.08352431654930115, \"chain\": 1, \"draw\": 146}, {\"draws\": 346, \"mouse\": 4, \"mu_intercept_per_group\": 12.488118171691895, \"sigma_intercept_per_group\": 0.1736849695444107, \"sigma_obs\": 163.4583282470703, \"slope\": -0.08352431654930115, \"chain\": 1, \"draw\": 146}, {\"draws\": 346, \"mouse\": 5, \"mu_intercept_per_group\": 11.790566444396973, \"sigma_intercept_per_group\": 0.1736849695444107, \"sigma_obs\": 163.4583282470703, \"slope\": -0.08352431654930115, \"chain\": 1, \"draw\": 146}, {\"draws\": 346, \"mouse\": 6, \"mu_intercept_per_group\": 10.597892761230469, \"sigma_intercept_per_group\": 0.1736849695444107, \"sigma_obs\": 163.4583282470703, \"slope\": -0.08352431654930115, \"chain\": 1, \"draw\": 146}, {\"draws\": 346, \"mouse\": 7, \"mu_intercept_per_group\": 10.473967552185059, \"sigma_intercept_per_group\": 0.1736849695444107, \"sigma_obs\": 163.4583282470703, \"slope\": -0.08352431654930115, \"chain\": 1, \"draw\": 146}, {\"draws\": 347, \"mouse\": 0, \"mu_intercept_per_group\": 14.459736824035645, \"sigma_intercept_per_group\": 0.17575564980506897, \"sigma_obs\": 164.01219177246094, \"slope\": -0.08454252779483795, \"chain\": 1, \"draw\": 147}, {\"draws\": 347, \"mouse\": 1, \"mu_intercept_per_group\": 13.646803855895996, \"sigma_intercept_per_group\": 0.17575564980506897, \"sigma_obs\": 164.01219177246094, \"slope\": -0.08454252779483795, \"chain\": 1, \"draw\": 147}, {\"draws\": 347, \"mouse\": 2, \"mu_intercept_per_group\": 13.299881935119629, \"sigma_intercept_per_group\": 0.17575564980506897, \"sigma_obs\": 164.01219177246094, \"slope\": -0.08454252779483795, \"chain\": 1, \"draw\": 147}, {\"draws\": 347, \"mouse\": 3, \"mu_intercept_per_group\": 12.340914726257324, \"sigma_intercept_per_group\": 0.17575564980506897, \"sigma_obs\": 164.01219177246094, \"slope\": -0.08454252779483795, \"chain\": 1, \"draw\": 147}, {\"draws\": 347, \"mouse\": 4, \"mu_intercept_per_group\": 12.427800178527832, \"sigma_intercept_per_group\": 0.17575564980506897, \"sigma_obs\": 164.01219177246094, \"slope\": -0.08454252779483795, \"chain\": 1, \"draw\": 147}, {\"draws\": 347, \"mouse\": 5, \"mu_intercept_per_group\": 11.431812286376953, \"sigma_intercept_per_group\": 0.17575564980506897, \"sigma_obs\": 164.01219177246094, \"slope\": -0.08454252779483795, \"chain\": 1, \"draw\": 147}, {\"draws\": 347, \"mouse\": 6, \"mu_intercept_per_group\": 10.963041305541992, \"sigma_intercept_per_group\": 0.17575564980506897, \"sigma_obs\": 164.01219177246094, \"slope\": -0.08454252779483795, \"chain\": 1, \"draw\": 147}, {\"draws\": 347, \"mouse\": 7, \"mu_intercept_per_group\": 10.276229858398438, \"sigma_intercept_per_group\": 0.17575564980506897, \"sigma_obs\": 164.01219177246094, \"slope\": -0.08454252779483795, \"chain\": 1, \"draw\": 147}, {\"draws\": 348, \"mouse\": 0, \"mu_intercept_per_group\": 13.379469871520996, \"sigma_intercept_per_group\": 0.18036916851997375, \"sigma_obs\": 153.7692108154297, \"slope\": -0.07040717452764511, \"chain\": 1, \"draw\": 148}, {\"draws\": 348, \"mouse\": 1, \"mu_intercept_per_group\": 12.953351020812988, \"sigma_intercept_per_group\": 0.18036916851997375, \"sigma_obs\": 153.7692108154297, \"slope\": -0.07040717452764511, \"chain\": 1, \"draw\": 148}, {\"draws\": 348, \"mouse\": 2, \"mu_intercept_per_group\": 12.957268714904785, \"sigma_intercept_per_group\": 0.18036916851997375, \"sigma_obs\": 153.7692108154297, \"slope\": -0.07040717452764511, \"chain\": 1, \"draw\": 148}, {\"draws\": 348, \"mouse\": 3, \"mu_intercept_per_group\": 11.906176567077637, \"sigma_intercept_per_group\": 0.18036916851997375, \"sigma_obs\": 153.7692108154297, \"slope\": -0.07040717452764511, \"chain\": 1, \"draw\": 148}, {\"draws\": 348, \"mouse\": 4, \"mu_intercept_per_group\": 11.947840690612793, \"sigma_intercept_per_group\": 0.18036916851997375, \"sigma_obs\": 153.7692108154297, \"slope\": -0.07040717452764511, \"chain\": 1, \"draw\": 148}, {\"draws\": 348, \"mouse\": 5, \"mu_intercept_per_group\": 10.868128776550293, \"sigma_intercept_per_group\": 0.18036916851997375, \"sigma_obs\": 153.7692108154297, \"slope\": -0.07040717452764511, \"chain\": 1, \"draw\": 148}, {\"draws\": 348, \"mouse\": 6, \"mu_intercept_per_group\": 10.507010459899902, \"sigma_intercept_per_group\": 0.18036916851997375, \"sigma_obs\": 153.7692108154297, \"slope\": -0.07040717452764511, \"chain\": 1, \"draw\": 148}, {\"draws\": 348, \"mouse\": 7, \"mu_intercept_per_group\": 9.71311092376709, \"sigma_intercept_per_group\": 0.18036916851997375, \"sigma_obs\": 153.7692108154297, \"slope\": -0.07040717452764511, \"chain\": 1, \"draw\": 148}, {\"draws\": 349, \"mouse\": 0, \"mu_intercept_per_group\": 13.775824546813965, \"sigma_intercept_per_group\": 0.18095728754997253, \"sigma_obs\": 155.63870239257812, \"slope\": -0.07164477556943893, \"chain\": 1, \"draw\": 149}, {\"draws\": 349, \"mouse\": 1, \"mu_intercept_per_group\": 13.253445625305176, \"sigma_intercept_per_group\": 0.18095728754997253, \"sigma_obs\": 155.63870239257812, \"slope\": -0.07164477556943893, \"chain\": 1, \"draw\": 149}, {\"draws\": 349, \"mouse\": 2, \"mu_intercept_per_group\": 12.656513214111328, \"sigma_intercept_per_group\": 0.18095728754997253, \"sigma_obs\": 155.63870239257812, \"slope\": -0.07164477556943893, \"chain\": 1, \"draw\": 149}, {\"draws\": 349, \"mouse\": 3, \"mu_intercept_per_group\": 12.151703834533691, \"sigma_intercept_per_group\": 0.18095728754997253, \"sigma_obs\": 155.63870239257812, \"slope\": -0.07164477556943893, \"chain\": 1, \"draw\": 149}, {\"draws\": 349, \"mouse\": 4, \"mu_intercept_per_group\": 11.371196746826172, \"sigma_intercept_per_group\": 0.18095728754997253, \"sigma_obs\": 155.63870239257812, \"slope\": -0.07164477556943893, \"chain\": 1, \"draw\": 149}, {\"draws\": 349, \"mouse\": 5, \"mu_intercept_per_group\": 11.173198699951172, \"sigma_intercept_per_group\": 0.18095728754997253, \"sigma_obs\": 155.63870239257812, \"slope\": -0.07164477556943893, \"chain\": 1, \"draw\": 149}, {\"draws\": 349, \"mouse\": 6, \"mu_intercept_per_group\": 10.153051376342773, \"sigma_intercept_per_group\": 0.18095728754997253, \"sigma_obs\": 155.63870239257812, \"slope\": -0.07164477556943893, \"chain\": 1, \"draw\": 149}, {\"draws\": 349, \"mouse\": 7, \"mu_intercept_per_group\": 9.979215621948242, \"sigma_intercept_per_group\": 0.18095728754997253, \"sigma_obs\": 155.63870239257812, \"slope\": -0.07164477556943893, \"chain\": 1, \"draw\": 149}, {\"draws\": 350, \"mouse\": 0, \"mu_intercept_per_group\": 13.64220142364502, \"sigma_intercept_per_group\": 0.179874449968338, \"sigma_obs\": 158.93560791015625, \"slope\": -0.0729508027434349, \"chain\": 1, \"draw\": 150}, {\"draws\": 350, \"mouse\": 1, \"mu_intercept_per_group\": 13.247969627380371, \"sigma_intercept_per_group\": 0.179874449968338, \"sigma_obs\": 158.93560791015625, \"slope\": -0.0729508027434349, \"chain\": 1, \"draw\": 150}, {\"draws\": 350, \"mouse\": 2, \"mu_intercept_per_group\": 12.634551048278809, \"sigma_intercept_per_group\": 0.179874449968338, \"sigma_obs\": 158.93560791015625, \"slope\": -0.0729508027434349, \"chain\": 1, \"draw\": 150}, {\"draws\": 350, \"mouse\": 3, \"mu_intercept_per_group\": 11.815618515014648, \"sigma_intercept_per_group\": 0.179874449968338, \"sigma_obs\": 158.93560791015625, \"slope\": -0.0729508027434349, \"chain\": 1, \"draw\": 150}, {\"draws\": 350, \"mouse\": 4, \"mu_intercept_per_group\": 11.87020492553711, \"sigma_intercept_per_group\": 0.179874449968338, \"sigma_obs\": 158.93560791015625, \"slope\": -0.0729508027434349, \"chain\": 1, \"draw\": 150}, {\"draws\": 350, \"mouse\": 5, \"mu_intercept_per_group\": 10.872407913208008, \"sigma_intercept_per_group\": 0.179874449968338, \"sigma_obs\": 158.93560791015625, \"slope\": -0.0729508027434349, \"chain\": 1, \"draw\": 150}, {\"draws\": 350, \"mouse\": 6, \"mu_intercept_per_group\": 10.352826118469238, \"sigma_intercept_per_group\": 0.179874449968338, \"sigma_obs\": 158.93560791015625, \"slope\": -0.0729508027434349, \"chain\": 1, \"draw\": 150}, {\"draws\": 350, \"mouse\": 7, \"mu_intercept_per_group\": 9.704900741577148, \"sigma_intercept_per_group\": 0.179874449968338, \"sigma_obs\": 158.93560791015625, \"slope\": -0.0729508027434349, \"chain\": 1, \"draw\": 150}, {\"draws\": 351, \"mouse\": 0, \"mu_intercept_per_group\": 12.998723030090332, \"sigma_intercept_per_group\": 0.19491572678089142, \"sigma_obs\": 161.35028076171875, \"slope\": -0.08656472712755203, \"chain\": 1, \"draw\": 151}, {\"draws\": 351, \"mouse\": 1, \"mu_intercept_per_group\": 12.473092079162598, \"sigma_intercept_per_group\": 0.19491572678089142, \"sigma_obs\": 161.35028076171875, \"slope\": -0.08656472712755203, \"chain\": 1, \"draw\": 151}, {\"draws\": 351, \"mouse\": 2, \"mu_intercept_per_group\": 12.131442070007324, \"sigma_intercept_per_group\": 0.19491572678089142, \"sigma_obs\": 161.35028076171875, \"slope\": -0.08656472712755203, \"chain\": 1, \"draw\": 151}, {\"draws\": 351, \"mouse\": 3, \"mu_intercept_per_group\": 11.273433685302734, \"sigma_intercept_per_group\": 0.19491572678089142, \"sigma_obs\": 161.35028076171875, \"slope\": -0.08656472712755203, \"chain\": 1, \"draw\": 151}, {\"draws\": 351, \"mouse\": 4, \"mu_intercept_per_group\": 11.085597038269043, \"sigma_intercept_per_group\": 0.19491572678089142, \"sigma_obs\": 161.35028076171875, \"slope\": -0.08656472712755203, \"chain\": 1, \"draw\": 151}, {\"draws\": 351, \"mouse\": 5, \"mu_intercept_per_group\": 10.792365074157715, \"sigma_intercept_per_group\": 0.19491572678089142, \"sigma_obs\": 161.35028076171875, \"slope\": -0.08656472712755203, \"chain\": 1, \"draw\": 151}, {\"draws\": 351, \"mouse\": 6, \"mu_intercept_per_group\": 9.943517684936523, \"sigma_intercept_per_group\": 0.19491572678089142, \"sigma_obs\": 161.35028076171875, \"slope\": -0.08656472712755203, \"chain\": 1, \"draw\": 151}, {\"draws\": 351, \"mouse\": 7, \"mu_intercept_per_group\": 9.378074645996094, \"sigma_intercept_per_group\": 0.19491572678089142, \"sigma_obs\": 161.35028076171875, \"slope\": -0.08656472712755203, \"chain\": 1, \"draw\": 151}, {\"draws\": 352, \"mouse\": 0, \"mu_intercept_per_group\": 15.237778663635254, \"sigma_intercept_per_group\": 0.1689104288816452, \"sigma_obs\": 176.35040283203125, \"slope\": -0.06714195758104324, \"chain\": 1, \"draw\": 152}, {\"draws\": 352, \"mouse\": 1, \"mu_intercept_per_group\": 14.825862884521484, \"sigma_intercept_per_group\": 0.1689104288816452, \"sigma_obs\": 176.35040283203125, \"slope\": -0.06714195758104324, \"chain\": 1, \"draw\": 152}, {\"draws\": 352, \"mouse\": 2, \"mu_intercept_per_group\": 14.391940116882324, \"sigma_intercept_per_group\": 0.1689104288816452, \"sigma_obs\": 176.35040283203125, \"slope\": -0.06714195758104324, \"chain\": 1, \"draw\": 152}, {\"draws\": 352, \"mouse\": 3, \"mu_intercept_per_group\": 13.607640266418457, \"sigma_intercept_per_group\": 0.1689104288816452, \"sigma_obs\": 176.35040283203125, \"slope\": -0.06714195758104324, \"chain\": 1, \"draw\": 152}, {\"draws\": 352, \"mouse\": 4, \"mu_intercept_per_group\": 13.140423774719238, \"sigma_intercept_per_group\": 0.1689104288816452, \"sigma_obs\": 176.35040283203125, \"slope\": -0.06714195758104324, \"chain\": 1, \"draw\": 152}, {\"draws\": 352, \"mouse\": 5, \"mu_intercept_per_group\": 12.355171203613281, \"sigma_intercept_per_group\": 0.1689104288816452, \"sigma_obs\": 176.35040283203125, \"slope\": -0.06714195758104324, \"chain\": 1, \"draw\": 152}, {\"draws\": 352, \"mouse\": 6, \"mu_intercept_per_group\": 11.725190162658691, \"sigma_intercept_per_group\": 0.1689104288816452, \"sigma_obs\": 176.35040283203125, \"slope\": -0.06714195758104324, \"chain\": 1, \"draw\": 152}, {\"draws\": 352, \"mouse\": 7, \"mu_intercept_per_group\": 11.053407669067383, \"sigma_intercept_per_group\": 0.1689104288816452, \"sigma_obs\": 176.35040283203125, \"slope\": -0.06714195758104324, \"chain\": 1, \"draw\": 152}, {\"draws\": 353, \"mouse\": 0, \"mu_intercept_per_group\": 17.53590202331543, \"sigma_intercept_per_group\": 0.14128389954566956, \"sigma_obs\": 162.1825714111328, \"slope\": -0.06661471724510193, \"chain\": 1, \"draw\": 153}, {\"draws\": 353, \"mouse\": 1, \"mu_intercept_per_group\": 17.15983009338379, \"sigma_intercept_per_group\": 0.14128389954566956, \"sigma_obs\": 162.1825714111328, \"slope\": -0.06661471724510193, \"chain\": 1, \"draw\": 153}, {\"draws\": 353, \"mouse\": 2, \"mu_intercept_per_group\": 16.292531967163086, \"sigma_intercept_per_group\": 0.14128389954566956, \"sigma_obs\": 162.1825714111328, \"slope\": -0.06661471724510193, \"chain\": 1, \"draw\": 153}, {\"draws\": 353, \"mouse\": 3, \"mu_intercept_per_group\": 15.306584358215332, \"sigma_intercept_per_group\": 0.14128389954566956, \"sigma_obs\": 162.1825714111328, \"slope\": -0.06661471724510193, \"chain\": 1, \"draw\": 153}, {\"draws\": 353, \"mouse\": 4, \"mu_intercept_per_group\": 15.399009704589844, \"sigma_intercept_per_group\": 0.14128389954566956, \"sigma_obs\": 162.1825714111328, \"slope\": -0.06661471724510193, \"chain\": 1, \"draw\": 153}, {\"draws\": 353, \"mouse\": 5, \"mu_intercept_per_group\": 14.223976135253906, \"sigma_intercept_per_group\": 0.14128389954566956, \"sigma_obs\": 162.1825714111328, \"slope\": -0.06661471724510193, \"chain\": 1, \"draw\": 153}, {\"draws\": 353, \"mouse\": 6, \"mu_intercept_per_group\": 13.638792037963867, \"sigma_intercept_per_group\": 0.14128389954566956, \"sigma_obs\": 162.1825714111328, \"slope\": -0.06661471724510193, \"chain\": 1, \"draw\": 153}, {\"draws\": 353, \"mouse\": 7, \"mu_intercept_per_group\": 12.952911376953125, \"sigma_intercept_per_group\": 0.14128389954566956, \"sigma_obs\": 162.1825714111328, \"slope\": -0.06661471724510193, \"chain\": 1, \"draw\": 153}, {\"draws\": 354, \"mouse\": 0, \"mu_intercept_per_group\": 17.425329208374023, \"sigma_intercept_per_group\": 0.1403423249721527, \"sigma_obs\": 162.28097534179688, \"slope\": -0.0657920315861702, \"chain\": 1, \"draw\": 154}, {\"draws\": 354, \"mouse\": 1, \"mu_intercept_per_group\": 16.721975326538086, \"sigma_intercept_per_group\": 0.1403423249721527, \"sigma_obs\": 162.28097534179688, \"slope\": -0.0657920315861702, \"chain\": 1, \"draw\": 154}, {\"draws\": 354, \"mouse\": 2, \"mu_intercept_per_group\": 16.774629592895508, \"sigma_intercept_per_group\": 0.1403423249721527, \"sigma_obs\": 162.28097534179688, \"slope\": -0.0657920315861702, \"chain\": 1, \"draw\": 154}, {\"draws\": 354, \"mouse\": 3, \"mu_intercept_per_group\": 14.969338417053223, \"sigma_intercept_per_group\": 0.1403423249721527, \"sigma_obs\": 162.28097534179688, \"slope\": -0.0657920315861702, \"chain\": 1, \"draw\": 154}, {\"draws\": 354, \"mouse\": 4, \"mu_intercept_per_group\": 15.202767372131348, \"sigma_intercept_per_group\": 0.1403423249721527, \"sigma_obs\": 162.28097534179688, \"slope\": -0.0657920315861702, \"chain\": 1, \"draw\": 154}, {\"draws\": 354, \"mouse\": 5, \"mu_intercept_per_group\": 14.33953857421875, \"sigma_intercept_per_group\": 0.1403423249721527, \"sigma_obs\": 162.28097534179688, \"slope\": -0.0657920315861702, \"chain\": 1, \"draw\": 154}, {\"draws\": 354, \"mouse\": 6, \"mu_intercept_per_group\": 13.6787109375, \"sigma_intercept_per_group\": 0.1403423249721527, \"sigma_obs\": 162.28097534179688, \"slope\": -0.0657920315861702, \"chain\": 1, \"draw\": 154}, {\"draws\": 354, \"mouse\": 7, \"mu_intercept_per_group\": 12.997308731079102, \"sigma_intercept_per_group\": 0.1403423249721527, \"sigma_obs\": 162.28097534179688, \"slope\": -0.0657920315861702, \"chain\": 1, \"draw\": 154}, {\"draws\": 355, \"mouse\": 0, \"mu_intercept_per_group\": 17.615747451782227, \"sigma_intercept_per_group\": 0.13931511342525482, \"sigma_obs\": 162.45013427734375, \"slope\": -0.0656924843788147, \"chain\": 1, \"draw\": 155}, {\"draws\": 355, \"mouse\": 1, \"mu_intercept_per_group\": 16.84099769592285, \"sigma_intercept_per_group\": 0.13931511342525482, \"sigma_obs\": 162.45013427734375, \"slope\": -0.0656924843788147, \"chain\": 1, \"draw\": 155}, {\"draws\": 355, \"mouse\": 2, \"mu_intercept_per_group\": 16.705930709838867, \"sigma_intercept_per_group\": 0.13931511342525482, \"sigma_obs\": 162.45013427734375, \"slope\": -0.0656924843788147, \"chain\": 1, \"draw\": 155}, {\"draws\": 355, \"mouse\": 3, \"mu_intercept_per_group\": 15.148003578186035, \"sigma_intercept_per_group\": 0.13931511342525482, \"sigma_obs\": 162.45013427734375, \"slope\": -0.0656924843788147, \"chain\": 1, \"draw\": 155}, {\"draws\": 355, \"mouse\": 4, \"mu_intercept_per_group\": 15.239405632019043, \"sigma_intercept_per_group\": 0.13931511342525482, \"sigma_obs\": 162.45013427734375, \"slope\": -0.0656924843788147, \"chain\": 1, \"draw\": 155}, {\"draws\": 355, \"mouse\": 5, \"mu_intercept_per_group\": 14.224703788757324, \"sigma_intercept_per_group\": 0.13931511342525482, \"sigma_obs\": 162.45013427734375, \"slope\": -0.0656924843788147, \"chain\": 1, \"draw\": 155}, {\"draws\": 355, \"mouse\": 6, \"mu_intercept_per_group\": 13.684127807617188, \"sigma_intercept_per_group\": 0.13931511342525482, \"sigma_obs\": 162.45013427734375, \"slope\": -0.0656924843788147, \"chain\": 1, \"draw\": 155}, {\"draws\": 355, \"mouse\": 7, \"mu_intercept_per_group\": 12.91214656829834, \"sigma_intercept_per_group\": 0.13931511342525482, \"sigma_obs\": 162.45013427734375, \"slope\": -0.0656924843788147, \"chain\": 1, \"draw\": 155}, {\"draws\": 356, \"mouse\": 0, \"mu_intercept_per_group\": 15.095571517944336, \"sigma_intercept_per_group\": 0.16257496178150177, \"sigma_obs\": 147.82080078125, \"slope\": -0.08700266480445862, \"chain\": 1, \"draw\": 156}, {\"draws\": 356, \"mouse\": 1, \"mu_intercept_per_group\": 14.475992202758789, \"sigma_intercept_per_group\": 0.16257496178150177, \"sigma_obs\": 147.82080078125, \"slope\": -0.08700266480445862, \"chain\": 1, \"draw\": 156}, {\"draws\": 356, \"mouse\": 2, \"mu_intercept_per_group\": 14.042486190795898, \"sigma_intercept_per_group\": 0.16257496178150177, \"sigma_obs\": 147.82080078125, \"slope\": -0.08700266480445862, \"chain\": 1, \"draw\": 156}, {\"draws\": 356, \"mouse\": 3, \"mu_intercept_per_group\": 12.807051658630371, \"sigma_intercept_per_group\": 0.16257496178150177, \"sigma_obs\": 147.82080078125, \"slope\": -0.08700266480445862, \"chain\": 1, \"draw\": 156}, {\"draws\": 356, \"mouse\": 4, \"mu_intercept_per_group\": 13.087016105651855, \"sigma_intercept_per_group\": 0.16257496178150177, \"sigma_obs\": 147.82080078125, \"slope\": -0.08700266480445862, \"chain\": 1, \"draw\": 156}, {\"draws\": 356, \"mouse\": 5, \"mu_intercept_per_group\": 12.062162399291992, \"sigma_intercept_per_group\": 0.16257496178150177, \"sigma_obs\": 147.82080078125, \"slope\": -0.08700266480445862, \"chain\": 1, \"draw\": 156}, {\"draws\": 356, \"mouse\": 6, \"mu_intercept_per_group\": 11.097489356994629, \"sigma_intercept_per_group\": 0.16257496178150177, \"sigma_obs\": 147.82080078125, \"slope\": -0.08700266480445862, \"chain\": 1, \"draw\": 156}, {\"draws\": 356, \"mouse\": 7, \"mu_intercept_per_group\": 10.535606384277344, \"sigma_intercept_per_group\": 0.16257496178150177, \"sigma_obs\": 147.82080078125, \"slope\": -0.08700266480445862, \"chain\": 1, \"draw\": 156}, {\"draws\": 357, \"mouse\": 0, \"mu_intercept_per_group\": 14.993000984191895, \"sigma_intercept_per_group\": 0.15948832035064697, \"sigma_obs\": 146.8383331298828, \"slope\": -0.08726508170366287, \"chain\": 1, \"draw\": 157}, {\"draws\": 357, \"mouse\": 1, \"mu_intercept_per_group\": 14.554549217224121, \"sigma_intercept_per_group\": 0.15948832035064697, \"sigma_obs\": 146.8383331298828, \"slope\": -0.08726508170366287, \"chain\": 1, \"draw\": 157}, {\"draws\": 357, \"mouse\": 2, \"mu_intercept_per_group\": 13.830145835876465, \"sigma_intercept_per_group\": 0.15948832035064697, \"sigma_obs\": 146.8383331298828, \"slope\": -0.08726508170366287, \"chain\": 1, \"draw\": 157}, {\"draws\": 357, \"mouse\": 3, \"mu_intercept_per_group\": 13.593080520629883, \"sigma_intercept_per_group\": 0.15948832035064697, \"sigma_obs\": 146.8383331298828, \"slope\": -0.08726508170366287, \"chain\": 1, \"draw\": 157}, {\"draws\": 357, \"mouse\": 4, \"mu_intercept_per_group\": 12.844162940979004, \"sigma_intercept_per_group\": 0.15948832035064697, \"sigma_obs\": 146.8383331298828, \"slope\": -0.08726508170366287, \"chain\": 1, \"draw\": 157}, {\"draws\": 357, \"mouse\": 5, \"mu_intercept_per_group\": 12.042919158935547, \"sigma_intercept_per_group\": 0.15948832035064697, \"sigma_obs\": 146.8383331298828, \"slope\": -0.08726508170366287, \"chain\": 1, \"draw\": 157}, {\"draws\": 357, \"mouse\": 6, \"mu_intercept_per_group\": 11.560737609863281, \"sigma_intercept_per_group\": 0.15948832035064697, \"sigma_obs\": 146.8383331298828, \"slope\": -0.08726508170366287, \"chain\": 1, \"draw\": 157}, {\"draws\": 357, \"mouse\": 7, \"mu_intercept_per_group\": 11.052539825439453, \"sigma_intercept_per_group\": 0.15948832035064697, \"sigma_obs\": 146.8383331298828, \"slope\": -0.08726508170366287, \"chain\": 1, \"draw\": 157}, {\"draws\": 358, \"mouse\": 0, \"mu_intercept_per_group\": 15.790468215942383, \"sigma_intercept_per_group\": 0.15367932617664337, \"sigma_obs\": 160.49163818359375, \"slope\": -0.06588724255561829, \"chain\": 1, \"draw\": 158}, {\"draws\": 358, \"mouse\": 1, \"mu_intercept_per_group\": 15.5836763381958, \"sigma_intercept_per_group\": 0.15367932617664337, \"sigma_obs\": 160.49163818359375, \"slope\": -0.06588724255561829, \"chain\": 1, \"draw\": 158}, {\"draws\": 358, \"mouse\": 2, \"mu_intercept_per_group\": 14.830252647399902, \"sigma_intercept_per_group\": 0.15367932617664337, \"sigma_obs\": 160.49163818359375, \"slope\": -0.06588724255561829, \"chain\": 1, \"draw\": 158}, {\"draws\": 358, \"mouse\": 3, \"mu_intercept_per_group\": 14.261167526245117, \"sigma_intercept_per_group\": 0.15367932617664337, \"sigma_obs\": 160.49163818359375, \"slope\": -0.06588724255561829, \"chain\": 1, \"draw\": 158}, {\"draws\": 358, \"mouse\": 4, \"mu_intercept_per_group\": 13.979279518127441, \"sigma_intercept_per_group\": 0.15367932617664337, \"sigma_obs\": 160.49163818359375, \"slope\": -0.06588724255561829, \"chain\": 1, \"draw\": 158}, {\"draws\": 358, \"mouse\": 5, \"mu_intercept_per_group\": 13.174742698669434, \"sigma_intercept_per_group\": 0.15367932617664337, \"sigma_obs\": 160.49163818359375, \"slope\": -0.06588724255561829, \"chain\": 1, \"draw\": 158}, {\"draws\": 358, \"mouse\": 6, \"mu_intercept_per_group\": 12.22509765625, \"sigma_intercept_per_group\": 0.15367932617664337, \"sigma_obs\": 160.49163818359375, \"slope\": -0.06588724255561829, \"chain\": 1, \"draw\": 158}, {\"draws\": 358, \"mouse\": 7, \"mu_intercept_per_group\": 11.611554145812988, \"sigma_intercept_per_group\": 0.15367932617664337, \"sigma_obs\": 160.49163818359375, \"slope\": -0.06588724255561829, \"chain\": 1, \"draw\": 158}, {\"draws\": 359, \"mouse\": 0, \"mu_intercept_per_group\": 16.18404769897461, \"sigma_intercept_per_group\": 0.15458452701568604, \"sigma_obs\": 161.28297424316406, \"slope\": -0.06625016778707504, \"chain\": 1, \"draw\": 159}, {\"draws\": 359, \"mouse\": 1, \"mu_intercept_per_group\": 15.3949613571167, \"sigma_intercept_per_group\": 0.15458452701568604, \"sigma_obs\": 161.28297424316406, \"slope\": -0.06625016778707504, \"chain\": 1, \"draw\": 159}, {\"draws\": 359, \"mouse\": 2, \"mu_intercept_per_group\": 15.126367568969727, \"sigma_intercept_per_group\": 0.15458452701568604, \"sigma_obs\": 161.28297424316406, \"slope\": -0.06625016778707504, \"chain\": 1, \"draw\": 159}, {\"draws\": 359, \"mouse\": 3, \"mu_intercept_per_group\": 13.940696716308594, \"sigma_intercept_per_group\": 0.15458452701568604, \"sigma_obs\": 161.28297424316406, \"slope\": -0.06625016778707504, \"chain\": 1, \"draw\": 159}, {\"draws\": 359, \"mouse\": 4, \"mu_intercept_per_group\": 13.673789024353027, \"sigma_intercept_per_group\": 0.15458452701568604, \"sigma_obs\": 161.28297424316406, \"slope\": -0.06625016778707504, \"chain\": 1, \"draw\": 159}, {\"draws\": 359, \"mouse\": 5, \"mu_intercept_per_group\": 12.837729454040527, \"sigma_intercept_per_group\": 0.15458452701568604, \"sigma_obs\": 161.28297424316406, \"slope\": -0.06625016778707504, \"chain\": 1, \"draw\": 159}, {\"draws\": 359, \"mouse\": 6, \"mu_intercept_per_group\": 12.444664001464844, \"sigma_intercept_per_group\": 0.15458452701568604, \"sigma_obs\": 161.28297424316406, \"slope\": -0.06625016778707504, \"chain\": 1, \"draw\": 159}, {\"draws\": 359, \"mouse\": 7, \"mu_intercept_per_group\": 11.611335754394531, \"sigma_intercept_per_group\": 0.15458452701568604, \"sigma_obs\": 161.28297424316406, \"slope\": -0.06625016778707504, \"chain\": 1, \"draw\": 159}, {\"draws\": 360, \"mouse\": 0, \"mu_intercept_per_group\": 14.923480033874512, \"sigma_intercept_per_group\": 0.16493892669677734, \"sigma_obs\": 152.4871826171875, \"slope\": -0.0688360184431076, \"chain\": 1, \"draw\": 160}, {\"draws\": 360, \"mouse\": 1, \"mu_intercept_per_group\": 14.130745887756348, \"sigma_intercept_per_group\": 0.16493892669677734, \"sigma_obs\": 152.4871826171875, \"slope\": -0.0688360184431076, \"chain\": 1, \"draw\": 160}, {\"draws\": 360, \"mouse\": 2, \"mu_intercept_per_group\": 13.717340469360352, \"sigma_intercept_per_group\": 0.16493892669677734, \"sigma_obs\": 152.4871826171875, \"slope\": -0.0688360184431076, \"chain\": 1, \"draw\": 160}, {\"draws\": 360, \"mouse\": 3, \"mu_intercept_per_group\": 13.01559066772461, \"sigma_intercept_per_group\": 0.16493892669677734, \"sigma_obs\": 152.4871826171875, \"slope\": -0.0688360184431076, \"chain\": 1, \"draw\": 160}, {\"draws\": 360, \"mouse\": 4, \"mu_intercept_per_group\": 12.635318756103516, \"sigma_intercept_per_group\": 0.16493892669677734, \"sigma_obs\": 152.4871826171875, \"slope\": -0.0688360184431076, \"chain\": 1, \"draw\": 160}, {\"draws\": 360, \"mouse\": 5, \"mu_intercept_per_group\": 11.689322471618652, \"sigma_intercept_per_group\": 0.16493892669677734, \"sigma_obs\": 152.4871826171875, \"slope\": -0.0688360184431076, \"chain\": 1, \"draw\": 160}, {\"draws\": 360, \"mouse\": 6, \"mu_intercept_per_group\": 11.4557466506958, \"sigma_intercept_per_group\": 0.16493892669677734, \"sigma_obs\": 152.4871826171875, \"slope\": -0.0688360184431076, \"chain\": 1, \"draw\": 160}, {\"draws\": 360, \"mouse\": 7, \"mu_intercept_per_group\": 10.482300758361816, \"sigma_intercept_per_group\": 0.16493892669677734, \"sigma_obs\": 152.4871826171875, \"slope\": -0.0688360184431076, \"chain\": 1, \"draw\": 160}, {\"draws\": 361, \"mouse\": 0, \"mu_intercept_per_group\": 14.510807991027832, \"sigma_intercept_per_group\": 0.1651998907327652, \"sigma_obs\": 153.85084533691406, \"slope\": -0.06777732074260712, \"chain\": 1, \"draw\": 161}, {\"draws\": 361, \"mouse\": 1, \"mu_intercept_per_group\": 14.2293062210083, \"sigma_intercept_per_group\": 0.1651998907327652, \"sigma_obs\": 153.85084533691406, \"slope\": -0.06777732074260712, \"chain\": 1, \"draw\": 161}, {\"draws\": 361, \"mouse\": 2, \"mu_intercept_per_group\": 13.88329792022705, \"sigma_intercept_per_group\": 0.1651998907327652, \"sigma_obs\": 153.85084533691406, \"slope\": -0.06777732074260712, \"chain\": 1, \"draw\": 161}, {\"draws\": 361, \"mouse\": 3, \"mu_intercept_per_group\": 13.410494804382324, \"sigma_intercept_per_group\": 0.1651998907327652, \"sigma_obs\": 153.85084533691406, \"slope\": -0.06777732074260712, \"chain\": 1, \"draw\": 161}, {\"draws\": 361, \"mouse\": 4, \"mu_intercept_per_group\": 12.71130084991455, \"sigma_intercept_per_group\": 0.1651998907327652, \"sigma_obs\": 153.85084533691406, \"slope\": -0.06777732074260712, \"chain\": 1, \"draw\": 161}, {\"draws\": 361, \"mouse\": 5, \"mu_intercept_per_group\": 11.390707015991211, \"sigma_intercept_per_group\": 0.1651998907327652, \"sigma_obs\": 153.85084533691406, \"slope\": -0.06777732074260712, \"chain\": 1, \"draw\": 161}, {\"draws\": 361, \"mouse\": 6, \"mu_intercept_per_group\": 11.59572696685791, \"sigma_intercept_per_group\": 0.1651998907327652, \"sigma_obs\": 153.85084533691406, \"slope\": -0.06777732074260712, \"chain\": 1, \"draw\": 161}, {\"draws\": 361, \"mouse\": 7, \"mu_intercept_per_group\": 10.909896850585938, \"sigma_intercept_per_group\": 0.1651998907327652, \"sigma_obs\": 153.85084533691406, \"slope\": -0.06777732074260712, \"chain\": 1, \"draw\": 161}, {\"draws\": 362, \"mouse\": 0, \"mu_intercept_per_group\": 14.864847183227539, \"sigma_intercept_per_group\": 0.16432254016399384, \"sigma_obs\": 153.90696716308594, \"slope\": -0.0661151111125946, \"chain\": 1, \"draw\": 162}, {\"draws\": 362, \"mouse\": 1, \"mu_intercept_per_group\": 13.903584480285645, \"sigma_intercept_per_group\": 0.16432254016399384, \"sigma_obs\": 153.90696716308594, \"slope\": -0.0661151111125946, \"chain\": 1, \"draw\": 162}, {\"draws\": 362, \"mouse\": 2, \"mu_intercept_per_group\": 13.67200756072998, \"sigma_intercept_per_group\": 0.16432254016399384, \"sigma_obs\": 153.90696716308594, \"slope\": -0.0661151111125946, \"chain\": 1, \"draw\": 162}, {\"draws\": 362, \"mouse\": 3, \"mu_intercept_per_group\": 12.937527656555176, \"sigma_intercept_per_group\": 0.16432254016399384, \"sigma_obs\": 153.90696716308594, \"slope\": -0.0661151111125946, \"chain\": 1, \"draw\": 162}, {\"draws\": 362, \"mouse\": 4, \"mu_intercept_per_group\": 12.82373332977295, \"sigma_intercept_per_group\": 0.16432254016399384, \"sigma_obs\": 153.90696716308594, \"slope\": -0.0661151111125946, \"chain\": 1, \"draw\": 162}, {\"draws\": 362, \"mouse\": 5, \"mu_intercept_per_group\": 12.03880500793457, \"sigma_intercept_per_group\": 0.16432254016399384, \"sigma_obs\": 153.90696716308594, \"slope\": -0.0661151111125946, \"chain\": 1, \"draw\": 162}, {\"draws\": 362, \"mouse\": 6, \"mu_intercept_per_group\": 11.279519081115723, \"sigma_intercept_per_group\": 0.16432254016399384, \"sigma_obs\": 153.90696716308594, \"slope\": -0.0661151111125946, \"chain\": 1, \"draw\": 162}, {\"draws\": 362, \"mouse\": 7, \"mu_intercept_per_group\": 10.389389038085938, \"sigma_intercept_per_group\": 0.16432254016399384, \"sigma_obs\": 153.90696716308594, \"slope\": -0.0661151111125946, \"chain\": 1, \"draw\": 162}, {\"draws\": 363, \"mouse\": 0, \"mu_intercept_per_group\": 14.57564926147461, \"sigma_intercept_per_group\": 0.16686572134494781, \"sigma_obs\": 156.46682739257812, \"slope\": -0.05447984114289284, \"chain\": 1, \"draw\": 163}, {\"draws\": 363, \"mouse\": 1, \"mu_intercept_per_group\": 13.820369720458984, \"sigma_intercept_per_group\": 0.16686572134494781, \"sigma_obs\": 156.46682739257812, \"slope\": -0.05447984114289284, \"chain\": 1, \"draw\": 163}, {\"draws\": 363, \"mouse\": 2, \"mu_intercept_per_group\": 13.316329002380371, \"sigma_intercept_per_group\": 0.16686572134494781, \"sigma_obs\": 156.46682739257812, \"slope\": -0.05447984114289284, \"chain\": 1, \"draw\": 163}, {\"draws\": 363, \"mouse\": 3, \"mu_intercept_per_group\": 12.755746841430664, \"sigma_intercept_per_group\": 0.16686572134494781, \"sigma_obs\": 156.46682739257812, \"slope\": -0.05447984114289284, \"chain\": 1, \"draw\": 163}, {\"draws\": 363, \"mouse\": 4, \"mu_intercept_per_group\": 12.343648910522461, \"sigma_intercept_per_group\": 0.16686572134494781, \"sigma_obs\": 156.46682739257812, \"slope\": -0.05447984114289284, \"chain\": 1, \"draw\": 163}, {\"draws\": 363, \"mouse\": 5, \"mu_intercept_per_group\": 11.866270065307617, \"sigma_intercept_per_group\": 0.16686572134494781, \"sigma_obs\": 156.46682739257812, \"slope\": -0.05447984114289284, \"chain\": 1, \"draw\": 163}, {\"draws\": 363, \"mouse\": 6, \"mu_intercept_per_group\": 11.130376815795898, \"sigma_intercept_per_group\": 0.16686572134494781, \"sigma_obs\": 156.46682739257812, \"slope\": -0.05447984114289284, \"chain\": 1, \"draw\": 163}, {\"draws\": 363, \"mouse\": 7, \"mu_intercept_per_group\": 10.385289192199707, \"sigma_intercept_per_group\": 0.16686572134494781, \"sigma_obs\": 156.46682739257812, \"slope\": -0.05447984114289284, \"chain\": 1, \"draw\": 163}, {\"draws\": 364, \"mouse\": 0, \"mu_intercept_per_group\": 13.363438606262207, \"sigma_intercept_per_group\": 0.18769162893295288, \"sigma_obs\": 164.19357299804688, \"slope\": -0.07010256499052048, \"chain\": 1, \"draw\": 164}, {\"draws\": 364, \"mouse\": 1, \"mu_intercept_per_group\": 12.750486373901367, \"sigma_intercept_per_group\": 0.18769162893295288, \"sigma_obs\": 164.19357299804688, \"slope\": -0.07010256499052048, \"chain\": 1, \"draw\": 164}, {\"draws\": 364, \"mouse\": 2, \"mu_intercept_per_group\": 12.508452415466309, \"sigma_intercept_per_group\": 0.18769162893295288, \"sigma_obs\": 164.19357299804688, \"slope\": -0.07010256499052048, \"chain\": 1, \"draw\": 164}, {\"draws\": 364, \"mouse\": 3, \"mu_intercept_per_group\": 11.557296752929688, \"sigma_intercept_per_group\": 0.18769162893295288, \"sigma_obs\": 164.19357299804688, \"slope\": -0.07010256499052048, \"chain\": 1, \"draw\": 164}, {\"draws\": 364, \"mouse\": 4, \"mu_intercept_per_group\": 11.498832702636719, \"sigma_intercept_per_group\": 0.18769162893295288, \"sigma_obs\": 164.19357299804688, \"slope\": -0.07010256499052048, \"chain\": 1, \"draw\": 164}, {\"draws\": 364, \"mouse\": 5, \"mu_intercept_per_group\": 11.078760147094727, \"sigma_intercept_per_group\": 0.18769162893295288, \"sigma_obs\": 164.19357299804688, \"slope\": -0.07010256499052048, \"chain\": 1, \"draw\": 164}, {\"draws\": 364, \"mouse\": 6, \"mu_intercept_per_group\": 9.96546745300293, \"sigma_intercept_per_group\": 0.18769162893295288, \"sigma_obs\": 164.19357299804688, \"slope\": -0.07010256499052048, \"chain\": 1, \"draw\": 164}, {\"draws\": 364, \"mouse\": 7, \"mu_intercept_per_group\": 9.620348930358887, \"sigma_intercept_per_group\": 0.18769162893295288, \"sigma_obs\": 164.19357299804688, \"slope\": -0.07010256499052048, \"chain\": 1, \"draw\": 164}, {\"draws\": 365, \"mouse\": 0, \"mu_intercept_per_group\": 13.13082504272461, \"sigma_intercept_per_group\": 0.19163355231285095, \"sigma_obs\": 166.0701141357422, \"slope\": -0.06705614924430847, \"chain\": 1, \"draw\": 165}, {\"draws\": 365, \"mouse\": 1, \"mu_intercept_per_group\": 12.579262733459473, \"sigma_intercept_per_group\": 0.19163355231285095, \"sigma_obs\": 166.0701141357422, \"slope\": -0.06705614924430847, \"chain\": 1, \"draw\": 165}, {\"draws\": 365, \"mouse\": 2, \"mu_intercept_per_group\": 12.040949821472168, \"sigma_intercept_per_group\": 0.19163355231285095, \"sigma_obs\": 166.0701141357422, \"slope\": -0.06705614924430847, \"chain\": 1, \"draw\": 165}, {\"draws\": 365, \"mouse\": 3, \"mu_intercept_per_group\": 11.889212608337402, \"sigma_intercept_per_group\": 0.19163355231285095, \"sigma_obs\": 166.0701141357422, \"slope\": -0.06705614924430847, \"chain\": 1, \"draw\": 165}, {\"draws\": 365, \"mouse\": 4, \"mu_intercept_per_group\": 11.221502304077148, \"sigma_intercept_per_group\": 0.19163355231285095, \"sigma_obs\": 166.0701141357422, \"slope\": -0.06705614924430847, \"chain\": 1, \"draw\": 165}, {\"draws\": 365, \"mouse\": 5, \"mu_intercept_per_group\": 10.363592147827148, \"sigma_intercept_per_group\": 0.19163355231285095, \"sigma_obs\": 166.0701141357422, \"slope\": -0.06705614924430847, \"chain\": 1, \"draw\": 165}, {\"draws\": 365, \"mouse\": 6, \"mu_intercept_per_group\": 10.063629150390625, \"sigma_intercept_per_group\": 0.19163355231285095, \"sigma_obs\": 166.0701141357422, \"slope\": -0.06705614924430847, \"chain\": 1, \"draw\": 165}, {\"draws\": 365, \"mouse\": 7, \"mu_intercept_per_group\": 9.549739837646484, \"sigma_intercept_per_group\": 0.19163355231285095, \"sigma_obs\": 166.0701141357422, \"slope\": -0.06705614924430847, \"chain\": 1, \"draw\": 165}, {\"draws\": 366, \"mouse\": 0, \"mu_intercept_per_group\": 12.541130065917969, \"sigma_intercept_per_group\": 0.1902773678302765, \"sigma_obs\": 150.62429809570312, \"slope\": -0.052352916449308395, \"chain\": 1, \"draw\": 166}, {\"draws\": 366, \"mouse\": 1, \"mu_intercept_per_group\": 12.230269432067871, \"sigma_intercept_per_group\": 0.1902773678302765, \"sigma_obs\": 150.62429809570312, \"slope\": -0.052352916449308395, \"chain\": 1, \"draw\": 166}, {\"draws\": 366, \"mouse\": 2, \"mu_intercept_per_group\": 11.756897926330566, \"sigma_intercept_per_group\": 0.1902773678302765, \"sigma_obs\": 150.62429809570312, \"slope\": -0.052352916449308395, \"chain\": 1, \"draw\": 166}, {\"draws\": 366, \"mouse\": 3, \"mu_intercept_per_group\": 10.821857452392578, \"sigma_intercept_per_group\": 0.1902773678302765, \"sigma_obs\": 150.62429809570312, \"slope\": -0.052352916449308395, \"chain\": 1, \"draw\": 166}, {\"draws\": 366, \"mouse\": 4, \"mu_intercept_per_group\": 10.892109870910645, \"sigma_intercept_per_group\": 0.1902773678302765, \"sigma_obs\": 150.62429809570312, \"slope\": -0.052352916449308395, \"chain\": 1, \"draw\": 166}, {\"draws\": 366, \"mouse\": 5, \"mu_intercept_per_group\": 9.94920539855957, \"sigma_intercept_per_group\": 0.1902773678302765, \"sigma_obs\": 150.62429809570312, \"slope\": -0.052352916449308395, \"chain\": 1, \"draw\": 166}, {\"draws\": 366, \"mouse\": 6, \"mu_intercept_per_group\": 9.463586807250977, \"sigma_intercept_per_group\": 0.1902773678302765, \"sigma_obs\": 150.62429809570312, \"slope\": -0.052352916449308395, \"chain\": 1, \"draw\": 166}, {\"draws\": 366, \"mouse\": 7, \"mu_intercept_per_group\": 8.908963203430176, \"sigma_intercept_per_group\": 0.1902773678302765, \"sigma_obs\": 150.62429809570312, \"slope\": -0.052352916449308395, \"chain\": 1, \"draw\": 166}, {\"draws\": 367, \"mouse\": 0, \"mu_intercept_per_group\": 12.571971893310547, \"sigma_intercept_per_group\": 0.1895897090435028, \"sigma_obs\": 150.79043579101562, \"slope\": -0.05178321525454521, \"chain\": 1, \"draw\": 167}, {\"draws\": 367, \"mouse\": 1, \"mu_intercept_per_group\": 11.955726623535156, \"sigma_intercept_per_group\": 0.1895897090435028, \"sigma_obs\": 150.79043579101562, \"slope\": -0.05178321525454521, \"chain\": 1, \"draw\": 167}, {\"draws\": 367, \"mouse\": 2, \"mu_intercept_per_group\": 11.646255493164062, \"sigma_intercept_per_group\": 0.1895897090435028, \"sigma_obs\": 150.79043579101562, \"slope\": -0.05178321525454521, \"chain\": 1, \"draw\": 167}, {\"draws\": 367, \"mouse\": 3, \"mu_intercept_per_group\": 11.147428512573242, \"sigma_intercept_per_group\": 0.1895897090435028, \"sigma_obs\": 150.79043579101562, \"slope\": -0.05178321525454521, \"chain\": 1, \"draw\": 167}, {\"draws\": 367, \"mouse\": 4, \"mu_intercept_per_group\": 10.406262397766113, \"sigma_intercept_per_group\": 0.1895897090435028, \"sigma_obs\": 150.79043579101562, \"slope\": -0.05178321525454521, \"chain\": 1, \"draw\": 167}, {\"draws\": 367, \"mouse\": 5, \"mu_intercept_per_group\": 10.21398639678955, \"sigma_intercept_per_group\": 0.1895897090435028, \"sigma_obs\": 150.79043579101562, \"slope\": -0.05178321525454521, \"chain\": 1, \"draw\": 167}, {\"draws\": 367, \"mouse\": 6, \"mu_intercept_per_group\": 9.385309219360352, \"sigma_intercept_per_group\": 0.1895897090435028, \"sigma_obs\": 150.79043579101562, \"slope\": -0.05178321525454521, \"chain\": 1, \"draw\": 167}, {\"draws\": 367, \"mouse\": 7, \"mu_intercept_per_group\": 8.977984428405762, \"sigma_intercept_per_group\": 0.1895897090435028, \"sigma_obs\": 150.79043579101562, \"slope\": -0.05178321525454521, \"chain\": 1, \"draw\": 167}, {\"draws\": 368, \"mouse\": 0, \"mu_intercept_per_group\": 12.236979484558105, \"sigma_intercept_per_group\": 0.18929852545261383, \"sigma_obs\": 150.43545532226562, \"slope\": -0.05386246368288994, \"chain\": 1, \"draw\": 168}, {\"draws\": 368, \"mouse\": 1, \"mu_intercept_per_group\": 12.226408004760742, \"sigma_intercept_per_group\": 0.18929852545261383, \"sigma_obs\": 150.43545532226562, \"slope\": -0.05386246368288994, \"chain\": 1, \"draw\": 168}, {\"draws\": 368, \"mouse\": 2, \"mu_intercept_per_group\": 11.740386009216309, \"sigma_intercept_per_group\": 0.18929852545261383, \"sigma_obs\": 150.43545532226562, \"slope\": -0.05386246368288994, \"chain\": 1, \"draw\": 168}, {\"draws\": 368, \"mouse\": 3, \"mu_intercept_per_group\": 11.192767143249512, \"sigma_intercept_per_group\": 0.18929852545261383, \"sigma_obs\": 150.43545532226562, \"slope\": -0.05386246368288994, \"chain\": 1, \"draw\": 168}, {\"draws\": 368, \"mouse\": 4, \"mu_intercept_per_group\": 10.391913414001465, \"sigma_intercept_per_group\": 0.18929852545261383, \"sigma_obs\": 150.43545532226562, \"slope\": -0.05386246368288994, \"chain\": 1, \"draw\": 168}, {\"draws\": 368, \"mouse\": 5, \"mu_intercept_per_group\": 10.220685005187988, \"sigma_intercept_per_group\": 0.18929852545261383, \"sigma_obs\": 150.43545532226562, \"slope\": -0.05386246368288994, \"chain\": 1, \"draw\": 168}, {\"draws\": 368, \"mouse\": 6, \"mu_intercept_per_group\": 9.382489204406738, \"sigma_intercept_per_group\": 0.18929852545261383, \"sigma_obs\": 150.43545532226562, \"slope\": -0.05386246368288994, \"chain\": 1, \"draw\": 168}, {\"draws\": 368, \"mouse\": 7, \"mu_intercept_per_group\": 8.592232704162598, \"sigma_intercept_per_group\": 0.18929852545261383, \"sigma_obs\": 150.43545532226562, \"slope\": -0.05386246368288994, \"chain\": 1, \"draw\": 168}, {\"draws\": 369, \"mouse\": 0, \"mu_intercept_per_group\": 13.116318702697754, \"sigma_intercept_per_group\": 0.19123831391334534, \"sigma_obs\": 151.34864807128906, \"slope\": -0.06623108685016632, \"chain\": 1, \"draw\": 169}, {\"draws\": 369, \"mouse\": 1, \"mu_intercept_per_group\": 12.081130027770996, \"sigma_intercept_per_group\": 0.19123831391334534, \"sigma_obs\": 151.34864807128906, \"slope\": -0.06623108685016632, \"chain\": 1, \"draw\": 169}, {\"draws\": 369, \"mouse\": 2, \"mu_intercept_per_group\": 11.793829917907715, \"sigma_intercept_per_group\": 0.19123831391334534, \"sigma_obs\": 151.34864807128906, \"slope\": -0.06623108685016632, \"chain\": 1, \"draw\": 169}, {\"draws\": 369, \"mouse\": 3, \"mu_intercept_per_group\": 11.110079765319824, \"sigma_intercept_per_group\": 0.19123831391334534, \"sigma_obs\": 151.34864807128906, \"slope\": -0.06623108685016632, \"chain\": 1, \"draw\": 169}, {\"draws\": 369, \"mouse\": 4, \"mu_intercept_per_group\": 11.016359329223633, \"sigma_intercept_per_group\": 0.19123831391334534, \"sigma_obs\": 151.34864807128906, \"slope\": -0.06623108685016632, \"chain\": 1, \"draw\": 169}, {\"draws\": 369, \"mouse\": 5, \"mu_intercept_per_group\": 10.47037124633789, \"sigma_intercept_per_group\": 0.19123831391334534, \"sigma_obs\": 151.34864807128906, \"slope\": -0.06623108685016632, \"chain\": 1, \"draw\": 169}, {\"draws\": 369, \"mouse\": 6, \"mu_intercept_per_group\": 9.601457595825195, \"sigma_intercept_per_group\": 0.19123831391334534, \"sigma_obs\": 151.34864807128906, \"slope\": -0.06623108685016632, \"chain\": 1, \"draw\": 169}, {\"draws\": 369, \"mouse\": 7, \"mu_intercept_per_group\": 8.936043739318848, \"sigma_intercept_per_group\": 0.19123831391334534, \"sigma_obs\": 151.34864807128906, \"slope\": -0.06623108685016632, \"chain\": 1, \"draw\": 169}, {\"draws\": 370, \"mouse\": 0, \"mu_intercept_per_group\": 12.512492179870605, \"sigma_intercept_per_group\": 0.19056251645088196, \"sigma_obs\": 150.35211181640625, \"slope\": -0.06519699841737747, \"chain\": 1, \"draw\": 170}, {\"draws\": 370, \"mouse\": 1, \"mu_intercept_per_group\": 12.552674293518066, \"sigma_intercept_per_group\": 0.19056251645088196, \"sigma_obs\": 150.35211181640625, \"slope\": -0.06519699841737747, \"chain\": 1, \"draw\": 170}, {\"draws\": 370, \"mouse\": 2, \"mu_intercept_per_group\": 12.010431289672852, \"sigma_intercept_per_group\": 0.19056251645088196, \"sigma_obs\": 150.35211181640625, \"slope\": -0.06519699841737747, \"chain\": 1, \"draw\": 170}, {\"draws\": 370, \"mouse\": 3, \"mu_intercept_per_group\": 11.02402400970459, \"sigma_intercept_per_group\": 0.19056251645088196, \"sigma_obs\": 150.35211181640625, \"slope\": -0.06519699841737747, \"chain\": 1, \"draw\": 170}, {\"draws\": 370, \"mouse\": 4, \"mu_intercept_per_group\": 11.018819808959961, \"sigma_intercept_per_group\": 0.19056251645088196, \"sigma_obs\": 150.35211181640625, \"slope\": -0.06519699841737747, \"chain\": 1, \"draw\": 170}, {\"draws\": 370, \"mouse\": 5, \"mu_intercept_per_group\": 9.97007942199707, \"sigma_intercept_per_group\": 0.19056251645088196, \"sigma_obs\": 150.35211181640625, \"slope\": -0.06519699841737747, \"chain\": 1, \"draw\": 170}, {\"draws\": 370, \"mouse\": 6, \"mu_intercept_per_group\": 9.798152923583984, \"sigma_intercept_per_group\": 0.19056251645088196, \"sigma_obs\": 150.35211181640625, \"slope\": -0.06519699841737747, \"chain\": 1, \"draw\": 170}, {\"draws\": 370, \"mouse\": 7, \"mu_intercept_per_group\": 9.02044677734375, \"sigma_intercept_per_group\": 0.19056251645088196, \"sigma_obs\": 150.35211181640625, \"slope\": -0.06519699841737747, \"chain\": 1, \"draw\": 170}, {\"draws\": 371, \"mouse\": 0, \"mu_intercept_per_group\": 12.812009811401367, \"sigma_intercept_per_group\": 0.19088414311408997, \"sigma_obs\": 151.40487670898438, \"slope\": -0.06754539161920547, \"chain\": 1, \"draw\": 171}, {\"draws\": 371, \"mouse\": 1, \"mu_intercept_per_group\": 11.784419059753418, \"sigma_intercept_per_group\": 0.19088414311408997, \"sigma_obs\": 151.40487670898438, \"slope\": -0.06754539161920547, \"chain\": 1, \"draw\": 171}, {\"draws\": 371, \"mouse\": 2, \"mu_intercept_per_group\": 11.56460952758789, \"sigma_intercept_per_group\": 0.19088414311408997, \"sigma_obs\": 151.40487670898438, \"slope\": -0.06754539161920547, \"chain\": 1, \"draw\": 171}, {\"draws\": 371, \"mouse\": 3, \"mu_intercept_per_group\": 11.426183700561523, \"sigma_intercept_per_group\": 0.19088414311408997, \"sigma_obs\": 151.40487670898438, \"slope\": -0.06754539161920547, \"chain\": 1, \"draw\": 171}, {\"draws\": 371, \"mouse\": 4, \"mu_intercept_per_group\": 10.6475830078125, \"sigma_intercept_per_group\": 0.19088414311408997, \"sigma_obs\": 151.40487670898438, \"slope\": -0.06754539161920547, \"chain\": 1, \"draw\": 171}, {\"draws\": 371, \"mouse\": 5, \"mu_intercept_per_group\": 10.5401611328125, \"sigma_intercept_per_group\": 0.19088414311408997, \"sigma_obs\": 151.40487670898438, \"slope\": -0.06754539161920547, \"chain\": 1, \"draw\": 171}, {\"draws\": 371, \"mouse\": 6, \"mu_intercept_per_group\": 9.505638122558594, \"sigma_intercept_per_group\": 0.19088414311408997, \"sigma_obs\": 151.40487670898438, \"slope\": -0.06754539161920547, \"chain\": 1, \"draw\": 171}, {\"draws\": 371, \"mouse\": 7, \"mu_intercept_per_group\": 9.53036880493164, \"sigma_intercept_per_group\": 0.19088414311408997, \"sigma_obs\": 151.40487670898438, \"slope\": -0.06754539161920547, \"chain\": 1, \"draw\": 171}, {\"draws\": 372, \"mouse\": 0, \"mu_intercept_per_group\": 12.66419792175293, \"sigma_intercept_per_group\": 0.18613310158252716, \"sigma_obs\": 148.2689971923828, \"slope\": -0.06645490974187851, \"chain\": 1, \"draw\": 172}, {\"draws\": 372, \"mouse\": 1, \"mu_intercept_per_group\": 12.691750526428223, \"sigma_intercept_per_group\": 0.18613310158252716, \"sigma_obs\": 148.2689971923828, \"slope\": -0.06645490974187851, \"chain\": 1, \"draw\": 172}, {\"draws\": 372, \"mouse\": 2, \"mu_intercept_per_group\": 12.27346420288086, \"sigma_intercept_per_group\": 0.18613310158252716, \"sigma_obs\": 148.2689971923828, \"slope\": -0.06645490974187851, \"chain\": 1, \"draw\": 172}, {\"draws\": 372, \"mouse\": 3, \"mu_intercept_per_group\": 10.902251243591309, \"sigma_intercept_per_group\": 0.18613310158252716, \"sigma_obs\": 148.2689971923828, \"slope\": -0.06645490974187851, \"chain\": 1, \"draw\": 172}, {\"draws\": 372, \"mouse\": 4, \"mu_intercept_per_group\": 11.389171600341797, \"sigma_intercept_per_group\": 0.18613310158252716, \"sigma_obs\": 148.2689971923828, \"slope\": -0.06645490974187851, \"chain\": 1, \"draw\": 172}, {\"draws\": 372, \"mouse\": 5, \"mu_intercept_per_group\": 10.112502098083496, \"sigma_intercept_per_group\": 0.18613310158252716, \"sigma_obs\": 148.2689971923828, \"slope\": -0.06645490974187851, \"chain\": 1, \"draw\": 172}, {\"draws\": 372, \"mouse\": 6, \"mu_intercept_per_group\": 9.492619514465332, \"sigma_intercept_per_group\": 0.18613310158252716, \"sigma_obs\": 148.2689971923828, \"slope\": -0.06645490974187851, \"chain\": 1, \"draw\": 172}, {\"draws\": 372, \"mouse\": 7, \"mu_intercept_per_group\": 8.729066848754883, \"sigma_intercept_per_group\": 0.18613310158252716, \"sigma_obs\": 148.2689971923828, \"slope\": -0.06645490974187851, \"chain\": 1, \"draw\": 172}, {\"draws\": 373, \"mouse\": 0, \"mu_intercept_per_group\": 12.950766563415527, \"sigma_intercept_per_group\": 0.18650256097316742, \"sigma_obs\": 146.77127075195312, \"slope\": -0.06830093264579773, \"chain\": 1, \"draw\": 173}, {\"draws\": 373, \"mouse\": 1, \"mu_intercept_per_group\": 12.331162452697754, \"sigma_intercept_per_group\": 0.18650256097316742, \"sigma_obs\": 146.77127075195312, \"slope\": -0.06830093264579773, \"chain\": 1, \"draw\": 173}, {\"draws\": 373, \"mouse\": 2, \"mu_intercept_per_group\": 11.817872047424316, \"sigma_intercept_per_group\": 0.18650256097316742, \"sigma_obs\": 146.77127075195312, \"slope\": -0.06830093264579773, \"chain\": 1, \"draw\": 173}, {\"draws\": 373, \"mouse\": 3, \"mu_intercept_per_group\": 11.60405445098877, \"sigma_intercept_per_group\": 0.18650256097316742, \"sigma_obs\": 146.77127075195312, \"slope\": -0.06830093264579773, \"chain\": 1, \"draw\": 173}, {\"draws\": 373, \"mouse\": 4, \"mu_intercept_per_group\": 10.727846145629883, \"sigma_intercept_per_group\": 0.18650256097316742, \"sigma_obs\": 146.77127075195312, \"slope\": -0.06830093264579773, \"chain\": 1, \"draw\": 173}, {\"draws\": 373, \"mouse\": 5, \"mu_intercept_per_group\": 10.481087684631348, \"sigma_intercept_per_group\": 0.18650256097316742, \"sigma_obs\": 146.77127075195312, \"slope\": -0.06830093264579773, \"chain\": 1, \"draw\": 173}, {\"draws\": 373, \"mouse\": 6, \"mu_intercept_per_group\": 9.464472770690918, \"sigma_intercept_per_group\": 0.18650256097316742, \"sigma_obs\": 146.77127075195312, \"slope\": -0.06830093264579773, \"chain\": 1, \"draw\": 173}, {\"draws\": 373, \"mouse\": 7, \"mu_intercept_per_group\": 8.990625381469727, \"sigma_intercept_per_group\": 0.18650256097316742, \"sigma_obs\": 146.77127075195312, \"slope\": -0.06830093264579773, \"chain\": 1, \"draw\": 173}, {\"draws\": 374, \"mouse\": 0, \"mu_intercept_per_group\": 13.148079872131348, \"sigma_intercept_per_group\": 0.18524590134620667, \"sigma_obs\": 146.67955017089844, \"slope\": -0.06737637519836426, \"chain\": 1, \"draw\": 174}, {\"draws\": 374, \"mouse\": 1, \"mu_intercept_per_group\": 12.407031059265137, \"sigma_intercept_per_group\": 0.18524590134620667, \"sigma_obs\": 146.67955017089844, \"slope\": -0.06737637519836426, \"chain\": 1, \"draw\": 174}, {\"draws\": 374, \"mouse\": 2, \"mu_intercept_per_group\": 11.972633361816406, \"sigma_intercept_per_group\": 0.18524590134620667, \"sigma_obs\": 146.67955017089844, \"slope\": -0.06737637519836426, \"chain\": 1, \"draw\": 174}, {\"draws\": 374, \"mouse\": 3, \"mu_intercept_per_group\": 11.384232521057129, \"sigma_intercept_per_group\": 0.18524590134620667, \"sigma_obs\": 146.67955017089844, \"slope\": -0.06737637519836426, \"chain\": 1, \"draw\": 174}, {\"draws\": 374, \"mouse\": 4, \"mu_intercept_per_group\": 10.504753112792969, \"sigma_intercept_per_group\": 0.18524590134620667, \"sigma_obs\": 146.67955017089844, \"slope\": -0.06737637519836426, \"chain\": 1, \"draw\": 174}, {\"draws\": 374, \"mouse\": 5, \"mu_intercept_per_group\": 10.362749099731445, \"sigma_intercept_per_group\": 0.18524590134620667, \"sigma_obs\": 146.67955017089844, \"slope\": -0.06737637519836426, \"chain\": 1, \"draw\": 174}, {\"draws\": 374, \"mouse\": 6, \"mu_intercept_per_group\": 9.645885467529297, \"sigma_intercept_per_group\": 0.18524590134620667, \"sigma_obs\": 146.67955017089844, \"slope\": -0.06737637519836426, \"chain\": 1, \"draw\": 174}, {\"draws\": 374, \"mouse\": 7, \"mu_intercept_per_group\": 8.92519760131836, \"sigma_intercept_per_group\": 0.18524590134620667, \"sigma_obs\": 146.67955017089844, \"slope\": -0.06737637519836426, \"chain\": 1, \"draw\": 174}, {\"draws\": 375, \"mouse\": 0, \"mu_intercept_per_group\": 13.0271635055542, \"sigma_intercept_per_group\": 0.18564116954803467, \"sigma_obs\": 146.8563232421875, \"slope\": -0.06721179187297821, \"chain\": 1, \"draw\": 175}, {\"draws\": 375, \"mouse\": 1, \"mu_intercept_per_group\": 12.220669746398926, \"sigma_intercept_per_group\": 0.18564116954803467, \"sigma_obs\": 146.8563232421875, \"slope\": -0.06721179187297821, \"chain\": 1, \"draw\": 175}, {\"draws\": 375, \"mouse\": 2, \"mu_intercept_per_group\": 11.844443321228027, \"sigma_intercept_per_group\": 0.18564116954803467, \"sigma_obs\": 146.8563232421875, \"slope\": -0.06721179187297821, \"chain\": 1, \"draw\": 175}, {\"draws\": 375, \"mouse\": 3, \"mu_intercept_per_group\": 11.68951416015625, \"sigma_intercept_per_group\": 0.18564116954803467, \"sigma_obs\": 146.8563232421875, \"slope\": -0.06721179187297821, \"chain\": 1, \"draw\": 175}, {\"draws\": 375, \"mouse\": 4, \"mu_intercept_per_group\": 10.672066688537598, \"sigma_intercept_per_group\": 0.18564116954803467, \"sigma_obs\": 146.8563232421875, \"slope\": -0.06721179187297821, \"chain\": 1, \"draw\": 175}, {\"draws\": 375, \"mouse\": 5, \"mu_intercept_per_group\": 10.617361068725586, \"sigma_intercept_per_group\": 0.18564116954803467, \"sigma_obs\": 146.8563232421875, \"slope\": -0.06721179187297821, \"chain\": 1, \"draw\": 175}, {\"draws\": 375, \"mouse\": 6, \"mu_intercept_per_group\": 9.604995727539062, \"sigma_intercept_per_group\": 0.18564116954803467, \"sigma_obs\": 146.8563232421875, \"slope\": -0.06721179187297821, \"chain\": 1, \"draw\": 175}, {\"draws\": 375, \"mouse\": 7, \"mu_intercept_per_group\": 9.1520357131958, \"sigma_intercept_per_group\": 0.18564116954803467, \"sigma_obs\": 146.8563232421875, \"slope\": -0.06721179187297821, \"chain\": 1, \"draw\": 175}, {\"draws\": 376, \"mouse\": 0, \"mu_intercept_per_group\": 12.818319320678711, \"sigma_intercept_per_group\": 0.18715789914131165, \"sigma_obs\": 148.65907287597656, \"slope\": -0.0653090700507164, \"chain\": 1, \"draw\": 176}, {\"draws\": 376, \"mouse\": 1, \"mu_intercept_per_group\": 12.292084693908691, \"sigma_intercept_per_group\": 0.18715789914131165, \"sigma_obs\": 148.65907287597656, \"slope\": -0.0653090700507164, \"chain\": 1, \"draw\": 176}, {\"draws\": 376, \"mouse\": 2, \"mu_intercept_per_group\": 12.10886287689209, \"sigma_intercept_per_group\": 0.18715789914131165, \"sigma_obs\": 148.65907287597656, \"slope\": -0.0653090700507164, \"chain\": 1, \"draw\": 176}, {\"draws\": 376, \"mouse\": 3, \"mu_intercept_per_group\": 10.885504722595215, \"sigma_intercept_per_group\": 0.18715789914131165, \"sigma_obs\": 148.65907287597656, \"slope\": -0.0653090700507164, \"chain\": 1, \"draw\": 176}, {\"draws\": 376, \"mouse\": 4, \"mu_intercept_per_group\": 11.233843803405762, \"sigma_intercept_per_group\": 0.18715789914131165, \"sigma_obs\": 148.65907287597656, \"slope\": -0.0653090700507164, \"chain\": 1, \"draw\": 176}, {\"draws\": 376, \"mouse\": 5, \"mu_intercept_per_group\": 10.157581329345703, \"sigma_intercept_per_group\": 0.18715789914131165, \"sigma_obs\": 148.65907287597656, \"slope\": -0.0653090700507164, \"chain\": 1, \"draw\": 176}, {\"draws\": 376, \"mouse\": 6, \"mu_intercept_per_group\": 9.380881309509277, \"sigma_intercept_per_group\": 0.18715789914131165, \"sigma_obs\": 148.65907287597656, \"slope\": -0.0653090700507164, \"chain\": 1, \"draw\": 176}, {\"draws\": 376, \"mouse\": 7, \"mu_intercept_per_group\": 9.306441307067871, \"sigma_intercept_per_group\": 0.18715789914131165, \"sigma_obs\": 148.65907287597656, \"slope\": -0.0653090700507164, \"chain\": 1, \"draw\": 176}, {\"draws\": 377, \"mouse\": 0, \"mu_intercept_per_group\": 12.87801456451416, \"sigma_intercept_per_group\": 0.19154083728790283, \"sigma_obs\": 155.26910400390625, \"slope\": -0.07411891967058182, \"chain\": 1, \"draw\": 177}, {\"draws\": 377, \"mouse\": 1, \"mu_intercept_per_group\": 12.238102912902832, \"sigma_intercept_per_group\": 0.19154083728790283, \"sigma_obs\": 155.26910400390625, \"slope\": -0.07411891967058182, \"chain\": 1, \"draw\": 177}, {\"draws\": 377, \"mouse\": 2, \"mu_intercept_per_group\": 12.315152168273926, \"sigma_intercept_per_group\": 0.19154083728790283, \"sigma_obs\": 155.26910400390625, \"slope\": -0.07411891967058182, \"chain\": 1, \"draw\": 177}, {\"draws\": 377, \"mouse\": 3, \"mu_intercept_per_group\": 11.33901309967041, \"sigma_intercept_per_group\": 0.19154083728790283, \"sigma_obs\": 155.26910400390625, \"slope\": -0.07411891967058182, \"chain\": 1, \"draw\": 177}, {\"draws\": 377, \"mouse\": 4, \"mu_intercept_per_group\": 10.752800941467285, \"sigma_intercept_per_group\": 0.19154083728790283, \"sigma_obs\": 155.26910400390625, \"slope\": -0.07411891967058182, \"chain\": 1, \"draw\": 177}, {\"draws\": 377, \"mouse\": 5, \"mu_intercept_per_group\": 10.167573928833008, \"sigma_intercept_per_group\": 0.19154083728790283, \"sigma_obs\": 155.26910400390625, \"slope\": -0.07411891967058182, \"chain\": 1, \"draw\": 177}, {\"draws\": 377, \"mouse\": 6, \"mu_intercept_per_group\": 9.534988403320312, \"sigma_intercept_per_group\": 0.19154083728790283, \"sigma_obs\": 155.26910400390625, \"slope\": -0.07411891967058182, \"chain\": 1, \"draw\": 177}, {\"draws\": 377, \"mouse\": 7, \"mu_intercept_per_group\": 8.867799758911133, \"sigma_intercept_per_group\": 0.19154083728790283, \"sigma_obs\": 155.26910400390625, \"slope\": -0.07411891967058182, \"chain\": 1, \"draw\": 177}, {\"draws\": 378, \"mouse\": 0, \"mu_intercept_per_group\": 12.656946182250977, \"sigma_intercept_per_group\": 0.19436922669410706, \"sigma_obs\": 156.11849975585938, \"slope\": -0.07443562150001526, \"chain\": 1, \"draw\": 178}, {\"draws\": 378, \"mouse\": 1, \"mu_intercept_per_group\": 12.4667329788208, \"sigma_intercept_per_group\": 0.19436922669410706, \"sigma_obs\": 156.11849975585938, \"slope\": -0.07443562150001526, \"chain\": 1, \"draw\": 178}, {\"draws\": 378, \"mouse\": 2, \"mu_intercept_per_group\": 11.596043586730957, \"sigma_intercept_per_group\": 0.19436922669410706, \"sigma_obs\": 156.11849975585938, \"slope\": -0.07443562150001526, \"chain\": 1, \"draw\": 178}, {\"draws\": 378, \"mouse\": 3, \"mu_intercept_per_group\": 11.388028144836426, \"sigma_intercept_per_group\": 0.19436922669410706, \"sigma_obs\": 156.11849975585938, \"slope\": -0.07443562150001526, \"chain\": 1, \"draw\": 178}, {\"draws\": 378, \"mouse\": 4, \"mu_intercept_per_group\": 10.801067352294922, \"sigma_intercept_per_group\": 0.19436922669410706, \"sigma_obs\": 156.11849975585938, \"slope\": -0.07443562150001526, \"chain\": 1, \"draw\": 178}, {\"draws\": 378, \"mouse\": 5, \"mu_intercept_per_group\": 10.287583351135254, \"sigma_intercept_per_group\": 0.19436922669410706, \"sigma_obs\": 156.11849975585938, \"slope\": -0.07443562150001526, \"chain\": 1, \"draw\": 178}, {\"draws\": 378, \"mouse\": 6, \"mu_intercept_per_group\": 9.370577812194824, \"sigma_intercept_per_group\": 0.19436922669410706, \"sigma_obs\": 156.11849975585938, \"slope\": -0.07443562150001526, \"chain\": 1, \"draw\": 178}, {\"draws\": 378, \"mouse\": 7, \"mu_intercept_per_group\": 9.113391876220703, \"sigma_intercept_per_group\": 0.19436922669410706, \"sigma_obs\": 156.11849975585938, \"slope\": -0.07443562150001526, \"chain\": 1, \"draw\": 178}, {\"draws\": 379, \"mouse\": 0, \"mu_intercept_per_group\": 12.7953462600708, \"sigma_intercept_per_group\": 0.19433347880840302, \"sigma_obs\": 156.33885192871094, \"slope\": -0.07479564100503922, \"chain\": 1, \"draw\": 179}, {\"draws\": 379, \"mouse\": 1, \"mu_intercept_per_group\": 12.315389633178711, \"sigma_intercept_per_group\": 0.19433347880840302, \"sigma_obs\": 156.33885192871094, \"slope\": -0.07479564100503922, \"chain\": 1, \"draw\": 179}, {\"draws\": 379, \"mouse\": 2, \"mu_intercept_per_group\": 11.614874839782715, \"sigma_intercept_per_group\": 0.19433347880840302, \"sigma_obs\": 156.33885192871094, \"slope\": -0.07479564100503922, \"chain\": 1, \"draw\": 179}, {\"draws\": 379, \"mouse\": 3, \"mu_intercept_per_group\": 11.41845417022705, \"sigma_intercept_per_group\": 0.19433347880840302, \"sigma_obs\": 156.33885192871094, \"slope\": -0.07479564100503922, \"chain\": 1, \"draw\": 179}, {\"draws\": 379, \"mouse\": 4, \"mu_intercept_per_group\": 10.740232467651367, \"sigma_intercept_per_group\": 0.19433347880840302, \"sigma_obs\": 156.33885192871094, \"slope\": -0.07479564100503922, \"chain\": 1, \"draw\": 179}, {\"draws\": 379, \"mouse\": 5, \"mu_intercept_per_group\": 10.244901657104492, \"sigma_intercept_per_group\": 0.19433347880840302, \"sigma_obs\": 156.33885192871094, \"slope\": -0.07479564100503922, \"chain\": 1, \"draw\": 179}, {\"draws\": 379, \"mouse\": 6, \"mu_intercept_per_group\": 9.240859031677246, \"sigma_intercept_per_group\": 0.19433347880840302, \"sigma_obs\": 156.33885192871094, \"slope\": -0.07479564100503922, \"chain\": 1, \"draw\": 179}, {\"draws\": 379, \"mouse\": 7, \"mu_intercept_per_group\": 9.122730255126953, \"sigma_intercept_per_group\": 0.19433347880840302, \"sigma_obs\": 156.33885192871094, \"slope\": -0.07479564100503922, \"chain\": 1, \"draw\": 179}, {\"draws\": 380, \"mouse\": 0, \"mu_intercept_per_group\": 12.537094116210938, \"sigma_intercept_per_group\": 0.19546842575073242, \"sigma_obs\": 155.02615356445312, \"slope\": -0.0789605900645256, \"chain\": 1, \"draw\": 180}, {\"draws\": 380, \"mouse\": 1, \"mu_intercept_per_group\": 12.060355186462402, \"sigma_intercept_per_group\": 0.19546842575073242, \"sigma_obs\": 155.02615356445312, \"slope\": -0.0789605900645256, \"chain\": 1, \"draw\": 180}, {\"draws\": 380, \"mouse\": 2, \"mu_intercept_per_group\": 11.88012409210205, \"sigma_intercept_per_group\": 0.19546842575073242, \"sigma_obs\": 155.02615356445312, \"slope\": -0.0789605900645256, \"chain\": 1, \"draw\": 180}, {\"draws\": 380, \"mouse\": 3, \"mu_intercept_per_group\": 10.83531379699707, \"sigma_intercept_per_group\": 0.19546842575073242, \"sigma_obs\": 155.02615356445312, \"slope\": -0.0789605900645256, \"chain\": 1, \"draw\": 180}, {\"draws\": 380, \"mouse\": 4, \"mu_intercept_per_group\": 10.912355422973633, \"sigma_intercept_per_group\": 0.19546842575073242, \"sigma_obs\": 155.02615356445312, \"slope\": -0.0789605900645256, \"chain\": 1, \"draw\": 180}, {\"draws\": 380, \"mouse\": 5, \"mu_intercept_per_group\": 10.18154525756836, \"sigma_intercept_per_group\": 0.19546842575073242, \"sigma_obs\": 155.02615356445312, \"slope\": -0.0789605900645256, \"chain\": 1, \"draw\": 180}, {\"draws\": 380, \"mouse\": 6, \"mu_intercept_per_group\": 9.929411888122559, \"sigma_intercept_per_group\": 0.19546842575073242, \"sigma_obs\": 155.02615356445312, \"slope\": -0.0789605900645256, \"chain\": 1, \"draw\": 180}, {\"draws\": 380, \"mouse\": 7, \"mu_intercept_per_group\": 9.049249649047852, \"sigma_intercept_per_group\": 0.19546842575073242, \"sigma_obs\": 155.02615356445312, \"slope\": -0.0789605900645256, \"chain\": 1, \"draw\": 180}, {\"draws\": 381, \"mouse\": 0, \"mu_intercept_per_group\": 12.497556686401367, \"sigma_intercept_per_group\": 0.19743938744068146, \"sigma_obs\": 155.72979736328125, \"slope\": -0.08135275542736053, \"chain\": 1, \"draw\": 181}, {\"draws\": 381, \"mouse\": 1, \"mu_intercept_per_group\": 12.12718677520752, \"sigma_intercept_per_group\": 0.19743938744068146, \"sigma_obs\": 155.72979736328125, \"slope\": -0.08135275542736053, \"chain\": 1, \"draw\": 181}, {\"draws\": 381, \"mouse\": 2, \"mu_intercept_per_group\": 11.601325035095215, \"sigma_intercept_per_group\": 0.19743938744068146, \"sigma_obs\": 155.72979736328125, \"slope\": -0.08135275542736053, \"chain\": 1, \"draw\": 181}, {\"draws\": 381, \"mouse\": 3, \"mu_intercept_per_group\": 11.277591705322266, \"sigma_intercept_per_group\": 0.19743938744068146, \"sigma_obs\": 155.72979736328125, \"slope\": -0.08135275542736053, \"chain\": 1, \"draw\": 181}, {\"draws\": 381, \"mouse\": 4, \"mu_intercept_per_group\": 10.727303504943848, \"sigma_intercept_per_group\": 0.19743938744068146, \"sigma_obs\": 155.72979736328125, \"slope\": -0.08135275542736053, \"chain\": 1, \"draw\": 181}, {\"draws\": 381, \"mouse\": 5, \"mu_intercept_per_group\": 9.942352294921875, \"sigma_intercept_per_group\": 0.19743938744068146, \"sigma_obs\": 155.72979736328125, \"slope\": -0.08135275542736053, \"chain\": 1, \"draw\": 181}, {\"draws\": 381, \"mouse\": 6, \"mu_intercept_per_group\": 9.03083610534668, \"sigma_intercept_per_group\": 0.19743938744068146, \"sigma_obs\": 155.72979736328125, \"slope\": -0.08135275542736053, \"chain\": 1, \"draw\": 181}, {\"draws\": 381, \"mouse\": 7, \"mu_intercept_per_group\": 9.100761413574219, \"sigma_intercept_per_group\": 0.19743938744068146, \"sigma_obs\": 155.72979736328125, \"slope\": -0.08135275542736053, \"chain\": 1, \"draw\": 181}, {\"draws\": 382, \"mouse\": 0, \"mu_intercept_per_group\": 12.489059448242188, \"sigma_intercept_per_group\": 0.19780631363391876, \"sigma_obs\": 155.4095458984375, \"slope\": -0.08183284848928452, \"chain\": 1, \"draw\": 182}, {\"draws\": 382, \"mouse\": 1, \"mu_intercept_per_group\": 12.17947006225586, \"sigma_intercept_per_group\": 0.19780631363391876, \"sigma_obs\": 155.4095458984375, \"slope\": -0.08183284848928452, \"chain\": 1, \"draw\": 182}, {\"draws\": 382, \"mouse\": 2, \"mu_intercept_per_group\": 11.853824615478516, \"sigma_intercept_per_group\": 0.19780631363391876, \"sigma_obs\": 155.4095458984375, \"slope\": -0.08183284848928452, \"chain\": 1, \"draw\": 182}, {\"draws\": 382, \"mouse\": 3, \"mu_intercept_per_group\": 10.985800743103027, \"sigma_intercept_per_group\": 0.19780631363391876, \"sigma_obs\": 155.4095458984375, \"slope\": -0.08183284848928452, \"chain\": 1, \"draw\": 182}, {\"draws\": 382, \"mouse\": 4, \"mu_intercept_per_group\": 10.56196117401123, \"sigma_intercept_per_group\": 0.19780631363391876, \"sigma_obs\": 155.4095458984375, \"slope\": -0.08183284848928452, \"chain\": 1, \"draw\": 182}, {\"draws\": 382, \"mouse\": 5, \"mu_intercept_per_group\": 10.056319236755371, \"sigma_intercept_per_group\": 0.19780631363391876, \"sigma_obs\": 155.4095458984375, \"slope\": -0.08183284848928452, \"chain\": 1, \"draw\": 182}, {\"draws\": 382, \"mouse\": 6, \"mu_intercept_per_group\": 9.01395320892334, \"sigma_intercept_per_group\": 0.19780631363391876, \"sigma_obs\": 155.4095458984375, \"slope\": -0.08183284848928452, \"chain\": 1, \"draw\": 182}, {\"draws\": 382, \"mouse\": 7, \"mu_intercept_per_group\": 9.161755561828613, \"sigma_intercept_per_group\": 0.19780631363391876, \"sigma_obs\": 155.4095458984375, \"slope\": -0.08183284848928452, \"chain\": 1, \"draw\": 182}, {\"draws\": 383, \"mouse\": 0, \"mu_intercept_per_group\": 12.450019836425781, \"sigma_intercept_per_group\": 0.19986002147197723, \"sigma_obs\": 155.46432495117188, \"slope\": -0.08156628161668777, \"chain\": 1, \"draw\": 183}, {\"draws\": 383, \"mouse\": 1, \"mu_intercept_per_group\": 11.859177589416504, \"sigma_intercept_per_group\": 0.19986002147197723, \"sigma_obs\": 155.46432495117188, \"slope\": -0.08156628161668777, \"chain\": 1, \"draw\": 183}, {\"draws\": 383, \"mouse\": 2, \"mu_intercept_per_group\": 11.41866397857666, \"sigma_intercept_per_group\": 0.19986002147197723, \"sigma_obs\": 155.46432495117188, \"slope\": -0.08156628161668777, \"chain\": 1, \"draw\": 183}, {\"draws\": 383, \"mouse\": 3, \"mu_intercept_per_group\": 11.12281322479248, \"sigma_intercept_per_group\": 0.19986002147197723, \"sigma_obs\": 155.46432495117188, \"slope\": -0.08156628161668777, \"chain\": 1, \"draw\": 183}, {\"draws\": 383, \"mouse\": 4, \"mu_intercept_per_group\": 10.692384719848633, \"sigma_intercept_per_group\": 0.19986002147197723, \"sigma_obs\": 155.46432495117188, \"slope\": -0.08156628161668777, \"chain\": 1, \"draw\": 183}, {\"draws\": 383, \"mouse\": 5, \"mu_intercept_per_group\": 10.338139533996582, \"sigma_intercept_per_group\": 0.19986002147197723, \"sigma_obs\": 155.46432495117188, \"slope\": -0.08156628161668777, \"chain\": 1, \"draw\": 183}, {\"draws\": 383, \"mouse\": 6, \"mu_intercept_per_group\": 9.525213241577148, \"sigma_intercept_per_group\": 0.19986002147197723, \"sigma_obs\": 155.46432495117188, \"slope\": -0.08156628161668777, \"chain\": 1, \"draw\": 183}, {\"draws\": 383, \"mouse\": 7, \"mu_intercept_per_group\": 8.317643165588379, \"sigma_intercept_per_group\": 0.19986002147197723, \"sigma_obs\": 155.46432495117188, \"slope\": -0.08156628161668777, \"chain\": 1, \"draw\": 183}, {\"draws\": 384, \"mouse\": 0, \"mu_intercept_per_group\": 12.37799072265625, \"sigma_intercept_per_group\": 0.19335003197193146, \"sigma_obs\": 149.31884765625, \"slope\": -0.08075529336929321, \"chain\": 1, \"draw\": 184}, {\"draws\": 384, \"mouse\": 1, \"mu_intercept_per_group\": 11.81569766998291, \"sigma_intercept_per_group\": 0.19335003197193146, \"sigma_obs\": 149.31884765625, \"slope\": -0.08075529336929321, \"chain\": 1, \"draw\": 184}, {\"draws\": 384, \"mouse\": 2, \"mu_intercept_per_group\": 11.838033676147461, \"sigma_intercept_per_group\": 0.19335003197193146, \"sigma_obs\": 149.31884765625, \"slope\": -0.08075529336929321, \"chain\": 1, \"draw\": 184}, {\"draws\": 384, \"mouse\": 3, \"mu_intercept_per_group\": 10.954232215881348, \"sigma_intercept_per_group\": 0.19335003197193146, \"sigma_obs\": 149.31884765625, \"slope\": -0.08075529336929321, \"chain\": 1, \"draw\": 184}, {\"draws\": 384, \"mouse\": 4, \"mu_intercept_per_group\": 10.596997261047363, \"sigma_intercept_per_group\": 0.19335003197193146, \"sigma_obs\": 149.31884765625, \"slope\": -0.08075529336929321, \"chain\": 1, \"draw\": 184}, {\"draws\": 384, \"mouse\": 5, \"mu_intercept_per_group\": 9.6729154586792, \"sigma_intercept_per_group\": 0.19335003197193146, \"sigma_obs\": 149.31884765625, \"slope\": -0.08075529336929321, \"chain\": 1, \"draw\": 184}, {\"draws\": 384, \"mouse\": 6, \"mu_intercept_per_group\": 9.065829277038574, \"sigma_intercept_per_group\": 0.19335003197193146, \"sigma_obs\": 149.31884765625, \"slope\": -0.08075529336929321, \"chain\": 1, \"draw\": 184}, {\"draws\": 384, \"mouse\": 7, \"mu_intercept_per_group\": 9.404691696166992, \"sigma_intercept_per_group\": 0.19335003197193146, \"sigma_obs\": 149.31884765625, \"slope\": -0.08075529336929321, \"chain\": 1, \"draw\": 184}, {\"draws\": 385, \"mouse\": 0, \"mu_intercept_per_group\": 12.883316993713379, \"sigma_intercept_per_group\": 0.18860268592834473, \"sigma_obs\": 154.22743225097656, \"slope\": -0.0811733677983284, \"chain\": 1, \"draw\": 185}, {\"draws\": 385, \"mouse\": 1, \"mu_intercept_per_group\": 12.363544464111328, \"sigma_intercept_per_group\": 0.18860268592834473, \"sigma_obs\": 154.22743225097656, \"slope\": -0.0811733677983284, \"chain\": 1, \"draw\": 185}, {\"draws\": 385, \"mouse\": 2, \"mu_intercept_per_group\": 12.040763854980469, \"sigma_intercept_per_group\": 0.18860268592834473, \"sigma_obs\": 154.22743225097656, \"slope\": -0.0811733677983284, \"chain\": 1, \"draw\": 185}, {\"draws\": 385, \"mouse\": 3, \"mu_intercept_per_group\": 11.50536823272705, \"sigma_intercept_per_group\": 0.18860268592834473, \"sigma_obs\": 154.22743225097656, \"slope\": -0.0811733677983284, \"chain\": 1, \"draw\": 185}, {\"draws\": 385, \"mouse\": 4, \"mu_intercept_per_group\": 11.060718536376953, \"sigma_intercept_per_group\": 0.18860268592834473, \"sigma_obs\": 154.22743225097656, \"slope\": -0.0811733677983284, \"chain\": 1, \"draw\": 185}, {\"draws\": 385, \"mouse\": 5, \"mu_intercept_per_group\": 10.751811981201172, \"sigma_intercept_per_group\": 0.18860268592834473, \"sigma_obs\": 154.22743225097656, \"slope\": -0.0811733677983284, \"chain\": 1, \"draw\": 185}, {\"draws\": 385, \"mouse\": 6, \"mu_intercept_per_group\": 9.790292739868164, \"sigma_intercept_per_group\": 0.18860268592834473, \"sigma_obs\": 154.22743225097656, \"slope\": -0.0811733677983284, \"chain\": 1, \"draw\": 185}, {\"draws\": 385, \"mouse\": 7, \"mu_intercept_per_group\": 8.557805061340332, \"sigma_intercept_per_group\": 0.18860268592834473, \"sigma_obs\": 154.22743225097656, \"slope\": -0.0811733677983284, \"chain\": 1, \"draw\": 185}, {\"draws\": 386, \"mouse\": 0, \"mu_intercept_per_group\": 12.934347152709961, \"sigma_intercept_per_group\": 0.19038672745227814, \"sigma_obs\": 153.0908660888672, \"slope\": -0.08357714116573334, \"chain\": 1, \"draw\": 186}, {\"draws\": 386, \"mouse\": 1, \"mu_intercept_per_group\": 12.429522514343262, \"sigma_intercept_per_group\": 0.19038672745227814, \"sigma_obs\": 153.0908660888672, \"slope\": -0.08357714116573334, \"chain\": 1, \"draw\": 186}, {\"draws\": 386, \"mouse\": 2, \"mu_intercept_per_group\": 12.391849517822266, \"sigma_intercept_per_group\": 0.19038672745227814, \"sigma_obs\": 153.0908660888672, \"slope\": -0.08357714116573334, \"chain\": 1, \"draw\": 186}, {\"draws\": 386, \"mouse\": 3, \"mu_intercept_per_group\": 11.151676177978516, \"sigma_intercept_per_group\": 0.19038672745227814, \"sigma_obs\": 153.0908660888672, \"slope\": -0.08357714116573334, \"chain\": 1, \"draw\": 186}, {\"draws\": 386, \"mouse\": 4, \"mu_intercept_per_group\": 11.435468673706055, \"sigma_intercept_per_group\": 0.19038672745227814, \"sigma_obs\": 153.0908660888672, \"slope\": -0.08357714116573334, \"chain\": 1, \"draw\": 186}, {\"draws\": 386, \"mouse\": 5, \"mu_intercept_per_group\": 10.58168888092041, \"sigma_intercept_per_group\": 0.19038672745227814, \"sigma_obs\": 153.0908660888672, \"slope\": -0.08357714116573334, \"chain\": 1, \"draw\": 186}, {\"draws\": 386, \"mouse\": 6, \"mu_intercept_per_group\": 9.903373718261719, \"sigma_intercept_per_group\": 0.19038672745227814, \"sigma_obs\": 153.0908660888672, \"slope\": -0.08357714116573334, \"chain\": 1, \"draw\": 186}, {\"draws\": 386, \"mouse\": 7, \"mu_intercept_per_group\": 8.993569374084473, \"sigma_intercept_per_group\": 0.19038672745227814, \"sigma_obs\": 153.0908660888672, \"slope\": -0.08357714116573334, \"chain\": 1, \"draw\": 186}, {\"draws\": 387, \"mouse\": 0, \"mu_intercept_per_group\": 13.468652725219727, \"sigma_intercept_per_group\": 0.1881278157234192, \"sigma_obs\": 158.40794372558594, \"slope\": -0.08018859475851059, \"chain\": 1, \"draw\": 187}, {\"draws\": 387, \"mouse\": 1, \"mu_intercept_per_group\": 12.622488021850586, \"sigma_intercept_per_group\": 0.1881278157234192, \"sigma_obs\": 158.40794372558594, \"slope\": -0.08018859475851059, \"chain\": 1, \"draw\": 187}, {\"draws\": 387, \"mouse\": 2, \"mu_intercept_per_group\": 12.556891441345215, \"sigma_intercept_per_group\": 0.1881278157234192, \"sigma_obs\": 158.40794372558594, \"slope\": -0.08018859475851059, \"chain\": 1, \"draw\": 187}, {\"draws\": 387, \"mouse\": 3, \"mu_intercept_per_group\": 11.384284973144531, \"sigma_intercept_per_group\": 0.1881278157234192, \"sigma_obs\": 158.40794372558594, \"slope\": -0.08018859475851059, \"chain\": 1, \"draw\": 187}, {\"draws\": 387, \"mouse\": 4, \"mu_intercept_per_group\": 11.680924415588379, \"sigma_intercept_per_group\": 0.1881278157234192, \"sigma_obs\": 158.40794372558594, \"slope\": -0.08018859475851059, \"chain\": 1, \"draw\": 187}, {\"draws\": 387, \"mouse\": 5, \"mu_intercept_per_group\": 10.891386032104492, \"sigma_intercept_per_group\": 0.1881278157234192, \"sigma_obs\": 158.40794372558594, \"slope\": -0.08018859475851059, \"chain\": 1, \"draw\": 187}, {\"draws\": 387, \"mouse\": 6, \"mu_intercept_per_group\": 9.8121919631958, \"sigma_intercept_per_group\": 0.1881278157234192, \"sigma_obs\": 158.40794372558594, \"slope\": -0.08018859475851059, \"chain\": 1, \"draw\": 187}, {\"draws\": 387, \"mouse\": 7, \"mu_intercept_per_group\": 9.639166831970215, \"sigma_intercept_per_group\": 0.1881278157234192, \"sigma_obs\": 158.40794372558594, \"slope\": -0.08018859475851059, \"chain\": 1, \"draw\": 187}, {\"draws\": 388, \"mouse\": 0, \"mu_intercept_per_group\": 13.383336067199707, \"sigma_intercept_per_group\": 0.1857098937034607, \"sigma_obs\": 158.6779022216797, \"slope\": -0.07986912876367569, \"chain\": 1, \"draw\": 188}, {\"draws\": 388, \"mouse\": 1, \"mu_intercept_per_group\": 12.864226341247559, \"sigma_intercept_per_group\": 0.1857098937034607, \"sigma_obs\": 158.6779022216797, \"slope\": -0.07986912876367569, \"chain\": 1, \"draw\": 188}, {\"draws\": 388, \"mouse\": 2, \"mu_intercept_per_group\": 12.53146743774414, \"sigma_intercept_per_group\": 0.1857098937034607, \"sigma_obs\": 158.6779022216797, \"slope\": -0.07986912876367569, \"chain\": 1, \"draw\": 188}, {\"draws\": 388, \"mouse\": 3, \"mu_intercept_per_group\": 11.143710136413574, \"sigma_intercept_per_group\": 0.1857098937034607, \"sigma_obs\": 158.6779022216797, \"slope\": -0.07986912876367569, \"chain\": 1, \"draw\": 188}, {\"draws\": 388, \"mouse\": 4, \"mu_intercept_per_group\": 11.503098487854004, \"sigma_intercept_per_group\": 0.1857098937034607, \"sigma_obs\": 158.6779022216797, \"slope\": -0.07986912876367569, \"chain\": 1, \"draw\": 188}, {\"draws\": 388, \"mouse\": 5, \"mu_intercept_per_group\": 10.806650161743164, \"sigma_intercept_per_group\": 0.1857098937034607, \"sigma_obs\": 158.6779022216797, \"slope\": -0.07986912876367569, \"chain\": 1, \"draw\": 188}, {\"draws\": 388, \"mouse\": 6, \"mu_intercept_per_group\": 10.021404266357422, \"sigma_intercept_per_group\": 0.1857098937034607, \"sigma_obs\": 158.6779022216797, \"slope\": -0.07986912876367569, \"chain\": 1, \"draw\": 188}, {\"draws\": 388, \"mouse\": 7, \"mu_intercept_per_group\": 9.69623851776123, \"sigma_intercept_per_group\": 0.1857098937034607, \"sigma_obs\": 158.6779022216797, \"slope\": -0.07986912876367569, \"chain\": 1, \"draw\": 188}, {\"draws\": 389, \"mouse\": 0, \"mu_intercept_per_group\": 16.03046226501465, \"sigma_intercept_per_group\": 0.1550503522157669, \"sigma_obs\": 156.25479125976562, \"slope\": -0.09531330317258835, \"chain\": 1, \"draw\": 189}, {\"draws\": 389, \"mouse\": 1, \"mu_intercept_per_group\": 15.258575439453125, \"sigma_intercept_per_group\": 0.1550503522157669, \"sigma_obs\": 156.25479125976562, \"slope\": -0.09531330317258835, \"chain\": 1, \"draw\": 189}, {\"draws\": 389, \"mouse\": 2, \"mu_intercept_per_group\": 14.96428394317627, \"sigma_intercept_per_group\": 0.1550503522157669, \"sigma_obs\": 156.25479125976562, \"slope\": -0.09531330317258835, \"chain\": 1, \"draw\": 189}, {\"draws\": 389, \"mouse\": 3, \"mu_intercept_per_group\": 14.02058219909668, \"sigma_intercept_per_group\": 0.1550503522157669, \"sigma_obs\": 156.25479125976562, \"slope\": -0.09531330317258835, \"chain\": 1, \"draw\": 189}, {\"draws\": 389, \"mouse\": 4, \"mu_intercept_per_group\": 14.16817855834961, \"sigma_intercept_per_group\": 0.1550503522157669, \"sigma_obs\": 156.25479125976562, \"slope\": -0.09531330317258835, \"chain\": 1, \"draw\": 189}, {\"draws\": 389, \"mouse\": 5, \"mu_intercept_per_group\": 12.984156608581543, \"sigma_intercept_per_group\": 0.1550503522157669, \"sigma_obs\": 156.25479125976562, \"slope\": -0.09531330317258835, \"chain\": 1, \"draw\": 189}, {\"draws\": 389, \"mouse\": 6, \"mu_intercept_per_group\": 12.250389099121094, \"sigma_intercept_per_group\": 0.1550503522157669, \"sigma_obs\": 156.25479125976562, \"slope\": -0.09531330317258835, \"chain\": 1, \"draw\": 189}, {\"draws\": 389, \"mouse\": 7, \"mu_intercept_per_group\": 11.9334716796875, \"sigma_intercept_per_group\": 0.1550503522157669, \"sigma_obs\": 156.25479125976562, \"slope\": -0.09531330317258835, \"chain\": 1, \"draw\": 189}, {\"draws\": 390, \"mouse\": 0, \"mu_intercept_per_group\": 14.005534172058105, \"sigma_intercept_per_group\": 0.17783060669898987, \"sigma_obs\": 152.8268280029297, \"slope\": -0.0843115970492363, \"chain\": 1, \"draw\": 190}, {\"draws\": 390, \"mouse\": 1, \"mu_intercept_per_group\": 13.142993927001953, \"sigma_intercept_per_group\": 0.17783060669898987, \"sigma_obs\": 152.8268280029297, \"slope\": -0.0843115970492363, \"chain\": 1, \"draw\": 190}, {\"draws\": 390, \"mouse\": 2, \"mu_intercept_per_group\": 13.0439453125, \"sigma_intercept_per_group\": 0.17783060669898987, \"sigma_obs\": 152.8268280029297, \"slope\": -0.0843115970492363, \"chain\": 1, \"draw\": 190}, {\"draws\": 390, \"mouse\": 3, \"mu_intercept_per_group\": 12.168203353881836, \"sigma_intercept_per_group\": 0.17783060669898987, \"sigma_obs\": 152.8268280029297, \"slope\": -0.0843115970492363, \"chain\": 1, \"draw\": 190}, {\"draws\": 390, \"mouse\": 4, \"mu_intercept_per_group\": 11.728386878967285, \"sigma_intercept_per_group\": 0.17783060669898987, \"sigma_obs\": 152.8268280029297, \"slope\": -0.0843115970492363, \"chain\": 1, \"draw\": 190}, {\"draws\": 390, \"mouse\": 5, \"mu_intercept_per_group\": 11.032597541809082, \"sigma_intercept_per_group\": 0.17783060669898987, \"sigma_obs\": 152.8268280029297, \"slope\": -0.0843115970492363, \"chain\": 1, \"draw\": 190}, {\"draws\": 390, \"mouse\": 6, \"mu_intercept_per_group\": 10.546845436096191, \"sigma_intercept_per_group\": 0.17783060669898987, \"sigma_obs\": 152.8268280029297, \"slope\": -0.0843115970492363, \"chain\": 1, \"draw\": 190}, {\"draws\": 390, \"mouse\": 7, \"mu_intercept_per_group\": 9.589110374450684, \"sigma_intercept_per_group\": 0.17783060669898987, \"sigma_obs\": 152.8268280029297, \"slope\": -0.0843115970492363, \"chain\": 1, \"draw\": 190}, {\"draws\": 391, \"mouse\": 0, \"mu_intercept_per_group\": 13.582708358764648, \"sigma_intercept_per_group\": 0.1779867261648178, \"sigma_obs\": 151.39288330078125, \"slope\": -0.08408652245998383, \"chain\": 1, \"draw\": 191}, {\"draws\": 391, \"mouse\": 1, \"mu_intercept_per_group\": 13.455455780029297, \"sigma_intercept_per_group\": 0.1779867261648178, \"sigma_obs\": 151.39288330078125, \"slope\": -0.08408652245998383, \"chain\": 1, \"draw\": 191}, {\"draws\": 391, \"mouse\": 2, \"mu_intercept_per_group\": 12.620955467224121, \"sigma_intercept_per_group\": 0.1779867261648178, \"sigma_obs\": 151.39288330078125, \"slope\": -0.08408652245998383, \"chain\": 1, \"draw\": 191}, {\"draws\": 391, \"mouse\": 3, \"mu_intercept_per_group\": 12.083989143371582, \"sigma_intercept_per_group\": 0.1779867261648178, \"sigma_obs\": 151.39288330078125, \"slope\": -0.08408652245998383, \"chain\": 1, \"draw\": 191}, {\"draws\": 391, \"mouse\": 4, \"mu_intercept_per_group\": 11.998888969421387, \"sigma_intercept_per_group\": 0.1779867261648178, \"sigma_obs\": 151.39288330078125, \"slope\": -0.08408652245998383, \"chain\": 1, \"draw\": 191}, {\"draws\": 391, \"mouse\": 5, \"mu_intercept_per_group\": 10.87841510772705, \"sigma_intercept_per_group\": 0.1779867261648178, \"sigma_obs\": 151.39288330078125, \"slope\": -0.08408652245998383, \"chain\": 1, \"draw\": 191}, {\"draws\": 391, \"mouse\": 6, \"mu_intercept_per_group\": 9.941411018371582, \"sigma_intercept_per_group\": 0.1779867261648178, \"sigma_obs\": 151.39288330078125, \"slope\": -0.08408652245998383, \"chain\": 1, \"draw\": 191}, {\"draws\": 391, \"mouse\": 7, \"mu_intercept_per_group\": 9.882513999938965, \"sigma_intercept_per_group\": 0.1779867261648178, \"sigma_obs\": 151.39288330078125, \"slope\": -0.08408652245998383, \"chain\": 1, \"draw\": 191}, {\"draws\": 392, \"mouse\": 0, \"mu_intercept_per_group\": 13.166404724121094, \"sigma_intercept_per_group\": 0.18182706832885742, \"sigma_obs\": 153.4783935546875, \"slope\": -0.07679153233766556, \"chain\": 1, \"draw\": 192}, {\"draws\": 392, \"mouse\": 1, \"mu_intercept_per_group\": 13.145697593688965, \"sigma_intercept_per_group\": 0.18182706832885742, \"sigma_obs\": 153.4783935546875, \"slope\": -0.07679153233766556, \"chain\": 1, \"draw\": 192}, {\"draws\": 392, \"mouse\": 2, \"mu_intercept_per_group\": 12.600214004516602, \"sigma_intercept_per_group\": 0.18182706832885742, \"sigma_obs\": 153.4783935546875, \"slope\": -0.07679153233766556, \"chain\": 1, \"draw\": 192}, {\"draws\": 392, \"mouse\": 3, \"mu_intercept_per_group\": 11.849442481994629, \"sigma_intercept_per_group\": 0.18182706832885742, \"sigma_obs\": 153.4783935546875, \"slope\": -0.07679153233766556, \"chain\": 1, \"draw\": 192}, {\"draws\": 392, \"mouse\": 4, \"mu_intercept_per_group\": 11.249131202697754, \"sigma_intercept_per_group\": 0.18182706832885742, \"sigma_obs\": 153.4783935546875, \"slope\": -0.07679153233766556, \"chain\": 1, \"draw\": 192}, {\"draws\": 392, \"mouse\": 5, \"mu_intercept_per_group\": 11.124531745910645, \"sigma_intercept_per_group\": 0.18182706832885742, \"sigma_obs\": 153.4783935546875, \"slope\": -0.07679153233766556, \"chain\": 1, \"draw\": 192}, {\"draws\": 392, \"mouse\": 6, \"mu_intercept_per_group\": 10.594484329223633, \"sigma_intercept_per_group\": 0.18182706832885742, \"sigma_obs\": 153.4783935546875, \"slope\": -0.07679153233766556, \"chain\": 1, \"draw\": 192}, {\"draws\": 392, \"mouse\": 7, \"mu_intercept_per_group\": 9.512516021728516, \"sigma_intercept_per_group\": 0.18182706832885742, \"sigma_obs\": 153.4783935546875, \"slope\": -0.07679153233766556, \"chain\": 1, \"draw\": 192}, {\"draws\": 393, \"mouse\": 0, \"mu_intercept_per_group\": 13.487308502197266, \"sigma_intercept_per_group\": 0.17829427123069763, \"sigma_obs\": 156.47772216796875, \"slope\": -0.07788334786891937, \"chain\": 1, \"draw\": 193}, {\"draws\": 393, \"mouse\": 1, \"mu_intercept_per_group\": 13.463095664978027, \"sigma_intercept_per_group\": 0.17829427123069763, \"sigma_obs\": 156.47772216796875, \"slope\": -0.07788334786891937, \"chain\": 1, \"draw\": 193}, {\"draws\": 393, \"mouse\": 2, \"mu_intercept_per_group\": 12.876612663269043, \"sigma_intercept_per_group\": 0.17829427123069763, \"sigma_obs\": 156.47772216796875, \"slope\": -0.07788334786891937, \"chain\": 1, \"draw\": 193}, {\"draws\": 393, \"mouse\": 3, \"mu_intercept_per_group\": 12.272603988647461, \"sigma_intercept_per_group\": 0.17829427123069763, \"sigma_obs\": 156.47772216796875, \"slope\": -0.07788334786891937, \"chain\": 1, \"draw\": 193}, {\"draws\": 393, \"mouse\": 4, \"mu_intercept_per_group\": 11.942445755004883, \"sigma_intercept_per_group\": 0.17829427123069763, \"sigma_obs\": 156.47772216796875, \"slope\": -0.07788334786891937, \"chain\": 1, \"draw\": 193}, {\"draws\": 393, \"mouse\": 5, \"mu_intercept_per_group\": 11.020515441894531, \"sigma_intercept_per_group\": 0.17829427123069763, \"sigma_obs\": 156.47772216796875, \"slope\": -0.07788334786891937, \"chain\": 1, \"draw\": 193}, {\"draws\": 393, \"mouse\": 6, \"mu_intercept_per_group\": 10.314573287963867, \"sigma_intercept_per_group\": 0.17829427123069763, \"sigma_obs\": 156.47772216796875, \"slope\": -0.07788334786891937, \"chain\": 1, \"draw\": 193}, {\"draws\": 393, \"mouse\": 7, \"mu_intercept_per_group\": 10.356409072875977, \"sigma_intercept_per_group\": 0.17829427123069763, \"sigma_obs\": 156.47772216796875, \"slope\": -0.07788334786891937, \"chain\": 1, \"draw\": 193}, {\"draws\": 394, \"mouse\": 0, \"mu_intercept_per_group\": 12.767130851745605, \"sigma_intercept_per_group\": 0.19623038172721863, \"sigma_obs\": 168.7848663330078, \"slope\": -0.07269217818975449, \"chain\": 1, \"draw\": 194}, {\"draws\": 394, \"mouse\": 1, \"mu_intercept_per_group\": 12.362947463989258, \"sigma_intercept_per_group\": 0.19623038172721863, \"sigma_obs\": 168.7848663330078, \"slope\": -0.07269217818975449, \"chain\": 1, \"draw\": 194}, {\"draws\": 394, \"mouse\": 2, \"mu_intercept_per_group\": 12.188924789428711, \"sigma_intercept_per_group\": 0.19623038172721863, \"sigma_obs\": 168.7848663330078, \"slope\": -0.07269217818975449, \"chain\": 1, \"draw\": 194}, {\"draws\": 394, \"mouse\": 3, \"mu_intercept_per_group\": 11.220755577087402, \"sigma_intercept_per_group\": 0.19623038172721863, \"sigma_obs\": 168.7848663330078, \"slope\": -0.07269217818975449, \"chain\": 1, \"draw\": 194}, {\"draws\": 394, \"mouse\": 4, \"mu_intercept_per_group\": 11.336852073669434, \"sigma_intercept_per_group\": 0.19623038172721863, \"sigma_obs\": 168.7848663330078, \"slope\": -0.07269217818975449, \"chain\": 1, \"draw\": 194}, {\"draws\": 394, \"mouse\": 5, \"mu_intercept_per_group\": 10.477126121520996, \"sigma_intercept_per_group\": 0.19623038172721863, \"sigma_obs\": 168.7848663330078, \"slope\": -0.07269217818975449, \"chain\": 1, \"draw\": 194}, {\"draws\": 394, \"mouse\": 6, \"mu_intercept_per_group\": 9.810073852539062, \"sigma_intercept_per_group\": 0.19623038172721863, \"sigma_obs\": 168.7848663330078, \"slope\": -0.07269217818975449, \"chain\": 1, \"draw\": 194}, {\"draws\": 394, \"mouse\": 7, \"mu_intercept_per_group\": 8.935006141662598, \"sigma_intercept_per_group\": 0.19623038172721863, \"sigma_obs\": 168.7848663330078, \"slope\": -0.07269217818975449, \"chain\": 1, \"draw\": 194}, {\"draws\": 395, \"mouse\": 0, \"mu_intercept_per_group\": 12.690834045410156, \"sigma_intercept_per_group\": 0.1985475718975067, \"sigma_obs\": 170.1644744873047, \"slope\": -0.07111567258834839, \"chain\": 1, \"draw\": 195}, {\"draws\": 395, \"mouse\": 1, \"mu_intercept_per_group\": 12.46633529663086, \"sigma_intercept_per_group\": 0.1985475718975067, \"sigma_obs\": 170.1644744873047, \"slope\": -0.07111567258834839, \"chain\": 1, \"draw\": 195}, {\"draws\": 395, \"mouse\": 2, \"mu_intercept_per_group\": 11.70811653137207, \"sigma_intercept_per_group\": 0.1985475718975067, \"sigma_obs\": 170.1644744873047, \"slope\": -0.07111567258834839, \"chain\": 1, \"draw\": 195}, {\"draws\": 395, \"mouse\": 3, \"mu_intercept_per_group\": 11.392850875854492, \"sigma_intercept_per_group\": 0.1985475718975067, \"sigma_obs\": 170.1644744873047, \"slope\": -0.07111567258834839, \"chain\": 1, \"draw\": 195}, {\"draws\": 395, \"mouse\": 4, \"mu_intercept_per_group\": 10.722586631774902, \"sigma_intercept_per_group\": 0.1985475718975067, \"sigma_obs\": 170.1644744873047, \"slope\": -0.07111567258834839, \"chain\": 1, \"draw\": 195}, {\"draws\": 395, \"mouse\": 5, \"mu_intercept_per_group\": 10.370020866394043, \"sigma_intercept_per_group\": 0.1985475718975067, \"sigma_obs\": 170.1644744873047, \"slope\": -0.07111567258834839, \"chain\": 1, \"draw\": 195}, {\"draws\": 395, \"mouse\": 6, \"mu_intercept_per_group\": 9.603815078735352, \"sigma_intercept_per_group\": 0.1985475718975067, \"sigma_obs\": 170.1644744873047, \"slope\": -0.07111567258834839, \"chain\": 1, \"draw\": 195}, {\"draws\": 395, \"mouse\": 7, \"mu_intercept_per_group\": 9.309660911560059, \"sigma_intercept_per_group\": 0.1985475718975067, \"sigma_obs\": 170.1644744873047, \"slope\": -0.07111567258834839, \"chain\": 1, \"draw\": 195}, {\"draws\": 396, \"mouse\": 0, \"mu_intercept_per_group\": 12.64820671081543, \"sigma_intercept_per_group\": 0.19787049293518066, \"sigma_obs\": 170.51512145996094, \"slope\": -0.07129013538360596, \"chain\": 1, \"draw\": 196}, {\"draws\": 396, \"mouse\": 1, \"mu_intercept_per_group\": 12.492427825927734, \"sigma_intercept_per_group\": 0.19787049293518066, \"sigma_obs\": 170.51512145996094, \"slope\": -0.07129013538360596, \"chain\": 1, \"draw\": 196}, {\"draws\": 396, \"mouse\": 2, \"mu_intercept_per_group\": 11.596842765808105, \"sigma_intercept_per_group\": 0.19787049293518066, \"sigma_obs\": 170.51512145996094, \"slope\": -0.07129013538360596, \"chain\": 1, \"draw\": 196}, {\"draws\": 396, \"mouse\": 3, \"mu_intercept_per_group\": 11.418265342712402, \"sigma_intercept_per_group\": 0.19787049293518066, \"sigma_obs\": 170.51512145996094, \"slope\": -0.07129013538360596, \"chain\": 1, \"draw\": 196}, {\"draws\": 396, \"mouse\": 4, \"mu_intercept_per_group\": 10.735663414001465, \"sigma_intercept_per_group\": 0.19787049293518066, \"sigma_obs\": 170.51512145996094, \"slope\": -0.07129013538360596, \"chain\": 1, \"draw\": 196}, {\"draws\": 396, \"mouse\": 5, \"mu_intercept_per_group\": 10.380441665649414, \"sigma_intercept_per_group\": 0.19787049293518066, \"sigma_obs\": 170.51512145996094, \"slope\": -0.07129013538360596, \"chain\": 1, \"draw\": 196}, {\"draws\": 396, \"mouse\": 6, \"mu_intercept_per_group\": 9.553747177124023, \"sigma_intercept_per_group\": 0.19787049293518066, \"sigma_obs\": 170.51512145996094, \"slope\": -0.07129013538360596, \"chain\": 1, \"draw\": 196}, {\"draws\": 396, \"mouse\": 7, \"mu_intercept_per_group\": 9.242801666259766, \"sigma_intercept_per_group\": 0.19787049293518066, \"sigma_obs\": 170.51512145996094, \"slope\": -0.07129013538360596, \"chain\": 1, \"draw\": 196}, {\"draws\": 397, \"mouse\": 0, \"mu_intercept_per_group\": 12.824043273925781, \"sigma_intercept_per_group\": 0.19562679529190063, \"sigma_obs\": 170.07687377929688, \"slope\": -0.07028821110725403, \"chain\": 1, \"draw\": 197}, {\"draws\": 397, \"mouse\": 1, \"mu_intercept_per_group\": 12.014741897583008, \"sigma_intercept_per_group\": 0.19562679529190063, \"sigma_obs\": 170.07687377929688, \"slope\": -0.07028821110725403, \"chain\": 1, \"draw\": 197}, {\"draws\": 397, \"mouse\": 2, \"mu_intercept_per_group\": 11.6793212890625, \"sigma_intercept_per_group\": 0.19562679529190063, \"sigma_obs\": 170.07687377929688, \"slope\": -0.07028821110725403, \"chain\": 1, \"draw\": 197}, {\"draws\": 397, \"mouse\": 3, \"mu_intercept_per_group\": 11.078754425048828, \"sigma_intercept_per_group\": 0.19562679529190063, \"sigma_obs\": 170.07687377929688, \"slope\": -0.07028821110725403, \"chain\": 1, \"draw\": 197}, {\"draws\": 397, \"mouse\": 4, \"mu_intercept_per_group\": 11.310856819152832, \"sigma_intercept_per_group\": 0.19562679529190063, \"sigma_obs\": 170.07687377929688, \"slope\": -0.07028821110725403, \"chain\": 1, \"draw\": 197}, {\"draws\": 397, \"mouse\": 5, \"mu_intercept_per_group\": 10.744590759277344, \"sigma_intercept_per_group\": 0.19562679529190063, \"sigma_obs\": 170.07687377929688, \"slope\": -0.07028821110725403, \"chain\": 1, \"draw\": 197}, {\"draws\": 397, \"mouse\": 6, \"mu_intercept_per_group\": 9.98843002319336, \"sigma_intercept_per_group\": 0.19562679529190063, \"sigma_obs\": 170.07687377929688, \"slope\": -0.07028821110725403, \"chain\": 1, \"draw\": 197}, {\"draws\": 397, \"mouse\": 7, \"mu_intercept_per_group\": 9.413721084594727, \"sigma_intercept_per_group\": 0.19562679529190063, \"sigma_obs\": 170.07687377929688, \"slope\": -0.07028821110725403, \"chain\": 1, \"draw\": 197}, {\"draws\": 398, \"mouse\": 0, \"mu_intercept_per_group\": 12.926457405090332, \"sigma_intercept_per_group\": 0.197383850812912, \"sigma_obs\": 169.67063903808594, \"slope\": -0.07104787975549698, \"chain\": 1, \"draw\": 198}, {\"draws\": 398, \"mouse\": 1, \"mu_intercept_per_group\": 12.26836109161377, \"sigma_intercept_per_group\": 0.197383850812912, \"sigma_obs\": 169.67063903808594, \"slope\": -0.07104787975549698, \"chain\": 1, \"draw\": 198}, {\"draws\": 398, \"mouse\": 2, \"mu_intercept_per_group\": 11.874608039855957, \"sigma_intercept_per_group\": 0.197383850812912, \"sigma_obs\": 169.67063903808594, \"slope\": -0.07104787975549698, \"chain\": 1, \"draw\": 198}, {\"draws\": 398, \"mouse\": 3, \"mu_intercept_per_group\": 10.981867790222168, \"sigma_intercept_per_group\": 0.197383850812912, \"sigma_obs\": 169.67063903808594, \"slope\": -0.07104787975549698, \"chain\": 1, \"draw\": 198}, {\"draws\": 398, \"mouse\": 4, \"mu_intercept_per_group\": 11.322296142578125, \"sigma_intercept_per_group\": 0.197383850812912, \"sigma_obs\": 169.67063903808594, \"slope\": -0.07104787975549698, \"chain\": 1, \"draw\": 198}, {\"draws\": 398, \"mouse\": 5, \"mu_intercept_per_group\": 10.69482135772705, \"sigma_intercept_per_group\": 0.197383850812912, \"sigma_obs\": 169.67063903808594, \"slope\": -0.07104787975549698, \"chain\": 1, \"draw\": 198}, {\"draws\": 398, \"mouse\": 6, \"mu_intercept_per_group\": 9.950383186340332, \"sigma_intercept_per_group\": 0.197383850812912, \"sigma_obs\": 169.67063903808594, \"slope\": -0.07104787975549698, \"chain\": 1, \"draw\": 198}, {\"draws\": 398, \"mouse\": 7, \"mu_intercept_per_group\": 9.403265953063965, \"sigma_intercept_per_group\": 0.197383850812912, \"sigma_obs\": 169.67063903808594, \"slope\": -0.07104787975549698, \"chain\": 1, \"draw\": 198}, {\"draws\": 399, \"mouse\": 0, \"mu_intercept_per_group\": 12.796547889709473, \"sigma_intercept_per_group\": 0.19631730020046234, \"sigma_obs\": 168.92117309570312, \"slope\": -0.06710312515497208, \"chain\": 1, \"draw\": 199}, {\"draws\": 399, \"mouse\": 1, \"mu_intercept_per_group\": 12.476238250732422, \"sigma_intercept_per_group\": 0.19631730020046234, \"sigma_obs\": 168.92117309570312, \"slope\": -0.06710312515497208, \"chain\": 1, \"draw\": 199}, {\"draws\": 399, \"mouse\": 2, \"mu_intercept_per_group\": 12.109540939331055, \"sigma_intercept_per_group\": 0.19631730020046234, \"sigma_obs\": 168.92117309570312, \"slope\": -0.06710312515497208, \"chain\": 1, \"draw\": 199}, {\"draws\": 399, \"mouse\": 3, \"mu_intercept_per_group\": 11.644816398620605, \"sigma_intercept_per_group\": 0.19631730020046234, \"sigma_obs\": 168.92117309570312, \"slope\": -0.06710312515497208, \"chain\": 1, \"draw\": 199}, {\"draws\": 399, \"mouse\": 4, \"mu_intercept_per_group\": 11.078916549682617, \"sigma_intercept_per_group\": 0.19631730020046234, \"sigma_obs\": 168.92117309570312, \"slope\": -0.06710312515497208, \"chain\": 1, \"draw\": 199}, {\"draws\": 399, \"mouse\": 5, \"mu_intercept_per_group\": 10.28056812286377, \"sigma_intercept_per_group\": 0.19631730020046234, \"sigma_obs\": 168.92117309570312, \"slope\": -0.06710312515497208, \"chain\": 1, \"draw\": 199}, {\"draws\": 399, \"mouse\": 6, \"mu_intercept_per_group\": 9.79960823059082, \"sigma_intercept_per_group\": 0.19631730020046234, \"sigma_obs\": 168.92117309570312, \"slope\": -0.06710312515497208, \"chain\": 1, \"draw\": 199}, {\"draws\": 399, \"mouse\": 7, \"mu_intercept_per_group\": 8.978117942810059, \"sigma_intercept_per_group\": 0.19631730020046234, \"sigma_obs\": 168.92117309570312, \"slope\": -0.06710312515497208, \"chain\": 1, \"draw\": 199}, {\"draws\": 400, \"mouse\": 0, \"mu_intercept_per_group\": 14.888341903686523, \"sigma_intercept_per_group\": 0.1654447317123413, \"sigma_obs\": 151.10556030273438, \"slope\": -0.08654462546110153, \"chain\": 2, \"draw\": 0}, {\"draws\": 400, \"mouse\": 1, \"mu_intercept_per_group\": 14.40766716003418, \"sigma_intercept_per_group\": 0.1654447317123413, \"sigma_obs\": 151.10556030273438, \"slope\": -0.08654462546110153, \"chain\": 2, \"draw\": 0}, {\"draws\": 400, \"mouse\": 2, \"mu_intercept_per_group\": 14.076800346374512, \"sigma_intercept_per_group\": 0.1654447317123413, \"sigma_obs\": 151.10556030273438, \"slope\": -0.08654462546110153, \"chain\": 2, \"draw\": 0}, {\"draws\": 400, \"mouse\": 3, \"mu_intercept_per_group\": 13.212808609008789, \"sigma_intercept_per_group\": 0.1654447317123413, \"sigma_obs\": 151.10556030273438, \"slope\": -0.08654462546110153, \"chain\": 2, \"draw\": 0}, {\"draws\": 400, \"mouse\": 4, \"mu_intercept_per_group\": 12.647953987121582, \"sigma_intercept_per_group\": 0.1654447317123413, \"sigma_obs\": 151.10556030273438, \"slope\": -0.08654462546110153, \"chain\": 2, \"draw\": 0}, {\"draws\": 400, \"mouse\": 5, \"mu_intercept_per_group\": 12.126741409301758, \"sigma_intercept_per_group\": 0.1654447317123413, \"sigma_obs\": 151.10556030273438, \"slope\": -0.08654462546110153, \"chain\": 2, \"draw\": 0}, {\"draws\": 400, \"mouse\": 6, \"mu_intercept_per_group\": 10.676491737365723, \"sigma_intercept_per_group\": 0.1654447317123413, \"sigma_obs\": 151.10556030273438, \"slope\": -0.08654462546110153, \"chain\": 2, \"draw\": 0}, {\"draws\": 400, \"mouse\": 7, \"mu_intercept_per_group\": 10.519247055053711, \"sigma_intercept_per_group\": 0.1654447317123413, \"sigma_obs\": 151.10556030273438, \"slope\": -0.08654462546110153, \"chain\": 2, \"draw\": 0}, {\"draws\": 401, \"mouse\": 0, \"mu_intercept_per_group\": 14.85486125946045, \"sigma_intercept_per_group\": 0.16275635361671448, \"sigma_obs\": 158.94036865234375, \"slope\": -0.0649128183722496, \"chain\": 2, \"draw\": 1}, {\"draws\": 401, \"mouse\": 1, \"mu_intercept_per_group\": 14.624690055847168, \"sigma_intercept_per_group\": 0.16275635361671448, \"sigma_obs\": 158.94036865234375, \"slope\": -0.0649128183722496, \"chain\": 2, \"draw\": 1}, {\"draws\": 401, \"mouse\": 2, \"mu_intercept_per_group\": 14.196861267089844, \"sigma_intercept_per_group\": 0.16275635361671448, \"sigma_obs\": 158.94036865234375, \"slope\": -0.0649128183722496, \"chain\": 2, \"draw\": 1}, {\"draws\": 401, \"mouse\": 3, \"mu_intercept_per_group\": 13.260457992553711, \"sigma_intercept_per_group\": 0.16275635361671448, \"sigma_obs\": 158.94036865234375, \"slope\": -0.0649128183722496, \"chain\": 2, \"draw\": 1}, {\"draws\": 401, \"mouse\": 4, \"mu_intercept_per_group\": 12.714371681213379, \"sigma_intercept_per_group\": 0.16275635361671448, \"sigma_obs\": 158.94036865234375, \"slope\": -0.0649128183722496, \"chain\": 2, \"draw\": 1}, {\"draws\": 401, \"mouse\": 5, \"mu_intercept_per_group\": 11.7321195602417, \"sigma_intercept_per_group\": 0.16275635361671448, \"sigma_obs\": 158.94036865234375, \"slope\": -0.0649128183722496, \"chain\": 2, \"draw\": 1}, {\"draws\": 401, \"mouse\": 6, \"mu_intercept_per_group\": 11.716872215270996, \"sigma_intercept_per_group\": 0.16275635361671448, \"sigma_obs\": 158.94036865234375, \"slope\": -0.0649128183722496, \"chain\": 2, \"draw\": 1}, {\"draws\": 401, \"mouse\": 7, \"mu_intercept_per_group\": 10.939886093139648, \"sigma_intercept_per_group\": 0.16275635361671448, \"sigma_obs\": 158.94036865234375, \"slope\": -0.0649128183722496, \"chain\": 2, \"draw\": 1}, {\"draws\": 402, \"mouse\": 0, \"mu_intercept_per_group\": 15.019832611083984, \"sigma_intercept_per_group\": 0.16562378406524658, \"sigma_obs\": 159.03529357910156, \"slope\": -0.06644048541784286, \"chain\": 2, \"draw\": 2}, {\"draws\": 402, \"mouse\": 1, \"mu_intercept_per_group\": 14.091050148010254, \"sigma_intercept_per_group\": 0.16562378406524658, \"sigma_obs\": 159.03529357910156, \"slope\": -0.06644048541784286, \"chain\": 2, \"draw\": 2}, {\"draws\": 402, \"mouse\": 2, \"mu_intercept_per_group\": 13.690096855163574, \"sigma_intercept_per_group\": 0.16562378406524658, \"sigma_obs\": 159.03529357910156, \"slope\": -0.06644048541784286, \"chain\": 2, \"draw\": 2}, {\"draws\": 402, \"mouse\": 3, \"mu_intercept_per_group\": 12.98733139038086, \"sigma_intercept_per_group\": 0.16562378406524658, \"sigma_obs\": 159.03529357910156, \"slope\": -0.06644048541784286, \"chain\": 2, \"draw\": 2}, {\"draws\": 402, \"mouse\": 4, \"mu_intercept_per_group\": 13.024249076843262, \"sigma_intercept_per_group\": 0.16562378406524658, \"sigma_obs\": 159.03529357910156, \"slope\": -0.06644048541784286, \"chain\": 2, \"draw\": 2}, {\"draws\": 402, \"mouse\": 5, \"mu_intercept_per_group\": 12.495028495788574, \"sigma_intercept_per_group\": 0.16562378406524658, \"sigma_obs\": 159.03529357910156, \"slope\": -0.06644048541784286, \"chain\": 2, \"draw\": 2}, {\"draws\": 402, \"mouse\": 6, \"mu_intercept_per_group\": 10.800976753234863, \"sigma_intercept_per_group\": 0.16562378406524658, \"sigma_obs\": 159.03529357910156, \"slope\": -0.06644048541784286, \"chain\": 2, \"draw\": 2}, {\"draws\": 402, \"mouse\": 7, \"mu_intercept_per_group\": 10.757391929626465, \"sigma_intercept_per_group\": 0.16562378406524658, \"sigma_obs\": 159.03529357910156, \"slope\": -0.06644048541784286, \"chain\": 2, \"draw\": 2}, {\"draws\": 403, \"mouse\": 0, \"mu_intercept_per_group\": 15.685649871826172, \"sigma_intercept_per_group\": 0.15775935351848602, \"sigma_obs\": 156.34913635253906, \"slope\": -0.06892076134681702, \"chain\": 2, \"draw\": 3}, {\"draws\": 403, \"mouse\": 1, \"mu_intercept_per_group\": 14.839642524719238, \"sigma_intercept_per_group\": 0.15775935351848602, \"sigma_obs\": 156.34913635253906, \"slope\": -0.06892076134681702, \"chain\": 2, \"draw\": 3}, {\"draws\": 403, \"mouse\": 2, \"mu_intercept_per_group\": 14.13385009765625, \"sigma_intercept_per_group\": 0.15775935351848602, \"sigma_obs\": 156.34913635253906, \"slope\": -0.06892076134681702, \"chain\": 2, \"draw\": 3}, {\"draws\": 403, \"mouse\": 3, \"mu_intercept_per_group\": 13.737863540649414, \"sigma_intercept_per_group\": 0.15775935351848602, \"sigma_obs\": 156.34913635253906, \"slope\": -0.06892076134681702, \"chain\": 2, \"draw\": 3}, {\"draws\": 403, \"mouse\": 4, \"mu_intercept_per_group\": 13.665936470031738, \"sigma_intercept_per_group\": 0.15775935351848602, \"sigma_obs\": 156.34913635253906, \"slope\": -0.06892076134681702, \"chain\": 2, \"draw\": 3}, {\"draws\": 403, \"mouse\": 5, \"mu_intercept_per_group\": 12.437740325927734, \"sigma_intercept_per_group\": 0.15775935351848602, \"sigma_obs\": 156.34913635253906, \"slope\": -0.06892076134681702, \"chain\": 2, \"draw\": 3}, {\"draws\": 403, \"mouse\": 6, \"mu_intercept_per_group\": 12.418856620788574, \"sigma_intercept_per_group\": 0.15775935351848602, \"sigma_obs\": 156.34913635253906, \"slope\": -0.06892076134681702, \"chain\": 2, \"draw\": 3}, {\"draws\": 403, \"mouse\": 7, \"mu_intercept_per_group\": 11.111886978149414, \"sigma_intercept_per_group\": 0.15775935351848602, \"sigma_obs\": 156.34913635253906, \"slope\": -0.06892076134681702, \"chain\": 2, \"draw\": 3}, {\"draws\": 404, \"mouse\": 0, \"mu_intercept_per_group\": 15.252425193786621, \"sigma_intercept_per_group\": 0.1627047061920166, \"sigma_obs\": 155.53164672851562, \"slope\": -0.06082133203744888, \"chain\": 2, \"draw\": 4}, {\"draws\": 404, \"mouse\": 1, \"mu_intercept_per_group\": 14.431634902954102, \"sigma_intercept_per_group\": 0.1627047061920166, \"sigma_obs\": 155.53164672851562, \"slope\": -0.06082133203744888, \"chain\": 2, \"draw\": 4}, {\"draws\": 404, \"mouse\": 2, \"mu_intercept_per_group\": 14.314803123474121, \"sigma_intercept_per_group\": 0.1627047061920166, \"sigma_obs\": 155.53164672851562, \"slope\": -0.06082133203744888, \"chain\": 2, \"draw\": 4}, {\"draws\": 404, \"mouse\": 3, \"mu_intercept_per_group\": 13.166622161865234, \"sigma_intercept_per_group\": 0.1627047061920166, \"sigma_obs\": 155.53164672851562, \"slope\": -0.06082133203744888, \"chain\": 2, \"draw\": 4}, {\"draws\": 404, \"mouse\": 4, \"mu_intercept_per_group\": 12.512718200683594, \"sigma_intercept_per_group\": 0.1627047061920166, \"sigma_obs\": 155.53164672851562, \"slope\": -0.06082133203744888, \"chain\": 2, \"draw\": 4}, {\"draws\": 404, \"mouse\": 5, \"mu_intercept_per_group\": 11.81348991394043, \"sigma_intercept_per_group\": 0.1627047061920166, \"sigma_obs\": 155.53164672851562, \"slope\": -0.06082133203744888, \"chain\": 2, \"draw\": 4}, {\"draws\": 404, \"mouse\": 6, \"mu_intercept_per_group\": 10.588493347167969, \"sigma_intercept_per_group\": 0.1627047061920166, \"sigma_obs\": 155.53164672851562, \"slope\": -0.06082133203744888, \"chain\": 2, \"draw\": 4}, {\"draws\": 404, \"mouse\": 7, \"mu_intercept_per_group\": 10.751630783081055, \"sigma_intercept_per_group\": 0.1627047061920166, \"sigma_obs\": 155.53164672851562, \"slope\": -0.06082133203744888, \"chain\": 2, \"draw\": 4}, {\"draws\": 405, \"mouse\": 0, \"mu_intercept_per_group\": 14.890533447265625, \"sigma_intercept_per_group\": 0.16249942779541016, \"sigma_obs\": 155.24386596679688, \"slope\": -0.06230606138706207, \"chain\": 2, \"draw\": 5}, {\"draws\": 405, \"mouse\": 1, \"mu_intercept_per_group\": 14.45731258392334, \"sigma_intercept_per_group\": 0.16249942779541016, \"sigma_obs\": 155.24386596679688, \"slope\": -0.06230606138706207, \"chain\": 2, \"draw\": 5}, {\"draws\": 405, \"mouse\": 2, \"mu_intercept_per_group\": 14.271419525146484, \"sigma_intercept_per_group\": 0.16249942779541016, \"sigma_obs\": 155.24386596679688, \"slope\": -0.06230606138706207, \"chain\": 2, \"draw\": 5}, {\"draws\": 405, \"mouse\": 3, \"mu_intercept_per_group\": 13.18639087677002, \"sigma_intercept_per_group\": 0.16249942779541016, \"sigma_obs\": 155.24386596679688, \"slope\": -0.06230606138706207, \"chain\": 2, \"draw\": 5}, {\"draws\": 405, \"mouse\": 4, \"mu_intercept_per_group\": 12.589668273925781, \"sigma_intercept_per_group\": 0.16249942779541016, \"sigma_obs\": 155.24386596679688, \"slope\": -0.06230606138706207, \"chain\": 2, \"draw\": 5}, {\"draws\": 405, \"mouse\": 5, \"mu_intercept_per_group\": 11.77703857421875, \"sigma_intercept_per_group\": 0.16249942779541016, \"sigma_obs\": 155.24386596679688, \"slope\": -0.06230606138706207, \"chain\": 2, \"draw\": 5}, {\"draws\": 405, \"mouse\": 6, \"mu_intercept_per_group\": 10.845157623291016, \"sigma_intercept_per_group\": 0.16249942779541016, \"sigma_obs\": 155.24386596679688, \"slope\": -0.06230606138706207, \"chain\": 2, \"draw\": 5}, {\"draws\": 405, \"mouse\": 7, \"mu_intercept_per_group\": 10.568714141845703, \"sigma_intercept_per_group\": 0.16249942779541016, \"sigma_obs\": 155.24386596679688, \"slope\": -0.06230606138706207, \"chain\": 2, \"draw\": 5}, {\"draws\": 406, \"mouse\": 0, \"mu_intercept_per_group\": 13.610603332519531, \"sigma_intercept_per_group\": 0.19202834367752075, \"sigma_obs\": 180.83380126953125, \"slope\": -0.08682350069284439, \"chain\": 2, \"draw\": 6}, {\"draws\": 406, \"mouse\": 1, \"mu_intercept_per_group\": 13.012045860290527, \"sigma_intercept_per_group\": 0.19202834367752075, \"sigma_obs\": 180.83380126953125, \"slope\": -0.08682350069284439, \"chain\": 2, \"draw\": 6}, {\"draws\": 406, \"mouse\": 2, \"mu_intercept_per_group\": 12.748360633850098, \"sigma_intercept_per_group\": 0.19202834367752075, \"sigma_obs\": 180.83380126953125, \"slope\": -0.08682350069284439, \"chain\": 2, \"draw\": 6}, {\"draws\": 406, \"mouse\": 3, \"mu_intercept_per_group\": 11.876299858093262, \"sigma_intercept_per_group\": 0.19202834367752075, \"sigma_obs\": 180.83380126953125, \"slope\": -0.08682350069284439, \"chain\": 2, \"draw\": 6}, {\"draws\": 406, \"mouse\": 4, \"mu_intercept_per_group\": 11.956412315368652, \"sigma_intercept_per_group\": 0.19202834367752075, \"sigma_obs\": 180.83380126953125, \"slope\": -0.08682350069284439, \"chain\": 2, \"draw\": 6}, {\"draws\": 406, \"mouse\": 5, \"mu_intercept_per_group\": 10.96593189239502, \"sigma_intercept_per_group\": 0.19202834367752075, \"sigma_obs\": 180.83380126953125, \"slope\": -0.08682350069284439, \"chain\": 2, \"draw\": 6}, {\"draws\": 406, \"mouse\": 6, \"mu_intercept_per_group\": 10.168115615844727, \"sigma_intercept_per_group\": 0.19202834367752075, \"sigma_obs\": 180.83380126953125, \"slope\": -0.08682350069284439, \"chain\": 2, \"draw\": 6}, {\"draws\": 406, \"mouse\": 7, \"mu_intercept_per_group\": 9.887242317199707, \"sigma_intercept_per_group\": 0.19202834367752075, \"sigma_obs\": 180.83380126953125, \"slope\": -0.08682350069284439, \"chain\": 2, \"draw\": 6}, {\"draws\": 407, \"mouse\": 0, \"mu_intercept_per_group\": 15.594502449035645, \"sigma_intercept_per_group\": 0.1520005613565445, \"sigma_obs\": 142.8279571533203, \"slope\": -0.06278184801340103, \"chain\": 2, \"draw\": 7}, {\"draws\": 407, \"mouse\": 1, \"mu_intercept_per_group\": 14.769917488098145, \"sigma_intercept_per_group\": 0.1520005613565445, \"sigma_obs\": 142.8279571533203, \"slope\": -0.06278184801340103, \"chain\": 2, \"draw\": 7}, {\"draws\": 407, \"mouse\": 2, \"mu_intercept_per_group\": 14.40555191040039, \"sigma_intercept_per_group\": 0.1520005613565445, \"sigma_obs\": 142.8279571533203, \"slope\": -0.06278184801340103, \"chain\": 2, \"draw\": 7}, {\"draws\": 407, \"mouse\": 3, \"mu_intercept_per_group\": 13.61966609954834, \"sigma_intercept_per_group\": 0.1520005613565445, \"sigma_obs\": 142.8279571533203, \"slope\": -0.06278184801340103, \"chain\": 2, \"draw\": 7}, {\"draws\": 407, \"mouse\": 4, \"mu_intercept_per_group\": 12.980920791625977, \"sigma_intercept_per_group\": 0.1520005613565445, \"sigma_obs\": 142.8279571533203, \"slope\": -0.06278184801340103, \"chain\": 2, \"draw\": 7}, {\"draws\": 407, \"mouse\": 5, \"mu_intercept_per_group\": 12.1857271194458, \"sigma_intercept_per_group\": 0.1520005613565445, \"sigma_obs\": 142.8279571533203, \"slope\": -0.06278184801340103, \"chain\": 2, \"draw\": 7}, {\"draws\": 407, \"mouse\": 6, \"mu_intercept_per_group\": 11.645034790039062, \"sigma_intercept_per_group\": 0.1520005613565445, \"sigma_obs\": 142.8279571533203, \"slope\": -0.06278184801340103, \"chain\": 2, \"draw\": 7}, {\"draws\": 407, \"mouse\": 7, \"mu_intercept_per_group\": 10.779138565063477, \"sigma_intercept_per_group\": 0.1520005613565445, \"sigma_obs\": 142.8279571533203, \"slope\": -0.06278184801340103, \"chain\": 2, \"draw\": 7}, {\"draws\": 408, \"mouse\": 0, \"mu_intercept_per_group\": 15.429301261901855, \"sigma_intercept_per_group\": 0.14942170679569244, \"sigma_obs\": 139.94544982910156, \"slope\": -0.062405284494161606, \"chain\": 2, \"draw\": 8}, {\"draws\": 408, \"mouse\": 1, \"mu_intercept_per_group\": 15.035329818725586, \"sigma_intercept_per_group\": 0.14942170679569244, \"sigma_obs\": 139.94544982910156, \"slope\": -0.062405284494161606, \"chain\": 2, \"draw\": 8}, {\"draws\": 408, \"mouse\": 2, \"mu_intercept_per_group\": 14.609110832214355, \"sigma_intercept_per_group\": 0.14942170679569244, \"sigma_obs\": 139.94544982910156, \"slope\": -0.062405284494161606, \"chain\": 2, \"draw\": 8}, {\"draws\": 408, \"mouse\": 3, \"mu_intercept_per_group\": 13.73770809173584, \"sigma_intercept_per_group\": 0.14942170679569244, \"sigma_obs\": 139.94544982910156, \"slope\": -0.062405284494161606, \"chain\": 2, \"draw\": 8}, {\"draws\": 408, \"mouse\": 4, \"mu_intercept_per_group\": 13.7697172164917, \"sigma_intercept_per_group\": 0.14942170679569244, \"sigma_obs\": 139.94544982910156, \"slope\": -0.062405284494161606, \"chain\": 2, \"draw\": 8}, {\"draws\": 408, \"mouse\": 5, \"mu_intercept_per_group\": 12.406205177307129, \"sigma_intercept_per_group\": 0.14942170679569244, \"sigma_obs\": 139.94544982910156, \"slope\": -0.062405284494161606, \"chain\": 2, \"draw\": 8}, {\"draws\": 408, \"mouse\": 6, \"mu_intercept_per_group\": 11.167028427124023, \"sigma_intercept_per_group\": 0.14942170679569244, \"sigma_obs\": 139.94544982910156, \"slope\": -0.062405284494161606, \"chain\": 2, \"draw\": 8}, {\"draws\": 408, \"mouse\": 7, \"mu_intercept_per_group\": 10.806463241577148, \"sigma_intercept_per_group\": 0.14942170679569244, \"sigma_obs\": 139.94544982910156, \"slope\": -0.062405284494161606, \"chain\": 2, \"draw\": 8}, {\"draws\": 409, \"mouse\": 0, \"mu_intercept_per_group\": 17.032302856445312, \"sigma_intercept_per_group\": 0.14279340207576752, \"sigma_obs\": 143.0254669189453, \"slope\": -0.07127956300973892, \"chain\": 2, \"draw\": 9}, {\"draws\": 409, \"mouse\": 1, \"mu_intercept_per_group\": 15.954893112182617, \"sigma_intercept_per_group\": 0.14279340207576752, \"sigma_obs\": 143.0254669189453, \"slope\": -0.07127956300973892, \"chain\": 2, \"draw\": 9}, {\"draws\": 409, \"mouse\": 2, \"mu_intercept_per_group\": 15.310171127319336, \"sigma_intercept_per_group\": 0.14279340207576752, \"sigma_obs\": 143.0254669189453, \"slope\": -0.07127956300973892, \"chain\": 2, \"draw\": 9}, {\"draws\": 409, \"mouse\": 3, \"mu_intercept_per_group\": 14.447613716125488, \"sigma_intercept_per_group\": 0.14279340207576752, \"sigma_obs\": 143.0254669189453, \"slope\": -0.07127956300973892, \"chain\": 2, \"draw\": 9}, {\"draws\": 409, \"mouse\": 4, \"mu_intercept_per_group\": 13.822270393371582, \"sigma_intercept_per_group\": 0.14279340207576752, \"sigma_obs\": 143.0254669189453, \"slope\": -0.07127956300973892, \"chain\": 2, \"draw\": 9}, {\"draws\": 409, \"mouse\": 5, \"mu_intercept_per_group\": 13.979208946228027, \"sigma_intercept_per_group\": 0.14279340207576752, \"sigma_obs\": 143.0254669189453, \"slope\": -0.07127956300973892, \"chain\": 2, \"draw\": 9}, {\"draws\": 409, \"mouse\": 6, \"mu_intercept_per_group\": 12.1441068649292, \"sigma_intercept_per_group\": 0.14279340207576752, \"sigma_obs\": 143.0254669189453, \"slope\": -0.07127956300973892, \"chain\": 2, \"draw\": 9}, {\"draws\": 409, \"mouse\": 7, \"mu_intercept_per_group\": 11.658154487609863, \"sigma_intercept_per_group\": 0.14279340207576752, \"sigma_obs\": 143.0254669189453, \"slope\": -0.07127956300973892, \"chain\": 2, \"draw\": 9}, {\"draws\": 410, \"mouse\": 0, \"mu_intercept_per_group\": 12.768599510192871, \"sigma_intercept_per_group\": 0.20480017364025116, \"sigma_obs\": 180.92807006835938, \"slope\": -0.07780852913856506, \"chain\": 2, \"draw\": 10}, {\"draws\": 410, \"mouse\": 1, \"mu_intercept_per_group\": 12.654294967651367, \"sigma_intercept_per_group\": 0.20480017364025116, \"sigma_obs\": 180.92807006835938, \"slope\": -0.07780852913856506, \"chain\": 2, \"draw\": 10}, {\"draws\": 410, \"mouse\": 2, \"mu_intercept_per_group\": 12.1585693359375, \"sigma_intercept_per_group\": 0.20480017364025116, \"sigma_obs\": 180.92807006835938, \"slope\": -0.07780852913856506, \"chain\": 2, \"draw\": 10}, {\"draws\": 410, \"mouse\": 3, \"mu_intercept_per_group\": 11.424306869506836, \"sigma_intercept_per_group\": 0.20480017364025116, \"sigma_obs\": 180.92807006835938, \"slope\": -0.07780852913856506, \"chain\": 2, \"draw\": 10}, {\"draws\": 410, \"mouse\": 4, \"mu_intercept_per_group\": 11.099905014038086, \"sigma_intercept_per_group\": 0.20480017364025116, \"sigma_obs\": 180.92807006835938, \"slope\": -0.07780852913856506, \"chain\": 2, \"draw\": 10}, {\"draws\": 410, \"mouse\": 5, \"mu_intercept_per_group\": 10.195935249328613, \"sigma_intercept_per_group\": 0.20480017364025116, \"sigma_obs\": 180.92807006835938, \"slope\": -0.07780852913856506, \"chain\": 2, \"draw\": 10}, {\"draws\": 410, \"mouse\": 6, \"mu_intercept_per_group\": 9.291520118713379, \"sigma_intercept_per_group\": 0.20480017364025116, \"sigma_obs\": 180.92807006835938, \"slope\": -0.07780852913856506, \"chain\": 2, \"draw\": 10}, {\"draws\": 410, \"mouse\": 7, \"mu_intercept_per_group\": 9.267498970031738, \"sigma_intercept_per_group\": 0.20480017364025116, \"sigma_obs\": 180.92807006835938, \"slope\": -0.07780852913856506, \"chain\": 2, \"draw\": 10}, {\"draws\": 411, \"mouse\": 0, \"mu_intercept_per_group\": 11.585061073303223, \"sigma_intercept_per_group\": 0.2214348167181015, \"sigma_obs\": 163.9548797607422, \"slope\": -0.07144522666931152, \"chain\": 2, \"draw\": 11}, {\"draws\": 411, \"mouse\": 1, \"mu_intercept_per_group\": 11.113973617553711, \"sigma_intercept_per_group\": 0.2214348167181015, \"sigma_obs\": 163.9548797607422, \"slope\": -0.07144522666931152, \"chain\": 2, \"draw\": 11}, {\"draws\": 411, \"mouse\": 2, \"mu_intercept_per_group\": 10.722859382629395, \"sigma_intercept_per_group\": 0.2214348167181015, \"sigma_obs\": 163.9548797607422, \"slope\": -0.07144522666931152, \"chain\": 2, \"draw\": 11}, {\"draws\": 411, \"mouse\": 3, \"mu_intercept_per_group\": 9.633184432983398, \"sigma_intercept_per_group\": 0.2214348167181015, \"sigma_obs\": 163.9548797607422, \"slope\": -0.07144522666931152, \"chain\": 2, \"draw\": 11}, {\"draws\": 411, \"mouse\": 4, \"mu_intercept_per_group\": 9.764606475830078, \"sigma_intercept_per_group\": 0.2214348167181015, \"sigma_obs\": 163.9548797607422, \"slope\": -0.07144522666931152, \"chain\": 2, \"draw\": 11}, {\"draws\": 411, \"mouse\": 5, \"mu_intercept_per_group\": 9.288086891174316, \"sigma_intercept_per_group\": 0.2214348167181015, \"sigma_obs\": 163.9548797607422, \"slope\": -0.07144522666931152, \"chain\": 2, \"draw\": 11}, {\"draws\": 411, \"mouse\": 6, \"mu_intercept_per_group\": 8.173136711120605, \"sigma_intercept_per_group\": 0.2214348167181015, \"sigma_obs\": 163.9548797607422, \"slope\": -0.07144522666931152, \"chain\": 2, \"draw\": 11}, {\"draws\": 411, \"mouse\": 7, \"mu_intercept_per_group\": 8.224796295166016, \"sigma_intercept_per_group\": 0.2214348167181015, \"sigma_obs\": 163.9548797607422, \"slope\": -0.07144522666931152, \"chain\": 2, \"draw\": 11}, {\"draws\": 412, \"mouse\": 0, \"mu_intercept_per_group\": 11.971421241760254, \"sigma_intercept_per_group\": 0.2099563181400299, \"sigma_obs\": 164.44155883789062, \"slope\": -0.08326325565576553, \"chain\": 2, \"draw\": 12}, {\"draws\": 412, \"mouse\": 1, \"mu_intercept_per_group\": 11.693188667297363, \"sigma_intercept_per_group\": 0.2099563181400299, \"sigma_obs\": 164.44155883789062, \"slope\": -0.08326325565576553, \"chain\": 2, \"draw\": 12}, {\"draws\": 412, \"mouse\": 2, \"mu_intercept_per_group\": 11.634601593017578, \"sigma_intercept_per_group\": 0.2099563181400299, \"sigma_obs\": 164.44155883789062, \"slope\": -0.08326325565576553, \"chain\": 2, \"draw\": 12}, {\"draws\": 412, \"mouse\": 3, \"mu_intercept_per_group\": 10.486390113830566, \"sigma_intercept_per_group\": 0.2099563181400299, \"sigma_obs\": 164.44155883789062, \"slope\": -0.08326325565576553, \"chain\": 2, \"draw\": 12}, {\"draws\": 412, \"mouse\": 4, \"mu_intercept_per_group\": 10.522756576538086, \"sigma_intercept_per_group\": 0.2099563181400299, \"sigma_obs\": 164.44155883789062, \"slope\": -0.08326325565576553, \"chain\": 2, \"draw\": 12}, {\"draws\": 412, \"mouse\": 5, \"mu_intercept_per_group\": 9.779806137084961, \"sigma_intercept_per_group\": 0.2099563181400299, \"sigma_obs\": 164.44155883789062, \"slope\": -0.08326325565576553, \"chain\": 2, \"draw\": 12}, {\"draws\": 412, \"mouse\": 6, \"mu_intercept_per_group\": 8.958017349243164, \"sigma_intercept_per_group\": 0.2099563181400299, \"sigma_obs\": 164.44155883789062, \"slope\": -0.08326325565576553, \"chain\": 2, \"draw\": 12}, {\"draws\": 412, \"mouse\": 7, \"mu_intercept_per_group\": 8.669276237487793, \"sigma_intercept_per_group\": 0.2099563181400299, \"sigma_obs\": 164.44155883789062, \"slope\": -0.08326325565576553, \"chain\": 2, \"draw\": 12}, {\"draws\": 413, \"mouse\": 0, \"mu_intercept_per_group\": 11.069727897644043, \"sigma_intercept_per_group\": 0.22253428399562836, \"sigma_obs\": 164.6060791015625, \"slope\": -0.08226106315851212, \"chain\": 2, \"draw\": 13}, {\"draws\": 413, \"mouse\": 1, \"mu_intercept_per_group\": 10.773505210876465, \"sigma_intercept_per_group\": 0.22253428399562836, \"sigma_obs\": 164.6060791015625, \"slope\": -0.08226106315851212, \"chain\": 2, \"draw\": 13}, {\"draws\": 413, \"mouse\": 2, \"mu_intercept_per_group\": 10.645813941955566, \"sigma_intercept_per_group\": 0.22253428399562836, \"sigma_obs\": 164.6060791015625, \"slope\": -0.08226106315851212, \"chain\": 2, \"draw\": 13}, {\"draws\": 413, \"mouse\": 3, \"mu_intercept_per_group\": 10.215442657470703, \"sigma_intercept_per_group\": 0.22253428399562836, \"sigma_obs\": 164.6060791015625, \"slope\": -0.08226106315851212, \"chain\": 2, \"draw\": 13}, {\"draws\": 413, \"mouse\": 4, \"mu_intercept_per_group\": 9.723576545715332, \"sigma_intercept_per_group\": 0.22253428399562836, \"sigma_obs\": 164.6060791015625, \"slope\": -0.08226106315851212, \"chain\": 2, \"draw\": 13}, {\"draws\": 413, \"mouse\": 5, \"mu_intercept_per_group\": 9.266192436218262, \"sigma_intercept_per_group\": 0.22253428399562836, \"sigma_obs\": 164.6060791015625, \"slope\": -0.08226106315851212, \"chain\": 2, \"draw\": 13}, {\"draws\": 413, \"mouse\": 6, \"mu_intercept_per_group\": 8.511537551879883, \"sigma_intercept_per_group\": 0.22253428399562836, \"sigma_obs\": 164.6060791015625, \"slope\": -0.08226106315851212, \"chain\": 2, \"draw\": 13}, {\"draws\": 413, \"mouse\": 7, \"mu_intercept_per_group\": 8.126106262207031, \"sigma_intercept_per_group\": 0.22253428399562836, \"sigma_obs\": 164.6060791015625, \"slope\": -0.08226106315851212, \"chain\": 2, \"draw\": 13}, {\"draws\": 414, \"mouse\": 0, \"mu_intercept_per_group\": 11.134750366210938, \"sigma_intercept_per_group\": 0.22325658798217773, \"sigma_obs\": 164.3876953125, \"slope\": -0.08227717876434326, \"chain\": 2, \"draw\": 14}, {\"draws\": 414, \"mouse\": 1, \"mu_intercept_per_group\": 10.735974311828613, \"sigma_intercept_per_group\": 0.22325658798217773, \"sigma_obs\": 164.3876953125, \"slope\": -0.08227717876434326, \"chain\": 2, \"draw\": 14}, {\"draws\": 414, \"mouse\": 2, \"mu_intercept_per_group\": 10.568948745727539, \"sigma_intercept_per_group\": 0.22325658798217773, \"sigma_obs\": 164.3876953125, \"slope\": -0.08227717876434326, \"chain\": 2, \"draw\": 14}, {\"draws\": 414, \"mouse\": 3, \"mu_intercept_per_group\": 10.24992561340332, \"sigma_intercept_per_group\": 0.22325658798217773, \"sigma_obs\": 164.3876953125, \"slope\": -0.08227717876434326, \"chain\": 2, \"draw\": 14}, {\"draws\": 414, \"mouse\": 4, \"mu_intercept_per_group\": 9.773850440979004, \"sigma_intercept_per_group\": 0.22325658798217773, \"sigma_obs\": 164.3876953125, \"slope\": -0.08227717876434326, \"chain\": 2, \"draw\": 14}, {\"draws\": 414, \"mouse\": 5, \"mu_intercept_per_group\": 9.224091529846191, \"sigma_intercept_per_group\": 0.22325658798217773, \"sigma_obs\": 164.3876953125, \"slope\": -0.08227717876434326, \"chain\": 2, \"draw\": 14}, {\"draws\": 414, \"mouse\": 6, \"mu_intercept_per_group\": 8.674237251281738, \"sigma_intercept_per_group\": 0.22325658798217773, \"sigma_obs\": 164.3876953125, \"slope\": -0.08227717876434326, \"chain\": 2, \"draw\": 14}, {\"draws\": 414, \"mouse\": 7, \"mu_intercept_per_group\": 8.078651428222656, \"sigma_intercept_per_group\": 0.22325658798217773, \"sigma_obs\": 164.3876953125, \"slope\": -0.08227717876434326, \"chain\": 2, \"draw\": 14}, {\"draws\": 415, \"mouse\": 0, \"mu_intercept_per_group\": 11.749277114868164, \"sigma_intercept_per_group\": 0.21108415722846985, \"sigma_obs\": 163.08673095703125, \"slope\": -0.08169598877429962, \"chain\": 2, \"draw\": 15}, {\"draws\": 415, \"mouse\": 1, \"mu_intercept_per_group\": 11.376606941223145, \"sigma_intercept_per_group\": 0.21108415722846985, \"sigma_obs\": 163.08673095703125, \"slope\": -0.08169598877429962, \"chain\": 2, \"draw\": 15}, {\"draws\": 415, \"mouse\": 2, \"mu_intercept_per_group\": 11.132996559143066, \"sigma_intercept_per_group\": 0.21108415722846985, \"sigma_obs\": 163.08673095703125, \"slope\": -0.08169598877429962, \"chain\": 2, \"draw\": 15}, {\"draws\": 415, \"mouse\": 3, \"mu_intercept_per_group\": 10.83637809753418, \"sigma_intercept_per_group\": 0.21108415722846985, \"sigma_obs\": 163.08673095703125, \"slope\": -0.08169598877429962, \"chain\": 2, \"draw\": 15}, {\"draws\": 415, \"mouse\": 4, \"mu_intercept_per_group\": 10.38392162322998, \"sigma_intercept_per_group\": 0.21108415722846985, \"sigma_obs\": 163.08673095703125, \"slope\": -0.08169598877429962, \"chain\": 2, \"draw\": 15}, {\"draws\": 415, \"mouse\": 5, \"mu_intercept_per_group\": 9.70915412902832, \"sigma_intercept_per_group\": 0.21108415722846985, \"sigma_obs\": 163.08673095703125, \"slope\": -0.08169598877429962, \"chain\": 2, \"draw\": 15}, {\"draws\": 415, \"mouse\": 6, \"mu_intercept_per_group\": 8.6279296875, \"sigma_intercept_per_group\": 0.21108415722846985, \"sigma_obs\": 163.08673095703125, \"slope\": -0.08169598877429962, \"chain\": 2, \"draw\": 15}, {\"draws\": 415, \"mouse\": 7, \"mu_intercept_per_group\": 8.655316352844238, \"sigma_intercept_per_group\": 0.21108415722846985, \"sigma_obs\": 163.08673095703125, \"slope\": -0.08169598877429962, \"chain\": 2, \"draw\": 15}, {\"draws\": 416, \"mouse\": 0, \"mu_intercept_per_group\": 11.533220291137695, \"sigma_intercept_per_group\": 0.2156168818473816, \"sigma_obs\": 162.587158203125, \"slope\": -0.08326390385627747, \"chain\": 2, \"draw\": 16}, {\"draws\": 416, \"mouse\": 1, \"mu_intercept_per_group\": 11.115812301635742, \"sigma_intercept_per_group\": 0.2156168818473816, \"sigma_obs\": 162.587158203125, \"slope\": -0.08326390385627747, \"chain\": 2, \"draw\": 16}, {\"draws\": 416, \"mouse\": 2, \"mu_intercept_per_group\": 11.069747924804688, \"sigma_intercept_per_group\": 0.2156168818473816, \"sigma_obs\": 162.587158203125, \"slope\": -0.08326390385627747, \"chain\": 2, \"draw\": 16}, {\"draws\": 416, \"mouse\": 3, \"mu_intercept_per_group\": 10.188580513000488, \"sigma_intercept_per_group\": 0.2156168818473816, \"sigma_obs\": 162.587158203125, \"slope\": -0.08326390385627747, \"chain\": 2, \"draw\": 16}, {\"draws\": 416, \"mouse\": 4, \"mu_intercept_per_group\": 10.06746768951416, \"sigma_intercept_per_group\": 0.2156168818473816, \"sigma_obs\": 162.587158203125, \"slope\": -0.08326390385627747, \"chain\": 2, \"draw\": 16}, {\"draws\": 416, \"mouse\": 5, \"mu_intercept_per_group\": 9.505382537841797, \"sigma_intercept_per_group\": 0.2156168818473816, \"sigma_obs\": 162.587158203125, \"slope\": -0.08326390385627747, \"chain\": 2, \"draw\": 16}, {\"draws\": 416, \"mouse\": 6, \"mu_intercept_per_group\": 9.358001708984375, \"sigma_intercept_per_group\": 0.2156168818473816, \"sigma_obs\": 162.587158203125, \"slope\": -0.08326390385627747, \"chain\": 2, \"draw\": 16}, {\"draws\": 416, \"mouse\": 7, \"mu_intercept_per_group\": 8.288642883300781, \"sigma_intercept_per_group\": 0.2156168818473816, \"sigma_obs\": 162.587158203125, \"slope\": -0.08326390385627747, \"chain\": 2, \"draw\": 16}, {\"draws\": 417, \"mouse\": 0, \"mu_intercept_per_group\": 11.573699951171875, \"sigma_intercept_per_group\": 0.21543851494789124, \"sigma_obs\": 160.47503662109375, \"slope\": -0.08393547683954239, \"chain\": 2, \"draw\": 17}, {\"draws\": 417, \"mouse\": 1, \"mu_intercept_per_group\": 11.160157203674316, \"sigma_intercept_per_group\": 0.21543851494789124, \"sigma_obs\": 160.47503662109375, \"slope\": -0.08393547683954239, \"chain\": 2, \"draw\": 17}, {\"draws\": 417, \"mouse\": 2, \"mu_intercept_per_group\": 10.538969039916992, \"sigma_intercept_per_group\": 0.21543851494789124, \"sigma_obs\": 160.47503662109375, \"slope\": -0.08393547683954239, \"chain\": 2, \"draw\": 17}, {\"draws\": 417, \"mouse\": 3, \"mu_intercept_per_group\": 10.221807479858398, \"sigma_intercept_per_group\": 0.21543851494789124, \"sigma_obs\": 160.47503662109375, \"slope\": -0.08393547683954239, \"chain\": 2, \"draw\": 17}, {\"draws\": 417, \"mouse\": 4, \"mu_intercept_per_group\": 9.648465156555176, \"sigma_intercept_per_group\": 0.21543851494789124, \"sigma_obs\": 160.47503662109375, \"slope\": -0.08393547683954239, \"chain\": 2, \"draw\": 17}, {\"draws\": 417, \"mouse\": 5, \"mu_intercept_per_group\": 9.444034576416016, \"sigma_intercept_per_group\": 0.21543851494789124, \"sigma_obs\": 160.47503662109375, \"slope\": -0.08393547683954239, \"chain\": 2, \"draw\": 17}, {\"draws\": 417, \"mouse\": 6, \"mu_intercept_per_group\": 8.451303482055664, \"sigma_intercept_per_group\": 0.21543851494789124, \"sigma_obs\": 160.47503662109375, \"slope\": -0.08393547683954239, \"chain\": 2, \"draw\": 17}, {\"draws\": 417, \"mouse\": 7, \"mu_intercept_per_group\": 8.420334815979004, \"sigma_intercept_per_group\": 0.21543851494789124, \"sigma_obs\": 160.47503662109375, \"slope\": -0.08393547683954239, \"chain\": 2, \"draw\": 17}, {\"draws\": 418, \"mouse\": 0, \"mu_intercept_per_group\": 11.156004905700684, \"sigma_intercept_per_group\": 0.23017588257789612, \"sigma_obs\": 172.0043182373047, \"slope\": -0.07143470644950867, \"chain\": 2, \"draw\": 18}, {\"draws\": 418, \"mouse\": 1, \"mu_intercept_per_group\": 10.717941284179688, \"sigma_intercept_per_group\": 0.23017588257789612, \"sigma_obs\": 172.0043182373047, \"slope\": -0.07143470644950867, \"chain\": 2, \"draw\": 18}, {\"draws\": 418, \"mouse\": 2, \"mu_intercept_per_group\": 10.041720390319824, \"sigma_intercept_per_group\": 0.23017588257789612, \"sigma_obs\": 172.0043182373047, \"slope\": -0.07143470644950867, \"chain\": 2, \"draw\": 18}, {\"draws\": 418, \"mouse\": 3, \"mu_intercept_per_group\": 9.91441535949707, \"sigma_intercept_per_group\": 0.23017588257789612, \"sigma_obs\": 172.0043182373047, \"slope\": -0.07143470644950867, \"chain\": 2, \"draw\": 18}, {\"draws\": 418, \"mouse\": 4, \"mu_intercept_per_group\": 9.924802780151367, \"sigma_intercept_per_group\": 0.23017588257789612, \"sigma_obs\": 172.0043182373047, \"slope\": -0.07143470644950867, \"chain\": 2, \"draw\": 18}, {\"draws\": 418, \"mouse\": 5, \"mu_intercept_per_group\": 8.932737350463867, \"sigma_intercept_per_group\": 0.23017588257789612, \"sigma_obs\": 172.0043182373047, \"slope\": -0.07143470644950867, \"chain\": 2, \"draw\": 18}, {\"draws\": 418, \"mouse\": 6, \"mu_intercept_per_group\": 8.181751251220703, \"sigma_intercept_per_group\": 0.23017588257789612, \"sigma_obs\": 172.0043182373047, \"slope\": -0.07143470644950867, \"chain\": 2, \"draw\": 18}, {\"draws\": 418, \"mouse\": 7, \"mu_intercept_per_group\": 8.356310844421387, \"sigma_intercept_per_group\": 0.23017588257789612, \"sigma_obs\": 172.0043182373047, \"slope\": -0.07143470644950867, \"chain\": 2, \"draw\": 18}, {\"draws\": 419, \"mouse\": 0, \"mu_intercept_per_group\": 10.964831352233887, \"sigma_intercept_per_group\": 0.22970034182071686, \"sigma_obs\": 170.40774536132812, \"slope\": -0.07432404905557632, \"chain\": 2, \"draw\": 19}, {\"draws\": 419, \"mouse\": 1, \"mu_intercept_per_group\": 10.78445053100586, \"sigma_intercept_per_group\": 0.22970034182071686, \"sigma_obs\": 170.40774536132812, \"slope\": -0.07432404905557632, \"chain\": 2, \"draw\": 19}, {\"draws\": 419, \"mouse\": 2, \"mu_intercept_per_group\": 10.638895034790039, \"sigma_intercept_per_group\": 0.22970034182071686, \"sigma_obs\": 170.40774536132812, \"slope\": -0.07432404905557632, \"chain\": 2, \"draw\": 19}, {\"draws\": 419, \"mouse\": 3, \"mu_intercept_per_group\": 9.648151397705078, \"sigma_intercept_per_group\": 0.22970034182071686, \"sigma_obs\": 170.40774536132812, \"slope\": -0.07432404905557632, \"chain\": 2, \"draw\": 19}, {\"draws\": 419, \"mouse\": 4, \"mu_intercept_per_group\": 9.183878898620605, \"sigma_intercept_per_group\": 0.22970034182071686, \"sigma_obs\": 170.40774536132812, \"slope\": -0.07432404905557632, \"chain\": 2, \"draw\": 19}, {\"draws\": 419, \"mouse\": 5, \"mu_intercept_per_group\": 9.116517066955566, \"sigma_intercept_per_group\": 0.22970034182071686, \"sigma_obs\": 170.40774536132812, \"slope\": -0.07432404905557632, \"chain\": 2, \"draw\": 19}, {\"draws\": 419, \"mouse\": 6, \"mu_intercept_per_group\": 8.53581428527832, \"sigma_intercept_per_group\": 0.22970034182071686, \"sigma_obs\": 170.40774536132812, \"slope\": -0.07432404905557632, \"chain\": 2, \"draw\": 19}, {\"draws\": 419, \"mouse\": 7, \"mu_intercept_per_group\": 7.9250030517578125, \"sigma_intercept_per_group\": 0.22970034182071686, \"sigma_obs\": 170.40774536132812, \"slope\": -0.07432404905557632, \"chain\": 2, \"draw\": 19}, {\"draws\": 420, \"mouse\": 0, \"mu_intercept_per_group\": 10.867576599121094, \"sigma_intercept_per_group\": 0.23634251952171326, \"sigma_obs\": 162.651123046875, \"slope\": -0.07906027883291245, \"chain\": 2, \"draw\": 20}, {\"draws\": 420, \"mouse\": 1, \"mu_intercept_per_group\": 10.099522590637207, \"sigma_intercept_per_group\": 0.23634251952171326, \"sigma_obs\": 162.651123046875, \"slope\": -0.07906027883291245, \"chain\": 2, \"draw\": 20}, {\"draws\": 420, \"mouse\": 2, \"mu_intercept_per_group\": 9.70169448852539, \"sigma_intercept_per_group\": 0.23634251952171326, \"sigma_obs\": 162.651123046875, \"slope\": -0.07906027883291245, \"chain\": 2, \"draw\": 20}, {\"draws\": 420, \"mouse\": 3, \"mu_intercept_per_group\": 9.393524169921875, \"sigma_intercept_per_group\": 0.23634251952171326, \"sigma_obs\": 162.651123046875, \"slope\": -0.07906027883291245, \"chain\": 2, \"draw\": 20}, {\"draws\": 420, \"mouse\": 4, \"mu_intercept_per_group\": 9.342092514038086, \"sigma_intercept_per_group\": 0.23634251952171326, \"sigma_obs\": 162.651123046875, \"slope\": -0.07906027883291245, \"chain\": 2, \"draw\": 20}, {\"draws\": 420, \"mouse\": 5, \"mu_intercept_per_group\": 8.830272674560547, \"sigma_intercept_per_group\": 0.23634251952171326, \"sigma_obs\": 162.651123046875, \"slope\": -0.07906027883291245, \"chain\": 2, \"draw\": 20}, {\"draws\": 420, \"mouse\": 6, \"mu_intercept_per_group\": 8.279443740844727, \"sigma_intercept_per_group\": 0.23634251952171326, \"sigma_obs\": 162.651123046875, \"slope\": -0.07906027883291245, \"chain\": 2, \"draw\": 20}, {\"draws\": 420, \"mouse\": 7, \"mu_intercept_per_group\": 7.597849369049072, \"sigma_intercept_per_group\": 0.23634251952171326, \"sigma_obs\": 162.651123046875, \"slope\": -0.07906027883291245, \"chain\": 2, \"draw\": 20}, {\"draws\": 421, \"mouse\": 0, \"mu_intercept_per_group\": 10.813675880432129, \"sigma_intercept_per_group\": 0.2346765100955963, \"sigma_obs\": 159.10992431640625, \"slope\": -0.07811708003282547, \"chain\": 2, \"draw\": 21}, {\"draws\": 421, \"mouse\": 1, \"mu_intercept_per_group\": 10.160679817199707, \"sigma_intercept_per_group\": 0.2346765100955963, \"sigma_obs\": 159.10992431640625, \"slope\": -0.07811708003282547, \"chain\": 2, \"draw\": 21}, {\"draws\": 421, \"mouse\": 2, \"mu_intercept_per_group\": 9.765503883361816, \"sigma_intercept_per_group\": 0.2346765100955963, \"sigma_obs\": 159.10992431640625, \"slope\": -0.07811708003282547, \"chain\": 2, \"draw\": 21}, {\"draws\": 421, \"mouse\": 3, \"mu_intercept_per_group\": 9.446843147277832, \"sigma_intercept_per_group\": 0.2346765100955963, \"sigma_obs\": 159.10992431640625, \"slope\": -0.07811708003282547, \"chain\": 2, \"draw\": 21}, {\"draws\": 421, \"mouse\": 4, \"mu_intercept_per_group\": 9.434677124023438, \"sigma_intercept_per_group\": 0.2346765100955963, \"sigma_obs\": 159.10992431640625, \"slope\": -0.07811708003282547, \"chain\": 2, \"draw\": 21}, {\"draws\": 421, \"mouse\": 5, \"mu_intercept_per_group\": 8.383135795593262, \"sigma_intercept_per_group\": 0.2346765100955963, \"sigma_obs\": 159.10992431640625, \"slope\": -0.07811708003282547, \"chain\": 2, \"draw\": 21}, {\"draws\": 421, \"mouse\": 6, \"mu_intercept_per_group\": 8.074289321899414, \"sigma_intercept_per_group\": 0.2346765100955963, \"sigma_obs\": 159.10992431640625, \"slope\": -0.07811708003282547, \"chain\": 2, \"draw\": 21}, {\"draws\": 421, \"mouse\": 7, \"mu_intercept_per_group\": 7.710807800292969, \"sigma_intercept_per_group\": 0.2346765100955963, \"sigma_obs\": 159.10992431640625, \"slope\": -0.07811708003282547, \"chain\": 2, \"draw\": 21}, {\"draws\": 422, \"mouse\": 0, \"mu_intercept_per_group\": 10.646231651306152, \"sigma_intercept_per_group\": 0.23529785871505737, \"sigma_obs\": 159.6610870361328, \"slope\": -0.08117885887622833, \"chain\": 2, \"draw\": 22}, {\"draws\": 422, \"mouse\": 1, \"mu_intercept_per_group\": 10.23409652709961, \"sigma_intercept_per_group\": 0.23529785871505737, \"sigma_obs\": 159.6610870361328, \"slope\": -0.08117885887622833, \"chain\": 2, \"draw\": 22}, {\"draws\": 422, \"mouse\": 2, \"mu_intercept_per_group\": 10.127097129821777, \"sigma_intercept_per_group\": 0.23529785871505737, \"sigma_obs\": 159.6610870361328, \"slope\": -0.08117885887622833, \"chain\": 2, \"draw\": 22}, {\"draws\": 422, \"mouse\": 3, \"mu_intercept_per_group\": 9.379155158996582, \"sigma_intercept_per_group\": 0.23529785871505737, \"sigma_obs\": 159.6610870361328, \"slope\": -0.08117885887622833, \"chain\": 2, \"draw\": 22}, {\"draws\": 422, \"mouse\": 4, \"mu_intercept_per_group\": 8.897319793701172, \"sigma_intercept_per_group\": 0.23529785871505737, \"sigma_obs\": 159.6610870361328, \"slope\": -0.08117885887622833, \"chain\": 2, \"draw\": 22}, {\"draws\": 422, \"mouse\": 5, \"mu_intercept_per_group\": 8.855780601501465, \"sigma_intercept_per_group\": 0.23529785871505737, \"sigma_obs\": 159.6610870361328, \"slope\": -0.08117885887622833, \"chain\": 2, \"draw\": 22}, {\"draws\": 422, \"mouse\": 6, \"mu_intercept_per_group\": 8.096993446350098, \"sigma_intercept_per_group\": 0.23529785871505737, \"sigma_obs\": 159.6610870361328, \"slope\": -0.08117885887622833, \"chain\": 2, \"draw\": 22}, {\"draws\": 422, \"mouse\": 7, \"mu_intercept_per_group\": 7.7655205726623535, \"sigma_intercept_per_group\": 0.23529785871505737, \"sigma_obs\": 159.6610870361328, \"slope\": -0.08117885887622833, \"chain\": 2, \"draw\": 22}, {\"draws\": 423, \"mouse\": 0, \"mu_intercept_per_group\": 10.485528945922852, \"sigma_intercept_per_group\": 0.23492127656936646, \"sigma_obs\": 159.39947509765625, \"slope\": -0.08194537460803986, \"chain\": 2, \"draw\": 23}, {\"draws\": 423, \"mouse\": 1, \"mu_intercept_per_group\": 10.501583099365234, \"sigma_intercept_per_group\": 0.23492127656936646, \"sigma_obs\": 159.39947509765625, \"slope\": -0.08194537460803986, \"chain\": 2, \"draw\": 23}, {\"draws\": 423, \"mouse\": 2, \"mu_intercept_per_group\": 9.613543510437012, \"sigma_intercept_per_group\": 0.23492127656936646, \"sigma_obs\": 159.39947509765625, \"slope\": -0.08194537460803986, \"chain\": 2, \"draw\": 23}, {\"draws\": 423, \"mouse\": 3, \"mu_intercept_per_group\": 9.158976554870605, \"sigma_intercept_per_group\": 0.23492127656936646, \"sigma_obs\": 159.39947509765625, \"slope\": -0.08194537460803986, \"chain\": 2, \"draw\": 23}, {\"draws\": 423, \"mouse\": 4, \"mu_intercept_per_group\": 9.241883277893066, \"sigma_intercept_per_group\": 0.23492127656936646, \"sigma_obs\": 159.39947509765625, \"slope\": -0.08194537460803986, \"chain\": 2, \"draw\": 23}, {\"draws\": 423, \"mouse\": 5, \"mu_intercept_per_group\": 8.64568042755127, \"sigma_intercept_per_group\": 0.23492127656936646, \"sigma_obs\": 159.39947509765625, \"slope\": -0.08194537460803986, \"chain\": 2, \"draw\": 23}, {\"draws\": 423, \"mouse\": 6, \"mu_intercept_per_group\": 8.218493461608887, \"sigma_intercept_per_group\": 0.23492127656936646, \"sigma_obs\": 159.39947509765625, \"slope\": -0.08194537460803986, \"chain\": 2, \"draw\": 23}, {\"draws\": 423, \"mouse\": 7, \"mu_intercept_per_group\": 7.902749538421631, \"sigma_intercept_per_group\": 0.23492127656936646, \"sigma_obs\": 159.39947509765625, \"slope\": -0.08194537460803986, \"chain\": 2, \"draw\": 23}, {\"draws\": 424, \"mouse\": 0, \"mu_intercept_per_group\": 11.12568473815918, \"sigma_intercept_per_group\": 0.2255685180425644, \"sigma_obs\": 161.38705444335938, \"slope\": -0.0800485759973526, \"chain\": 2, \"draw\": 24}, {\"draws\": 424, \"mouse\": 1, \"mu_intercept_per_group\": 10.317984580993652, \"sigma_intercept_per_group\": 0.2255685180425644, \"sigma_obs\": 161.38705444335938, \"slope\": -0.0800485759973526, \"chain\": 2, \"draw\": 24}, {\"draws\": 424, \"mouse\": 2, \"mu_intercept_per_group\": 10.626225471496582, \"sigma_intercept_per_group\": 0.2255685180425644, \"sigma_obs\": 161.38705444335938, \"slope\": -0.0800485759973526, \"chain\": 2, \"draw\": 24}, {\"draws\": 424, \"mouse\": 3, \"mu_intercept_per_group\": 9.989714622497559, \"sigma_intercept_per_group\": 0.2255685180425644, \"sigma_obs\": 161.38705444335938, \"slope\": -0.0800485759973526, \"chain\": 2, \"draw\": 24}, {\"draws\": 424, \"mouse\": 4, \"mu_intercept_per_group\": 9.194526672363281, \"sigma_intercept_per_group\": 0.2255685180425644, \"sigma_obs\": 161.38705444335938, \"slope\": -0.0800485759973526, \"chain\": 2, \"draw\": 24}, {\"draws\": 424, \"mouse\": 5, \"mu_intercept_per_group\": 8.895760536193848, \"sigma_intercept_per_group\": 0.2255685180425644, \"sigma_obs\": 161.38705444335938, \"slope\": -0.0800485759973526, \"chain\": 2, \"draw\": 24}, {\"draws\": 424, \"mouse\": 6, \"mu_intercept_per_group\": 8.069524765014648, \"sigma_intercept_per_group\": 0.2255685180425644, \"sigma_obs\": 161.38705444335938, \"slope\": -0.0800485759973526, \"chain\": 2, \"draw\": 24}, {\"draws\": 424, \"mouse\": 7, \"mu_intercept_per_group\": 7.953125953674316, \"sigma_intercept_per_group\": 0.2255685180425644, \"sigma_obs\": 161.38705444335938, \"slope\": -0.0800485759973526, \"chain\": 2, \"draw\": 24}, {\"draws\": 425, \"mouse\": 0, \"mu_intercept_per_group\": 10.762978553771973, \"sigma_intercept_per_group\": 0.22575412690639496, \"sigma_obs\": 161.2741241455078, \"slope\": -0.0790572538971901, \"chain\": 2, \"draw\": 25}, {\"draws\": 425, \"mouse\": 1, \"mu_intercept_per_group\": 10.789127349853516, \"sigma_intercept_per_group\": 0.22575412690639496, \"sigma_obs\": 161.2741241455078, \"slope\": -0.0790572538971901, \"chain\": 2, \"draw\": 25}, {\"draws\": 425, \"mouse\": 2, \"mu_intercept_per_group\": 10.4011869430542, \"sigma_intercept_per_group\": 0.22575412690639496, \"sigma_obs\": 161.2741241455078, \"slope\": -0.0790572538971901, \"chain\": 2, \"draw\": 25}, {\"draws\": 425, \"mouse\": 3, \"mu_intercept_per_group\": 9.700591087341309, \"sigma_intercept_per_group\": 0.22575412690639496, \"sigma_obs\": 161.2741241455078, \"slope\": -0.0790572538971901, \"chain\": 2, \"draw\": 25}, {\"draws\": 425, \"mouse\": 4, \"mu_intercept_per_group\": 9.555181503295898, \"sigma_intercept_per_group\": 0.22575412690639496, \"sigma_obs\": 161.2741241455078, \"slope\": -0.0790572538971901, \"chain\": 2, \"draw\": 25}, {\"draws\": 425, \"mouse\": 5, \"mu_intercept_per_group\": 8.917437553405762, \"sigma_intercept_per_group\": 0.22575412690639496, \"sigma_obs\": 161.2741241455078, \"slope\": -0.0790572538971901, \"chain\": 2, \"draw\": 25}, {\"draws\": 425, \"mouse\": 6, \"mu_intercept_per_group\": 8.472830772399902, \"sigma_intercept_per_group\": 0.22575412690639496, \"sigma_obs\": 161.2741241455078, \"slope\": -0.0790572538971901, \"chain\": 2, \"draw\": 25}, {\"draws\": 425, \"mouse\": 7, \"mu_intercept_per_group\": 8.156163215637207, \"sigma_intercept_per_group\": 0.22575412690639496, \"sigma_obs\": 161.2741241455078, \"slope\": -0.0790572538971901, \"chain\": 2, \"draw\": 25}, {\"draws\": 426, \"mouse\": 0, \"mu_intercept_per_group\": 11.447863578796387, \"sigma_intercept_per_group\": 0.2233513593673706, \"sigma_obs\": 160.79205322265625, \"slope\": -0.07733839005231857, \"chain\": 2, \"draw\": 26}, {\"draws\": 426, \"mouse\": 1, \"mu_intercept_per_group\": 10.669754028320312, \"sigma_intercept_per_group\": 0.2233513593673706, \"sigma_obs\": 160.79205322265625, \"slope\": -0.07733839005231857, \"chain\": 2, \"draw\": 26}, {\"draws\": 426, \"mouse\": 2, \"mu_intercept_per_group\": 10.379434585571289, \"sigma_intercept_per_group\": 0.2233513593673706, \"sigma_obs\": 160.79205322265625, \"slope\": -0.07733839005231857, \"chain\": 2, \"draw\": 26}, {\"draws\": 426, \"mouse\": 3, \"mu_intercept_per_group\": 9.868987083435059, \"sigma_intercept_per_group\": 0.2233513593673706, \"sigma_obs\": 160.79205322265625, \"slope\": -0.07733839005231857, \"chain\": 2, \"draw\": 26}, {\"draws\": 426, \"mouse\": 4, \"mu_intercept_per_group\": 9.585095405578613, \"sigma_intercept_per_group\": 0.2233513593673706, \"sigma_obs\": 160.79205322265625, \"slope\": -0.07733839005231857, \"chain\": 2, \"draw\": 26}, {\"draws\": 426, \"mouse\": 5, \"mu_intercept_per_group\": 8.973808288574219, \"sigma_intercept_per_group\": 0.2233513593673706, \"sigma_obs\": 160.79205322265625, \"slope\": -0.07733839005231857, \"chain\": 2, \"draw\": 26}, {\"draws\": 426, \"mouse\": 6, \"mu_intercept_per_group\": 8.440485000610352, \"sigma_intercept_per_group\": 0.2233513593673706, \"sigma_obs\": 160.79205322265625, \"slope\": -0.07733839005231857, \"chain\": 2, \"draw\": 26}, {\"draws\": 426, \"mouse\": 7, \"mu_intercept_per_group\": 7.6807708740234375, \"sigma_intercept_per_group\": 0.2233513593673706, \"sigma_obs\": 160.79205322265625, \"slope\": -0.07733839005231857, \"chain\": 2, \"draw\": 26}, {\"draws\": 427, \"mouse\": 0, \"mu_intercept_per_group\": 10.88450813293457, \"sigma_intercept_per_group\": 0.2239961177110672, \"sigma_obs\": 160.4739532470703, \"slope\": -0.07661618292331696, \"chain\": 2, \"draw\": 27}, {\"draws\": 427, \"mouse\": 1, \"mu_intercept_per_group\": 10.854190826416016, \"sigma_intercept_per_group\": 0.2239961177110672, \"sigma_obs\": 160.4739532470703, \"slope\": -0.07661618292331696, \"chain\": 2, \"draw\": 27}, {\"draws\": 427, \"mouse\": 2, \"mu_intercept_per_group\": 10.494632720947266, \"sigma_intercept_per_group\": 0.2239961177110672, \"sigma_obs\": 160.4739532470703, \"slope\": -0.07661618292331696, \"chain\": 2, \"draw\": 27}, {\"draws\": 427, \"mouse\": 3, \"mu_intercept_per_group\": 9.66582202911377, \"sigma_intercept_per_group\": 0.2239961177110672, \"sigma_obs\": 160.4739532470703, \"slope\": -0.07661618292331696, \"chain\": 2, \"draw\": 27}, {\"draws\": 427, \"mouse\": 4, \"mu_intercept_per_group\": 9.528913497924805, \"sigma_intercept_per_group\": 0.2239961177110672, \"sigma_obs\": 160.4739532470703, \"slope\": -0.07661618292331696, \"chain\": 2, \"draw\": 27}, {\"draws\": 427, \"mouse\": 5, \"mu_intercept_per_group\": 9.086385726928711, \"sigma_intercept_per_group\": 0.2239961177110672, \"sigma_obs\": 160.4739532470703, \"slope\": -0.07661618292331696, \"chain\": 2, \"draw\": 27}, {\"draws\": 427, \"mouse\": 6, \"mu_intercept_per_group\": 8.35349178314209, \"sigma_intercept_per_group\": 0.2239961177110672, \"sigma_obs\": 160.4739532470703, \"slope\": -0.07661618292331696, \"chain\": 2, \"draw\": 27}, {\"draws\": 427, \"mouse\": 7, \"mu_intercept_per_group\": 7.956252098083496, \"sigma_intercept_per_group\": 0.2239961177110672, \"sigma_obs\": 160.4739532470703, \"slope\": -0.07661618292331696, \"chain\": 2, \"draw\": 27}, {\"draws\": 428, \"mouse\": 0, \"mu_intercept_per_group\": 10.908121109008789, \"sigma_intercept_per_group\": 0.2242361456155777, \"sigma_obs\": 160.55348205566406, \"slope\": -0.07656186819076538, \"chain\": 2, \"draw\": 28}, {\"draws\": 428, \"mouse\": 1, \"mu_intercept_per_group\": 10.848950386047363, \"sigma_intercept_per_group\": 0.2242361456155777, \"sigma_obs\": 160.55348205566406, \"slope\": -0.07656186819076538, \"chain\": 2, \"draw\": 28}, {\"draws\": 428, \"mouse\": 2, \"mu_intercept_per_group\": 10.49420166015625, \"sigma_intercept_per_group\": 0.2242361456155777, \"sigma_obs\": 160.55348205566406, \"slope\": -0.07656186819076538, \"chain\": 2, \"draw\": 28}, {\"draws\": 428, \"mouse\": 3, \"mu_intercept_per_group\": 9.648954391479492, \"sigma_intercept_per_group\": 0.2242361456155777, \"sigma_obs\": 160.55348205566406, \"slope\": -0.07656186819076538, \"chain\": 2, \"draw\": 28}, {\"draws\": 428, \"mouse\": 4, \"mu_intercept_per_group\": 9.550978660583496, \"sigma_intercept_per_group\": 0.2242361456155777, \"sigma_obs\": 160.55348205566406, \"slope\": -0.07656186819076538, \"chain\": 2, \"draw\": 28}, {\"draws\": 428, \"mouse\": 5, \"mu_intercept_per_group\": 9.03639030456543, \"sigma_intercept_per_group\": 0.2242361456155777, \"sigma_obs\": 160.55348205566406, \"slope\": -0.07656186819076538, \"chain\": 2, \"draw\": 28}, {\"draws\": 428, \"mouse\": 6, \"mu_intercept_per_group\": 8.4039306640625, \"sigma_intercept_per_group\": 0.2242361456155777, \"sigma_obs\": 160.55348205566406, \"slope\": -0.07656186819076538, \"chain\": 2, \"draw\": 28}, {\"draws\": 428, \"mouse\": 7, \"mu_intercept_per_group\": 7.913067817687988, \"sigma_intercept_per_group\": 0.2242361456155777, \"sigma_obs\": 160.55348205566406, \"slope\": -0.07656186819076538, \"chain\": 2, \"draw\": 28}, {\"draws\": 429, \"mouse\": 0, \"mu_intercept_per_group\": 10.497650146484375, \"sigma_intercept_per_group\": 0.2401166558265686, \"sigma_obs\": 163.55001831054688, \"slope\": -0.08301593363285065, \"chain\": 2, \"draw\": 29}, {\"draws\": 429, \"mouse\": 1, \"mu_intercept_per_group\": 10.070962905883789, \"sigma_intercept_per_group\": 0.2401166558265686, \"sigma_obs\": 163.55001831054688, \"slope\": -0.08301593363285065, \"chain\": 2, \"draw\": 29}, {\"draws\": 429, \"mouse\": 2, \"mu_intercept_per_group\": 9.663228988647461, \"sigma_intercept_per_group\": 0.2401166558265686, \"sigma_obs\": 163.55001831054688, \"slope\": -0.08301593363285065, \"chain\": 2, \"draw\": 29}, {\"draws\": 429, \"mouse\": 3, \"mu_intercept_per_group\": 9.321764945983887, \"sigma_intercept_per_group\": 0.2401166558265686, \"sigma_obs\": 163.55001831054688, \"slope\": -0.08301593363285065, \"chain\": 2, \"draw\": 29}, {\"draws\": 429, \"mouse\": 4, \"mu_intercept_per_group\": 9.132986068725586, \"sigma_intercept_per_group\": 0.2401166558265686, \"sigma_obs\": 163.55001831054688, \"slope\": -0.08301593363285065, \"chain\": 2, \"draw\": 29}, {\"draws\": 429, \"mouse\": 5, \"mu_intercept_per_group\": 8.44288444519043, \"sigma_intercept_per_group\": 0.2401166558265686, \"sigma_obs\": 163.55001831054688, \"slope\": -0.08301593363285065, \"chain\": 2, \"draw\": 29}, {\"draws\": 429, \"mouse\": 6, \"mu_intercept_per_group\": 7.903697490692139, \"sigma_intercept_per_group\": 0.2401166558265686, \"sigma_obs\": 163.55001831054688, \"slope\": -0.08301593363285065, \"chain\": 2, \"draw\": 29}, {\"draws\": 429, \"mouse\": 7, \"mu_intercept_per_group\": 7.420753002166748, \"sigma_intercept_per_group\": 0.2401166558265686, \"sigma_obs\": 163.55001831054688, \"slope\": -0.08301593363285065, \"chain\": 2, \"draw\": 29}, {\"draws\": 430, \"mouse\": 0, \"mu_intercept_per_group\": 9.960468292236328, \"sigma_intercept_per_group\": 0.25667399168014526, \"sigma_obs\": 174.62579345703125, \"slope\": -0.08173730969429016, \"chain\": 2, \"draw\": 30}, {\"draws\": 430, \"mouse\": 1, \"mu_intercept_per_group\": 9.66272258758545, \"sigma_intercept_per_group\": 0.25667399168014526, \"sigma_obs\": 174.62579345703125, \"slope\": -0.08173730969429016, \"chain\": 2, \"draw\": 30}, {\"draws\": 430, \"mouse\": 2, \"mu_intercept_per_group\": 9.487077713012695, \"sigma_intercept_per_group\": 0.25667399168014526, \"sigma_obs\": 174.62579345703125, \"slope\": -0.08173730969429016, \"chain\": 2, \"draw\": 30}, {\"draws\": 430, \"mouse\": 3, \"mu_intercept_per_group\": 8.943098068237305, \"sigma_intercept_per_group\": 0.25667399168014526, \"sigma_obs\": 174.62579345703125, \"slope\": -0.08173730969429016, \"chain\": 2, \"draw\": 30}, {\"draws\": 430, \"mouse\": 4, \"mu_intercept_per_group\": 8.766592025756836, \"sigma_intercept_per_group\": 0.25667399168014526, \"sigma_obs\": 174.62579345703125, \"slope\": -0.08173730969429016, \"chain\": 2, \"draw\": 30}, {\"draws\": 430, \"mouse\": 5, \"mu_intercept_per_group\": 8.030084609985352, \"sigma_intercept_per_group\": 0.25667399168014526, \"sigma_obs\": 174.62579345703125, \"slope\": -0.08173730969429016, \"chain\": 2, \"draw\": 30}, {\"draws\": 430, \"mouse\": 6, \"mu_intercept_per_group\": 7.843801498413086, \"sigma_intercept_per_group\": 0.25667399168014526, \"sigma_obs\": 174.62579345703125, \"slope\": -0.08173730969429016, \"chain\": 2, \"draw\": 30}, {\"draws\": 430, \"mouse\": 7, \"mu_intercept_per_group\": 7.460757732391357, \"sigma_intercept_per_group\": 0.25667399168014526, \"sigma_obs\": 174.62579345703125, \"slope\": -0.08173730969429016, \"chain\": 2, \"draw\": 30}, {\"draws\": 431, \"mouse\": 0, \"mu_intercept_per_group\": 8.628853797912598, \"sigma_intercept_per_group\": 0.29117879271507263, \"sigma_obs\": 161.71368408203125, \"slope\": -0.07103201001882553, \"chain\": 2, \"draw\": 31}, {\"draws\": 431, \"mouse\": 1, \"mu_intercept_per_group\": 8.249129295349121, \"sigma_intercept_per_group\": 0.29117879271507263, \"sigma_obs\": 161.71368408203125, \"slope\": -0.07103201001882553, \"chain\": 2, \"draw\": 31}, {\"draws\": 431, \"mouse\": 2, \"mu_intercept_per_group\": 7.967729568481445, \"sigma_intercept_per_group\": 0.29117879271507263, \"sigma_obs\": 161.71368408203125, \"slope\": -0.07103201001882553, \"chain\": 2, \"draw\": 31}, {\"draws\": 431, \"mouse\": 3, \"mu_intercept_per_group\": 7.547793388366699, \"sigma_intercept_per_group\": 0.29117879271507263, \"sigma_obs\": 161.71368408203125, \"slope\": -0.07103201001882553, \"chain\": 2, \"draw\": 31}, {\"draws\": 431, \"mouse\": 4, \"mu_intercept_per_group\": 7.1674933433532715, \"sigma_intercept_per_group\": 0.29117879271507263, \"sigma_obs\": 161.71368408203125, \"slope\": -0.07103201001882553, \"chain\": 2, \"draw\": 31}, {\"draws\": 431, \"mouse\": 5, \"mu_intercept_per_group\": 6.977872848510742, \"sigma_intercept_per_group\": 0.29117879271507263, \"sigma_obs\": 161.71368408203125, \"slope\": -0.07103201001882553, \"chain\": 2, \"draw\": 31}, {\"draws\": 431, \"mouse\": 6, \"mu_intercept_per_group\": 6.541923522949219, \"sigma_intercept_per_group\": 0.29117879271507263, \"sigma_obs\": 161.71368408203125, \"slope\": -0.07103201001882553, \"chain\": 2, \"draw\": 31}, {\"draws\": 431, \"mouse\": 7, \"mu_intercept_per_group\": 6.096682071685791, \"sigma_intercept_per_group\": 0.29117879271507263, \"sigma_obs\": 161.71368408203125, \"slope\": -0.07103201001882553, \"chain\": 2, \"draw\": 31}, {\"draws\": 432, \"mouse\": 0, \"mu_intercept_per_group\": 8.6244535446167, \"sigma_intercept_per_group\": 0.2895817756652832, \"sigma_obs\": 161.65292358398438, \"slope\": -0.07020153850317001, \"chain\": 2, \"draw\": 32}, {\"draws\": 432, \"mouse\": 1, \"mu_intercept_per_group\": 8.5012788772583, \"sigma_intercept_per_group\": 0.2895817756652832, \"sigma_obs\": 161.65292358398438, \"slope\": -0.07020153850317001, \"chain\": 2, \"draw\": 32}, {\"draws\": 432, \"mouse\": 2, \"mu_intercept_per_group\": 8.140556335449219, \"sigma_intercept_per_group\": 0.2895817756652832, \"sigma_obs\": 161.65292358398438, \"slope\": -0.07020153850317001, \"chain\": 2, \"draw\": 32}, {\"draws\": 432, \"mouse\": 3, \"mu_intercept_per_group\": 7.402920246124268, \"sigma_intercept_per_group\": 0.2895817756652832, \"sigma_obs\": 161.65292358398438, \"slope\": -0.07020153850317001, \"chain\": 2, \"draw\": 32}, {\"draws\": 432, \"mouse\": 4, \"mu_intercept_per_group\": 7.263827323913574, \"sigma_intercept_per_group\": 0.2895817756652832, \"sigma_obs\": 161.65292358398438, \"slope\": -0.07020153850317001, \"chain\": 2, \"draw\": 32}, {\"draws\": 432, \"mouse\": 5, \"mu_intercept_per_group\": 6.908813953399658, \"sigma_intercept_per_group\": 0.2895817756652832, \"sigma_obs\": 161.65292358398438, \"slope\": -0.07020153850317001, \"chain\": 2, \"draw\": 32}, {\"draws\": 432, \"mouse\": 6, \"mu_intercept_per_group\": 6.4722371101379395, \"sigma_intercept_per_group\": 0.2895817756652832, \"sigma_obs\": 161.65292358398438, \"slope\": -0.07020153850317001, \"chain\": 2, \"draw\": 32}, {\"draws\": 432, \"mouse\": 7, \"mu_intercept_per_group\": 6.0451202392578125, \"sigma_intercept_per_group\": 0.2895817756652832, \"sigma_obs\": 161.65292358398438, \"slope\": -0.07020153850317001, \"chain\": 2, \"draw\": 32}, {\"draws\": 433, \"mouse\": 0, \"mu_intercept_per_group\": 8.725288391113281, \"sigma_intercept_per_group\": 0.28724268078804016, \"sigma_obs\": 161.43893432617188, \"slope\": -0.07083023339509964, \"chain\": 2, \"draw\": 33}, {\"draws\": 433, \"mouse\": 1, \"mu_intercept_per_group\": 8.5458402633667, \"sigma_intercept_per_group\": 0.28724268078804016, \"sigma_obs\": 161.43893432617188, \"slope\": -0.07083023339509964, \"chain\": 2, \"draw\": 33}, {\"draws\": 433, \"mouse\": 2, \"mu_intercept_per_group\": 7.9974045753479, \"sigma_intercept_per_group\": 0.28724268078804016, \"sigma_obs\": 161.43893432617188, \"slope\": -0.07083023339509964, \"chain\": 2, \"draw\": 33}, {\"draws\": 433, \"mouse\": 3, \"mu_intercept_per_group\": 7.267980575561523, \"sigma_intercept_per_group\": 0.28724268078804016, \"sigma_obs\": 161.43893432617188, \"slope\": -0.07083023339509964, \"chain\": 2, \"draw\": 33}, {\"draws\": 433, \"mouse\": 4, \"mu_intercept_per_group\": 7.360105991363525, \"sigma_intercept_per_group\": 0.28724268078804016, \"sigma_obs\": 161.43893432617188, \"slope\": -0.07083023339509964, \"chain\": 2, \"draw\": 33}, {\"draws\": 433, \"mouse\": 5, \"mu_intercept_per_group\": 6.772966384887695, \"sigma_intercept_per_group\": 0.28724268078804016, \"sigma_obs\": 161.43893432617188, \"slope\": -0.07083023339509964, \"chain\": 2, \"draw\": 33}, {\"draws\": 433, \"mouse\": 6, \"mu_intercept_per_group\": 6.537482738494873, \"sigma_intercept_per_group\": 0.28724268078804016, \"sigma_obs\": 161.43893432617188, \"slope\": -0.07083023339509964, \"chain\": 2, \"draw\": 33}, {\"draws\": 433, \"mouse\": 7, \"mu_intercept_per_group\": 6.099184989929199, \"sigma_intercept_per_group\": 0.28724268078804016, \"sigma_obs\": 161.43893432617188, \"slope\": -0.07083023339509964, \"chain\": 2, \"draw\": 33}, {\"draws\": 434, \"mouse\": 0, \"mu_intercept_per_group\": 8.690382957458496, \"sigma_intercept_per_group\": 0.28858307003974915, \"sigma_obs\": 161.8458251953125, \"slope\": -0.07076181471347809, \"chain\": 2, \"draw\": 34}, {\"draws\": 434, \"mouse\": 1, \"mu_intercept_per_group\": 8.383362770080566, \"sigma_intercept_per_group\": 0.28858307003974915, \"sigma_obs\": 161.8458251953125, \"slope\": -0.07076181471347809, \"chain\": 2, \"draw\": 34}, {\"draws\": 434, \"mouse\": 2, \"mu_intercept_per_group\": 8.14223861694336, \"sigma_intercept_per_group\": 0.28858307003974915, \"sigma_obs\": 161.8458251953125, \"slope\": -0.07076181471347809, \"chain\": 2, \"draw\": 34}, {\"draws\": 434, \"mouse\": 3, \"mu_intercept_per_group\": 7.5921125411987305, \"sigma_intercept_per_group\": 0.28858307003974915, \"sigma_obs\": 161.8458251953125, \"slope\": -0.07076181471347809, \"chain\": 2, \"draw\": 34}, {\"draws\": 434, \"mouse\": 4, \"mu_intercept_per_group\": 7.4609479904174805, \"sigma_intercept_per_group\": 0.28858307003974915, \"sigma_obs\": 161.8458251953125, \"slope\": -0.07076181471347809, \"chain\": 2, \"draw\": 34}, {\"draws\": 434, \"mouse\": 5, \"mu_intercept_per_group\": 6.937032699584961, \"sigma_intercept_per_group\": 0.28858307003974915, \"sigma_obs\": 161.8458251953125, \"slope\": -0.07076181471347809, \"chain\": 2, \"draw\": 34}, {\"draws\": 434, \"mouse\": 6, \"mu_intercept_per_group\": 6.457260608673096, \"sigma_intercept_per_group\": 0.28858307003974915, \"sigma_obs\": 161.8458251953125, \"slope\": -0.07076181471347809, \"chain\": 2, \"draw\": 34}, {\"draws\": 434, \"mouse\": 7, \"mu_intercept_per_group\": 6.134805202484131, \"sigma_intercept_per_group\": 0.28858307003974915, \"sigma_obs\": 161.8458251953125, \"slope\": -0.07076181471347809, \"chain\": 2, \"draw\": 34}, {\"draws\": 435, \"mouse\": 0, \"mu_intercept_per_group\": 8.289484024047852, \"sigma_intercept_per_group\": 0.30277860164642334, \"sigma_obs\": 171.62908935546875, \"slope\": -0.05883854255080223, \"chain\": 2, \"draw\": 35}, {\"draws\": 435, \"mouse\": 1, \"mu_intercept_per_group\": 8.025862693786621, \"sigma_intercept_per_group\": 0.30277860164642334, \"sigma_obs\": 171.62908935546875, \"slope\": -0.05883854255080223, \"chain\": 2, \"draw\": 35}, {\"draws\": 435, \"mouse\": 2, \"mu_intercept_per_group\": 7.915266036987305, \"sigma_intercept_per_group\": 0.30277860164642334, \"sigma_obs\": 171.62908935546875, \"slope\": -0.05883854255080223, \"chain\": 2, \"draw\": 35}, {\"draws\": 435, \"mouse\": 3, \"mu_intercept_per_group\": 7.367823123931885, \"sigma_intercept_per_group\": 0.30277860164642334, \"sigma_obs\": 171.62908935546875, \"slope\": -0.05883854255080223, \"chain\": 2, \"draw\": 35}, {\"draws\": 435, \"mouse\": 4, \"mu_intercept_per_group\": 7.180119037628174, \"sigma_intercept_per_group\": 0.30277860164642334, \"sigma_obs\": 171.62908935546875, \"slope\": -0.05883854255080223, \"chain\": 2, \"draw\": 35}, {\"draws\": 435, \"mouse\": 5, \"mu_intercept_per_group\": 6.803749084472656, \"sigma_intercept_per_group\": 0.30277860164642334, \"sigma_obs\": 171.62908935546875, \"slope\": -0.05883854255080223, \"chain\": 2, \"draw\": 35}, {\"draws\": 435, \"mouse\": 6, \"mu_intercept_per_group\": 6.46006965637207, \"sigma_intercept_per_group\": 0.30277860164642334, \"sigma_obs\": 171.62908935546875, \"slope\": -0.05883854255080223, \"chain\": 2, \"draw\": 35}, {\"draws\": 435, \"mouse\": 7, \"mu_intercept_per_group\": 6.164252281188965, \"sigma_intercept_per_group\": 0.30277860164642334, \"sigma_obs\": 171.62908935546875, \"slope\": -0.05883854255080223, \"chain\": 2, \"draw\": 35}, {\"draws\": 436, \"mouse\": 0, \"mu_intercept_per_group\": 8.643742561340332, \"sigma_intercept_per_group\": 0.29968637228012085, \"sigma_obs\": 171.18707275390625, \"slope\": -0.058990463614463806, \"chain\": 2, \"draw\": 36}, {\"draws\": 436, \"mouse\": 1, \"mu_intercept_per_group\": 8.056166648864746, \"sigma_intercept_per_group\": 0.29968637228012085, \"sigma_obs\": 171.18707275390625, \"slope\": -0.058990463614463806, \"chain\": 2, \"draw\": 36}, {\"draws\": 436, \"mouse\": 2, \"mu_intercept_per_group\": 7.973758697509766, \"sigma_intercept_per_group\": 0.29968637228012085, \"sigma_obs\": 171.18707275390625, \"slope\": -0.058990463614463806, \"chain\": 2, \"draw\": 36}, {\"draws\": 436, \"mouse\": 3, \"mu_intercept_per_group\": 7.610030651092529, \"sigma_intercept_per_group\": 0.29968637228012085, \"sigma_obs\": 171.18707275390625, \"slope\": -0.058990463614463806, \"chain\": 2, \"draw\": 36}, {\"draws\": 436, \"mouse\": 4, \"mu_intercept_per_group\": 7.257688045501709, \"sigma_intercept_per_group\": 0.29968637228012085, \"sigma_obs\": 171.18707275390625, \"slope\": -0.058990463614463806, \"chain\": 2, \"draw\": 36}, {\"draws\": 436, \"mouse\": 5, \"mu_intercept_per_group\": 6.531717300415039, \"sigma_intercept_per_group\": 0.29968637228012085, \"sigma_obs\": 171.18707275390625, \"slope\": -0.058990463614463806, \"chain\": 2, \"draw\": 36}, {\"draws\": 436, \"mouse\": 6, \"mu_intercept_per_group\": 6.439729690551758, \"sigma_intercept_per_group\": 0.29968637228012085, \"sigma_obs\": 171.18707275390625, \"slope\": -0.058990463614463806, \"chain\": 2, \"draw\": 36}, {\"draws\": 436, \"mouse\": 7, \"mu_intercept_per_group\": 6.165639877319336, \"sigma_intercept_per_group\": 0.29968637228012085, \"sigma_obs\": 171.18707275390625, \"slope\": -0.058990463614463806, \"chain\": 2, \"draw\": 36}, {\"draws\": 437, \"mouse\": 0, \"mu_intercept_per_group\": 8.881002426147461, \"sigma_intercept_per_group\": 0.29066500067710876, \"sigma_obs\": 169.03955078125, \"slope\": -0.058019425719976425, \"chain\": 2, \"draw\": 37}, {\"draws\": 437, \"mouse\": 1, \"mu_intercept_per_group\": 8.282999038696289, \"sigma_intercept_per_group\": 0.29066500067710876, \"sigma_obs\": 169.03955078125, \"slope\": -0.058019425719976425, \"chain\": 2, \"draw\": 37}, {\"draws\": 437, \"mouse\": 2, \"mu_intercept_per_group\": 7.965280532836914, \"sigma_intercept_per_group\": 0.29066500067710876, \"sigma_obs\": 169.03955078125, \"slope\": -0.058019425719976425, \"chain\": 2, \"draw\": 37}, {\"draws\": 437, \"mouse\": 3, \"mu_intercept_per_group\": 7.503580093383789, \"sigma_intercept_per_group\": 0.29066500067710876, \"sigma_obs\": 169.03955078125, \"slope\": -0.058019425719976425, \"chain\": 2, \"draw\": 37}, {\"draws\": 437, \"mouse\": 4, \"mu_intercept_per_group\": 7.362312316894531, \"sigma_intercept_per_group\": 0.29066500067710876, \"sigma_obs\": 169.03955078125, \"slope\": -0.058019425719976425, \"chain\": 2, \"draw\": 37}, {\"draws\": 437, \"mouse\": 5, \"mu_intercept_per_group\": 7.368962287902832, \"sigma_intercept_per_group\": 0.29066500067710876, \"sigma_obs\": 169.03955078125, \"slope\": -0.058019425719976425, \"chain\": 2, \"draw\": 37}, {\"draws\": 437, \"mouse\": 6, \"mu_intercept_per_group\": 6.603176116943359, \"sigma_intercept_per_group\": 0.29066500067710876, \"sigma_obs\": 169.03955078125, \"slope\": -0.058019425719976425, \"chain\": 2, \"draw\": 37}, {\"draws\": 437, \"mouse\": 7, \"mu_intercept_per_group\": 6.164427280426025, \"sigma_intercept_per_group\": 0.29066500067710876, \"sigma_obs\": 169.03955078125, \"slope\": -0.058019425719976425, \"chain\": 2, \"draw\": 37}, {\"draws\": 438, \"mouse\": 0, \"mu_intercept_per_group\": 10.835359573364258, \"sigma_intercept_per_group\": 0.2286989837884903, \"sigma_obs\": 172.61668395996094, \"slope\": -0.06488732248544693, \"chain\": 2, \"draw\": 38}, {\"draws\": 438, \"mouse\": 1, \"mu_intercept_per_group\": 10.848184585571289, \"sigma_intercept_per_group\": 0.2286989837884903, \"sigma_obs\": 172.61668395996094, \"slope\": -0.06488732248544693, \"chain\": 2, \"draw\": 38}, {\"draws\": 438, \"mouse\": 2, \"mu_intercept_per_group\": 10.456892013549805, \"sigma_intercept_per_group\": 0.2286989837884903, \"sigma_obs\": 172.61668395996094, \"slope\": -0.06488732248544693, \"chain\": 2, \"draw\": 38}, {\"draws\": 438, \"mouse\": 3, \"mu_intercept_per_group\": 9.964470863342285, \"sigma_intercept_per_group\": 0.2286989837884903, \"sigma_obs\": 172.61668395996094, \"slope\": -0.06488732248544693, \"chain\": 2, \"draw\": 38}, {\"draws\": 438, \"mouse\": 4, \"mu_intercept_per_group\": 9.559369087219238, \"sigma_intercept_per_group\": 0.2286989837884903, \"sigma_obs\": 172.61668395996094, \"slope\": -0.06488732248544693, \"chain\": 2, \"draw\": 38}, {\"draws\": 438, \"mouse\": 5, \"mu_intercept_per_group\": 8.71455192565918, \"sigma_intercept_per_group\": 0.2286989837884903, \"sigma_obs\": 172.61668395996094, \"slope\": -0.06488732248544693, \"chain\": 2, \"draw\": 38}, {\"draws\": 438, \"mouse\": 6, \"mu_intercept_per_group\": 8.28702449798584, \"sigma_intercept_per_group\": 0.2286989837884903, \"sigma_obs\": 172.61668395996094, \"slope\": -0.06488732248544693, \"chain\": 2, \"draw\": 38}, {\"draws\": 438, \"mouse\": 7, \"mu_intercept_per_group\": 7.817932605743408, \"sigma_intercept_per_group\": 0.2286989837884903, \"sigma_obs\": 172.61668395996094, \"slope\": -0.06488732248544693, \"chain\": 2, \"draw\": 38}, {\"draws\": 439, \"mouse\": 0, \"mu_intercept_per_group\": 11.403360366821289, \"sigma_intercept_per_group\": 0.228714719414711, \"sigma_obs\": 173.6847381591797, \"slope\": -0.06420806795358658, \"chain\": 2, \"draw\": 39}, {\"draws\": 439, \"mouse\": 1, \"mu_intercept_per_group\": 10.567046165466309, \"sigma_intercept_per_group\": 0.228714719414711, \"sigma_obs\": 173.6847381591797, \"slope\": -0.06420806795358658, \"chain\": 2, \"draw\": 39}, {\"draws\": 439, \"mouse\": 2, \"mu_intercept_per_group\": 10.424309730529785, \"sigma_intercept_per_group\": 0.228714719414711, \"sigma_obs\": 173.6847381591797, \"slope\": -0.06420806795358658, \"chain\": 2, \"draw\": 39}, {\"draws\": 439, \"mouse\": 3, \"mu_intercept_per_group\": 9.666422843933105, \"sigma_intercept_per_group\": 0.228714719414711, \"sigma_obs\": 173.6847381591797, \"slope\": -0.06420806795358658, \"chain\": 2, \"draw\": 39}, {\"draws\": 439, \"mouse\": 4, \"mu_intercept_per_group\": 9.525850296020508, \"sigma_intercept_per_group\": 0.228714719414711, \"sigma_obs\": 173.6847381591797, \"slope\": -0.06420806795358658, \"chain\": 2, \"draw\": 39}, {\"draws\": 439, \"mouse\": 5, \"mu_intercept_per_group\": 9.479146957397461, \"sigma_intercept_per_group\": 0.228714719414711, \"sigma_obs\": 173.6847381591797, \"slope\": -0.06420806795358658, \"chain\": 2, \"draw\": 39}, {\"draws\": 439, \"mouse\": 6, \"mu_intercept_per_group\": 8.700003623962402, \"sigma_intercept_per_group\": 0.228714719414711, \"sigma_obs\": 173.6847381591797, \"slope\": -0.06420806795358658, \"chain\": 2, \"draw\": 39}, {\"draws\": 439, \"mouse\": 7, \"mu_intercept_per_group\": 8.264161109924316, \"sigma_intercept_per_group\": 0.228714719414711, \"sigma_obs\": 173.6847381591797, \"slope\": -0.06420806795358658, \"chain\": 2, \"draw\": 39}, {\"draws\": 440, \"mouse\": 0, \"mu_intercept_per_group\": 11.000784873962402, \"sigma_intercept_per_group\": 0.22642143070697784, \"sigma_obs\": 173.7490234375, \"slope\": -0.06372055411338806, \"chain\": 2, \"draw\": 40}, {\"draws\": 440, \"mouse\": 1, \"mu_intercept_per_group\": 10.692840576171875, \"sigma_intercept_per_group\": 0.22642143070697784, \"sigma_obs\": 173.7490234375, \"slope\": -0.06372055411338806, \"chain\": 2, \"draw\": 40}, {\"draws\": 440, \"mouse\": 2, \"mu_intercept_per_group\": 10.559507369995117, \"sigma_intercept_per_group\": 0.22642143070697784, \"sigma_obs\": 173.7490234375, \"slope\": -0.06372055411338806, \"chain\": 2, \"draw\": 40}, {\"draws\": 440, \"mouse\": 3, \"mu_intercept_per_group\": 9.779891014099121, \"sigma_intercept_per_group\": 0.22642143070697784, \"sigma_obs\": 173.7490234375, \"slope\": -0.06372055411338806, \"chain\": 2, \"draw\": 40}, {\"draws\": 440, \"mouse\": 4, \"mu_intercept_per_group\": 9.518723487854004, \"sigma_intercept_per_group\": 0.22642143070697784, \"sigma_obs\": 173.7490234375, \"slope\": -0.06372055411338806, \"chain\": 2, \"draw\": 40}, {\"draws\": 440, \"mouse\": 5, \"mu_intercept_per_group\": 9.509939193725586, \"sigma_intercept_per_group\": 0.22642143070697784, \"sigma_obs\": 173.7490234375, \"slope\": -0.06372055411338806, \"chain\": 2, \"draw\": 40}, {\"draws\": 440, \"mouse\": 6, \"mu_intercept_per_group\": 8.589333534240723, \"sigma_intercept_per_group\": 0.22642143070697784, \"sigma_obs\": 173.7490234375, \"slope\": -0.06372055411338806, \"chain\": 2, \"draw\": 40}, {\"draws\": 440, \"mouse\": 7, \"mu_intercept_per_group\": 8.119646072387695, \"sigma_intercept_per_group\": 0.22642143070697784, \"sigma_obs\": 173.7490234375, \"slope\": -0.06372055411338806, \"chain\": 2, \"draw\": 40}, {\"draws\": 441, \"mouse\": 0, \"mu_intercept_per_group\": 11.450591087341309, \"sigma_intercept_per_group\": 0.22136849164962769, \"sigma_obs\": 171.36282348632812, \"slope\": -0.06487567722797394, \"chain\": 2, \"draw\": 41}, {\"draws\": 441, \"mouse\": 1, \"mu_intercept_per_group\": 11.047038078308105, \"sigma_intercept_per_group\": 0.22136849164962769, \"sigma_obs\": 171.36282348632812, \"slope\": -0.06487567722797394, \"chain\": 2, \"draw\": 41}, {\"draws\": 441, \"mouse\": 2, \"mu_intercept_per_group\": 10.839789390563965, \"sigma_intercept_per_group\": 0.22136849164962769, \"sigma_obs\": 171.36282348632812, \"slope\": -0.06487567722797394, \"chain\": 2, \"draw\": 41}, {\"draws\": 441, \"mouse\": 3, \"mu_intercept_per_group\": 10.265939712524414, \"sigma_intercept_per_group\": 0.22136849164962769, \"sigma_obs\": 171.36282348632812, \"slope\": -0.06487567722797394, \"chain\": 2, \"draw\": 41}, {\"draws\": 441, \"mouse\": 4, \"mu_intercept_per_group\": 10.023138046264648, \"sigma_intercept_per_group\": 0.22136849164962769, \"sigma_obs\": 171.36282348632812, \"slope\": -0.06487567722797394, \"chain\": 2, \"draw\": 41}, {\"draws\": 441, \"mouse\": 5, \"mu_intercept_per_group\": 9.035391807556152, \"sigma_intercept_per_group\": 0.22136849164962769, \"sigma_obs\": 171.36282348632812, \"slope\": -0.06487567722797394, \"chain\": 2, \"draw\": 41}, {\"draws\": 441, \"mouse\": 6, \"mu_intercept_per_group\": 8.712274551391602, \"sigma_intercept_per_group\": 0.22136849164962769, \"sigma_obs\": 171.36282348632812, \"slope\": -0.06487567722797394, \"chain\": 2, \"draw\": 41}, {\"draws\": 441, \"mouse\": 7, \"mu_intercept_per_group\": 8.307158470153809, \"sigma_intercept_per_group\": 0.22136849164962769, \"sigma_obs\": 171.36282348632812, \"slope\": -0.06487567722797394, \"chain\": 2, \"draw\": 41}, {\"draws\": 442, \"mouse\": 0, \"mu_intercept_per_group\": 11.52735710144043, \"sigma_intercept_per_group\": 0.2200172245502472, \"sigma_obs\": 169.9317626953125, \"slope\": -0.06378025561571121, \"chain\": 2, \"draw\": 42}, {\"draws\": 442, \"mouse\": 1, \"mu_intercept_per_group\": 11.034555435180664, \"sigma_intercept_per_group\": 0.2200172245502472, \"sigma_obs\": 169.9317626953125, \"slope\": -0.06378025561571121, \"chain\": 2, \"draw\": 42}, {\"draws\": 442, \"mouse\": 2, \"mu_intercept_per_group\": 10.62299919128418, \"sigma_intercept_per_group\": 0.2200172245502472, \"sigma_obs\": 169.9317626953125, \"slope\": -0.06378025561571121, \"chain\": 2, \"draw\": 42}, {\"draws\": 442, \"mouse\": 3, \"mu_intercept_per_group\": 10.024384498596191, \"sigma_intercept_per_group\": 0.2200172245502472, \"sigma_obs\": 169.9317626953125, \"slope\": -0.06378025561571121, \"chain\": 2, \"draw\": 42}, {\"draws\": 442, \"mouse\": 4, \"mu_intercept_per_group\": 9.569182395935059, \"sigma_intercept_per_group\": 0.2200172245502472, \"sigma_obs\": 169.9317626953125, \"slope\": -0.06378025561571121, \"chain\": 2, \"draw\": 42}, {\"draws\": 442, \"mouse\": 5, \"mu_intercept_per_group\": 9.730545043945312, \"sigma_intercept_per_group\": 0.2200172245502472, \"sigma_obs\": 169.9317626953125, \"slope\": -0.06378025561571121, \"chain\": 2, \"draw\": 42}, {\"draws\": 442, \"mouse\": 6, \"mu_intercept_per_group\": 9.005781173706055, \"sigma_intercept_per_group\": 0.2200172245502472, \"sigma_obs\": 169.9317626953125, \"slope\": -0.06378025561571121, \"chain\": 2, \"draw\": 42}, {\"draws\": 442, \"mouse\": 7, \"mu_intercept_per_group\": 8.504383087158203, \"sigma_intercept_per_group\": 0.2200172245502472, \"sigma_obs\": 169.9317626953125, \"slope\": -0.06378025561571121, \"chain\": 2, \"draw\": 42}, {\"draws\": 443, \"mouse\": 0, \"mu_intercept_per_group\": 11.589679718017578, \"sigma_intercept_per_group\": 0.21914023160934448, \"sigma_obs\": 169.41815185546875, \"slope\": -0.06351737678050995, \"chain\": 2, \"draw\": 43}, {\"draws\": 443, \"mouse\": 1, \"mu_intercept_per_group\": 11.089373588562012, \"sigma_intercept_per_group\": 0.21914023160934448, \"sigma_obs\": 169.41815185546875, \"slope\": -0.06351737678050995, \"chain\": 2, \"draw\": 43}, {\"draws\": 443, \"mouse\": 2, \"mu_intercept_per_group\": 10.786385536193848, \"sigma_intercept_per_group\": 0.21914023160934448, \"sigma_obs\": 169.41815185546875, \"slope\": -0.06351737678050995, \"chain\": 2, \"draw\": 43}, {\"draws\": 443, \"mouse\": 3, \"mu_intercept_per_group\": 10.461063385009766, \"sigma_intercept_per_group\": 0.21914023160934448, \"sigma_obs\": 169.41815185546875, \"slope\": -0.06351737678050995, \"chain\": 2, \"draw\": 43}, {\"draws\": 443, \"mouse\": 4, \"mu_intercept_per_group\": 9.90804386138916, \"sigma_intercept_per_group\": 0.21914023160934448, \"sigma_obs\": 169.41815185546875, \"slope\": -0.06351737678050995, \"chain\": 2, \"draw\": 43}, {\"draws\": 443, \"mouse\": 5, \"mu_intercept_per_group\": 9.208351135253906, \"sigma_intercept_per_group\": 0.21914023160934448, \"sigma_obs\": 169.41815185546875, \"slope\": -0.06351737678050995, \"chain\": 2, \"draw\": 43}, {\"draws\": 443, \"mouse\": 6, \"mu_intercept_per_group\": 8.726519584655762, \"sigma_intercept_per_group\": 0.21914023160934448, \"sigma_obs\": 169.41815185546875, \"slope\": -0.06351737678050995, \"chain\": 2, \"draw\": 43}, {\"draws\": 443, \"mouse\": 7, \"mu_intercept_per_group\": 8.451125144958496, \"sigma_intercept_per_group\": 0.21914023160934448, \"sigma_obs\": 169.41815185546875, \"slope\": -0.06351737678050995, \"chain\": 2, \"draw\": 43}, {\"draws\": 444, \"mouse\": 0, \"mu_intercept_per_group\": 10.680131912231445, \"sigma_intercept_per_group\": 0.2345544993877411, \"sigma_obs\": 172.96356201171875, \"slope\": -0.05743410810828209, \"chain\": 2, \"draw\": 44}, {\"draws\": 444, \"mouse\": 1, \"mu_intercept_per_group\": 10.250387191772461, \"sigma_intercept_per_group\": 0.2345544993877411, \"sigma_obs\": 172.96356201171875, \"slope\": -0.05743410810828209, \"chain\": 2, \"draw\": 44}, {\"draws\": 444, \"mouse\": 2, \"mu_intercept_per_group\": 10.015312194824219, \"sigma_intercept_per_group\": 0.2345544993877411, \"sigma_obs\": 172.96356201171875, \"slope\": -0.05743410810828209, \"chain\": 2, \"draw\": 44}, {\"draws\": 444, \"mouse\": 3, \"mu_intercept_per_group\": 9.425230026245117, \"sigma_intercept_per_group\": 0.2345544993877411, \"sigma_obs\": 172.96356201171875, \"slope\": -0.05743410810828209, \"chain\": 2, \"draw\": 44}, {\"draws\": 444, \"mouse\": 4, \"mu_intercept_per_group\": 9.215442657470703, \"sigma_intercept_per_group\": 0.2345544993877411, \"sigma_obs\": 172.96356201171875, \"slope\": -0.05743410810828209, \"chain\": 2, \"draw\": 44}, {\"draws\": 444, \"mouse\": 5, \"mu_intercept_per_group\": 9.105801582336426, \"sigma_intercept_per_group\": 0.2345544993877411, \"sigma_obs\": 172.96356201171875, \"slope\": -0.05743410810828209, \"chain\": 2, \"draw\": 44}, {\"draws\": 444, \"mouse\": 6, \"mu_intercept_per_group\": 8.031173706054688, \"sigma_intercept_per_group\": 0.2345544993877411, \"sigma_obs\": 172.96356201171875, \"slope\": -0.05743410810828209, \"chain\": 2, \"draw\": 44}, {\"draws\": 444, \"mouse\": 7, \"mu_intercept_per_group\": 8.029448509216309, \"sigma_intercept_per_group\": 0.2345544993877411, \"sigma_obs\": 172.96356201171875, \"slope\": -0.05743410810828209, \"chain\": 2, \"draw\": 44}, {\"draws\": 445, \"mouse\": 0, \"mu_intercept_per_group\": 10.400936126708984, \"sigma_intercept_per_group\": 0.2372584342956543, \"sigma_obs\": 164.4080047607422, \"slope\": -0.06563950330018997, \"chain\": 2, \"draw\": 45}, {\"draws\": 445, \"mouse\": 1, \"mu_intercept_per_group\": 10.209083557128906, \"sigma_intercept_per_group\": 0.2372584342956543, \"sigma_obs\": 164.4080047607422, \"slope\": -0.06563950330018997, \"chain\": 2, \"draw\": 45}, {\"draws\": 445, \"mouse\": 2, \"mu_intercept_per_group\": 9.752976417541504, \"sigma_intercept_per_group\": 0.2372584342956543, \"sigma_obs\": 164.4080047607422, \"slope\": -0.06563950330018997, \"chain\": 2, \"draw\": 45}, {\"draws\": 445, \"mouse\": 3, \"mu_intercept_per_group\": 9.2090425491333, \"sigma_intercept_per_group\": 0.2372584342956543, \"sigma_obs\": 164.4080047607422, \"slope\": -0.06563950330018997, \"chain\": 2, \"draw\": 45}, {\"draws\": 445, \"mouse\": 4, \"mu_intercept_per_group\": 9.028961181640625, \"sigma_intercept_per_group\": 0.2372584342956543, \"sigma_obs\": 164.4080047607422, \"slope\": -0.06563950330018997, \"chain\": 2, \"draw\": 45}, {\"draws\": 445, \"mouse\": 5, \"mu_intercept_per_group\": 8.7451171875, \"sigma_intercept_per_group\": 0.2372584342956543, \"sigma_obs\": 164.4080047607422, \"slope\": -0.06563950330018997, \"chain\": 2, \"draw\": 45}, {\"draws\": 445, \"mouse\": 6, \"mu_intercept_per_group\": 7.968263149261475, \"sigma_intercept_per_group\": 0.2372584342956543, \"sigma_obs\": 164.4080047607422, \"slope\": -0.06563950330018997, \"chain\": 2, \"draw\": 45}, {\"draws\": 445, \"mouse\": 7, \"mu_intercept_per_group\": 7.5474371910095215, \"sigma_intercept_per_group\": 0.2372584342956543, \"sigma_obs\": 164.4080047607422, \"slope\": -0.06563950330018997, \"chain\": 2, \"draw\": 45}, {\"draws\": 446, \"mouse\": 0, \"mu_intercept_per_group\": 11.15816879272461, \"sigma_intercept_per_group\": 0.22557450830936432, \"sigma_obs\": 167.06539916992188, \"slope\": -0.06296083331108093, \"chain\": 2, \"draw\": 46}, {\"draws\": 446, \"mouse\": 1, \"mu_intercept_per_group\": 10.941359519958496, \"sigma_intercept_per_group\": 0.22557450830936432, \"sigma_obs\": 167.06539916992188, \"slope\": -0.06296083331108093, \"chain\": 2, \"draw\": 46}, {\"draws\": 446, \"mouse\": 2, \"mu_intercept_per_group\": 10.203751564025879, \"sigma_intercept_per_group\": 0.22557450830936432, \"sigma_obs\": 167.06539916992188, \"slope\": -0.06296083331108093, \"chain\": 2, \"draw\": 46}, {\"draws\": 446, \"mouse\": 3, \"mu_intercept_per_group\": 9.76528549194336, \"sigma_intercept_per_group\": 0.22557450830936432, \"sigma_obs\": 167.06539916992188, \"slope\": -0.06296083331108093, \"chain\": 2, \"draw\": 46}, {\"draws\": 446, \"mouse\": 4, \"mu_intercept_per_group\": 9.65722370147705, \"sigma_intercept_per_group\": 0.22557450830936432, \"sigma_obs\": 167.06539916992188, \"slope\": -0.06296083331108093, \"chain\": 2, \"draw\": 46}, {\"draws\": 446, \"mouse\": 5, \"mu_intercept_per_group\": 9.108976364135742, \"sigma_intercept_per_group\": 0.22557450830936432, \"sigma_obs\": 167.06539916992188, \"slope\": -0.06296083331108093, \"chain\": 2, \"draw\": 46}, {\"draws\": 446, \"mouse\": 6, \"mu_intercept_per_group\": 8.276859283447266, \"sigma_intercept_per_group\": 0.22557450830936432, \"sigma_obs\": 167.06539916992188, \"slope\": -0.06296083331108093, \"chain\": 2, \"draw\": 46}, {\"draws\": 446, \"mouse\": 7, \"mu_intercept_per_group\": 7.728311538696289, \"sigma_intercept_per_group\": 0.22557450830936432, \"sigma_obs\": 167.06539916992188, \"slope\": -0.06296083331108093, \"chain\": 2, \"draw\": 46}, {\"draws\": 447, \"mouse\": 0, \"mu_intercept_per_group\": 10.591968536376953, \"sigma_intercept_per_group\": 0.23921136558055878, \"sigma_obs\": 168.4557647705078, \"slope\": -0.06332807242870331, \"chain\": 2, \"draw\": 47}, {\"draws\": 447, \"mouse\": 1, \"mu_intercept_per_group\": 10.299786567687988, \"sigma_intercept_per_group\": 0.23921136558055878, \"sigma_obs\": 168.4557647705078, \"slope\": -0.06332807242870331, \"chain\": 2, \"draw\": 47}, {\"draws\": 447, \"mouse\": 2, \"mu_intercept_per_group\": 9.590119361877441, \"sigma_intercept_per_group\": 0.23921136558055878, \"sigma_obs\": 168.4557647705078, \"slope\": -0.06332807242870331, \"chain\": 2, \"draw\": 47}, {\"draws\": 447, \"mouse\": 3, \"mu_intercept_per_group\": 9.290824890136719, \"sigma_intercept_per_group\": 0.23921136558055878, \"sigma_obs\": 168.4557647705078, \"slope\": -0.06332807242870331, \"chain\": 2, \"draw\": 47}, {\"draws\": 447, \"mouse\": 4, \"mu_intercept_per_group\": 8.987826347351074, \"sigma_intercept_per_group\": 0.23921136558055878, \"sigma_obs\": 168.4557647705078, \"slope\": -0.06332807242870331, \"chain\": 2, \"draw\": 47}, {\"draws\": 447, \"mouse\": 5, \"mu_intercept_per_group\": 8.296098709106445, \"sigma_intercept_per_group\": 0.23921136558055878, \"sigma_obs\": 168.4557647705078, \"slope\": -0.06332807242870331, \"chain\": 2, \"draw\": 47}, {\"draws\": 447, \"mouse\": 6, \"mu_intercept_per_group\": 8.145371437072754, \"sigma_intercept_per_group\": 0.23921136558055878, \"sigma_obs\": 168.4557647705078, \"slope\": -0.06332807242870331, \"chain\": 2, \"draw\": 47}, {\"draws\": 447, \"mouse\": 7, \"mu_intercept_per_group\": 7.8881025314331055, \"sigma_intercept_per_group\": 0.23921136558055878, \"sigma_obs\": 168.4557647705078, \"slope\": -0.06332807242870331, \"chain\": 2, \"draw\": 47}, {\"draws\": 448, \"mouse\": 0, \"mu_intercept_per_group\": 9.296293258666992, \"sigma_intercept_per_group\": 0.26736152172088623, \"sigma_obs\": 154.5170135498047, \"slope\": -0.09832918643951416, \"chain\": 2, \"draw\": 48}, {\"draws\": 448, \"mouse\": 1, \"mu_intercept_per_group\": 9.21183967590332, \"sigma_intercept_per_group\": 0.26736152172088623, \"sigma_obs\": 154.5170135498047, \"slope\": -0.09832918643951416, \"chain\": 2, \"draw\": 48}, {\"draws\": 448, \"mouse\": 2, \"mu_intercept_per_group\": 8.543603897094727, \"sigma_intercept_per_group\": 0.26736152172088623, \"sigma_obs\": 154.5170135498047, \"slope\": -0.09832918643951416, \"chain\": 2, \"draw\": 48}, {\"draws\": 448, \"mouse\": 3, \"mu_intercept_per_group\": 8.102198600769043, \"sigma_intercept_per_group\": 0.26736152172088623, \"sigma_obs\": 154.5170135498047, \"slope\": -0.09832918643951416, \"chain\": 2, \"draw\": 48}, {\"draws\": 448, \"mouse\": 4, \"mu_intercept_per_group\": 8.071576118469238, \"sigma_intercept_per_group\": 0.26736152172088623, \"sigma_obs\": 154.5170135498047, \"slope\": -0.09832918643951416, \"chain\": 2, \"draw\": 48}, {\"draws\": 448, \"mouse\": 5, \"mu_intercept_per_group\": 7.451039791107178, \"sigma_intercept_per_group\": 0.26736152172088623, \"sigma_obs\": 154.5170135498047, \"slope\": -0.09832918643951416, \"chain\": 2, \"draw\": 48}, {\"draws\": 448, \"mouse\": 6, \"mu_intercept_per_group\": 6.988076210021973, \"sigma_intercept_per_group\": 0.26736152172088623, \"sigma_obs\": 154.5170135498047, \"slope\": -0.09832918643951416, \"chain\": 2, \"draw\": 48}, {\"draws\": 448, \"mouse\": 7, \"mu_intercept_per_group\": 6.425987720489502, \"sigma_intercept_per_group\": 0.26736152172088623, \"sigma_obs\": 154.5170135498047, \"slope\": -0.09832918643951416, \"chain\": 2, \"draw\": 48}, {\"draws\": 449, \"mouse\": 0, \"mu_intercept_per_group\": 8.159847259521484, \"sigma_intercept_per_group\": 0.3188561797142029, \"sigma_obs\": 180.64523315429688, \"slope\": -0.08424386382102966, \"chain\": 2, \"draw\": 49}, {\"draws\": 449, \"mouse\": 1, \"mu_intercept_per_group\": 7.766512870788574, \"sigma_intercept_per_group\": 0.3188561797142029, \"sigma_obs\": 180.64523315429688, \"slope\": -0.08424386382102966, \"chain\": 2, \"draw\": 49}, {\"draws\": 449, \"mouse\": 2, \"mu_intercept_per_group\": 7.876578330993652, \"sigma_intercept_per_group\": 0.3188561797142029, \"sigma_obs\": 180.64523315429688, \"slope\": -0.08424386382102966, \"chain\": 2, \"draw\": 49}, {\"draws\": 449, \"mouse\": 3, \"mu_intercept_per_group\": 7.347164630889893, \"sigma_intercept_per_group\": 0.3188561797142029, \"sigma_obs\": 180.64523315429688, \"slope\": -0.08424386382102966, \"chain\": 2, \"draw\": 49}, {\"draws\": 449, \"mouse\": 4, \"mu_intercept_per_group\": 7.1071248054504395, \"sigma_intercept_per_group\": 0.3188561797142029, \"sigma_obs\": 180.64523315429688, \"slope\": -0.08424386382102966, \"chain\": 2, \"draw\": 49}, {\"draws\": 449, \"mouse\": 5, \"mu_intercept_per_group\": 6.812893390655518, \"sigma_intercept_per_group\": 0.3188561797142029, \"sigma_obs\": 180.64523315429688, \"slope\": -0.08424386382102966, \"chain\": 2, \"draw\": 49}, {\"draws\": 449, \"mouse\": 6, \"mu_intercept_per_group\": 6.141685962677002, \"sigma_intercept_per_group\": 0.3188561797142029, \"sigma_obs\": 180.64523315429688, \"slope\": -0.08424386382102966, \"chain\": 2, \"draw\": 49}, {\"draws\": 449, \"mouse\": 7, \"mu_intercept_per_group\": 5.853161334991455, \"sigma_intercept_per_group\": 0.3188561797142029, \"sigma_obs\": 180.64523315429688, \"slope\": -0.08424386382102966, \"chain\": 2, \"draw\": 49}, {\"draws\": 450, \"mouse\": 0, \"mu_intercept_per_group\": 8.09184741973877, \"sigma_intercept_per_group\": 0.3202996850013733, \"sigma_obs\": 181.21145629882812, \"slope\": -0.08502837270498276, \"chain\": 2, \"draw\": 50}, {\"draws\": 450, \"mouse\": 1, \"mu_intercept_per_group\": 7.695606231689453, \"sigma_intercept_per_group\": 0.3202996850013733, \"sigma_obs\": 181.21145629882812, \"slope\": -0.08502837270498276, \"chain\": 2, \"draw\": 50}, {\"draws\": 450, \"mouse\": 2, \"mu_intercept_per_group\": 7.650889873504639, \"sigma_intercept_per_group\": 0.3202996850013733, \"sigma_obs\": 181.21145629882812, \"slope\": -0.08502837270498276, \"chain\": 2, \"draw\": 50}, {\"draws\": 450, \"mouse\": 3, \"mu_intercept_per_group\": 7.466743469238281, \"sigma_intercept_per_group\": 0.3202996850013733, \"sigma_obs\": 181.21145629882812, \"slope\": -0.08502837270498276, \"chain\": 2, \"draw\": 50}, {\"draws\": 450, \"mouse\": 4, \"mu_intercept_per_group\": 7.166990280151367, \"sigma_intercept_per_group\": 0.3202996850013733, \"sigma_obs\": 181.21145629882812, \"slope\": -0.08502837270498276, \"chain\": 2, \"draw\": 50}, {\"draws\": 450, \"mouse\": 5, \"mu_intercept_per_group\": 6.8383073806762695, \"sigma_intercept_per_group\": 0.3202996850013733, \"sigma_obs\": 181.21145629882812, \"slope\": -0.08502837270498276, \"chain\": 2, \"draw\": 50}, {\"draws\": 450, \"mouse\": 6, \"mu_intercept_per_group\": 6.163649082183838, \"sigma_intercept_per_group\": 0.3202996850013733, \"sigma_obs\": 181.21145629882812, \"slope\": -0.08502837270498276, \"chain\": 2, \"draw\": 50}, {\"draws\": 450, \"mouse\": 7, \"mu_intercept_per_group\": 5.894227504730225, \"sigma_intercept_per_group\": 0.3202996850013733, \"sigma_obs\": 181.21145629882812, \"slope\": -0.08502837270498276, \"chain\": 2, \"draw\": 50}, {\"draws\": 451, \"mouse\": 0, \"mu_intercept_per_group\": 8.055660247802734, \"sigma_intercept_per_group\": 0.313834011554718, \"sigma_obs\": 171.03970336914062, \"slope\": -0.06615259498357773, \"chain\": 2, \"draw\": 51}, {\"draws\": 451, \"mouse\": 1, \"mu_intercept_per_group\": 7.614591598510742, \"sigma_intercept_per_group\": 0.313834011554718, \"sigma_obs\": 171.03970336914062, \"slope\": -0.06615259498357773, \"chain\": 2, \"draw\": 51}, {\"draws\": 451, \"mouse\": 2, \"mu_intercept_per_group\": 7.800124645233154, \"sigma_intercept_per_group\": 0.313834011554718, \"sigma_obs\": 171.03970336914062, \"slope\": -0.06615259498357773, \"chain\": 2, \"draw\": 51}, {\"draws\": 451, \"mouse\": 3, \"mu_intercept_per_group\": 6.843294143676758, \"sigma_intercept_per_group\": 0.313834011554718, \"sigma_obs\": 171.03970336914062, \"slope\": -0.06615259498357773, \"chain\": 2, \"draw\": 51}, {\"draws\": 451, \"mouse\": 4, \"mu_intercept_per_group\": 6.942677021026611, \"sigma_intercept_per_group\": 0.313834011554718, \"sigma_obs\": 171.03970336914062, \"slope\": -0.06615259498357773, \"chain\": 2, \"draw\": 51}, {\"draws\": 451, \"mouse\": 5, \"mu_intercept_per_group\": 6.644626617431641, \"sigma_intercept_per_group\": 0.313834011554718, \"sigma_obs\": 171.03970336914062, \"slope\": -0.06615259498357773, \"chain\": 2, \"draw\": 51}, {\"draws\": 451, \"mouse\": 6, \"mu_intercept_per_group\": 5.964592933654785, \"sigma_intercept_per_group\": 0.313834011554718, \"sigma_obs\": 171.03970336914062, \"slope\": -0.06615259498357773, \"chain\": 2, \"draw\": 51}, {\"draws\": 451, \"mouse\": 7, \"mu_intercept_per_group\": 5.923946857452393, \"sigma_intercept_per_group\": 0.313834011554718, \"sigma_obs\": 171.03970336914062, \"slope\": -0.06615259498357773, \"chain\": 2, \"draw\": 51}, {\"draws\": 452, \"mouse\": 0, \"mu_intercept_per_group\": 7.699512958526611, \"sigma_intercept_per_group\": 0.3210662603378296, \"sigma_obs\": 171.3245849609375, \"slope\": -0.06572113186120987, \"chain\": 2, \"draw\": 52}, {\"draws\": 452, \"mouse\": 1, \"mu_intercept_per_group\": 7.722393035888672, \"sigma_intercept_per_group\": 0.3210662603378296, \"sigma_obs\": 171.3245849609375, \"slope\": -0.06572113186120987, \"chain\": 2, \"draw\": 52}, {\"draws\": 452, \"mouse\": 2, \"mu_intercept_per_group\": 7.299005508422852, \"sigma_intercept_per_group\": 0.3210662603378296, \"sigma_obs\": 171.3245849609375, \"slope\": -0.06572113186120987, \"chain\": 2, \"draw\": 52}, {\"draws\": 452, \"mouse\": 3, \"mu_intercept_per_group\": 6.963217735290527, \"sigma_intercept_per_group\": 0.3210662603378296, \"sigma_obs\": 171.3245849609375, \"slope\": -0.06572113186120987, \"chain\": 2, \"draw\": 52}, {\"draws\": 452, \"mouse\": 4, \"mu_intercept_per_group\": 6.662054538726807, \"sigma_intercept_per_group\": 0.3210662603378296, \"sigma_obs\": 171.3245849609375, \"slope\": -0.06572113186120987, \"chain\": 2, \"draw\": 52}, {\"draws\": 452, \"mouse\": 5, \"mu_intercept_per_group\": 6.493292808532715, \"sigma_intercept_per_group\": 0.3210662603378296, \"sigma_obs\": 171.3245849609375, \"slope\": -0.06572113186120987, \"chain\": 2, \"draw\": 52}, {\"draws\": 452, \"mouse\": 6, \"mu_intercept_per_group\": 6.15118408203125, \"sigma_intercept_per_group\": 0.3210662603378296, \"sigma_obs\": 171.3245849609375, \"slope\": -0.06572113186120987, \"chain\": 2, \"draw\": 52}, {\"draws\": 452, \"mouse\": 7, \"mu_intercept_per_group\": 5.700629711151123, \"sigma_intercept_per_group\": 0.3210662603378296, \"sigma_obs\": 171.3245849609375, \"slope\": -0.06572113186120987, \"chain\": 2, \"draw\": 52}, {\"draws\": 453, \"mouse\": 0, \"mu_intercept_per_group\": 7.665307998657227, \"sigma_intercept_per_group\": 0.3336234986782074, \"sigma_obs\": 173.25840759277344, \"slope\": -0.07267948240041733, \"chain\": 2, \"draw\": 53}, {\"draws\": 453, \"mouse\": 1, \"mu_intercept_per_group\": 7.252072334289551, \"sigma_intercept_per_group\": 0.3336234986782074, \"sigma_obs\": 173.25840759277344, \"slope\": -0.07267948240041733, \"chain\": 2, \"draw\": 53}, {\"draws\": 453, \"mouse\": 2, \"mu_intercept_per_group\": 7.210169315338135, \"sigma_intercept_per_group\": 0.3336234986782074, \"sigma_obs\": 173.25840759277344, \"slope\": -0.07267948240041733, \"chain\": 2, \"draw\": 53}, {\"draws\": 453, \"mouse\": 3, \"mu_intercept_per_group\": 6.656230449676514, \"sigma_intercept_per_group\": 0.3336234986782074, \"sigma_obs\": 173.25840759277344, \"slope\": -0.07267948240041733, \"chain\": 2, \"draw\": 53}, {\"draws\": 453, \"mouse\": 4, \"mu_intercept_per_group\": 6.550239086151123, \"sigma_intercept_per_group\": 0.3336234986782074, \"sigma_obs\": 173.25840759277344, \"slope\": -0.07267948240041733, \"chain\": 2, \"draw\": 53}, {\"draws\": 453, \"mouse\": 5, \"mu_intercept_per_group\": 6.437076091766357, \"sigma_intercept_per_group\": 0.3336234986782074, \"sigma_obs\": 173.25840759277344, \"slope\": -0.07267948240041733, \"chain\": 2, \"draw\": 53}, {\"draws\": 453, \"mouse\": 6, \"mu_intercept_per_group\": 6.05647087097168, \"sigma_intercept_per_group\": 0.3336234986782074, \"sigma_obs\": 173.25840759277344, \"slope\": -0.07267948240041733, \"chain\": 2, \"draw\": 53}, {\"draws\": 453, \"mouse\": 7, \"mu_intercept_per_group\": 5.529546737670898, \"sigma_intercept_per_group\": 0.3336234986782074, \"sigma_obs\": 173.25840759277344, \"slope\": -0.07267948240041733, \"chain\": 2, \"draw\": 53}, {\"draws\": 454, \"mouse\": 0, \"mu_intercept_per_group\": 7.856174945831299, \"sigma_intercept_per_group\": 0.33394646644592285, \"sigma_obs\": 173.7794189453125, \"slope\": -0.07251505553722382, \"chain\": 2, \"draw\": 54}, {\"draws\": 454, \"mouse\": 1, \"mu_intercept_per_group\": 7.346440315246582, \"sigma_intercept_per_group\": 0.33394646644592285, \"sigma_obs\": 173.7794189453125, \"slope\": -0.07251505553722382, \"chain\": 2, \"draw\": 54}, {\"draws\": 454, \"mouse\": 2, \"mu_intercept_per_group\": 7.126576900482178, \"sigma_intercept_per_group\": 0.33394646644592285, \"sigma_obs\": 173.7794189453125, \"slope\": -0.07251505553722382, \"chain\": 2, \"draw\": 54}, {\"draws\": 454, \"mouse\": 3, \"mu_intercept_per_group\": 6.6248087882995605, \"sigma_intercept_per_group\": 0.33394646644592285, \"sigma_obs\": 173.7794189453125, \"slope\": -0.07251505553722382, \"chain\": 2, \"draw\": 54}, {\"draws\": 454, \"mouse\": 4, \"mu_intercept_per_group\": 6.617331027984619, \"sigma_intercept_per_group\": 0.33394646644592285, \"sigma_obs\": 173.7794189453125, \"slope\": -0.07251505553722382, \"chain\": 2, \"draw\": 54}, {\"draws\": 454, \"mouse\": 5, \"mu_intercept_per_group\": 6.2533087730407715, \"sigma_intercept_per_group\": 0.33394646644592285, \"sigma_obs\": 173.7794189453125, \"slope\": -0.07251505553722382, \"chain\": 2, \"draw\": 54}, {\"draws\": 454, \"mouse\": 6, \"mu_intercept_per_group\": 5.832582950592041, \"sigma_intercept_per_group\": 0.33394646644592285, \"sigma_obs\": 173.7794189453125, \"slope\": -0.07251505553722382, \"chain\": 2, \"draw\": 54}, {\"draws\": 454, \"mouse\": 7, \"mu_intercept_per_group\": 5.548451900482178, \"sigma_intercept_per_group\": 0.33394646644592285, \"sigma_obs\": 173.7794189453125, \"slope\": -0.07251505553722382, \"chain\": 2, \"draw\": 54}, {\"draws\": 455, \"mouse\": 0, \"mu_intercept_per_group\": 8.732034683227539, \"sigma_intercept_per_group\": 0.27541473507881165, \"sigma_obs\": 155.835205078125, \"slope\": -0.04895037040114403, \"chain\": 2, \"draw\": 55}, {\"draws\": 455, \"mouse\": 1, \"mu_intercept_per_group\": 8.196680068969727, \"sigma_intercept_per_group\": 0.27541473507881165, \"sigma_obs\": 155.835205078125, \"slope\": -0.04895037040114403, \"chain\": 2, \"draw\": 55}, {\"draws\": 455, \"mouse\": 2, \"mu_intercept_per_group\": 8.04074478149414, \"sigma_intercept_per_group\": 0.27541473507881165, \"sigma_obs\": 155.835205078125, \"slope\": -0.04895037040114403, \"chain\": 2, \"draw\": 55}, {\"draws\": 455, \"mouse\": 3, \"mu_intercept_per_group\": 7.717096328735352, \"sigma_intercept_per_group\": 0.27541473507881165, \"sigma_obs\": 155.835205078125, \"slope\": -0.04895037040114403, \"chain\": 2, \"draw\": 55}, {\"draws\": 455, \"mouse\": 4, \"mu_intercept_per_group\": 7.614230632781982, \"sigma_intercept_per_group\": 0.27541473507881165, \"sigma_obs\": 155.835205078125, \"slope\": -0.04895037040114403, \"chain\": 2, \"draw\": 55}, {\"draws\": 455, \"mouse\": 5, \"mu_intercept_per_group\": 7.126282215118408, \"sigma_intercept_per_group\": 0.27541473507881165, \"sigma_obs\": 155.835205078125, \"slope\": -0.04895037040114403, \"chain\": 2, \"draw\": 55}, {\"draws\": 455, \"mouse\": 6, \"mu_intercept_per_group\": 6.609357833862305, \"sigma_intercept_per_group\": 0.27541473507881165, \"sigma_obs\": 155.835205078125, \"slope\": -0.04895037040114403, \"chain\": 2, \"draw\": 55}, {\"draws\": 455, \"mouse\": 7, \"mu_intercept_per_group\": 6.1565022468566895, \"sigma_intercept_per_group\": 0.27541473507881165, \"sigma_obs\": 155.835205078125, \"slope\": -0.04895037040114403, \"chain\": 2, \"draw\": 55}, {\"draws\": 456, \"mouse\": 0, \"mu_intercept_per_group\": 8.43300724029541, \"sigma_intercept_per_group\": 0.27602148056030273, \"sigma_obs\": 155.41177368164062, \"slope\": -0.04863549768924713, \"chain\": 2, \"draw\": 56}, {\"draws\": 456, \"mouse\": 1, \"mu_intercept_per_group\": 8.45565414428711, \"sigma_intercept_per_group\": 0.27602148056030273, \"sigma_obs\": 155.41177368164062, \"slope\": -0.04863549768924713, \"chain\": 2, \"draw\": 56}, {\"draws\": 456, \"mouse\": 2, \"mu_intercept_per_group\": 8.119881629943848, \"sigma_intercept_per_group\": 0.27602148056030273, \"sigma_obs\": 155.41177368164062, \"slope\": -0.04863549768924713, \"chain\": 2, \"draw\": 56}, {\"draws\": 456, \"mouse\": 3, \"mu_intercept_per_group\": 7.513341903686523, \"sigma_intercept_per_group\": 0.27602148056030273, \"sigma_obs\": 155.41177368164062, \"slope\": -0.04863549768924713, \"chain\": 2, \"draw\": 56}, {\"draws\": 456, \"mouse\": 4, \"mu_intercept_per_group\": 7.406586647033691, \"sigma_intercept_per_group\": 0.27602148056030273, \"sigma_obs\": 155.41177368164062, \"slope\": -0.04863549768924713, \"chain\": 2, \"draw\": 56}, {\"draws\": 456, \"mouse\": 5, \"mu_intercept_per_group\": 6.8308820724487305, \"sigma_intercept_per_group\": 0.27602148056030273, \"sigma_obs\": 155.41177368164062, \"slope\": -0.04863549768924713, \"chain\": 2, \"draw\": 56}, {\"draws\": 456, \"mouse\": 6, \"mu_intercept_per_group\": 6.759348392486572, \"sigma_intercept_per_group\": 0.27602148056030273, \"sigma_obs\": 155.41177368164062, \"slope\": -0.04863549768924713, \"chain\": 2, \"draw\": 56}, {\"draws\": 456, \"mouse\": 7, \"mu_intercept_per_group\": 6.021177768707275, \"sigma_intercept_per_group\": 0.27602148056030273, \"sigma_obs\": 155.41177368164062, \"slope\": -0.04863549768924713, \"chain\": 2, \"draw\": 56}, {\"draws\": 457, \"mouse\": 0, \"mu_intercept_per_group\": 8.565868377685547, \"sigma_intercept_per_group\": 0.28308624029159546, \"sigma_obs\": 155.55404663085938, \"slope\": -0.04847891628742218, \"chain\": 2, \"draw\": 57}, {\"draws\": 457, \"mouse\": 1, \"mu_intercept_per_group\": 8.351705551147461, \"sigma_intercept_per_group\": 0.28308624029159546, \"sigma_obs\": 155.55404663085938, \"slope\": -0.04847891628742218, \"chain\": 2, \"draw\": 57}, {\"draws\": 457, \"mouse\": 2, \"mu_intercept_per_group\": 8.104735374450684, \"sigma_intercept_per_group\": 0.28308624029159546, \"sigma_obs\": 155.55404663085938, \"slope\": -0.04847891628742218, \"chain\": 2, \"draw\": 57}, {\"draws\": 457, \"mouse\": 3, \"mu_intercept_per_group\": 7.646564960479736, \"sigma_intercept_per_group\": 0.28308624029159546, \"sigma_obs\": 155.55404663085938, \"slope\": -0.04847891628742218, \"chain\": 2, \"draw\": 57}, {\"draws\": 457, \"mouse\": 4, \"mu_intercept_per_group\": 7.380165100097656, \"sigma_intercept_per_group\": 0.28308624029159546, \"sigma_obs\": 155.55404663085938, \"slope\": -0.04847891628742218, \"chain\": 2, \"draw\": 57}, {\"draws\": 457, \"mouse\": 5, \"mu_intercept_per_group\": 6.9462409019470215, \"sigma_intercept_per_group\": 0.28308624029159546, \"sigma_obs\": 155.55404663085938, \"slope\": -0.04847891628742218, \"chain\": 2, \"draw\": 57}, {\"draws\": 457, \"mouse\": 6, \"mu_intercept_per_group\": 6.639675140380859, \"sigma_intercept_per_group\": 0.28308624029159546, \"sigma_obs\": 155.55404663085938, \"slope\": -0.04847891628742218, \"chain\": 2, \"draw\": 57}, {\"draws\": 457, \"mouse\": 7, \"mu_intercept_per_group\": 6.25723123550415, \"sigma_intercept_per_group\": 0.28308624029159546, \"sigma_obs\": 155.55404663085938, \"slope\": -0.04847891628742218, \"chain\": 2, \"draw\": 57}, {\"draws\": 458, \"mouse\": 0, \"mu_intercept_per_group\": 6.949525356292725, \"sigma_intercept_per_group\": 0.3473675847053528, \"sigma_obs\": 165.71170043945312, \"slope\": -0.030874066054821014, \"chain\": 2, \"draw\": 58}, {\"draws\": 458, \"mouse\": 1, \"mu_intercept_per_group\": 6.6135993003845215, \"sigma_intercept_per_group\": 0.3473675847053528, \"sigma_obs\": 165.71170043945312, \"slope\": -0.030874066054821014, \"chain\": 2, \"draw\": 58}, {\"draws\": 458, \"mouse\": 2, \"mu_intercept_per_group\": 6.51265287399292, \"sigma_intercept_per_group\": 0.3473675847053528, \"sigma_obs\": 165.71170043945312, \"slope\": -0.030874066054821014, \"chain\": 2, \"draw\": 58}, {\"draws\": 458, \"mouse\": 3, \"mu_intercept_per_group\": 6.112283706665039, \"sigma_intercept_per_group\": 0.3473675847053528, \"sigma_obs\": 165.71170043945312, \"slope\": -0.030874066054821014, \"chain\": 2, \"draw\": 58}, {\"draws\": 458, \"mouse\": 4, \"mu_intercept_per_group\": 5.894509792327881, \"sigma_intercept_per_group\": 0.3473675847053528, \"sigma_obs\": 165.71170043945312, \"slope\": -0.030874066054821014, \"chain\": 2, \"draw\": 58}, {\"draws\": 458, \"mouse\": 5, \"mu_intercept_per_group\": 5.715607166290283, \"sigma_intercept_per_group\": 0.3473675847053528, \"sigma_obs\": 165.71170043945312, \"slope\": -0.030874066054821014, \"chain\": 2, \"draw\": 58}, {\"draws\": 458, \"mouse\": 6, \"mu_intercept_per_group\": 5.328777313232422, \"sigma_intercept_per_group\": 0.3473675847053528, \"sigma_obs\": 165.71170043945312, \"slope\": -0.030874066054821014, \"chain\": 2, \"draw\": 58}, {\"draws\": 458, \"mouse\": 7, \"mu_intercept_per_group\": 5.01072359085083, \"sigma_intercept_per_group\": 0.3473675847053528, \"sigma_obs\": 165.71170043945312, \"slope\": -0.030874066054821014, \"chain\": 2, \"draw\": 58}, {\"draws\": 459, \"mouse\": 0, \"mu_intercept_per_group\": 6.497807025909424, \"sigma_intercept_per_group\": 0.39328765869140625, \"sigma_obs\": 176.8895721435547, \"slope\": -0.0604405514895916, \"chain\": 2, \"draw\": 59}, {\"draws\": 459, \"mouse\": 1, \"mu_intercept_per_group\": 6.18484354019165, \"sigma_intercept_per_group\": 0.39328765869140625, \"sigma_obs\": 176.8895721435547, \"slope\": -0.0604405514895916, \"chain\": 2, \"draw\": 59}, {\"draws\": 459, \"mouse\": 2, \"mu_intercept_per_group\": 5.986818790435791, \"sigma_intercept_per_group\": 0.39328765869140625, \"sigma_obs\": 176.8895721435547, \"slope\": -0.0604405514895916, \"chain\": 2, \"draw\": 59}, {\"draws\": 459, \"mouse\": 3, \"mu_intercept_per_group\": 5.5774383544921875, \"sigma_intercept_per_group\": 0.39328765869140625, \"sigma_obs\": 176.8895721435547, \"slope\": -0.0604405514895916, \"chain\": 2, \"draw\": 59}, {\"draws\": 459, \"mouse\": 4, \"mu_intercept_per_group\": 5.452005386352539, \"sigma_intercept_per_group\": 0.39328765869140625, \"sigma_obs\": 176.8895721435547, \"slope\": -0.0604405514895916, \"chain\": 2, \"draw\": 59}, {\"draws\": 459, \"mouse\": 5, \"mu_intercept_per_group\": 5.341454982757568, \"sigma_intercept_per_group\": 0.39328765869140625, \"sigma_obs\": 176.8895721435547, \"slope\": -0.0604405514895916, \"chain\": 2, \"draw\": 59}, {\"draws\": 459, \"mouse\": 6, \"mu_intercept_per_group\": 4.931356430053711, \"sigma_intercept_per_group\": 0.39328765869140625, \"sigma_obs\": 176.8895721435547, \"slope\": -0.0604405514895916, \"chain\": 2, \"draw\": 59}, {\"draws\": 459, \"mouse\": 7, \"mu_intercept_per_group\": 4.502289772033691, \"sigma_intercept_per_group\": 0.39328765869140625, \"sigma_obs\": 176.8895721435547, \"slope\": -0.0604405514895916, \"chain\": 2, \"draw\": 59}, {\"draws\": 460, \"mouse\": 0, \"mu_intercept_per_group\": 6.514055252075195, \"sigma_intercept_per_group\": 0.3672865629196167, \"sigma_obs\": 147.32569885253906, \"slope\": -0.09537924826145172, \"chain\": 2, \"draw\": 60}, {\"draws\": 460, \"mouse\": 1, \"mu_intercept_per_group\": 6.276599407196045, \"sigma_intercept_per_group\": 0.3672865629196167, \"sigma_obs\": 147.32569885253906, \"slope\": -0.09537924826145172, \"chain\": 2, \"draw\": 60}, {\"draws\": 460, \"mouse\": 2, \"mu_intercept_per_group\": 6.124724864959717, \"sigma_intercept_per_group\": 0.3672865629196167, \"sigma_obs\": 147.32569885253906, \"slope\": -0.09537924826145172, \"chain\": 2, \"draw\": 60}, {\"draws\": 460, \"mouse\": 3, \"mu_intercept_per_group\": 5.885587215423584, \"sigma_intercept_per_group\": 0.3672865629196167, \"sigma_obs\": 147.32569885253906, \"slope\": -0.09537924826145172, \"chain\": 2, \"draw\": 60}, {\"draws\": 460, \"mouse\": 4, \"mu_intercept_per_group\": 5.746590614318848, \"sigma_intercept_per_group\": 0.3672865629196167, \"sigma_obs\": 147.32569885253906, \"slope\": -0.09537924826145172, \"chain\": 2, \"draw\": 60}, {\"draws\": 460, \"mouse\": 5, \"mu_intercept_per_group\": 5.247281551361084, \"sigma_intercept_per_group\": 0.3672865629196167, \"sigma_obs\": 147.32569885253906, \"slope\": -0.09537924826145172, \"chain\": 2, \"draw\": 60}, {\"draws\": 460, \"mouse\": 6, \"mu_intercept_per_group\": 4.792264938354492, \"sigma_intercept_per_group\": 0.3672865629196167, \"sigma_obs\": 147.32569885253906, \"slope\": -0.09537924826145172, \"chain\": 2, \"draw\": 60}, {\"draws\": 460, \"mouse\": 7, \"mu_intercept_per_group\": 4.864965915679932, \"sigma_intercept_per_group\": 0.3672865629196167, \"sigma_obs\": 147.32569885253906, \"slope\": -0.09537924826145172, \"chain\": 2, \"draw\": 60}, {\"draws\": 461, \"mouse\": 0, \"mu_intercept_per_group\": 6.554480075836182, \"sigma_intercept_per_group\": 0.3665815591812134, \"sigma_obs\": 147.6616668701172, \"slope\": -0.09500093013048172, \"chain\": 2, \"draw\": 61}, {\"draws\": 461, \"mouse\": 1, \"mu_intercept_per_group\": 6.1901421546936035, \"sigma_intercept_per_group\": 0.3665815591812134, \"sigma_obs\": 147.6616668701172, \"slope\": -0.09500093013048172, \"chain\": 2, \"draw\": 61}, {\"draws\": 461, \"mouse\": 2, \"mu_intercept_per_group\": 6.2260918617248535, \"sigma_intercept_per_group\": 0.3665815591812134, \"sigma_obs\": 147.6616668701172, \"slope\": -0.09500093013048172, \"chain\": 2, \"draw\": 61}, {\"draws\": 461, \"mouse\": 3, \"mu_intercept_per_group\": 5.892199993133545, \"sigma_intercept_per_group\": 0.3665815591812134, \"sigma_obs\": 147.6616668701172, \"slope\": -0.09500093013048172, \"chain\": 2, \"draw\": 61}, {\"draws\": 461, \"mouse\": 4, \"mu_intercept_per_group\": 5.72261381149292, \"sigma_intercept_per_group\": 0.3665815591812134, \"sigma_obs\": 147.6616668701172, \"slope\": -0.09500093013048172, \"chain\": 2, \"draw\": 61}, {\"draws\": 461, \"mouse\": 5, \"mu_intercept_per_group\": 5.186578750610352, \"sigma_intercept_per_group\": 0.3665815591812134, \"sigma_obs\": 147.6616668701172, \"slope\": -0.09500093013048172, \"chain\": 2, \"draw\": 61}, {\"draws\": 461, \"mouse\": 6, \"mu_intercept_per_group\": 4.889737606048584, \"sigma_intercept_per_group\": 0.3665815591812134, \"sigma_obs\": 147.6616668701172, \"slope\": -0.09500093013048172, \"chain\": 2, \"draw\": 61}, {\"draws\": 461, \"mouse\": 7, \"mu_intercept_per_group\": 4.820383071899414, \"sigma_intercept_per_group\": 0.3665815591812134, \"sigma_obs\": 147.6616668701172, \"slope\": -0.09500093013048172, \"chain\": 2, \"draw\": 61}, {\"draws\": 462, \"mouse\": 0, \"mu_intercept_per_group\": 6.472660064697266, \"sigma_intercept_per_group\": 0.3661196827888489, \"sigma_obs\": 147.5276641845703, \"slope\": -0.09529218822717667, \"chain\": 2, \"draw\": 62}, {\"draws\": 462, \"mouse\": 1, \"mu_intercept_per_group\": 6.2887701988220215, \"sigma_intercept_per_group\": 0.3661196827888489, \"sigma_obs\": 147.5276641845703, \"slope\": -0.09529218822717667, \"chain\": 2, \"draw\": 62}, {\"draws\": 462, \"mouse\": 2, \"mu_intercept_per_group\": 6.168786525726318, \"sigma_intercept_per_group\": 0.3661196827888489, \"sigma_obs\": 147.5276641845703, \"slope\": -0.09529218822717667, \"chain\": 2, \"draw\": 62}, {\"draws\": 462, \"mouse\": 3, \"mu_intercept_per_group\": 5.908144474029541, \"sigma_intercept_per_group\": 0.3661196827888489, \"sigma_obs\": 147.5276641845703, \"slope\": -0.09529218822717667, \"chain\": 2, \"draw\": 62}, {\"draws\": 462, \"mouse\": 4, \"mu_intercept_per_group\": 5.7514543533325195, \"sigma_intercept_per_group\": 0.3661196827888489, \"sigma_obs\": 147.5276641845703, \"slope\": -0.09529218822717667, \"chain\": 2, \"draw\": 62}, {\"draws\": 462, \"mouse\": 5, \"mu_intercept_per_group\": 5.212613582611084, \"sigma_intercept_per_group\": 0.3661196827888489, \"sigma_obs\": 147.5276641845703, \"slope\": -0.09529218822717667, \"chain\": 2, \"draw\": 62}, {\"draws\": 462, \"mouse\": 6, \"mu_intercept_per_group\": 4.877633094787598, \"sigma_intercept_per_group\": 0.3661196827888489, \"sigma_obs\": 147.5276641845703, \"slope\": -0.09529218822717667, \"chain\": 2, \"draw\": 62}, {\"draws\": 462, \"mouse\": 7, \"mu_intercept_per_group\": 4.836812973022461, \"sigma_intercept_per_group\": 0.3661196827888489, \"sigma_obs\": 147.5276641845703, \"slope\": -0.09529218822717667, \"chain\": 2, \"draw\": 62}, {\"draws\": 463, \"mouse\": 0, \"mu_intercept_per_group\": 6.565699100494385, \"sigma_intercept_per_group\": 0.36803969740867615, \"sigma_obs\": 147.81008911132812, \"slope\": -0.09551750868558884, \"chain\": 2, \"draw\": 63}, {\"draws\": 463, \"mouse\": 1, \"mu_intercept_per_group\": 6.303422451019287, \"sigma_intercept_per_group\": 0.36803969740867615, \"sigma_obs\": 147.81008911132812, \"slope\": -0.09551750868558884, \"chain\": 2, \"draw\": 63}, {\"draws\": 463, \"mouse\": 2, \"mu_intercept_per_group\": 6.388793468475342, \"sigma_intercept_per_group\": 0.36803969740867615, \"sigma_obs\": 147.81008911132812, \"slope\": -0.09551750868558884, \"chain\": 2, \"draw\": 63}, {\"draws\": 463, \"mouse\": 3, \"mu_intercept_per_group\": 5.863444805145264, \"sigma_intercept_per_group\": 0.36803969740867615, \"sigma_obs\": 147.81008911132812, \"slope\": -0.09551750868558884, \"chain\": 2, \"draw\": 63}, {\"draws\": 463, \"mouse\": 4, \"mu_intercept_per_group\": 5.630448341369629, \"sigma_intercept_per_group\": 0.36803969740867615, \"sigma_obs\": 147.81008911132812, \"slope\": -0.09551750868558884, \"chain\": 2, \"draw\": 63}, {\"draws\": 463, \"mouse\": 5, \"mu_intercept_per_group\": 5.383974552154541, \"sigma_intercept_per_group\": 0.36803969740867615, \"sigma_obs\": 147.81008911132812, \"slope\": -0.09551750868558884, \"chain\": 2, \"draw\": 63}, {\"draws\": 463, \"mouse\": 6, \"mu_intercept_per_group\": 4.904223918914795, \"sigma_intercept_per_group\": 0.36803969740867615, \"sigma_obs\": 147.81008911132812, \"slope\": -0.09551750868558884, \"chain\": 2, \"draw\": 63}, {\"draws\": 463, \"mouse\": 7, \"mu_intercept_per_group\": 4.786993503570557, \"sigma_intercept_per_group\": 0.36803969740867615, \"sigma_obs\": 147.81008911132812, \"slope\": -0.09551750868558884, \"chain\": 2, \"draw\": 63}, {\"draws\": 464, \"mouse\": 0, \"mu_intercept_per_group\": 6.5037455558776855, \"sigma_intercept_per_group\": 0.3735440969467163, \"sigma_obs\": 148.82730102539062, \"slope\": -0.08962205052375793, \"chain\": 2, \"draw\": 64}, {\"draws\": 464, \"mouse\": 1, \"mu_intercept_per_group\": 6.127740383148193, \"sigma_intercept_per_group\": 0.3735440969467163, \"sigma_obs\": 148.82730102539062, \"slope\": -0.08962205052375793, \"chain\": 2, \"draw\": 64}, {\"draws\": 464, \"mouse\": 2, \"mu_intercept_per_group\": 6.106148719787598, \"sigma_intercept_per_group\": 0.3735440969467163, \"sigma_obs\": 148.82730102539062, \"slope\": -0.08962205052375793, \"chain\": 2, \"draw\": 64}, {\"draws\": 464, \"mouse\": 3, \"mu_intercept_per_group\": 5.7078094482421875, \"sigma_intercept_per_group\": 0.3735440969467163, \"sigma_obs\": 148.82730102539062, \"slope\": -0.08962205052375793, \"chain\": 2, \"draw\": 64}, {\"draws\": 464, \"mouse\": 4, \"mu_intercept_per_group\": 5.444681167602539, \"sigma_intercept_per_group\": 0.3735440969467163, \"sigma_obs\": 148.82730102539062, \"slope\": -0.08962205052375793, \"chain\": 2, \"draw\": 64}, {\"draws\": 464, \"mouse\": 5, \"mu_intercept_per_group\": 5.299670696258545, \"sigma_intercept_per_group\": 0.3735440969467163, \"sigma_obs\": 148.82730102539062, \"slope\": -0.08962205052375793, \"chain\": 2, \"draw\": 64}, {\"draws\": 464, \"mouse\": 6, \"mu_intercept_per_group\": 5.056453227996826, \"sigma_intercept_per_group\": 0.3735440969467163, \"sigma_obs\": 148.82730102539062, \"slope\": -0.08962205052375793, \"chain\": 2, \"draw\": 64}, {\"draws\": 464, \"mouse\": 7, \"mu_intercept_per_group\": 4.6277756690979, \"sigma_intercept_per_group\": 0.3735440969467163, \"sigma_obs\": 148.82730102539062, \"slope\": -0.08962205052375793, \"chain\": 2, \"draw\": 64}, {\"draws\": 465, \"mouse\": 0, \"mu_intercept_per_group\": 6.4102091789245605, \"sigma_intercept_per_group\": 0.37596386671066284, \"sigma_obs\": 149.1466522216797, \"slope\": -0.08910665661096573, \"chain\": 2, \"draw\": 65}, {\"draws\": 465, \"mouse\": 1, \"mu_intercept_per_group\": 6.377042293548584, \"sigma_intercept_per_group\": 0.37596386671066284, \"sigma_obs\": 149.1466522216797, \"slope\": -0.08910665661096573, \"chain\": 2, \"draw\": 65}, {\"draws\": 465, \"mouse\": 2, \"mu_intercept_per_group\": 6.195270538330078, \"sigma_intercept_per_group\": 0.37596386671066284, \"sigma_obs\": 149.1466522216797, \"slope\": -0.08910665661096573, \"chain\": 2, \"draw\": 65}, {\"draws\": 465, \"mouse\": 3, \"mu_intercept_per_group\": 5.753754138946533, \"sigma_intercept_per_group\": 0.37596386671066284, \"sigma_obs\": 149.1466522216797, \"slope\": -0.08910665661096573, \"chain\": 2, \"draw\": 65}, {\"draws\": 465, \"mouse\": 4, \"mu_intercept_per_group\": 5.313694953918457, \"sigma_intercept_per_group\": 0.37596386671066284, \"sigma_obs\": 149.1466522216797, \"slope\": -0.08910665661096573, \"chain\": 2, \"draw\": 65}, {\"draws\": 465, \"mouse\": 5, \"mu_intercept_per_group\": 5.308202743530273, \"sigma_intercept_per_group\": 0.37596386671066284, \"sigma_obs\": 149.1466522216797, \"slope\": -0.08910665661096573, \"chain\": 2, \"draw\": 65}, {\"draws\": 465, \"mouse\": 6, \"mu_intercept_per_group\": 4.877561092376709, \"sigma_intercept_per_group\": 0.37596386671066284, \"sigma_obs\": 149.1466522216797, \"slope\": -0.08910665661096573, \"chain\": 2, \"draw\": 65}, {\"draws\": 465, \"mouse\": 7, \"mu_intercept_per_group\": 4.554522514343262, \"sigma_intercept_per_group\": 0.37596386671066284, \"sigma_obs\": 149.1466522216797, \"slope\": -0.08910665661096573, \"chain\": 2, \"draw\": 65}, {\"draws\": 466, \"mouse\": 0, \"mu_intercept_per_group\": 6.417451858520508, \"sigma_intercept_per_group\": 0.37646806240081787, \"sigma_obs\": 152.2106170654297, \"slope\": -0.08164126425981522, \"chain\": 2, \"draw\": 66}, {\"draws\": 466, \"mouse\": 1, \"mu_intercept_per_group\": 6.341980457305908, \"sigma_intercept_per_group\": 0.37646806240081787, \"sigma_obs\": 152.2106170654297, \"slope\": -0.08164126425981522, \"chain\": 2, \"draw\": 66}, {\"draws\": 466, \"mouse\": 2, \"mu_intercept_per_group\": 6.148733139038086, \"sigma_intercept_per_group\": 0.37646806240081787, \"sigma_obs\": 152.2106170654297, \"slope\": -0.08164126425981522, \"chain\": 2, \"draw\": 66}, {\"draws\": 466, \"mouse\": 3, \"mu_intercept_per_group\": 5.768556118011475, \"sigma_intercept_per_group\": 0.37646806240081787, \"sigma_obs\": 152.2106170654297, \"slope\": -0.08164126425981522, \"chain\": 2, \"draw\": 66}, {\"draws\": 466, \"mouse\": 4, \"mu_intercept_per_group\": 5.305362701416016, \"sigma_intercept_per_group\": 0.37646806240081787, \"sigma_obs\": 152.2106170654297, \"slope\": -0.08164126425981522, \"chain\": 2, \"draw\": 66}, {\"draws\": 466, \"mouse\": 5, \"mu_intercept_per_group\": 5.233852863311768, \"sigma_intercept_per_group\": 0.37646806240081787, \"sigma_obs\": 152.2106170654297, \"slope\": -0.08164126425981522, \"chain\": 2, \"draw\": 66}, {\"draws\": 466, \"mouse\": 6, \"mu_intercept_per_group\": 4.916316986083984, \"sigma_intercept_per_group\": 0.37646806240081787, \"sigma_obs\": 152.2106170654297, \"slope\": -0.08164126425981522, \"chain\": 2, \"draw\": 66}, {\"draws\": 466, \"mouse\": 7, \"mu_intercept_per_group\": 4.831465721130371, \"sigma_intercept_per_group\": 0.37646806240081787, \"sigma_obs\": 152.2106170654297, \"slope\": -0.08164126425981522, \"chain\": 2, \"draw\": 66}, {\"draws\": 467, \"mouse\": 0, \"mu_intercept_per_group\": 7.307458400726318, \"sigma_intercept_per_group\": 0.34795311093330383, \"sigma_obs\": 169.852294921875, \"slope\": -0.06777648627758026, \"chain\": 2, \"draw\": 67}, {\"draws\": 467, \"mouse\": 1, \"mu_intercept_per_group\": 6.901961326599121, \"sigma_intercept_per_group\": 0.34795311093330383, \"sigma_obs\": 169.852294921875, \"slope\": -0.06777648627758026, \"chain\": 2, \"draw\": 67}, {\"draws\": 467, \"mouse\": 2, \"mu_intercept_per_group\": 6.687431812286377, \"sigma_intercept_per_group\": 0.34795311093330383, \"sigma_obs\": 169.852294921875, \"slope\": -0.06777648627758026, \"chain\": 2, \"draw\": 67}, {\"draws\": 467, \"mouse\": 3, \"mu_intercept_per_group\": 6.496728420257568, \"sigma_intercept_per_group\": 0.34795311093330383, \"sigma_obs\": 169.852294921875, \"slope\": -0.06777648627758026, \"chain\": 2, \"draw\": 67}, {\"draws\": 467, \"mouse\": 4, \"mu_intercept_per_group\": 6.154171466827393, \"sigma_intercept_per_group\": 0.34795311093330383, \"sigma_obs\": 169.852294921875, \"slope\": -0.06777648627758026, \"chain\": 2, \"draw\": 67}, {\"draws\": 467, \"mouse\": 5, \"mu_intercept_per_group\": 5.8109283447265625, \"sigma_intercept_per_group\": 0.34795311093330383, \"sigma_obs\": 169.852294921875, \"slope\": -0.06777648627758026, \"chain\": 2, \"draw\": 67}, {\"draws\": 467, \"mouse\": 6, \"mu_intercept_per_group\": 5.48355770111084, \"sigma_intercept_per_group\": 0.34795311093330383, \"sigma_obs\": 169.852294921875, \"slope\": -0.06777648627758026, \"chain\": 2, \"draw\": 67}, {\"draws\": 467, \"mouse\": 7, \"mu_intercept_per_group\": 5.411317825317383, \"sigma_intercept_per_group\": 0.34795311093330383, \"sigma_obs\": 169.852294921875, \"slope\": -0.06777648627758026, \"chain\": 2, \"draw\": 67}, {\"draws\": 468, \"mouse\": 0, \"mu_intercept_per_group\": 7.141073703765869, \"sigma_intercept_per_group\": 0.34698686003685, \"sigma_obs\": 164.8797607421875, \"slope\": -0.07407170534133911, \"chain\": 2, \"draw\": 68}, {\"draws\": 468, \"mouse\": 1, \"mu_intercept_per_group\": 6.880626201629639, \"sigma_intercept_per_group\": 0.34698686003685, \"sigma_obs\": 164.8797607421875, \"slope\": -0.07407170534133911, \"chain\": 2, \"draw\": 68}, {\"draws\": 468, \"mouse\": 2, \"mu_intercept_per_group\": 7.01500940322876, \"sigma_intercept_per_group\": 0.34698686003685, \"sigma_obs\": 164.8797607421875, \"slope\": -0.07407170534133911, \"chain\": 2, \"draw\": 68}, {\"draws\": 468, \"mouse\": 3, \"mu_intercept_per_group\": 6.541313648223877, \"sigma_intercept_per_group\": 0.34698686003685, \"sigma_obs\": 164.8797607421875, \"slope\": -0.07407170534133911, \"chain\": 2, \"draw\": 68}, {\"draws\": 468, \"mouse\": 4, \"mu_intercept_per_group\": 6.227987289428711, \"sigma_intercept_per_group\": 0.34698686003685, \"sigma_obs\": 164.8797607421875, \"slope\": -0.07407170534133911, \"chain\": 2, \"draw\": 68}, {\"draws\": 468, \"mouse\": 5, \"mu_intercept_per_group\": 5.883805751800537, \"sigma_intercept_per_group\": 0.34698686003685, \"sigma_obs\": 164.8797607421875, \"slope\": -0.07407170534133911, \"chain\": 2, \"draw\": 68}, {\"draws\": 468, \"mouse\": 6, \"mu_intercept_per_group\": 5.417060375213623, \"sigma_intercept_per_group\": 0.34698686003685, \"sigma_obs\": 164.8797607421875, \"slope\": -0.07407170534133911, \"chain\": 2, \"draw\": 68}, {\"draws\": 468, \"mouse\": 7, \"mu_intercept_per_group\": 5.165866851806641, \"sigma_intercept_per_group\": 0.34698686003685, \"sigma_obs\": 164.8797607421875, \"slope\": -0.07407170534133911, \"chain\": 2, \"draw\": 68}, {\"draws\": 469, \"mouse\": 0, \"mu_intercept_per_group\": 7.321566581726074, \"sigma_intercept_per_group\": 0.3475869596004486, \"sigma_obs\": 164.263671875, \"slope\": -0.07286475598812103, \"chain\": 2, \"draw\": 69}, {\"draws\": 469, \"mouse\": 1, \"mu_intercept_per_group\": 6.992372989654541, \"sigma_intercept_per_group\": 0.3475869596004486, \"sigma_obs\": 164.263671875, \"slope\": -0.07286475598812103, \"chain\": 2, \"draw\": 69}, {\"draws\": 469, \"mouse\": 2, \"mu_intercept_per_group\": 6.501923084259033, \"sigma_intercept_per_group\": 0.3475869596004486, \"sigma_obs\": 164.263671875, \"slope\": -0.07286475598812103, \"chain\": 2, \"draw\": 69}, {\"draws\": 469, \"mouse\": 3, \"mu_intercept_per_group\": 6.2137837409973145, \"sigma_intercept_per_group\": 0.3475869596004486, \"sigma_obs\": 164.263671875, \"slope\": -0.07286475598812103, \"chain\": 2, \"draw\": 69}, {\"draws\": 469, \"mouse\": 4, \"mu_intercept_per_group\": 6.092370510101318, \"sigma_intercept_per_group\": 0.3475869596004486, \"sigma_obs\": 164.263671875, \"slope\": -0.07286475598812103, \"chain\": 2, \"draw\": 69}, {\"draws\": 469, \"mouse\": 5, \"mu_intercept_per_group\": 5.853194713592529, \"sigma_intercept_per_group\": 0.3475869596004486, \"sigma_obs\": 164.263671875, \"slope\": -0.07286475598812103, \"chain\": 2, \"draw\": 69}, {\"draws\": 469, \"mouse\": 6, \"mu_intercept_per_group\": 5.574593544006348, \"sigma_intercept_per_group\": 0.3475869596004486, \"sigma_obs\": 164.263671875, \"slope\": -0.07286475598812103, \"chain\": 2, \"draw\": 69}, {\"draws\": 469, \"mouse\": 7, \"mu_intercept_per_group\": 5.317513465881348, \"sigma_intercept_per_group\": 0.3475869596004486, \"sigma_obs\": 164.263671875, \"slope\": -0.07286475598812103, \"chain\": 2, \"draw\": 69}, {\"draws\": 470, \"mouse\": 0, \"mu_intercept_per_group\": 7.658364772796631, \"sigma_intercept_per_group\": 0.32024577260017395, \"sigma_obs\": 157.22744750976562, \"slope\": -0.050805576145648956, \"chain\": 2, \"draw\": 70}, {\"draws\": 470, \"mouse\": 1, \"mu_intercept_per_group\": 6.972328186035156, \"sigma_intercept_per_group\": 0.32024577260017395, \"sigma_obs\": 157.22744750976562, \"slope\": -0.050805576145648956, \"chain\": 2, \"draw\": 70}, {\"draws\": 470, \"mouse\": 2, \"mu_intercept_per_group\": 7.154775142669678, \"sigma_intercept_per_group\": 0.32024577260017395, \"sigma_obs\": 157.22744750976562, \"slope\": -0.050805576145648956, \"chain\": 2, \"draw\": 70}, {\"draws\": 470, \"mouse\": 3, \"mu_intercept_per_group\": 6.755516052246094, \"sigma_intercept_per_group\": 0.32024577260017395, \"sigma_obs\": 157.22744750976562, \"slope\": -0.050805576145648956, \"chain\": 2, \"draw\": 70}, {\"draws\": 470, \"mouse\": 4, \"mu_intercept_per_group\": 6.585520267486572, \"sigma_intercept_per_group\": 0.32024577260017395, \"sigma_obs\": 157.22744750976562, \"slope\": -0.050805576145648956, \"chain\": 2, \"draw\": 70}, {\"draws\": 470, \"mouse\": 5, \"mu_intercept_per_group\": 5.989533424377441, \"sigma_intercept_per_group\": 0.32024577260017395, \"sigma_obs\": 157.22744750976562, \"slope\": -0.050805576145648956, \"chain\": 2, \"draw\": 70}, {\"draws\": 470, \"mouse\": 6, \"mu_intercept_per_group\": 5.453611850738525, \"sigma_intercept_per_group\": 0.32024577260017395, \"sigma_obs\": 157.22744750976562, \"slope\": -0.050805576145648956, \"chain\": 2, \"draw\": 70}, {\"draws\": 470, \"mouse\": 7, \"mu_intercept_per_group\": 5.492407321929932, \"sigma_intercept_per_group\": 0.32024577260017395, \"sigma_obs\": 157.22744750976562, \"slope\": -0.050805576145648956, \"chain\": 2, \"draw\": 70}, {\"draws\": 471, \"mouse\": 0, \"mu_intercept_per_group\": 7.486095428466797, \"sigma_intercept_per_group\": 0.3254791796207428, \"sigma_obs\": 157.08859252929688, \"slope\": -0.05073867738246918, \"chain\": 2, \"draw\": 71}, {\"draws\": 471, \"mouse\": 1, \"mu_intercept_per_group\": 7.256314754486084, \"sigma_intercept_per_group\": 0.3254791796207428, \"sigma_obs\": 157.08859252929688, \"slope\": -0.05073867738246918, \"chain\": 2, \"draw\": 71}, {\"draws\": 471, \"mouse\": 2, \"mu_intercept_per_group\": 7.041004180908203, \"sigma_intercept_per_group\": 0.3254791796207428, \"sigma_obs\": 157.08859252929688, \"slope\": -0.05073867738246918, \"chain\": 2, \"draw\": 71}, {\"draws\": 471, \"mouse\": 3, \"mu_intercept_per_group\": 6.629018306732178, \"sigma_intercept_per_group\": 0.3254791796207428, \"sigma_obs\": 157.08859252929688, \"slope\": -0.05073867738246918, \"chain\": 2, \"draw\": 71}, {\"draws\": 471, \"mouse\": 4, \"mu_intercept_per_group\": 6.316925525665283, \"sigma_intercept_per_group\": 0.3254791796207428, \"sigma_obs\": 157.08859252929688, \"slope\": -0.05073867738246918, \"chain\": 2, \"draw\": 71}, {\"draws\": 471, \"mouse\": 5, \"mu_intercept_per_group\": 5.9392828941345215, \"sigma_intercept_per_group\": 0.3254791796207428, \"sigma_obs\": 157.08859252929688, \"slope\": -0.05073867738246918, \"chain\": 2, \"draw\": 71}, {\"draws\": 471, \"mouse\": 6, \"mu_intercept_per_group\": 5.540716171264648, \"sigma_intercept_per_group\": 0.3254791796207428, \"sigma_obs\": 157.08859252929688, \"slope\": -0.05073867738246918, \"chain\": 2, \"draw\": 71}, {\"draws\": 471, \"mouse\": 7, \"mu_intercept_per_group\": 5.436342239379883, \"sigma_intercept_per_group\": 0.3254791796207428, \"sigma_obs\": 157.08859252929688, \"slope\": -0.05073867738246918, \"chain\": 2, \"draw\": 71}, {\"draws\": 472, \"mouse\": 0, \"mu_intercept_per_group\": 9.421185493469238, \"sigma_intercept_per_group\": 0.2689853608608246, \"sigma_obs\": 171.10186767578125, \"slope\": -0.06240619719028473, \"chain\": 2, \"draw\": 72}, {\"draws\": 472, \"mouse\": 1, \"mu_intercept_per_group\": 9.047863960266113, \"sigma_intercept_per_group\": 0.2689853608608246, \"sigma_obs\": 171.10186767578125, \"slope\": -0.06240619719028473, \"chain\": 2, \"draw\": 72}, {\"draws\": 472, \"mouse\": 2, \"mu_intercept_per_group\": 8.720521926879883, \"sigma_intercept_per_group\": 0.2689853608608246, \"sigma_obs\": 171.10186767578125, \"slope\": -0.06240619719028473, \"chain\": 2, \"draw\": 72}, {\"draws\": 472, \"mouse\": 3, \"mu_intercept_per_group\": 8.319019317626953, \"sigma_intercept_per_group\": 0.2689853608608246, \"sigma_obs\": 171.10186767578125, \"slope\": -0.06240619719028473, \"chain\": 2, \"draw\": 72}, {\"draws\": 472, \"mouse\": 4, \"mu_intercept_per_group\": 8.251093864440918, \"sigma_intercept_per_group\": 0.2689853608608246, \"sigma_obs\": 171.10186767578125, \"slope\": -0.06240619719028473, \"chain\": 2, \"draw\": 72}, {\"draws\": 472, \"mouse\": 5, \"mu_intercept_per_group\": 7.610103130340576, \"sigma_intercept_per_group\": 0.2689853608608246, \"sigma_obs\": 171.10186767578125, \"slope\": -0.06240619719028473, \"chain\": 2, \"draw\": 72}, {\"draws\": 472, \"mouse\": 6, \"mu_intercept_per_group\": 7.172958850860596, \"sigma_intercept_per_group\": 0.2689853608608246, \"sigma_obs\": 171.10186767578125, \"slope\": -0.06240619719028473, \"chain\": 2, \"draw\": 72}, {\"draws\": 472, \"mouse\": 7, \"mu_intercept_per_group\": 6.613310813903809, \"sigma_intercept_per_group\": 0.2689853608608246, \"sigma_obs\": 171.10186767578125, \"slope\": -0.06240619719028473, \"chain\": 2, \"draw\": 72}, {\"draws\": 473, \"mouse\": 0, \"mu_intercept_per_group\": 9.325508117675781, \"sigma_intercept_per_group\": 0.27016955614089966, \"sigma_obs\": 170.8755340576172, \"slope\": -0.06249178946018219, \"chain\": 2, \"draw\": 73}, {\"draws\": 473, \"mouse\": 1, \"mu_intercept_per_group\": 9.004729270935059, \"sigma_intercept_per_group\": 0.27016955614089966, \"sigma_obs\": 170.8755340576172, \"slope\": -0.06249178946018219, \"chain\": 2, \"draw\": 73}, {\"draws\": 473, \"mouse\": 2, \"mu_intercept_per_group\": 8.919561386108398, \"sigma_intercept_per_group\": 0.27016955614089966, \"sigma_obs\": 170.8755340576172, \"slope\": -0.06249178946018219, \"chain\": 2, \"draw\": 73}, {\"draws\": 473, \"mouse\": 3, \"mu_intercept_per_group\": 8.158345222473145, \"sigma_intercept_per_group\": 0.27016955614089966, \"sigma_obs\": 170.8755340576172, \"slope\": -0.06249178946018219, \"chain\": 2, \"draw\": 73}, {\"draws\": 473, \"mouse\": 4, \"mu_intercept_per_group\": 7.962389945983887, \"sigma_intercept_per_group\": 0.27016955614089966, \"sigma_obs\": 170.8755340576172, \"slope\": -0.06249178946018219, \"chain\": 2, \"draw\": 73}, {\"draws\": 473, \"mouse\": 5, \"mu_intercept_per_group\": 7.904488563537598, \"sigma_intercept_per_group\": 0.27016955614089966, \"sigma_obs\": 170.8755340576172, \"slope\": -0.06249178946018219, \"chain\": 2, \"draw\": 73}, {\"draws\": 473, \"mouse\": 6, \"mu_intercept_per_group\": 7.036054611206055, \"sigma_intercept_per_group\": 0.27016955614089966, \"sigma_obs\": 170.8755340576172, \"slope\": -0.06249178946018219, \"chain\": 2, \"draw\": 73}, {\"draws\": 473, \"mouse\": 7, \"mu_intercept_per_group\": 6.540874004364014, \"sigma_intercept_per_group\": 0.27016955614089966, \"sigma_obs\": 170.8755340576172, \"slope\": -0.06249178946018219, \"chain\": 2, \"draw\": 73}, {\"draws\": 474, \"mouse\": 0, \"mu_intercept_per_group\": 9.388785362243652, \"sigma_intercept_per_group\": 0.272103488445282, \"sigma_obs\": 169.60519409179688, \"slope\": -0.06313901394605637, \"chain\": 2, \"draw\": 74}, {\"draws\": 474, \"mouse\": 1, \"mu_intercept_per_group\": 8.92237663269043, \"sigma_intercept_per_group\": 0.272103488445282, \"sigma_obs\": 169.60519409179688, \"slope\": -0.06313901394605637, \"chain\": 2, \"draw\": 74}, {\"draws\": 474, \"mouse\": 2, \"mu_intercept_per_group\": 8.618518829345703, \"sigma_intercept_per_group\": 0.272103488445282, \"sigma_obs\": 169.60519409179688, \"slope\": -0.06313901394605637, \"chain\": 2, \"draw\": 74}, {\"draws\": 474, \"mouse\": 3, \"mu_intercept_per_group\": 8.154296875, \"sigma_intercept_per_group\": 0.272103488445282, \"sigma_obs\": 169.60519409179688, \"slope\": -0.06313901394605637, \"chain\": 2, \"draw\": 74}, {\"draws\": 474, \"mouse\": 4, \"mu_intercept_per_group\": 8.24767780303955, \"sigma_intercept_per_group\": 0.272103488445282, \"sigma_obs\": 169.60519409179688, \"slope\": -0.06313901394605637, \"chain\": 2, \"draw\": 74}, {\"draws\": 474, \"mouse\": 5, \"mu_intercept_per_group\": 7.321129322052002, \"sigma_intercept_per_group\": 0.272103488445282, \"sigma_obs\": 169.60519409179688, \"slope\": -0.06313901394605637, \"chain\": 2, \"draw\": 74}, {\"draws\": 474, \"mouse\": 6, \"mu_intercept_per_group\": 7.088648319244385, \"sigma_intercept_per_group\": 0.272103488445282, \"sigma_obs\": 169.60519409179688, \"slope\": -0.06313901394605637, \"chain\": 2, \"draw\": 74}, {\"draws\": 474, \"mouse\": 7, \"mu_intercept_per_group\": 6.316693305969238, \"sigma_intercept_per_group\": 0.272103488445282, \"sigma_obs\": 169.60519409179688, \"slope\": -0.06313901394605637, \"chain\": 2, \"draw\": 74}, {\"draws\": 475, \"mouse\": 0, \"mu_intercept_per_group\": 9.938694953918457, \"sigma_intercept_per_group\": 0.24814975261688232, \"sigma_obs\": 154.9445037841797, \"slope\": -0.08346876502037048, \"chain\": 2, \"draw\": 75}, {\"draws\": 475, \"mouse\": 1, \"mu_intercept_per_group\": 9.627227783203125, \"sigma_intercept_per_group\": 0.24814975261688232, \"sigma_obs\": 154.9445037841797, \"slope\": -0.08346876502037048, \"chain\": 2, \"draw\": 75}, {\"draws\": 475, \"mouse\": 2, \"mu_intercept_per_group\": 9.322254180908203, \"sigma_intercept_per_group\": 0.24814975261688232, \"sigma_obs\": 154.9445037841797, \"slope\": -0.08346876502037048, \"chain\": 2, \"draw\": 75}, {\"draws\": 475, \"mouse\": 3, \"mu_intercept_per_group\": 8.7411470413208, \"sigma_intercept_per_group\": 0.24814975261688232, \"sigma_obs\": 154.9445037841797, \"slope\": -0.08346876502037048, \"chain\": 2, \"draw\": 75}, {\"draws\": 475, \"mouse\": 4, \"mu_intercept_per_group\": 8.100523948669434, \"sigma_intercept_per_group\": 0.24814975261688232, \"sigma_obs\": 154.9445037841797, \"slope\": -0.08346876502037048, \"chain\": 2, \"draw\": 75}, {\"draws\": 475, \"mouse\": 5, \"mu_intercept_per_group\": 8.040528297424316, \"sigma_intercept_per_group\": 0.24814975261688232, \"sigma_obs\": 154.9445037841797, \"slope\": -0.08346876502037048, \"chain\": 2, \"draw\": 75}, {\"draws\": 475, \"mouse\": 6, \"mu_intercept_per_group\": 7.3770880699157715, \"sigma_intercept_per_group\": 0.24814975261688232, \"sigma_obs\": 154.9445037841797, \"slope\": -0.08346876502037048, \"chain\": 2, \"draw\": 75}, {\"draws\": 475, \"mouse\": 7, \"mu_intercept_per_group\": 6.953771591186523, \"sigma_intercept_per_group\": 0.24814975261688232, \"sigma_obs\": 154.9445037841797, \"slope\": -0.08346876502037048, \"chain\": 2, \"draw\": 75}, {\"draws\": 476, \"mouse\": 0, \"mu_intercept_per_group\": 12.932639122009277, \"sigma_intercept_per_group\": 0.18852344155311584, \"sigma_obs\": 156.29592895507812, \"slope\": -0.08535774052143097, \"chain\": 2, \"draw\": 76}, {\"draws\": 476, \"mouse\": 1, \"mu_intercept_per_group\": 12.2190580368042, \"sigma_intercept_per_group\": 0.18852344155311584, \"sigma_obs\": 156.29592895507812, \"slope\": -0.08535774052143097, \"chain\": 2, \"draw\": 76}, {\"draws\": 476, \"mouse\": 2, \"mu_intercept_per_group\": 12.359895706176758, \"sigma_intercept_per_group\": 0.18852344155311584, \"sigma_obs\": 156.29592895507812, \"slope\": -0.08535774052143097, \"chain\": 2, \"draw\": 76}, {\"draws\": 476, \"mouse\": 3, \"mu_intercept_per_group\": 11.788033485412598, \"sigma_intercept_per_group\": 0.18852344155311584, \"sigma_obs\": 156.29592895507812, \"slope\": -0.08535774052143097, \"chain\": 2, \"draw\": 76}, {\"draws\": 476, \"mouse\": 4, \"mu_intercept_per_group\": 10.886385917663574, \"sigma_intercept_per_group\": 0.18852344155311584, \"sigma_obs\": 156.29592895507812, \"slope\": -0.08535774052143097, \"chain\": 2, \"draw\": 76}, {\"draws\": 476, \"mouse\": 5, \"mu_intercept_per_group\": 10.701412200927734, \"sigma_intercept_per_group\": 0.18852344155311584, \"sigma_obs\": 156.29592895507812, \"slope\": -0.08535774052143097, \"chain\": 2, \"draw\": 76}, {\"draws\": 476, \"mouse\": 6, \"mu_intercept_per_group\": 10.06528377532959, \"sigma_intercept_per_group\": 0.18852344155311584, \"sigma_obs\": 156.29592895507812, \"slope\": -0.08535774052143097, \"chain\": 2, \"draw\": 76}, {\"draws\": 476, \"mouse\": 7, \"mu_intercept_per_group\": 9.617867469787598, \"sigma_intercept_per_group\": 0.18852344155311584, \"sigma_obs\": 156.29592895507812, \"slope\": -0.08535774052143097, \"chain\": 2, \"draw\": 76}, {\"draws\": 477, \"mouse\": 0, \"mu_intercept_per_group\": 11.56159782409668, \"sigma_intercept_per_group\": 0.21278509497642517, \"sigma_obs\": 159.62576293945312, \"slope\": -0.07528948783874512, \"chain\": 2, \"draw\": 77}, {\"draws\": 477, \"mouse\": 1, \"mu_intercept_per_group\": 10.88724136352539, \"sigma_intercept_per_group\": 0.21278509497642517, \"sigma_obs\": 159.62576293945312, \"slope\": -0.07528948783874512, \"chain\": 2, \"draw\": 77}, {\"draws\": 477, \"mouse\": 2, \"mu_intercept_per_group\": 11.06303596496582, \"sigma_intercept_per_group\": 0.21278509497642517, \"sigma_obs\": 159.62576293945312, \"slope\": -0.07528948783874512, \"chain\": 2, \"draw\": 77}, {\"draws\": 477, \"mouse\": 3, \"mu_intercept_per_group\": 10.47845458984375, \"sigma_intercept_per_group\": 0.21278509497642517, \"sigma_obs\": 159.62576293945312, \"slope\": -0.07528948783874512, \"chain\": 2, \"draw\": 77}, {\"draws\": 477, \"mouse\": 4, \"mu_intercept_per_group\": 10.169310569763184, \"sigma_intercept_per_group\": 0.21278509497642517, \"sigma_obs\": 159.62576293945312, \"slope\": -0.07528948783874512, \"chain\": 2, \"draw\": 77}, {\"draws\": 477, \"mouse\": 5, \"mu_intercept_per_group\": 9.411713600158691, \"sigma_intercept_per_group\": 0.21278509497642517, \"sigma_obs\": 159.62576293945312, \"slope\": -0.07528948783874512, \"chain\": 2, \"draw\": 77}, {\"draws\": 477, \"mouse\": 6, \"mu_intercept_per_group\": 8.57868480682373, \"sigma_intercept_per_group\": 0.21278509497642517, \"sigma_obs\": 159.62576293945312, \"slope\": -0.07528948783874512, \"chain\": 2, \"draw\": 77}, {\"draws\": 477, \"mouse\": 7, \"mu_intercept_per_group\": 8.281861305236816, \"sigma_intercept_per_group\": 0.21278509497642517, \"sigma_obs\": 159.62576293945312, \"slope\": -0.07528948783874512, \"chain\": 2, \"draw\": 77}, {\"draws\": 478, \"mouse\": 0, \"mu_intercept_per_group\": 11.545636177062988, \"sigma_intercept_per_group\": 0.21504534780979156, \"sigma_obs\": 159.4732208251953, \"slope\": -0.07598596811294556, \"chain\": 2, \"draw\": 78}, {\"draws\": 478, \"mouse\": 1, \"mu_intercept_per_group\": 11.04276180267334, \"sigma_intercept_per_group\": 0.21504534780979156, \"sigma_obs\": 159.4732208251953, \"slope\": -0.07598596811294556, \"chain\": 2, \"draw\": 78}, {\"draws\": 478, \"mouse\": 2, \"mu_intercept_per_group\": 10.735330581665039, \"sigma_intercept_per_group\": 0.21504534780979156, \"sigma_obs\": 159.4732208251953, \"slope\": -0.07598596811294556, \"chain\": 2, \"draw\": 78}, {\"draws\": 478, \"mouse\": 3, \"mu_intercept_per_group\": 10.296338081359863, \"sigma_intercept_per_group\": 0.21504534780979156, \"sigma_obs\": 159.4732208251953, \"slope\": -0.07598596811294556, \"chain\": 2, \"draw\": 78}, {\"draws\": 478, \"mouse\": 4, \"mu_intercept_per_group\": 10.15884017944336, \"sigma_intercept_per_group\": 0.21504534780979156, \"sigma_obs\": 159.4732208251953, \"slope\": -0.07598596811294556, \"chain\": 2, \"draw\": 78}, {\"draws\": 478, \"mouse\": 5, \"mu_intercept_per_group\": 9.414496421813965, \"sigma_intercept_per_group\": 0.21504534780979156, \"sigma_obs\": 159.4732208251953, \"slope\": -0.07598596811294556, \"chain\": 2, \"draw\": 78}, {\"draws\": 478, \"mouse\": 6, \"mu_intercept_per_group\": 8.789292335510254, \"sigma_intercept_per_group\": 0.21504534780979156, \"sigma_obs\": 159.4732208251953, \"slope\": -0.07598596811294556, \"chain\": 2, \"draw\": 78}, {\"draws\": 478, \"mouse\": 7, \"mu_intercept_per_group\": 8.05328369140625, \"sigma_intercept_per_group\": 0.21504534780979156, \"sigma_obs\": 159.4732208251953, \"slope\": -0.07598596811294556, \"chain\": 2, \"draw\": 78}, {\"draws\": 479, \"mouse\": 0, \"mu_intercept_per_group\": 11.42418098449707, \"sigma_intercept_per_group\": 0.21422994136810303, \"sigma_obs\": 159.0060272216797, \"slope\": -0.07558687031269073, \"chain\": 2, \"draw\": 79}, {\"draws\": 479, \"mouse\": 1, \"mu_intercept_per_group\": 11.180317878723145, \"sigma_intercept_per_group\": 0.21422994136810303, \"sigma_obs\": 159.0060272216797, \"slope\": -0.07558687031269073, \"chain\": 2, \"draw\": 79}, {\"draws\": 479, \"mouse\": 2, \"mu_intercept_per_group\": 10.422667503356934, \"sigma_intercept_per_group\": 0.21422994136810303, \"sigma_obs\": 159.0060272216797, \"slope\": -0.07558687031269073, \"chain\": 2, \"draw\": 79}, {\"draws\": 479, \"mouse\": 3, \"mu_intercept_per_group\": 10.320544242858887, \"sigma_intercept_per_group\": 0.21422994136810303, \"sigma_obs\": 159.0060272216797, \"slope\": -0.07558687031269073, \"chain\": 2, \"draw\": 79}, {\"draws\": 479, \"mouse\": 4, \"mu_intercept_per_group\": 10.15739631652832, \"sigma_intercept_per_group\": 0.21422994136810303, \"sigma_obs\": 159.0060272216797, \"slope\": -0.07558687031269073, \"chain\": 2, \"draw\": 79}, {\"draws\": 479, \"mouse\": 5, \"mu_intercept_per_group\": 9.457512855529785, \"sigma_intercept_per_group\": 0.21422994136810303, \"sigma_obs\": 159.0060272216797, \"slope\": -0.07558687031269073, \"chain\": 2, \"draw\": 79}, {\"draws\": 479, \"mouse\": 6, \"mu_intercept_per_group\": 8.775922775268555, \"sigma_intercept_per_group\": 0.21422994136810303, \"sigma_obs\": 159.0060272216797, \"slope\": -0.07558687031269073, \"chain\": 2, \"draw\": 79}, {\"draws\": 479, \"mouse\": 7, \"mu_intercept_per_group\": 7.928104400634766, \"sigma_intercept_per_group\": 0.21422994136810303, \"sigma_obs\": 159.0060272216797, \"slope\": -0.07558687031269073, \"chain\": 2, \"draw\": 79}, {\"draws\": 480, \"mouse\": 0, \"mu_intercept_per_group\": 11.755212783813477, \"sigma_intercept_per_group\": 0.21242567896842957, \"sigma_obs\": 150.33505249023438, \"slope\": -0.06271180510520935, \"chain\": 2, \"draw\": 80}, {\"draws\": 480, \"mouse\": 1, \"mu_intercept_per_group\": 11.084575653076172, \"sigma_intercept_per_group\": 0.21242567896842957, \"sigma_obs\": 150.33505249023438, \"slope\": -0.06271180510520935, \"chain\": 2, \"draw\": 80}, {\"draws\": 480, \"mouse\": 2, \"mu_intercept_per_group\": 11.055907249450684, \"sigma_intercept_per_group\": 0.21242567896842957, \"sigma_obs\": 150.33505249023438, \"slope\": -0.06271180510520935, \"chain\": 2, \"draw\": 80}, {\"draws\": 480, \"mouse\": 3, \"mu_intercept_per_group\": 10.10735034942627, \"sigma_intercept_per_group\": 0.21242567896842957, \"sigma_obs\": 150.33505249023438, \"slope\": -0.06271180510520935, \"chain\": 2, \"draw\": 80}, {\"draws\": 480, \"mouse\": 4, \"mu_intercept_per_group\": 9.75856876373291, \"sigma_intercept_per_group\": 0.21242567896842957, \"sigma_obs\": 150.33505249023438, \"slope\": -0.06271180510520935, \"chain\": 2, \"draw\": 80}, {\"draws\": 480, \"mouse\": 5, \"mu_intercept_per_group\": 8.929092407226562, \"sigma_intercept_per_group\": 0.21242567896842957, \"sigma_obs\": 150.33505249023438, \"slope\": -0.06271180510520935, \"chain\": 2, \"draw\": 80}, {\"draws\": 480, \"mouse\": 6, \"mu_intercept_per_group\": 8.716590881347656, \"sigma_intercept_per_group\": 0.21242567896842957, \"sigma_obs\": 150.33505249023438, \"slope\": -0.06271180510520935, \"chain\": 2, \"draw\": 80}, {\"draws\": 480, \"mouse\": 7, \"mu_intercept_per_group\": 7.776281833648682, \"sigma_intercept_per_group\": 0.21242567896842957, \"sigma_obs\": 150.33505249023438, \"slope\": -0.06271180510520935, \"chain\": 2, \"draw\": 80}, {\"draws\": 481, \"mouse\": 0, \"mu_intercept_per_group\": 10.826441764831543, \"sigma_intercept_per_group\": 0.2161622792482376, \"sigma_obs\": 152.1009979248047, \"slope\": -0.061788495630025864, \"chain\": 2, \"draw\": 81}, {\"draws\": 481, \"mouse\": 1, \"mu_intercept_per_group\": 10.998353958129883, \"sigma_intercept_per_group\": 0.2161622792482376, \"sigma_obs\": 152.1009979248047, \"slope\": -0.061788495630025864, \"chain\": 2, \"draw\": 81}, {\"draws\": 481, \"mouse\": 2, \"mu_intercept_per_group\": 10.348155975341797, \"sigma_intercept_per_group\": 0.2161622792482376, \"sigma_obs\": 152.1009979248047, \"slope\": -0.061788495630025864, \"chain\": 2, \"draw\": 81}, {\"draws\": 481, \"mouse\": 3, \"mu_intercept_per_group\": 9.986172676086426, \"sigma_intercept_per_group\": 0.2161622792482376, \"sigma_obs\": 152.1009979248047, \"slope\": -0.061788495630025864, \"chain\": 2, \"draw\": 81}, {\"draws\": 481, \"mouse\": 4, \"mu_intercept_per_group\": 9.823704719543457, \"sigma_intercept_per_group\": 0.2161622792482376, \"sigma_obs\": 152.1009979248047, \"slope\": -0.061788495630025864, \"chain\": 2, \"draw\": 81}, {\"draws\": 481, \"mouse\": 5, \"mu_intercept_per_group\": 9.538909912109375, \"sigma_intercept_per_group\": 0.2161622792482376, \"sigma_obs\": 152.1009979248047, \"slope\": -0.061788495630025864, \"chain\": 2, \"draw\": 81}, {\"draws\": 481, \"mouse\": 6, \"mu_intercept_per_group\": 8.533401489257812, \"sigma_intercept_per_group\": 0.2161622792482376, \"sigma_obs\": 152.1009979248047, \"slope\": -0.061788495630025864, \"chain\": 2, \"draw\": 81}, {\"draws\": 481, \"mouse\": 7, \"mu_intercept_per_group\": 8.237377166748047, \"sigma_intercept_per_group\": 0.2161622792482376, \"sigma_obs\": 152.1009979248047, \"slope\": -0.061788495630025864, \"chain\": 2, \"draw\": 81}, {\"draws\": 482, \"mouse\": 0, \"mu_intercept_per_group\": 11.945039749145508, \"sigma_intercept_per_group\": 0.20581142604351044, \"sigma_obs\": 150.38079833984375, \"slope\": -0.06381666660308838, \"chain\": 2, \"draw\": 82}, {\"draws\": 482, \"mouse\": 1, \"mu_intercept_per_group\": 10.999551773071289, \"sigma_intercept_per_group\": 0.20581142604351044, \"sigma_obs\": 150.38079833984375, \"slope\": -0.06381666660308838, \"chain\": 2, \"draw\": 82}, {\"draws\": 482, \"mouse\": 2, \"mu_intercept_per_group\": 11.032258987426758, \"sigma_intercept_per_group\": 0.20581142604351044, \"sigma_obs\": 150.38079833984375, \"slope\": -0.06381666660308838, \"chain\": 2, \"draw\": 82}, {\"draws\": 482, \"mouse\": 3, \"mu_intercept_per_group\": 10.10369873046875, \"sigma_intercept_per_group\": 0.20581142604351044, \"sigma_obs\": 150.38079833984375, \"slope\": -0.06381666660308838, \"chain\": 2, \"draw\": 82}, {\"draws\": 482, \"mouse\": 4, \"mu_intercept_per_group\": 9.765632629394531, \"sigma_intercept_per_group\": 0.20581142604351044, \"sigma_obs\": 150.38079833984375, \"slope\": -0.06381666660308838, \"chain\": 2, \"draw\": 82}, {\"draws\": 482, \"mouse\": 5, \"mu_intercept_per_group\": 9.038348197937012, \"sigma_intercept_per_group\": 0.20581142604351044, \"sigma_obs\": 150.38079833984375, \"slope\": -0.06381666660308838, \"chain\": 2, \"draw\": 82}, {\"draws\": 482, \"mouse\": 6, \"mu_intercept_per_group\": 8.461615562438965, \"sigma_intercept_per_group\": 0.20581142604351044, \"sigma_obs\": 150.38079833984375, \"slope\": -0.06381666660308838, \"chain\": 2, \"draw\": 82}, {\"draws\": 482, \"mouse\": 7, \"mu_intercept_per_group\": 7.913078308105469, \"sigma_intercept_per_group\": 0.20581142604351044, \"sigma_obs\": 150.38079833984375, \"slope\": -0.06381666660308838, \"chain\": 2, \"draw\": 82}, {\"draws\": 483, \"mouse\": 0, \"mu_intercept_per_group\": 13.12520694732666, \"sigma_intercept_per_group\": 0.1862373948097229, \"sigma_obs\": 153.2224578857422, \"slope\": -0.06481640785932541, \"chain\": 2, \"draw\": 83}, {\"draws\": 483, \"mouse\": 1, \"mu_intercept_per_group\": 12.069229125976562, \"sigma_intercept_per_group\": 0.1862373948097229, \"sigma_obs\": 153.2224578857422, \"slope\": -0.06481640785932541, \"chain\": 2, \"draw\": 83}, {\"draws\": 483, \"mouse\": 2, \"mu_intercept_per_group\": 11.857032775878906, \"sigma_intercept_per_group\": 0.1862373948097229, \"sigma_obs\": 153.2224578857422, \"slope\": -0.06481640785932541, \"chain\": 2, \"draw\": 83}, {\"draws\": 483, \"mouse\": 3, \"mu_intercept_per_group\": 11.093766212463379, \"sigma_intercept_per_group\": 0.1862373948097229, \"sigma_obs\": 153.2224578857422, \"slope\": -0.06481640785932541, \"chain\": 2, \"draw\": 83}, {\"draws\": 483, \"mouse\": 4, \"mu_intercept_per_group\": 11.008683204650879, \"sigma_intercept_per_group\": 0.1862373948097229, \"sigma_obs\": 153.2224578857422, \"slope\": -0.06481640785932541, \"chain\": 2, \"draw\": 83}, {\"draws\": 483, \"mouse\": 5, \"mu_intercept_per_group\": 10.677732467651367, \"sigma_intercept_per_group\": 0.1862373948097229, \"sigma_obs\": 153.2224578857422, \"slope\": -0.06481640785932541, \"chain\": 2, \"draw\": 83}, {\"draws\": 483, \"mouse\": 6, \"mu_intercept_per_group\": 9.52367877960205, \"sigma_intercept_per_group\": 0.1862373948097229, \"sigma_obs\": 153.2224578857422, \"slope\": -0.06481640785932541, \"chain\": 2, \"draw\": 83}, {\"draws\": 483, \"mouse\": 7, \"mu_intercept_per_group\": 9.28621768951416, \"sigma_intercept_per_group\": 0.1862373948097229, \"sigma_obs\": 153.2224578857422, \"slope\": -0.06481640785932541, \"chain\": 2, \"draw\": 83}, {\"draws\": 484, \"mouse\": 0, \"mu_intercept_per_group\": 12.64462661743164, \"sigma_intercept_per_group\": 0.18927285075187683, \"sigma_obs\": 152.1352996826172, \"slope\": -0.06489023566246033, \"chain\": 2, \"draw\": 84}, {\"draws\": 484, \"mouse\": 1, \"mu_intercept_per_group\": 12.379233360290527, \"sigma_intercept_per_group\": 0.18927285075187683, \"sigma_obs\": 152.1352996826172, \"slope\": -0.06489023566246033, \"chain\": 2, \"draw\": 84}, {\"draws\": 484, \"mouse\": 2, \"mu_intercept_per_group\": 12.093653678894043, \"sigma_intercept_per_group\": 0.18927285075187683, \"sigma_obs\": 152.1352996826172, \"slope\": -0.06489023566246033, \"chain\": 2, \"draw\": 84}, {\"draws\": 484, \"mouse\": 3, \"mu_intercept_per_group\": 11.542539596557617, \"sigma_intercept_per_group\": 0.18927285075187683, \"sigma_obs\": 152.1352996826172, \"slope\": -0.06489023566246033, \"chain\": 2, \"draw\": 84}, {\"draws\": 484, \"mouse\": 4, \"mu_intercept_per_group\": 10.751837730407715, \"sigma_intercept_per_group\": 0.18927285075187683, \"sigma_obs\": 152.1352996826172, \"slope\": -0.06489023566246033, \"chain\": 2, \"draw\": 84}, {\"draws\": 484, \"mouse\": 5, \"mu_intercept_per_group\": 10.74307918548584, \"sigma_intercept_per_group\": 0.18927285075187683, \"sigma_obs\": 152.1352996826172, \"slope\": -0.06489023566246033, \"chain\": 2, \"draw\": 84}, {\"draws\": 484, \"mouse\": 6, \"mu_intercept_per_group\": 9.719693183898926, \"sigma_intercept_per_group\": 0.18927285075187683, \"sigma_obs\": 152.1352996826172, \"slope\": -0.06489023566246033, \"chain\": 2, \"draw\": 84}, {\"draws\": 484, \"mouse\": 7, \"mu_intercept_per_group\": 9.354310989379883, \"sigma_intercept_per_group\": 0.18927285075187683, \"sigma_obs\": 152.1352996826172, \"slope\": -0.06489023566246033, \"chain\": 2, \"draw\": 84}, {\"draws\": 485, \"mouse\": 0, \"mu_intercept_per_group\": 13.303445816040039, \"sigma_intercept_per_group\": 0.18148335814476013, \"sigma_obs\": 152.68057250976562, \"slope\": -0.06136040762066841, \"chain\": 2, \"draw\": 85}, {\"draws\": 485, \"mouse\": 1, \"mu_intercept_per_group\": 12.623047828674316, \"sigma_intercept_per_group\": 0.18148335814476013, \"sigma_obs\": 152.68057250976562, \"slope\": -0.06136040762066841, \"chain\": 2, \"draw\": 85}, {\"draws\": 485, \"mouse\": 2, \"mu_intercept_per_group\": 12.092000961303711, \"sigma_intercept_per_group\": 0.18148335814476013, \"sigma_obs\": 152.68057250976562, \"slope\": -0.06136040762066841, \"chain\": 2, \"draw\": 85}, {\"draws\": 485, \"mouse\": 3, \"mu_intercept_per_group\": 11.432005882263184, \"sigma_intercept_per_group\": 0.18148335814476013, \"sigma_obs\": 152.68057250976562, \"slope\": -0.06136040762066841, \"chain\": 2, \"draw\": 85}, {\"draws\": 485, \"mouse\": 4, \"mu_intercept_per_group\": 11.586485862731934, \"sigma_intercept_per_group\": 0.18148335814476013, \"sigma_obs\": 152.68057250976562, \"slope\": -0.06136040762066841, \"chain\": 2, \"draw\": 85}, {\"draws\": 485, \"mouse\": 5, \"mu_intercept_per_group\": 10.095808982849121, \"sigma_intercept_per_group\": 0.18148335814476013, \"sigma_obs\": 152.68057250976562, \"slope\": -0.06136040762066841, \"chain\": 2, \"draw\": 85}, {\"draws\": 485, \"mouse\": 6, \"mu_intercept_per_group\": 9.697937965393066, \"sigma_intercept_per_group\": 0.18148335814476013, \"sigma_obs\": 152.68057250976562, \"slope\": -0.06136040762066841, \"chain\": 2, \"draw\": 85}, {\"draws\": 485, \"mouse\": 7, \"mu_intercept_per_group\": 9.146804809570312, \"sigma_intercept_per_group\": 0.18148335814476013, \"sigma_obs\": 152.68057250976562, \"slope\": -0.06136040762066841, \"chain\": 2, \"draw\": 85}, {\"draws\": 486, \"mouse\": 0, \"mu_intercept_per_group\": 13.24013614654541, \"sigma_intercept_per_group\": 0.18564924597740173, \"sigma_obs\": 151.98419189453125, \"slope\": -0.06158477067947388, \"chain\": 2, \"draw\": 86}, {\"draws\": 486, \"mouse\": 1, \"mu_intercept_per_group\": 12.590448379516602, \"sigma_intercept_per_group\": 0.18564924597740173, \"sigma_obs\": 151.98419189453125, \"slope\": -0.06158477067947388, \"chain\": 2, \"draw\": 86}, {\"draws\": 486, \"mouse\": 2, \"mu_intercept_per_group\": 12.2664155960083, \"sigma_intercept_per_group\": 0.18564924597740173, \"sigma_obs\": 151.98419189453125, \"slope\": -0.06158477067947388, \"chain\": 2, \"draw\": 86}, {\"draws\": 486, \"mouse\": 3, \"mu_intercept_per_group\": 11.491585731506348, \"sigma_intercept_per_group\": 0.18564924597740173, \"sigma_obs\": 151.98419189453125, \"slope\": -0.06158477067947388, \"chain\": 2, \"draw\": 86}, {\"draws\": 486, \"mouse\": 4, \"mu_intercept_per_group\": 11.589518547058105, \"sigma_intercept_per_group\": 0.18564924597740173, \"sigma_obs\": 151.98419189453125, \"slope\": -0.06158477067947388, \"chain\": 2, \"draw\": 86}, {\"draws\": 486, \"mouse\": 5, \"mu_intercept_per_group\": 10.120217323303223, \"sigma_intercept_per_group\": 0.18564924597740173, \"sigma_obs\": 151.98419189453125, \"slope\": -0.06158477067947388, \"chain\": 2, \"draw\": 86}, {\"draws\": 486, \"mouse\": 6, \"mu_intercept_per_group\": 9.761758804321289, \"sigma_intercept_per_group\": 0.18564924597740173, \"sigma_obs\": 151.98419189453125, \"slope\": -0.06158477067947388, \"chain\": 2, \"draw\": 86}, {\"draws\": 486, \"mouse\": 7, \"mu_intercept_per_group\": 8.895297050476074, \"sigma_intercept_per_group\": 0.18564924597740173, \"sigma_obs\": 151.98419189453125, \"slope\": -0.06158477067947388, \"chain\": 2, \"draw\": 86}, {\"draws\": 487, \"mouse\": 0, \"mu_intercept_per_group\": 12.771147727966309, \"sigma_intercept_per_group\": 0.1862250119447708, \"sigma_obs\": 153.5315399169922, \"slope\": -0.06226618215441704, \"chain\": 2, \"draw\": 87}, {\"draws\": 487, \"mouse\": 1, \"mu_intercept_per_group\": 12.480087280273438, \"sigma_intercept_per_group\": 0.1862250119447708, \"sigma_obs\": 153.5315399169922, \"slope\": -0.06226618215441704, \"chain\": 2, \"draw\": 87}, {\"draws\": 487, \"mouse\": 2, \"mu_intercept_per_group\": 12.093914031982422, \"sigma_intercept_per_group\": 0.1862250119447708, \"sigma_obs\": 153.5315399169922, \"slope\": -0.06226618215441704, \"chain\": 2, \"draw\": 87}, {\"draws\": 487, \"mouse\": 3, \"mu_intercept_per_group\": 11.490043640136719, \"sigma_intercept_per_group\": 0.1862250119447708, \"sigma_obs\": 153.5315399169922, \"slope\": -0.06226618215441704, \"chain\": 2, \"draw\": 87}, {\"draws\": 487, \"mouse\": 4, \"mu_intercept_per_group\": 10.809212684631348, \"sigma_intercept_per_group\": 0.1862250119447708, \"sigma_obs\": 153.5315399169922, \"slope\": -0.06226618215441704, \"chain\": 2, \"draw\": 87}, {\"draws\": 487, \"mouse\": 5, \"mu_intercept_per_group\": 10.495898246765137, \"sigma_intercept_per_group\": 0.1862250119447708, \"sigma_obs\": 153.5315399169922, \"slope\": -0.06226618215441704, \"chain\": 2, \"draw\": 87}, {\"draws\": 487, \"mouse\": 6, \"mu_intercept_per_group\": 9.897655487060547, \"sigma_intercept_per_group\": 0.1862250119447708, \"sigma_obs\": 153.5315399169922, \"slope\": -0.06226618215441704, \"chain\": 2, \"draw\": 87}, {\"draws\": 487, \"mouse\": 7, \"mu_intercept_per_group\": 9.540709495544434, \"sigma_intercept_per_group\": 0.1862250119447708, \"sigma_obs\": 153.5315399169922, \"slope\": -0.06226618215441704, \"chain\": 2, \"draw\": 87}, {\"draws\": 488, \"mouse\": 0, \"mu_intercept_per_group\": 12.476360321044922, \"sigma_intercept_per_group\": 0.19447076320648193, \"sigma_obs\": 156.21791076660156, \"slope\": -0.0790078416466713, \"chain\": 2, \"draw\": 88}, {\"draws\": 488, \"mouse\": 1, \"mu_intercept_per_group\": 12.365812301635742, \"sigma_intercept_per_group\": 0.19447076320648193, \"sigma_obs\": 156.21791076660156, \"slope\": -0.0790078416466713, \"chain\": 2, \"draw\": 88}, {\"draws\": 488, \"mouse\": 2, \"mu_intercept_per_group\": 11.538447380065918, \"sigma_intercept_per_group\": 0.19447076320648193, \"sigma_obs\": 156.21791076660156, \"slope\": -0.0790078416466713, \"chain\": 2, \"draw\": 88}, {\"draws\": 488, \"mouse\": 3, \"mu_intercept_per_group\": 10.973943710327148, \"sigma_intercept_per_group\": 0.19447076320648193, \"sigma_obs\": 156.21791076660156, \"slope\": -0.0790078416466713, \"chain\": 2, \"draw\": 88}, {\"draws\": 488, \"mouse\": 4, \"mu_intercept_per_group\": 10.928689956665039, \"sigma_intercept_per_group\": 0.19447076320648193, \"sigma_obs\": 156.21791076660156, \"slope\": -0.0790078416466713, \"chain\": 2, \"draw\": 88}, {\"draws\": 488, \"mouse\": 5, \"mu_intercept_per_group\": 10.100105285644531, \"sigma_intercept_per_group\": 0.19447076320648193, \"sigma_obs\": 156.21791076660156, \"slope\": -0.0790078416466713, \"chain\": 2, \"draw\": 88}, {\"draws\": 488, \"mouse\": 6, \"mu_intercept_per_group\": 9.807788848876953, \"sigma_intercept_per_group\": 0.19447076320648193, \"sigma_obs\": 156.21791076660156, \"slope\": -0.0790078416466713, \"chain\": 2, \"draw\": 88}, {\"draws\": 488, \"mouse\": 7, \"mu_intercept_per_group\": 9.028522491455078, \"sigma_intercept_per_group\": 0.19447076320648193, \"sigma_obs\": 156.21791076660156, \"slope\": -0.0790078416466713, \"chain\": 2, \"draw\": 88}, {\"draws\": 489, \"mouse\": 0, \"mu_intercept_per_group\": 12.53192138671875, \"sigma_intercept_per_group\": 0.19681388139724731, \"sigma_obs\": 156.21478271484375, \"slope\": -0.07884643226861954, \"chain\": 2, \"draw\": 89}, {\"draws\": 489, \"mouse\": 1, \"mu_intercept_per_group\": 12.319916725158691, \"sigma_intercept_per_group\": 0.19681388139724731, \"sigma_obs\": 156.21478271484375, \"slope\": -0.07884643226861954, \"chain\": 2, \"draw\": 89}, {\"draws\": 489, \"mouse\": 2, \"mu_intercept_per_group\": 11.605119705200195, \"sigma_intercept_per_group\": 0.19681388139724731, \"sigma_obs\": 156.21478271484375, \"slope\": -0.07884643226861954, \"chain\": 2, \"draw\": 89}, {\"draws\": 489, \"mouse\": 3, \"mu_intercept_per_group\": 10.945988655090332, \"sigma_intercept_per_group\": 0.19681388139724731, \"sigma_obs\": 156.21478271484375, \"slope\": -0.07884643226861954, \"chain\": 2, \"draw\": 89}, {\"draws\": 489, \"mouse\": 4, \"mu_intercept_per_group\": 11.019998550415039, \"sigma_intercept_per_group\": 0.19681388139724731, \"sigma_obs\": 156.21478271484375, \"slope\": -0.07884643226861954, \"chain\": 2, \"draw\": 89}, {\"draws\": 489, \"mouse\": 5, \"mu_intercept_per_group\": 10.103372573852539, \"sigma_intercept_per_group\": 0.19681388139724731, \"sigma_obs\": 156.21478271484375, \"slope\": -0.07884643226861954, \"chain\": 2, \"draw\": 89}, {\"draws\": 489, \"mouse\": 6, \"mu_intercept_per_group\": 9.790572166442871, \"sigma_intercept_per_group\": 0.19681388139724731, \"sigma_obs\": 156.21478271484375, \"slope\": -0.07884643226861954, \"chain\": 2, \"draw\": 89}, {\"draws\": 489, \"mouse\": 7, \"mu_intercept_per_group\": 9.053736686706543, \"sigma_intercept_per_group\": 0.19681388139724731, \"sigma_obs\": 156.21478271484375, \"slope\": -0.07884643226861954, \"chain\": 2, \"draw\": 89}, {\"draws\": 490, \"mouse\": 0, \"mu_intercept_per_group\": 12.935532569885254, \"sigma_intercept_per_group\": 0.18676790595054626, \"sigma_obs\": 155.32101440429688, \"slope\": -0.0776757150888443, \"chain\": 2, \"draw\": 90}, {\"draws\": 490, \"mouse\": 1, \"mu_intercept_per_group\": 12.759796142578125, \"sigma_intercept_per_group\": 0.18676790595054626, \"sigma_obs\": 155.32101440429688, \"slope\": -0.0776757150888443, \"chain\": 2, \"draw\": 90}, {\"draws\": 490, \"mouse\": 2, \"mu_intercept_per_group\": 12.05224895477295, \"sigma_intercept_per_group\": 0.18676790595054626, \"sigma_obs\": 155.32101440429688, \"slope\": -0.0776757150888443, \"chain\": 2, \"draw\": 90}, {\"draws\": 490, \"mouse\": 3, \"mu_intercept_per_group\": 11.347204208374023, \"sigma_intercept_per_group\": 0.18676790595054626, \"sigma_obs\": 155.32101440429688, \"slope\": -0.0776757150888443, \"chain\": 2, \"draw\": 90}, {\"draws\": 490, \"mouse\": 4, \"mu_intercept_per_group\": 11.154577255249023, \"sigma_intercept_per_group\": 0.18676790595054626, \"sigma_obs\": 155.32101440429688, \"slope\": -0.0776757150888443, \"chain\": 2, \"draw\": 90}, {\"draws\": 490, \"mouse\": 5, \"mu_intercept_per_group\": 10.716561317443848, \"sigma_intercept_per_group\": 0.18676790595054626, \"sigma_obs\": 155.32101440429688, \"slope\": -0.0776757150888443, \"chain\": 2, \"draw\": 90}, {\"draws\": 490, \"mouse\": 6, \"mu_intercept_per_group\": 9.705471992492676, \"sigma_intercept_per_group\": 0.18676790595054626, \"sigma_obs\": 155.32101440429688, \"slope\": -0.0776757150888443, \"chain\": 2, \"draw\": 90}, {\"draws\": 490, \"mouse\": 7, \"mu_intercept_per_group\": 9.292093276977539, \"sigma_intercept_per_group\": 0.18676790595054626, \"sigma_obs\": 155.32101440429688, \"slope\": -0.0776757150888443, \"chain\": 2, \"draw\": 90}, {\"draws\": 491, \"mouse\": 0, \"mu_intercept_per_group\": 9.364795684814453, \"sigma_intercept_per_group\": 0.26957306265830994, \"sigma_obs\": 174.12008666992188, \"slope\": -0.0695497915148735, \"chain\": 2, \"draw\": 91}, {\"draws\": 491, \"mouse\": 1, \"mu_intercept_per_group\": 9.013130187988281, \"sigma_intercept_per_group\": 0.26957306265830994, \"sigma_obs\": 174.12008666992188, \"slope\": -0.0695497915148735, \"chain\": 2, \"draw\": 91}, {\"draws\": 491, \"mouse\": 2, \"mu_intercept_per_group\": 8.71509075164795, \"sigma_intercept_per_group\": 0.26957306265830994, \"sigma_obs\": 174.12008666992188, \"slope\": -0.0695497915148735, \"chain\": 2, \"draw\": 91}, {\"draws\": 491, \"mouse\": 3, \"mu_intercept_per_group\": 8.364974975585938, \"sigma_intercept_per_group\": 0.26957306265830994, \"sigma_obs\": 174.12008666992188, \"slope\": -0.0695497915148735, \"chain\": 2, \"draw\": 91}, {\"draws\": 491, \"mouse\": 4, \"mu_intercept_per_group\": 8.182042121887207, \"sigma_intercept_per_group\": 0.26957306265830994, \"sigma_obs\": 174.12008666992188, \"slope\": -0.0695497915148735, \"chain\": 2, \"draw\": 91}, {\"draws\": 491, \"mouse\": 5, \"mu_intercept_per_group\": 7.689764976501465, \"sigma_intercept_per_group\": 0.26957306265830994, \"sigma_obs\": 174.12008666992188, \"slope\": -0.0695497915148735, \"chain\": 2, \"draw\": 91}, {\"draws\": 491, \"mouse\": 6, \"mu_intercept_per_group\": 7.349976062774658, \"sigma_intercept_per_group\": 0.26957306265830994, \"sigma_obs\": 174.12008666992188, \"slope\": -0.0695497915148735, \"chain\": 2, \"draw\": 91}, {\"draws\": 491, \"mouse\": 7, \"mu_intercept_per_group\": 6.887580871582031, \"sigma_intercept_per_group\": 0.26957306265830994, \"sigma_obs\": 174.12008666992188, \"slope\": -0.0695497915148735, \"chain\": 2, \"draw\": 91}, {\"draws\": 492, \"mouse\": 0, \"mu_intercept_per_group\": 9.833782196044922, \"sigma_intercept_per_group\": 0.25811803340911865, \"sigma_obs\": 172.88687133789062, \"slope\": -0.06958349049091339, \"chain\": 2, \"draw\": 92}, {\"draws\": 492, \"mouse\": 1, \"mu_intercept_per_group\": 9.536297798156738, \"sigma_intercept_per_group\": 0.25811803340911865, \"sigma_obs\": 172.88687133789062, \"slope\": -0.06958349049091339, \"chain\": 2, \"draw\": 92}, {\"draws\": 492, \"mouse\": 2, \"mu_intercept_per_group\": 9.239860534667969, \"sigma_intercept_per_group\": 0.25811803340911865, \"sigma_obs\": 172.88687133789062, \"slope\": -0.06958349049091339, \"chain\": 2, \"draw\": 92}, {\"draws\": 492, \"mouse\": 3, \"mu_intercept_per_group\": 8.596424102783203, \"sigma_intercept_per_group\": 0.25811803340911865, \"sigma_obs\": 172.88687133789062, \"slope\": -0.06958349049091339, \"chain\": 2, \"draw\": 92}, {\"draws\": 492, \"mouse\": 4, \"mu_intercept_per_group\": 8.589608192443848, \"sigma_intercept_per_group\": 0.25811803340911865, \"sigma_obs\": 172.88687133789062, \"slope\": -0.06958349049091339, \"chain\": 2, \"draw\": 92}, {\"draws\": 492, \"mouse\": 5, \"mu_intercept_per_group\": 8.07889461517334, \"sigma_intercept_per_group\": 0.25811803340911865, \"sigma_obs\": 172.88687133789062, \"slope\": -0.06958349049091339, \"chain\": 2, \"draw\": 92}, {\"draws\": 492, \"mouse\": 6, \"mu_intercept_per_group\": 7.32706356048584, \"sigma_intercept_per_group\": 0.25811803340911865, \"sigma_obs\": 172.88687133789062, \"slope\": -0.06958349049091339, \"chain\": 2, \"draw\": 92}, {\"draws\": 492, \"mouse\": 7, \"mu_intercept_per_group\": 7.02842903137207, \"sigma_intercept_per_group\": 0.25811803340911865, \"sigma_obs\": 172.88687133789062, \"slope\": -0.06958349049091339, \"chain\": 2, \"draw\": 92}, {\"draws\": 493, \"mouse\": 0, \"mu_intercept_per_group\": 9.527851104736328, \"sigma_intercept_per_group\": 0.2641361355781555, \"sigma_obs\": 171.5426025390625, \"slope\": -0.08288083970546722, \"chain\": 2, \"draw\": 93}, {\"draws\": 493, \"mouse\": 1, \"mu_intercept_per_group\": 9.255326271057129, \"sigma_intercept_per_group\": 0.2641361355781555, \"sigma_obs\": 171.5426025390625, \"slope\": -0.08288083970546722, \"chain\": 2, \"draw\": 93}, {\"draws\": 493, \"mouse\": 2, \"mu_intercept_per_group\": 9.118025779724121, \"sigma_intercept_per_group\": 0.2641361355781555, \"sigma_obs\": 171.5426025390625, \"slope\": -0.08288083970546722, \"chain\": 2, \"draw\": 93}, {\"draws\": 493, \"mouse\": 3, \"mu_intercept_per_group\": 8.373505592346191, \"sigma_intercept_per_group\": 0.2641361355781555, \"sigma_obs\": 171.5426025390625, \"slope\": -0.08288083970546722, \"chain\": 2, \"draw\": 93}, {\"draws\": 493, \"mouse\": 4, \"mu_intercept_per_group\": 8.454116821289062, \"sigma_intercept_per_group\": 0.2641361355781555, \"sigma_obs\": 171.5426025390625, \"slope\": -0.08288083970546722, \"chain\": 2, \"draw\": 93}, {\"draws\": 493, \"mouse\": 5, \"mu_intercept_per_group\": 7.900324821472168, \"sigma_intercept_per_group\": 0.2641361355781555, \"sigma_obs\": 171.5426025390625, \"slope\": -0.08288083970546722, \"chain\": 2, \"draw\": 93}, {\"draws\": 493, \"mouse\": 6, \"mu_intercept_per_group\": 7.372338771820068, \"sigma_intercept_per_group\": 0.2641361355781555, \"sigma_obs\": 171.5426025390625, \"slope\": -0.08288083970546722, \"chain\": 2, \"draw\": 93}, {\"draws\": 493, \"mouse\": 7, \"mu_intercept_per_group\": 7.328726291656494, \"sigma_intercept_per_group\": 0.2641361355781555, \"sigma_obs\": 171.5426025390625, \"slope\": -0.08288083970546722, \"chain\": 2, \"draw\": 93}, {\"draws\": 494, \"mouse\": 0, \"mu_intercept_per_group\": 10.323495864868164, \"sigma_intercept_per_group\": 0.2422562688589096, \"sigma_obs\": 163.37393188476562, \"slope\": -0.08069290965795517, \"chain\": 2, \"draw\": 94}, {\"draws\": 494, \"mouse\": 1, \"mu_intercept_per_group\": 9.951056480407715, \"sigma_intercept_per_group\": 0.2422562688589096, \"sigma_obs\": 163.37393188476562, \"slope\": -0.08069290965795517, \"chain\": 2, \"draw\": 94}, {\"draws\": 494, \"mouse\": 2, \"mu_intercept_per_group\": 9.481621742248535, \"sigma_intercept_per_group\": 0.2422562688589096, \"sigma_obs\": 163.37393188476562, \"slope\": -0.08069290965795517, \"chain\": 2, \"draw\": 94}, {\"draws\": 494, \"mouse\": 3, \"mu_intercept_per_group\": 8.887396812438965, \"sigma_intercept_per_group\": 0.2422562688589096, \"sigma_obs\": 163.37393188476562, \"slope\": -0.08069290965795517, \"chain\": 2, \"draw\": 94}, {\"draws\": 494, \"mouse\": 4, \"mu_intercept_per_group\": 8.913643836975098, \"sigma_intercept_per_group\": 0.2422562688589096, \"sigma_obs\": 163.37393188476562, \"slope\": -0.08069290965795517, \"chain\": 2, \"draw\": 94}, {\"draws\": 494, \"mouse\": 5, \"mu_intercept_per_group\": 8.35959529876709, \"sigma_intercept_per_group\": 0.2422562688589096, \"sigma_obs\": 163.37393188476562, \"slope\": -0.08069290965795517, \"chain\": 2, \"draw\": 94}, {\"draws\": 494, \"mouse\": 6, \"mu_intercept_per_group\": 7.756466865539551, \"sigma_intercept_per_group\": 0.2422562688589096, \"sigma_obs\": 163.37393188476562, \"slope\": -0.08069290965795517, \"chain\": 2, \"draw\": 94}, {\"draws\": 494, \"mouse\": 7, \"mu_intercept_per_group\": 7.735064506530762, \"sigma_intercept_per_group\": 0.2422562688589096, \"sigma_obs\": 163.37393188476562, \"slope\": -0.08069290965795517, \"chain\": 2, \"draw\": 94}, {\"draws\": 495, \"mouse\": 0, \"mu_intercept_per_group\": 10.02061939239502, \"sigma_intercept_per_group\": 0.2502657175064087, \"sigma_obs\": 164.17556762695312, \"slope\": -0.08068863302469254, \"chain\": 2, \"draw\": 95}, {\"draws\": 495, \"mouse\": 1, \"mu_intercept_per_group\": 9.676962852478027, \"sigma_intercept_per_group\": 0.2502657175064087, \"sigma_obs\": 164.17556762695312, \"slope\": -0.08068863302469254, \"chain\": 2, \"draw\": 95}, {\"draws\": 495, \"mouse\": 2, \"mu_intercept_per_group\": 9.574129104614258, \"sigma_intercept_per_group\": 0.2502657175064087, \"sigma_obs\": 164.17556762695312, \"slope\": -0.08068863302469254, \"chain\": 2, \"draw\": 95}, {\"draws\": 495, \"mouse\": 3, \"mu_intercept_per_group\": 8.839271545410156, \"sigma_intercept_per_group\": 0.2502657175064087, \"sigma_obs\": 164.17556762695312, \"slope\": -0.08068863302469254, \"chain\": 2, \"draw\": 95}, {\"draws\": 495, \"mouse\": 4, \"mu_intercept_per_group\": 8.6345853805542, \"sigma_intercept_per_group\": 0.2502657175064087, \"sigma_obs\": 164.17556762695312, \"slope\": -0.08068863302469254, \"chain\": 2, \"draw\": 95}, {\"draws\": 495, \"mouse\": 5, \"mu_intercept_per_group\": 8.394295692443848, \"sigma_intercept_per_group\": 0.2502657175064087, \"sigma_obs\": 164.17556762695312, \"slope\": -0.08068863302469254, \"chain\": 2, \"draw\": 95}, {\"draws\": 495, \"mouse\": 6, \"mu_intercept_per_group\": 7.831213474273682, \"sigma_intercept_per_group\": 0.2502657175064087, \"sigma_obs\": 164.17556762695312, \"slope\": -0.08068863302469254, \"chain\": 2, \"draw\": 95}, {\"draws\": 495, \"mouse\": 7, \"mu_intercept_per_group\": 7.496196746826172, \"sigma_intercept_per_group\": 0.2502657175064087, \"sigma_obs\": 164.17556762695312, \"slope\": -0.08068863302469254, \"chain\": 2, \"draw\": 95}, {\"draws\": 496, \"mouse\": 0, \"mu_intercept_per_group\": 10.105694770812988, \"sigma_intercept_per_group\": 0.24276196956634521, \"sigma_obs\": 159.04696655273438, \"slope\": -0.07757388055324554, \"chain\": 2, \"draw\": 96}, {\"draws\": 496, \"mouse\": 1, \"mu_intercept_per_group\": 9.778063774108887, \"sigma_intercept_per_group\": 0.24276196956634521, \"sigma_obs\": 159.04696655273438, \"slope\": -0.07757388055324554, \"chain\": 2, \"draw\": 96}, {\"draws\": 496, \"mouse\": 2, \"mu_intercept_per_group\": 9.53197193145752, \"sigma_intercept_per_group\": 0.24276196956634521, \"sigma_obs\": 159.04696655273438, \"slope\": -0.07757388055324554, \"chain\": 2, \"draw\": 96}, {\"draws\": 496, \"mouse\": 3, \"mu_intercept_per_group\": 9.064690589904785, \"sigma_intercept_per_group\": 0.24276196956634521, \"sigma_obs\": 159.04696655273438, \"slope\": -0.07757388055324554, \"chain\": 2, \"draw\": 96}, {\"draws\": 496, \"mouse\": 4, \"mu_intercept_per_group\": 8.766707420349121, \"sigma_intercept_per_group\": 0.24276196956634521, \"sigma_obs\": 159.04696655273438, \"slope\": -0.07757388055324554, \"chain\": 2, \"draw\": 96}, {\"draws\": 496, \"mouse\": 5, \"mu_intercept_per_group\": 8.075095176696777, \"sigma_intercept_per_group\": 0.24276196956634521, \"sigma_obs\": 159.04696655273438, \"slope\": -0.07757388055324554, \"chain\": 2, \"draw\": 96}, {\"draws\": 496, \"mouse\": 6, \"mu_intercept_per_group\": 7.63682746887207, \"sigma_intercept_per_group\": 0.24276196956634521, \"sigma_obs\": 159.04696655273438, \"slope\": -0.07757388055324554, \"chain\": 2, \"draw\": 96}, {\"draws\": 496, \"mouse\": 7, \"mu_intercept_per_group\": 7.367339611053467, \"sigma_intercept_per_group\": 0.24276196956634521, \"sigma_obs\": 159.04696655273438, \"slope\": -0.07757388055324554, \"chain\": 2, \"draw\": 96}, {\"draws\": 497, \"mouse\": 0, \"mu_intercept_per_group\": 9.59018611907959, \"sigma_intercept_per_group\": 0.26325440406799316, \"sigma_obs\": 166.37850952148438, \"slope\": -0.08614441752433777, \"chain\": 2, \"draw\": 97}, {\"draws\": 497, \"mouse\": 1, \"mu_intercept_per_group\": 9.181343078613281, \"sigma_intercept_per_group\": 0.26325440406799316, \"sigma_obs\": 166.37850952148438, \"slope\": -0.08614441752433777, \"chain\": 2, \"draw\": 97}, {\"draws\": 497, \"mouse\": 2, \"mu_intercept_per_group\": 8.998551368713379, \"sigma_intercept_per_group\": 0.26325440406799316, \"sigma_obs\": 166.37850952148438, \"slope\": -0.08614441752433777, \"chain\": 2, \"draw\": 97}, {\"draws\": 497, \"mouse\": 3, \"mu_intercept_per_group\": 8.423628807067871, \"sigma_intercept_per_group\": 0.26325440406799316, \"sigma_obs\": 166.37850952148438, \"slope\": -0.08614441752433777, \"chain\": 2, \"draw\": 97}, {\"draws\": 497, \"mouse\": 4, \"mu_intercept_per_group\": 8.375139236450195, \"sigma_intercept_per_group\": 0.26325440406799316, \"sigma_obs\": 166.37850952148438, \"slope\": -0.08614441752433777, \"chain\": 2, \"draw\": 97}, {\"draws\": 497, \"mouse\": 5, \"mu_intercept_per_group\": 8.030509948730469, \"sigma_intercept_per_group\": 0.26325440406799316, \"sigma_obs\": 166.37850952148438, \"slope\": -0.08614441752433777, \"chain\": 2, \"draw\": 97}, {\"draws\": 497, \"mouse\": 6, \"mu_intercept_per_group\": 7.273903846740723, \"sigma_intercept_per_group\": 0.26325440406799316, \"sigma_obs\": 166.37850952148438, \"slope\": -0.08614441752433777, \"chain\": 2, \"draw\": 97}, {\"draws\": 497, \"mouse\": 7, \"mu_intercept_per_group\": 7.107906341552734, \"sigma_intercept_per_group\": 0.26325440406799316, \"sigma_obs\": 166.37850952148438, \"slope\": -0.08614441752433777, \"chain\": 2, \"draw\": 97}, {\"draws\": 498, \"mouse\": 0, \"mu_intercept_per_group\": 9.615906715393066, \"sigma_intercept_per_group\": 0.2636185586452484, \"sigma_obs\": 166.15858459472656, \"slope\": -0.08628711104393005, \"chain\": 2, \"draw\": 98}, {\"draws\": 498, \"mouse\": 1, \"mu_intercept_per_group\": 9.193093299865723, \"sigma_intercept_per_group\": 0.2636185586452484, \"sigma_obs\": 166.15858459472656, \"slope\": -0.08628711104393005, \"chain\": 2, \"draw\": 98}, {\"draws\": 498, \"mouse\": 2, \"mu_intercept_per_group\": 9.004467964172363, \"sigma_intercept_per_group\": 0.2636185586452484, \"sigma_obs\": 166.15858459472656, \"slope\": -0.08628711104393005, \"chain\": 2, \"draw\": 98}, {\"draws\": 498, \"mouse\": 3, \"mu_intercept_per_group\": 8.396471977233887, \"sigma_intercept_per_group\": 0.2636185586452484, \"sigma_obs\": 166.15858459472656, \"slope\": -0.08628711104393005, \"chain\": 2, \"draw\": 98}, {\"draws\": 498, \"mouse\": 4, \"mu_intercept_per_group\": 8.50216007232666, \"sigma_intercept_per_group\": 0.2636185586452484, \"sigma_obs\": 166.15858459472656, \"slope\": -0.08628711104393005, \"chain\": 2, \"draw\": 98}, {\"draws\": 498, \"mouse\": 5, \"mu_intercept_per_group\": 7.903199672698975, \"sigma_intercept_per_group\": 0.2636185586452484, \"sigma_obs\": 166.15858459472656, \"slope\": -0.08628711104393005, \"chain\": 2, \"draw\": 98}, {\"draws\": 498, \"mouse\": 6, \"mu_intercept_per_group\": 7.333716869354248, \"sigma_intercept_per_group\": 0.2636185586452484, \"sigma_obs\": 166.15858459472656, \"slope\": -0.08628711104393005, \"chain\": 2, \"draw\": 98}, {\"draws\": 498, \"mouse\": 7, \"mu_intercept_per_group\": 7.102523326873779, \"sigma_intercept_per_group\": 0.2636185586452484, \"sigma_obs\": 166.15858459472656, \"slope\": -0.08628711104393005, \"chain\": 2, \"draw\": 98}, {\"draws\": 499, \"mouse\": 0, \"mu_intercept_per_group\": 8.076287269592285, \"sigma_intercept_per_group\": 0.31450146436691284, \"sigma_obs\": 172.6509246826172, \"slope\": -0.07073970139026642, \"chain\": 2, \"draw\": 99}, {\"draws\": 499, \"mouse\": 1, \"mu_intercept_per_group\": 7.764821529388428, \"sigma_intercept_per_group\": 0.31450146436691284, \"sigma_obs\": 172.6509246826172, \"slope\": -0.07073970139026642, \"chain\": 2, \"draw\": 99}, {\"draws\": 499, \"mouse\": 2, \"mu_intercept_per_group\": 7.65147066116333, \"sigma_intercept_per_group\": 0.31450146436691284, \"sigma_obs\": 172.6509246826172, \"slope\": -0.07073970139026642, \"chain\": 2, \"draw\": 99}, {\"draws\": 499, \"mouse\": 3, \"mu_intercept_per_group\": 7.337966442108154, \"sigma_intercept_per_group\": 0.31450146436691284, \"sigma_obs\": 172.6509246826172, \"slope\": -0.07073970139026642, \"chain\": 2, \"draw\": 99}, {\"draws\": 499, \"mouse\": 4, \"mu_intercept_per_group\": 6.855654716491699, \"sigma_intercept_per_group\": 0.31450146436691284, \"sigma_obs\": 172.6509246826172, \"slope\": -0.07073970139026642, \"chain\": 2, \"draw\": 99}, {\"draws\": 499, \"mouse\": 5, \"mu_intercept_per_group\": 6.540369033813477, \"sigma_intercept_per_group\": 0.31450146436691284, \"sigma_obs\": 172.6509246826172, \"slope\": -0.07073970139026642, \"chain\": 2, \"draw\": 99}, {\"draws\": 499, \"mouse\": 6, \"mu_intercept_per_group\": 6.252354145050049, \"sigma_intercept_per_group\": 0.31450146436691284, \"sigma_obs\": 172.6509246826172, \"slope\": -0.07073970139026642, \"chain\": 2, \"draw\": 99}, {\"draws\": 499, \"mouse\": 7, \"mu_intercept_per_group\": 5.7781901359558105, \"sigma_intercept_per_group\": 0.31450146436691284, \"sigma_obs\": 172.6509246826172, \"slope\": -0.07073970139026642, \"chain\": 2, \"draw\": 99}, {\"draws\": 500, \"mouse\": 0, \"mu_intercept_per_group\": 9.880399703979492, \"sigma_intercept_per_group\": 0.25553157925605774, \"sigma_obs\": 169.5948486328125, \"slope\": -0.045758526772260666, \"chain\": 2, \"draw\": 100}, {\"draws\": 500, \"mouse\": 1, \"mu_intercept_per_group\": 9.394253730773926, \"sigma_intercept_per_group\": 0.25553157925605774, \"sigma_obs\": 169.5948486328125, \"slope\": -0.045758526772260666, \"chain\": 2, \"draw\": 100}, {\"draws\": 500, \"mouse\": 2, \"mu_intercept_per_group\": 9.191393852233887, \"sigma_intercept_per_group\": 0.25553157925605774, \"sigma_obs\": 169.5948486328125, \"slope\": -0.045758526772260666, \"chain\": 2, \"draw\": 100}, {\"draws\": 500, \"mouse\": 3, \"mu_intercept_per_group\": 8.74843692779541, \"sigma_intercept_per_group\": 0.25553157925605774, \"sigma_obs\": 169.5948486328125, \"slope\": -0.045758526772260666, \"chain\": 2, \"draw\": 100}, {\"draws\": 500, \"mouse\": 4, \"mu_intercept_per_group\": 8.613178253173828, \"sigma_intercept_per_group\": 0.25553157925605774, \"sigma_obs\": 169.5948486328125, \"slope\": -0.045758526772260666, \"chain\": 2, \"draw\": 100}, {\"draws\": 500, \"mouse\": 5, \"mu_intercept_per_group\": 7.993298530578613, \"sigma_intercept_per_group\": 0.25553157925605774, \"sigma_obs\": 169.5948486328125, \"slope\": -0.045758526772260666, \"chain\": 2, \"draw\": 100}, {\"draws\": 500, \"mouse\": 6, \"mu_intercept_per_group\": 7.567458152770996, \"sigma_intercept_per_group\": 0.25553157925605774, \"sigma_obs\": 169.5948486328125, \"slope\": -0.045758526772260666, \"chain\": 2, \"draw\": 100}, {\"draws\": 500, \"mouse\": 7, \"mu_intercept_per_group\": 6.935690402984619, \"sigma_intercept_per_group\": 0.25553157925605774, \"sigma_obs\": 169.5948486328125, \"slope\": -0.045758526772260666, \"chain\": 2, \"draw\": 100}, {\"draws\": 501, \"mouse\": 0, \"mu_intercept_per_group\": 9.661397933959961, \"sigma_intercept_per_group\": 0.25660571455955505, \"sigma_obs\": 160.79306030273438, \"slope\": -0.08024026453495026, \"chain\": 2, \"draw\": 101}, {\"draws\": 501, \"mouse\": 1, \"mu_intercept_per_group\": 9.217397689819336, \"sigma_intercept_per_group\": 0.25660571455955505, \"sigma_obs\": 160.79306030273438, \"slope\": -0.08024026453495026, \"chain\": 2, \"draw\": 101}, {\"draws\": 501, \"mouse\": 2, \"mu_intercept_per_group\": 9.171735763549805, \"sigma_intercept_per_group\": 0.25660571455955505, \"sigma_obs\": 160.79306030273438, \"slope\": -0.08024026453495026, \"chain\": 2, \"draw\": 101}, {\"draws\": 501, \"mouse\": 3, \"mu_intercept_per_group\": 8.764423370361328, \"sigma_intercept_per_group\": 0.25660571455955505, \"sigma_obs\": 160.79306030273438, \"slope\": -0.08024026453495026, \"chain\": 2, \"draw\": 101}, {\"draws\": 501, \"mouse\": 4, \"mu_intercept_per_group\": 8.421716690063477, \"sigma_intercept_per_group\": 0.25660571455955505, \"sigma_obs\": 160.79306030273438, \"slope\": -0.08024026453495026, \"chain\": 2, \"draw\": 101}, {\"draws\": 501, \"mouse\": 5, \"mu_intercept_per_group\": 7.956793785095215, \"sigma_intercept_per_group\": 0.25660571455955505, \"sigma_obs\": 160.79306030273438, \"slope\": -0.08024026453495026, \"chain\": 2, \"draw\": 101}, {\"draws\": 501, \"mouse\": 6, \"mu_intercept_per_group\": 7.699286937713623, \"sigma_intercept_per_group\": 0.25660571455955505, \"sigma_obs\": 160.79306030273438, \"slope\": -0.08024026453495026, \"chain\": 2, \"draw\": 101}, {\"draws\": 501, \"mouse\": 7, \"mu_intercept_per_group\": 6.80728006362915, \"sigma_intercept_per_group\": 0.25660571455955505, \"sigma_obs\": 160.79306030273438, \"slope\": -0.08024026453495026, \"chain\": 2, \"draw\": 101}, {\"draws\": 502, \"mouse\": 0, \"mu_intercept_per_group\": 9.824418067932129, \"sigma_intercept_per_group\": 0.24453085660934448, \"sigma_obs\": 146.14407348632812, \"slope\": -0.0748400017619133, \"chain\": 2, \"draw\": 102}, {\"draws\": 502, \"mouse\": 1, \"mu_intercept_per_group\": 9.576421737670898, \"sigma_intercept_per_group\": 0.24453085660934448, \"sigma_obs\": 146.14407348632812, \"slope\": -0.0748400017619133, \"chain\": 2, \"draw\": 102}, {\"draws\": 502, \"mouse\": 2, \"mu_intercept_per_group\": 9.17935848236084, \"sigma_intercept_per_group\": 0.24453085660934448, \"sigma_obs\": 146.14407348632812, \"slope\": -0.0748400017619133, \"chain\": 2, \"draw\": 102}, {\"draws\": 502, \"mouse\": 3, \"mu_intercept_per_group\": 8.271381378173828, \"sigma_intercept_per_group\": 0.24453085660934448, \"sigma_obs\": 146.14407348632812, \"slope\": -0.0748400017619133, \"chain\": 2, \"draw\": 102}, {\"draws\": 502, \"mouse\": 4, \"mu_intercept_per_group\": 8.519057273864746, \"sigma_intercept_per_group\": 0.24453085660934448, \"sigma_obs\": 146.14407348632812, \"slope\": -0.0748400017619133, \"chain\": 2, \"draw\": 102}, {\"draws\": 502, \"mouse\": 5, \"mu_intercept_per_group\": 7.969805717468262, \"sigma_intercept_per_group\": 0.24453085660934448, \"sigma_obs\": 146.14407348632812, \"slope\": -0.0748400017619133, \"chain\": 2, \"draw\": 102}, {\"draws\": 502, \"mouse\": 6, \"mu_intercept_per_group\": 7.2708210945129395, \"sigma_intercept_per_group\": 0.24453085660934448, \"sigma_obs\": 146.14407348632812, \"slope\": -0.0748400017619133, \"chain\": 2, \"draw\": 102}, {\"draws\": 502, \"mouse\": 7, \"mu_intercept_per_group\": 7.139862537384033, \"sigma_intercept_per_group\": 0.24453085660934448, \"sigma_obs\": 146.14407348632812, \"slope\": -0.0748400017619133, \"chain\": 2, \"draw\": 102}, {\"draws\": 503, \"mouse\": 0, \"mu_intercept_per_group\": 8.308948516845703, \"sigma_intercept_per_group\": 0.2980811297893524, \"sigma_obs\": 160.15045166015625, \"slope\": -0.08658897131681442, \"chain\": 2, \"draw\": 103}, {\"draws\": 503, \"mouse\": 1, \"mu_intercept_per_group\": 8.036855697631836, \"sigma_intercept_per_group\": 0.2980811297893524, \"sigma_obs\": 160.15045166015625, \"slope\": -0.08658897131681442, \"chain\": 2, \"draw\": 103}, {\"draws\": 503, \"mouse\": 2, \"mu_intercept_per_group\": 7.619344234466553, \"sigma_intercept_per_group\": 0.2980811297893524, \"sigma_obs\": 160.15045166015625, \"slope\": -0.08658897131681442, \"chain\": 2, \"draw\": 103}, {\"draws\": 503, \"mouse\": 3, \"mu_intercept_per_group\": 7.430023670196533, \"sigma_intercept_per_group\": 0.2980811297893524, \"sigma_obs\": 160.15045166015625, \"slope\": -0.08658897131681442, \"chain\": 2, \"draw\": 103}, {\"draws\": 503, \"mouse\": 4, \"mu_intercept_per_group\": 7.104787826538086, \"sigma_intercept_per_group\": 0.2980811297893524, \"sigma_obs\": 160.15045166015625, \"slope\": -0.08658897131681442, \"chain\": 2, \"draw\": 103}, {\"draws\": 503, \"mouse\": 5, \"mu_intercept_per_group\": 6.785320281982422, \"sigma_intercept_per_group\": 0.2980811297893524, \"sigma_obs\": 160.15045166015625, \"slope\": -0.08658897131681442, \"chain\": 2, \"draw\": 103}, {\"draws\": 503, \"mouse\": 6, \"mu_intercept_per_group\": 6.413877010345459, \"sigma_intercept_per_group\": 0.2980811297893524, \"sigma_obs\": 160.15045166015625, \"slope\": -0.08658897131681442, \"chain\": 2, \"draw\": 103}, {\"draws\": 503, \"mouse\": 7, \"mu_intercept_per_group\": 5.945606708526611, \"sigma_intercept_per_group\": 0.2980811297893524, \"sigma_obs\": 160.15045166015625, \"slope\": -0.08658897131681442, \"chain\": 2, \"draw\": 103}, {\"draws\": 504, \"mouse\": 0, \"mu_intercept_per_group\": 8.237089157104492, \"sigma_intercept_per_group\": 0.2999798059463501, \"sigma_obs\": 160.37496948242188, \"slope\": -0.08687443286180496, \"chain\": 2, \"draw\": 104}, {\"draws\": 504, \"mouse\": 1, \"mu_intercept_per_group\": 8.293851852416992, \"sigma_intercept_per_group\": 0.2999798059463501, \"sigma_obs\": 160.37496948242188, \"slope\": -0.08687443286180496, \"chain\": 2, \"draw\": 104}, {\"draws\": 504, \"mouse\": 2, \"mu_intercept_per_group\": 7.74380350112915, \"sigma_intercept_per_group\": 0.2999798059463501, \"sigma_obs\": 160.37496948242188, \"slope\": -0.08687443286180496, \"chain\": 2, \"draw\": 104}, {\"draws\": 504, \"mouse\": 3, \"mu_intercept_per_group\": 7.436976909637451, \"sigma_intercept_per_group\": 0.2999798059463501, \"sigma_obs\": 160.37496948242188, \"slope\": -0.08687443286180496, \"chain\": 2, \"draw\": 104}, {\"draws\": 504, \"mouse\": 4, \"mu_intercept_per_group\": 7.219360828399658, \"sigma_intercept_per_group\": 0.2999798059463501, \"sigma_obs\": 160.37496948242188, \"slope\": -0.08687443286180496, \"chain\": 2, \"draw\": 104}, {\"draws\": 504, \"mouse\": 5, \"mu_intercept_per_group\": 6.7168354988098145, \"sigma_intercept_per_group\": 0.2999798059463501, \"sigma_obs\": 160.37496948242188, \"slope\": -0.08687443286180496, \"chain\": 2, \"draw\": 104}, {\"draws\": 504, \"mouse\": 6, \"mu_intercept_per_group\": 6.345272541046143, \"sigma_intercept_per_group\": 0.2999798059463501, \"sigma_obs\": 160.37496948242188, \"slope\": -0.08687443286180496, \"chain\": 2, \"draw\": 104}, {\"draws\": 504, \"mouse\": 7, \"mu_intercept_per_group\": 5.943778038024902, \"sigma_intercept_per_group\": 0.2999798059463501, \"sigma_obs\": 160.37496948242188, \"slope\": -0.08687443286180496, \"chain\": 2, \"draw\": 104}, {\"draws\": 505, \"mouse\": 0, \"mu_intercept_per_group\": 8.272396087646484, \"sigma_intercept_per_group\": 0.2994135320186615, \"sigma_obs\": 160.35195922851562, \"slope\": -0.08690104633569717, \"chain\": 2, \"draw\": 105}, {\"draws\": 505, \"mouse\": 1, \"mu_intercept_per_group\": 8.336804389953613, \"sigma_intercept_per_group\": 0.2994135320186615, \"sigma_obs\": 160.35195922851562, \"slope\": -0.08690104633569717, \"chain\": 2, \"draw\": 105}, {\"draws\": 505, \"mouse\": 2, \"mu_intercept_per_group\": 7.714394569396973, \"sigma_intercept_per_group\": 0.2994135320186615, \"sigma_obs\": 160.35195922851562, \"slope\": -0.08690104633569717, \"chain\": 2, \"draw\": 105}, {\"draws\": 505, \"mouse\": 3, \"mu_intercept_per_group\": 7.47652530670166, \"sigma_intercept_per_group\": 0.2994135320186615, \"sigma_obs\": 160.35195922851562, \"slope\": -0.08690104633569717, \"chain\": 2, \"draw\": 105}, {\"draws\": 505, \"mouse\": 4, \"mu_intercept_per_group\": 7.256885051727295, \"sigma_intercept_per_group\": 0.2994135320186615, \"sigma_obs\": 160.35195922851562, \"slope\": -0.08690104633569717, \"chain\": 2, \"draw\": 105}, {\"draws\": 505, \"mouse\": 5, \"mu_intercept_per_group\": 6.683455944061279, \"sigma_intercept_per_group\": 0.2994135320186615, \"sigma_obs\": 160.35195922851562, \"slope\": -0.08690104633569717, \"chain\": 2, \"draw\": 105}, {\"draws\": 505, \"mouse\": 6, \"mu_intercept_per_group\": 6.340023517608643, \"sigma_intercept_per_group\": 0.2994135320186615, \"sigma_obs\": 160.35195922851562, \"slope\": -0.08690104633569717, \"chain\": 2, \"draw\": 105}, {\"draws\": 505, \"mouse\": 7, \"mu_intercept_per_group\": 5.960358619689941, \"sigma_intercept_per_group\": 0.2994135320186615, \"sigma_obs\": 160.35195922851562, \"slope\": -0.08690104633569717, \"chain\": 2, \"draw\": 105}, {\"draws\": 506, \"mouse\": 0, \"mu_intercept_per_group\": 8.309426307678223, \"sigma_intercept_per_group\": 0.2966553866863251, \"sigma_obs\": 160.21072387695312, \"slope\": -0.08706247061491013, \"chain\": 2, \"draw\": 106}, {\"draws\": 506, \"mouse\": 1, \"mu_intercept_per_group\": 8.340046882629395, \"sigma_intercept_per_group\": 0.2966553866863251, \"sigma_obs\": 160.21072387695312, \"slope\": -0.08706247061491013, \"chain\": 2, \"draw\": 106}, {\"draws\": 506, \"mouse\": 2, \"mu_intercept_per_group\": 7.724703788757324, \"sigma_intercept_per_group\": 0.2966553866863251, \"sigma_obs\": 160.21072387695312, \"slope\": -0.08706247061491013, \"chain\": 2, \"draw\": 106}, {\"draws\": 506, \"mouse\": 3, \"mu_intercept_per_group\": 7.478125095367432, \"sigma_intercept_per_group\": 0.2966553866863251, \"sigma_obs\": 160.21072387695312, \"slope\": -0.08706247061491013, \"chain\": 2, \"draw\": 106}, {\"draws\": 506, \"mouse\": 4, \"mu_intercept_per_group\": 7.229281425476074, \"sigma_intercept_per_group\": 0.2966553866863251, \"sigma_obs\": 160.21072387695312, \"slope\": -0.08706247061491013, \"chain\": 2, \"draw\": 106}, {\"draws\": 506, \"mouse\": 5, \"mu_intercept_per_group\": 6.4946064949035645, \"sigma_intercept_per_group\": 0.2966553866863251, \"sigma_obs\": 160.21072387695312, \"slope\": -0.08706247061491013, \"chain\": 2, \"draw\": 106}, {\"draws\": 506, \"mouse\": 6, \"mu_intercept_per_group\": 6.285050868988037, \"sigma_intercept_per_group\": 0.2966553866863251, \"sigma_obs\": 160.21072387695312, \"slope\": -0.08706247061491013, \"chain\": 2, \"draw\": 106}, {\"draws\": 506, \"mouse\": 7, \"mu_intercept_per_group\": 6.077924728393555, \"sigma_intercept_per_group\": 0.2966553866863251, \"sigma_obs\": 160.21072387695312, \"slope\": -0.08706247061491013, \"chain\": 2, \"draw\": 106}, {\"draws\": 507, \"mouse\": 0, \"mu_intercept_per_group\": 8.302123069763184, \"sigma_intercept_per_group\": 0.29733264446258545, \"sigma_obs\": 160.11341857910156, \"slope\": -0.08716342598199844, \"chain\": 2, \"draw\": 107}, {\"draws\": 507, \"mouse\": 1, \"mu_intercept_per_group\": 8.32810115814209, \"sigma_intercept_per_group\": 0.29733264446258545, \"sigma_obs\": 160.11341857910156, \"slope\": -0.08716342598199844, \"chain\": 2, \"draw\": 107}, {\"draws\": 507, \"mouse\": 2, \"mu_intercept_per_group\": 7.786135673522949, \"sigma_intercept_per_group\": 0.29733264446258545, \"sigma_obs\": 160.11341857910156, \"slope\": -0.08716342598199844, \"chain\": 2, \"draw\": 107}, {\"draws\": 507, \"mouse\": 3, \"mu_intercept_per_group\": 7.488038539886475, \"sigma_intercept_per_group\": 0.29733264446258545, \"sigma_obs\": 160.11341857910156, \"slope\": -0.08716342598199844, \"chain\": 2, \"draw\": 107}, {\"draws\": 507, \"mouse\": 4, \"mu_intercept_per_group\": 7.123546123504639, \"sigma_intercept_per_group\": 0.29733264446258545, \"sigma_obs\": 160.11341857910156, \"slope\": -0.08716342598199844, \"chain\": 2, \"draw\": 107}, {\"draws\": 507, \"mouse\": 5, \"mu_intercept_per_group\": 6.547163486480713, \"sigma_intercept_per_group\": 0.29733264446258545, \"sigma_obs\": 160.11341857910156, \"slope\": -0.08716342598199844, \"chain\": 2, \"draw\": 107}, {\"draws\": 507, \"mouse\": 6, \"mu_intercept_per_group\": 6.2622270584106445, \"sigma_intercept_per_group\": 0.29733264446258545, \"sigma_obs\": 160.11341857910156, \"slope\": -0.08716342598199844, \"chain\": 2, \"draw\": 107}, {\"draws\": 507, \"mouse\": 7, \"mu_intercept_per_group\": 6.062909126281738, \"sigma_intercept_per_group\": 0.29733264446258545, \"sigma_obs\": 160.11341857910156, \"slope\": -0.08716342598199844, \"chain\": 2, \"draw\": 107}, {\"draws\": 508, \"mouse\": 0, \"mu_intercept_per_group\": 8.551190376281738, \"sigma_intercept_per_group\": 0.29457199573516846, \"sigma_obs\": 159.9733123779297, \"slope\": -0.08517684787511826, \"chain\": 2, \"draw\": 108}, {\"draws\": 508, \"mouse\": 1, \"mu_intercept_per_group\": 7.890814781188965, \"sigma_intercept_per_group\": 0.29457199573516846, \"sigma_obs\": 159.9733123779297, \"slope\": -0.08517684787511826, \"chain\": 2, \"draw\": 108}, {\"draws\": 508, \"mouse\": 2, \"mu_intercept_per_group\": 8.010278701782227, \"sigma_intercept_per_group\": 0.29457199573516846, \"sigma_obs\": 159.9733123779297, \"slope\": -0.08517684787511826, \"chain\": 2, \"draw\": 108}, {\"draws\": 508, \"mouse\": 3, \"mu_intercept_per_group\": 7.415907382965088, \"sigma_intercept_per_group\": 0.29457199573516846, \"sigma_obs\": 159.9733123779297, \"slope\": -0.08517684787511826, \"chain\": 2, \"draw\": 108}, {\"draws\": 508, \"mouse\": 4, \"mu_intercept_per_group\": 7.368361949920654, \"sigma_intercept_per_group\": 0.29457199573516846, \"sigma_obs\": 159.9733123779297, \"slope\": -0.08517684787511826, \"chain\": 2, \"draw\": 108}, {\"draws\": 508, \"mouse\": 5, \"mu_intercept_per_group\": 7.161288261413574, \"sigma_intercept_per_group\": 0.29457199573516846, \"sigma_obs\": 159.9733123779297, \"slope\": -0.08517684787511826, \"chain\": 2, \"draw\": 108}, {\"draws\": 508, \"mouse\": 6, \"mu_intercept_per_group\": 6.515252590179443, \"sigma_intercept_per_group\": 0.29457199573516846, \"sigma_obs\": 159.9733123779297, \"slope\": -0.08517684787511826, \"chain\": 2, \"draw\": 108}, {\"draws\": 508, \"mouse\": 7, \"mu_intercept_per_group\": 6.231669902801514, \"sigma_intercept_per_group\": 0.29457199573516846, \"sigma_obs\": 159.9733123779297, \"slope\": -0.08517684787511826, \"chain\": 2, \"draw\": 108}, {\"draws\": 509, \"mouse\": 0, \"mu_intercept_per_group\": 8.518560409545898, \"sigma_intercept_per_group\": 0.29281526803970337, \"sigma_obs\": 159.89735412597656, \"slope\": -0.08431792259216309, \"chain\": 2, \"draw\": 109}, {\"draws\": 509, \"mouse\": 1, \"mu_intercept_per_group\": 8.52962589263916, \"sigma_intercept_per_group\": 0.29281526803970337, \"sigma_obs\": 159.89735412597656, \"slope\": -0.08431792259216309, \"chain\": 2, \"draw\": 109}, {\"draws\": 509, \"mouse\": 2, \"mu_intercept_per_group\": 7.897233963012695, \"sigma_intercept_per_group\": 0.29281526803970337, \"sigma_obs\": 159.89735412597656, \"slope\": -0.08431792259216309, \"chain\": 2, \"draw\": 109}, {\"draws\": 509, \"mouse\": 3, \"mu_intercept_per_group\": 7.423099517822266, \"sigma_intercept_per_group\": 0.29281526803970337, \"sigma_obs\": 159.89735412597656, \"slope\": -0.08431792259216309, \"chain\": 2, \"draw\": 109}, {\"draws\": 509, \"mouse\": 4, \"mu_intercept_per_group\": 7.3768768310546875, \"sigma_intercept_per_group\": 0.29281526803970337, \"sigma_obs\": 159.89735412597656, \"slope\": -0.08431792259216309, \"chain\": 2, \"draw\": 109}, {\"draws\": 509, \"mouse\": 5, \"mu_intercept_per_group\": 6.842128753662109, \"sigma_intercept_per_group\": 0.29281526803970337, \"sigma_obs\": 159.89735412597656, \"slope\": -0.08431792259216309, \"chain\": 2, \"draw\": 109}, {\"draws\": 509, \"mouse\": 6, \"mu_intercept_per_group\": 6.6078643798828125, \"sigma_intercept_per_group\": 0.29281526803970337, \"sigma_obs\": 159.89735412597656, \"slope\": -0.08431792259216309, \"chain\": 2, \"draw\": 109}, {\"draws\": 509, \"mouse\": 7, \"mu_intercept_per_group\": 6.1349616050720215, \"sigma_intercept_per_group\": 0.29281526803970337, \"sigma_obs\": 159.89735412597656, \"slope\": -0.08431792259216309, \"chain\": 2, \"draw\": 109}, {\"draws\": 510, \"mouse\": 0, \"mu_intercept_per_group\": 8.599533081054688, \"sigma_intercept_per_group\": 0.290364533662796, \"sigma_obs\": 158.94000244140625, \"slope\": -0.08297716826200485, \"chain\": 2, \"draw\": 110}, {\"draws\": 510, \"mouse\": 1, \"mu_intercept_per_group\": 7.9677300453186035, \"sigma_intercept_per_group\": 0.290364533662796, \"sigma_obs\": 158.94000244140625, \"slope\": -0.08297716826200485, \"chain\": 2, \"draw\": 110}, {\"draws\": 510, \"mouse\": 2, \"mu_intercept_per_group\": 8.133524894714355, \"sigma_intercept_per_group\": 0.290364533662796, \"sigma_obs\": 158.94000244140625, \"slope\": -0.08297716826200485, \"chain\": 2, \"draw\": 110}, {\"draws\": 510, \"mouse\": 3, \"mu_intercept_per_group\": 7.693901062011719, \"sigma_intercept_per_group\": 0.290364533662796, \"sigma_obs\": 158.94000244140625, \"slope\": -0.08297716826200485, \"chain\": 2, \"draw\": 110}, {\"draws\": 510, \"mouse\": 4, \"mu_intercept_per_group\": 7.232498645782471, \"sigma_intercept_per_group\": 0.290364533662796, \"sigma_obs\": 158.94000244140625, \"slope\": -0.08297716826200485, \"chain\": 2, \"draw\": 110}, {\"draws\": 510, \"mouse\": 5, \"mu_intercept_per_group\": 7.171368598937988, \"sigma_intercept_per_group\": 0.290364533662796, \"sigma_obs\": 158.94000244140625, \"slope\": -0.08297716826200485, \"chain\": 2, \"draw\": 110}, {\"draws\": 510, \"mouse\": 6, \"mu_intercept_per_group\": 6.468323707580566, \"sigma_intercept_per_group\": 0.290364533662796, \"sigma_obs\": 158.94000244140625, \"slope\": -0.08297716826200485, \"chain\": 2, \"draw\": 110}, {\"draws\": 510, \"mouse\": 7, \"mu_intercept_per_group\": 6.278371334075928, \"sigma_intercept_per_group\": 0.290364533662796, \"sigma_obs\": 158.94000244140625, \"slope\": -0.08297716826200485, \"chain\": 2, \"draw\": 110}, {\"draws\": 511, \"mouse\": 0, \"mu_intercept_per_group\": 8.527189254760742, \"sigma_intercept_per_group\": 0.28842395544052124, \"sigma_obs\": 159.26425170898438, \"slope\": -0.0806172639131546, \"chain\": 2, \"draw\": 111}, {\"draws\": 511, \"mouse\": 1, \"mu_intercept_per_group\": 8.453483581542969, \"sigma_intercept_per_group\": 0.28842395544052124, \"sigma_obs\": 159.26425170898438, \"slope\": -0.0806172639131546, \"chain\": 2, \"draw\": 111}, {\"draws\": 511, \"mouse\": 2, \"mu_intercept_per_group\": 8.038064956665039, \"sigma_intercept_per_group\": 0.28842395544052124, \"sigma_obs\": 159.26425170898438, \"slope\": -0.0806172639131546, \"chain\": 2, \"draw\": 111}, {\"draws\": 511, \"mouse\": 3, \"mu_intercept_per_group\": 7.458521842956543, \"sigma_intercept_per_group\": 0.28842395544052124, \"sigma_obs\": 159.26425170898438, \"slope\": -0.0806172639131546, \"chain\": 2, \"draw\": 111}, {\"draws\": 511, \"mouse\": 4, \"mu_intercept_per_group\": 7.504243850708008, \"sigma_intercept_per_group\": 0.28842395544052124, \"sigma_obs\": 159.26425170898438, \"slope\": -0.0806172639131546, \"chain\": 2, \"draw\": 111}, {\"draws\": 511, \"mouse\": 5, \"mu_intercept_per_group\": 6.761460304260254, \"sigma_intercept_per_group\": 0.28842395544052124, \"sigma_obs\": 159.26425170898438, \"slope\": -0.0806172639131546, \"chain\": 2, \"draw\": 111}, {\"draws\": 511, \"mouse\": 6, \"mu_intercept_per_group\": 6.533613681793213, \"sigma_intercept_per_group\": 0.28842395544052124, \"sigma_obs\": 159.26425170898438, \"slope\": -0.0806172639131546, \"chain\": 2, \"draw\": 111}, {\"draws\": 511, \"mouse\": 7, \"mu_intercept_per_group\": 6.138243198394775, \"sigma_intercept_per_group\": 0.28842395544052124, \"sigma_obs\": 159.26425170898438, \"slope\": -0.0806172639131546, \"chain\": 2, \"draw\": 111}, {\"draws\": 512, \"mouse\": 0, \"mu_intercept_per_group\": 10.192229270935059, \"sigma_intercept_per_group\": 0.238240584731102, \"sigma_obs\": 145.45753479003906, \"slope\": -0.08072751015424728, \"chain\": 2, \"draw\": 112}, {\"draws\": 512, \"mouse\": 1, \"mu_intercept_per_group\": 9.64691162109375, \"sigma_intercept_per_group\": 0.238240584731102, \"sigma_obs\": 145.45753479003906, \"slope\": -0.08072751015424728, \"chain\": 2, \"draw\": 112}, {\"draws\": 512, \"mouse\": 2, \"mu_intercept_per_group\": 9.152430534362793, \"sigma_intercept_per_group\": 0.238240584731102, \"sigma_obs\": 145.45753479003906, \"slope\": -0.08072751015424728, \"chain\": 2, \"draw\": 112}, {\"draws\": 512, \"mouse\": 3, \"mu_intercept_per_group\": 8.837878227233887, \"sigma_intercept_per_group\": 0.238240584731102, \"sigma_obs\": 145.45753479003906, \"slope\": -0.08072751015424728, \"chain\": 2, \"draw\": 112}, {\"draws\": 512, \"mouse\": 4, \"mu_intercept_per_group\": 8.709260940551758, \"sigma_intercept_per_group\": 0.238240584731102, \"sigma_obs\": 145.45753479003906, \"slope\": -0.08072751015424728, \"chain\": 2, \"draw\": 112}, {\"draws\": 512, \"mouse\": 5, \"mu_intercept_per_group\": 8.037145614624023, \"sigma_intercept_per_group\": 0.238240584731102, \"sigma_obs\": 145.45753479003906, \"slope\": -0.08072751015424728, \"chain\": 2, \"draw\": 112}, {\"draws\": 512, \"mouse\": 6, \"mu_intercept_per_group\": 7.53815221786499, \"sigma_intercept_per_group\": 0.238240584731102, \"sigma_obs\": 145.45753479003906, \"slope\": -0.08072751015424728, \"chain\": 2, \"draw\": 112}, {\"draws\": 512, \"mouse\": 7, \"mu_intercept_per_group\": 7.098942756652832, \"sigma_intercept_per_group\": 0.238240584731102, \"sigma_obs\": 145.45753479003906, \"slope\": -0.08072751015424728, \"chain\": 2, \"draw\": 112}, {\"draws\": 513, \"mouse\": 0, \"mu_intercept_per_group\": 9.931018829345703, \"sigma_intercept_per_group\": 0.24191561341285706, \"sigma_obs\": 146.21607971191406, \"slope\": -0.08121389895677567, \"chain\": 2, \"draw\": 113}, {\"draws\": 513, \"mouse\": 1, \"mu_intercept_per_group\": 9.508871078491211, \"sigma_intercept_per_group\": 0.24191561341285706, \"sigma_obs\": 146.21607971191406, \"slope\": -0.08121389895677567, \"chain\": 2, \"draw\": 113}, {\"draws\": 513, \"mouse\": 2, \"mu_intercept_per_group\": 9.294468879699707, \"sigma_intercept_per_group\": 0.24191561341285706, \"sigma_obs\": 146.21607971191406, \"slope\": -0.08121389895677567, \"chain\": 2, \"draw\": 113}, {\"draws\": 513, \"mouse\": 3, \"mu_intercept_per_group\": 8.686004638671875, \"sigma_intercept_per_group\": 0.24191561341285706, \"sigma_obs\": 146.21607971191406, \"slope\": -0.08121389895677567, \"chain\": 2, \"draw\": 113}, {\"draws\": 513, \"mouse\": 4, \"mu_intercept_per_group\": 8.320435523986816, \"sigma_intercept_per_group\": 0.24191561341285706, \"sigma_obs\": 146.21607971191406, \"slope\": -0.08121389895677567, \"chain\": 2, \"draw\": 113}, {\"draws\": 513, \"mouse\": 5, \"mu_intercept_per_group\": 8.017645835876465, \"sigma_intercept_per_group\": 0.24191561341285706, \"sigma_obs\": 146.21607971191406, \"slope\": -0.08121389895677567, \"chain\": 2, \"draw\": 113}, {\"draws\": 513, \"mouse\": 6, \"mu_intercept_per_group\": 7.505574703216553, \"sigma_intercept_per_group\": 0.24191561341285706, \"sigma_obs\": 146.21607971191406, \"slope\": -0.08121389895677567, \"chain\": 2, \"draw\": 113}, {\"draws\": 513, \"mouse\": 7, \"mu_intercept_per_group\": 7.1351318359375, \"sigma_intercept_per_group\": 0.24191561341285706, \"sigma_obs\": 146.21607971191406, \"slope\": -0.08121389895677567, \"chain\": 2, \"draw\": 113}, {\"draws\": 514, \"mouse\": 0, \"mu_intercept_per_group\": 9.315531730651855, \"sigma_intercept_per_group\": 0.26002055406570435, \"sigma_obs\": 145.1957244873047, \"slope\": -0.08216843754053116, \"chain\": 2, \"draw\": 114}, {\"draws\": 514, \"mouse\": 1, \"mu_intercept_per_group\": 8.824545860290527, \"sigma_intercept_per_group\": 0.26002055406570435, \"sigma_obs\": 145.1957244873047, \"slope\": -0.08216843754053116, \"chain\": 2, \"draw\": 114}, {\"draws\": 514, \"mouse\": 2, \"mu_intercept_per_group\": 8.67225170135498, \"sigma_intercept_per_group\": 0.26002055406570435, \"sigma_obs\": 145.1957244873047, \"slope\": -0.08216843754053116, \"chain\": 2, \"draw\": 114}, {\"draws\": 514, \"mouse\": 3, \"mu_intercept_per_group\": 7.974691390991211, \"sigma_intercept_per_group\": 0.26002055406570435, \"sigma_obs\": 145.1957244873047, \"slope\": -0.08216843754053116, \"chain\": 2, \"draw\": 114}, {\"draws\": 514, \"mouse\": 4, \"mu_intercept_per_group\": 7.871941566467285, \"sigma_intercept_per_group\": 0.26002055406570435, \"sigma_obs\": 145.1957244873047, \"slope\": -0.08216843754053116, \"chain\": 2, \"draw\": 114}, {\"draws\": 514, \"mouse\": 5, \"mu_intercept_per_group\": 7.611280918121338, \"sigma_intercept_per_group\": 0.26002055406570435, \"sigma_obs\": 145.1957244873047, \"slope\": -0.08216843754053116, \"chain\": 2, \"draw\": 114}, {\"draws\": 514, \"mouse\": 6, \"mu_intercept_per_group\": 7.036925315856934, \"sigma_intercept_per_group\": 0.26002055406570435, \"sigma_obs\": 145.1957244873047, \"slope\": -0.08216843754053116, \"chain\": 2, \"draw\": 114}, {\"draws\": 514, \"mouse\": 7, \"mu_intercept_per_group\": 6.550048351287842, \"sigma_intercept_per_group\": 0.26002055406570435, \"sigma_obs\": 145.1957244873047, \"slope\": -0.08216843754053116, \"chain\": 2, \"draw\": 114}, {\"draws\": 515, \"mouse\": 0, \"mu_intercept_per_group\": 10.740941047668457, \"sigma_intercept_per_group\": 0.22610226273536682, \"sigma_obs\": 149.9112091064453, \"slope\": -0.07668668776750565, \"chain\": 2, \"draw\": 115}, {\"draws\": 515, \"mouse\": 1, \"mu_intercept_per_group\": 10.19688892364502, \"sigma_intercept_per_group\": 0.22610226273536682, \"sigma_obs\": 149.9112091064453, \"slope\": -0.07668668776750565, \"chain\": 2, \"draw\": 115}, {\"draws\": 515, \"mouse\": 2, \"mu_intercept_per_group\": 9.870147705078125, \"sigma_intercept_per_group\": 0.22610226273536682, \"sigma_obs\": 149.9112091064453, \"slope\": -0.07668668776750565, \"chain\": 2, \"draw\": 115}, {\"draws\": 515, \"mouse\": 3, \"mu_intercept_per_group\": 9.364384651184082, \"sigma_intercept_per_group\": 0.22610226273536682, \"sigma_obs\": 149.9112091064453, \"slope\": -0.07668668776750565, \"chain\": 2, \"draw\": 115}, {\"draws\": 515, \"mouse\": 4, \"mu_intercept_per_group\": 9.14587688446045, \"sigma_intercept_per_group\": 0.22610226273536682, \"sigma_obs\": 149.9112091064453, \"slope\": -0.07668668776750565, \"chain\": 2, \"draw\": 115}, {\"draws\": 515, \"mouse\": 5, \"mu_intercept_per_group\": 8.743733406066895, \"sigma_intercept_per_group\": 0.22610226273536682, \"sigma_obs\": 149.9112091064453, \"slope\": -0.07668668776750565, \"chain\": 2, \"draw\": 115}, {\"draws\": 515, \"mouse\": 6, \"mu_intercept_per_group\": 8.081732749938965, \"sigma_intercept_per_group\": 0.22610226273536682, \"sigma_obs\": 149.9112091064453, \"slope\": -0.07668668776750565, \"chain\": 2, \"draw\": 115}, {\"draws\": 515, \"mouse\": 7, \"mu_intercept_per_group\": 7.717783451080322, \"sigma_intercept_per_group\": 0.22610226273536682, \"sigma_obs\": 149.9112091064453, \"slope\": -0.07668668776750565, \"chain\": 2, \"draw\": 115}, {\"draws\": 516, \"mouse\": 0, \"mu_intercept_per_group\": 9.209675788879395, \"sigma_intercept_per_group\": 0.26608195900917053, \"sigma_obs\": 152.2930908203125, \"slope\": -0.08130082488059998, \"chain\": 2, \"draw\": 116}, {\"draws\": 516, \"mouse\": 1, \"mu_intercept_per_group\": 8.826081275939941, \"sigma_intercept_per_group\": 0.26608195900917053, \"sigma_obs\": 152.2930908203125, \"slope\": -0.08130082488059998, \"chain\": 2, \"draw\": 116}, {\"draws\": 516, \"mouse\": 2, \"mu_intercept_per_group\": 8.637925148010254, \"sigma_intercept_per_group\": 0.26608195900917053, \"sigma_obs\": 152.2930908203125, \"slope\": -0.08130082488059998, \"chain\": 2, \"draw\": 116}, {\"draws\": 516, \"mouse\": 3, \"mu_intercept_per_group\": 8.047011375427246, \"sigma_intercept_per_group\": 0.26608195900917053, \"sigma_obs\": 152.2930908203125, \"slope\": -0.08130082488059998, \"chain\": 2, \"draw\": 116}, {\"draws\": 516, \"mouse\": 4, \"mu_intercept_per_group\": 7.909860610961914, \"sigma_intercept_per_group\": 0.26608195900917053, \"sigma_obs\": 152.2930908203125, \"slope\": -0.08130082488059998, \"chain\": 2, \"draw\": 116}, {\"draws\": 516, \"mouse\": 5, \"mu_intercept_per_group\": 7.693511486053467, \"sigma_intercept_per_group\": 0.26608195900917053, \"sigma_obs\": 152.2930908203125, \"slope\": -0.08130082488059998, \"chain\": 2, \"draw\": 116}, {\"draws\": 516, \"mouse\": 6, \"mu_intercept_per_group\": 6.995692253112793, \"sigma_intercept_per_group\": 0.26608195900917053, \"sigma_obs\": 152.2930908203125, \"slope\": -0.08130082488059998, \"chain\": 2, \"draw\": 116}, {\"draws\": 516, \"mouse\": 7, \"mu_intercept_per_group\": 6.5258469581604, \"sigma_intercept_per_group\": 0.26608195900917053, \"sigma_obs\": 152.2930908203125, \"slope\": -0.08130082488059998, \"chain\": 2, \"draw\": 116}, {\"draws\": 517, \"mouse\": 0, \"mu_intercept_per_group\": 7.465918064117432, \"sigma_intercept_per_group\": 0.32971417903900146, \"sigma_obs\": 158.73829650878906, \"slope\": -0.08311841636896133, \"chain\": 2, \"draw\": 117}, {\"draws\": 517, \"mouse\": 1, \"mu_intercept_per_group\": 7.485874176025391, \"sigma_intercept_per_group\": 0.32971417903900146, \"sigma_obs\": 158.73829650878906, \"slope\": -0.08311841636896133, \"chain\": 2, \"draw\": 117}, {\"draws\": 517, \"mouse\": 2, \"mu_intercept_per_group\": 6.991905212402344, \"sigma_intercept_per_group\": 0.32971417903900146, \"sigma_obs\": 158.73829650878906, \"slope\": -0.08311841636896133, \"chain\": 2, \"draw\": 117}, {\"draws\": 517, \"mouse\": 3, \"mu_intercept_per_group\": 6.721418857574463, \"sigma_intercept_per_group\": 0.32971417903900146, \"sigma_obs\": 158.73829650878906, \"slope\": -0.08311841636896133, \"chain\": 2, \"draw\": 117}, {\"draws\": 517, \"mouse\": 4, \"mu_intercept_per_group\": 6.393702030181885, \"sigma_intercept_per_group\": 0.32971417903900146, \"sigma_obs\": 158.73829650878906, \"slope\": -0.08311841636896133, \"chain\": 2, \"draw\": 117}, {\"draws\": 517, \"mouse\": 5, \"mu_intercept_per_group\": 6.1131792068481445, \"sigma_intercept_per_group\": 0.32971417903900146, \"sigma_obs\": 158.73829650878906, \"slope\": -0.08311841636896133, \"chain\": 2, \"draw\": 117}, {\"draws\": 517, \"mouse\": 6, \"mu_intercept_per_group\": 5.646047115325928, \"sigma_intercept_per_group\": 0.32971417903900146, \"sigma_obs\": 158.73829650878906, \"slope\": -0.08311841636896133, \"chain\": 2, \"draw\": 117}, {\"draws\": 517, \"mouse\": 7, \"mu_intercept_per_group\": 5.398566722869873, \"sigma_intercept_per_group\": 0.32971417903900146, \"sigma_obs\": 158.73829650878906, \"slope\": -0.08311841636896133, \"chain\": 2, \"draw\": 117}, {\"draws\": 518, \"mouse\": 0, \"mu_intercept_per_group\": 7.538663387298584, \"sigma_intercept_per_group\": 0.32471656799316406, \"sigma_obs\": 160.24586486816406, \"slope\": -0.0853176936507225, \"chain\": 2, \"draw\": 118}, {\"draws\": 518, \"mouse\": 1, \"mu_intercept_per_group\": 7.2454118728637695, \"sigma_intercept_per_group\": 0.32471656799316406, \"sigma_obs\": 160.24586486816406, \"slope\": -0.0853176936507225, \"chain\": 2, \"draw\": 118}, {\"draws\": 518, \"mouse\": 2, \"mu_intercept_per_group\": 7.322647571563721, \"sigma_intercept_per_group\": 0.32471656799316406, \"sigma_obs\": 160.24586486816406, \"slope\": -0.0853176936507225, \"chain\": 2, \"draw\": 118}, {\"draws\": 518, \"mouse\": 3, \"mu_intercept_per_group\": 6.936844825744629, \"sigma_intercept_per_group\": 0.32471656799316406, \"sigma_obs\": 160.24586486816406, \"slope\": -0.0853176936507225, \"chain\": 2, \"draw\": 118}, {\"draws\": 518, \"mouse\": 4, \"mu_intercept_per_group\": 6.718649387359619, \"sigma_intercept_per_group\": 0.32471656799316406, \"sigma_obs\": 160.24586486816406, \"slope\": -0.0853176936507225, \"chain\": 2, \"draw\": 118}, {\"draws\": 518, \"mouse\": 5, \"mu_intercept_per_group\": 6.296597480773926, \"sigma_intercept_per_group\": 0.32471656799316406, \"sigma_obs\": 160.24586486816406, \"slope\": -0.0853176936507225, \"chain\": 2, \"draw\": 118}, {\"draws\": 518, \"mouse\": 6, \"mu_intercept_per_group\": 5.950411319732666, \"sigma_intercept_per_group\": 0.32471656799316406, \"sigma_obs\": 160.24586486816406, \"slope\": -0.0853176936507225, \"chain\": 2, \"draw\": 118}, {\"draws\": 518, \"mouse\": 7, \"mu_intercept_per_group\": 5.661221027374268, \"sigma_intercept_per_group\": 0.32471656799316406, \"sigma_obs\": 160.24586486816406, \"slope\": -0.0853176936507225, \"chain\": 2, \"draw\": 118}, {\"draws\": 519, \"mouse\": 0, \"mu_intercept_per_group\": 7.866353511810303, \"sigma_intercept_per_group\": 0.323323130607605, \"sigma_obs\": 160.40977478027344, \"slope\": -0.08473137021064758, \"chain\": 2, \"draw\": 119}, {\"draws\": 519, \"mouse\": 1, \"mu_intercept_per_group\": 7.473153591156006, \"sigma_intercept_per_group\": 0.323323130607605, \"sigma_obs\": 160.40977478027344, \"slope\": -0.08473137021064758, \"chain\": 2, \"draw\": 119}, {\"draws\": 519, \"mouse\": 2, \"mu_intercept_per_group\": 7.129768371582031, \"sigma_intercept_per_group\": 0.323323130607605, \"sigma_obs\": 160.40977478027344, \"slope\": -0.08473137021064758, \"chain\": 2, \"draw\": 119}, {\"draws\": 519, \"mouse\": 3, \"mu_intercept_per_group\": 6.815636157989502, \"sigma_intercept_per_group\": 0.323323130607605, \"sigma_obs\": 160.40977478027344, \"slope\": -0.08473137021064758, \"chain\": 2, \"draw\": 119}, {\"draws\": 519, \"mouse\": 4, \"mu_intercept_per_group\": 6.398346424102783, \"sigma_intercept_per_group\": 0.323323130607605, \"sigma_obs\": 160.40977478027344, \"slope\": -0.08473137021064758, \"chain\": 2, \"draw\": 119}, {\"draws\": 519, \"mouse\": 5, \"mu_intercept_per_group\": 6.516684055328369, \"sigma_intercept_per_group\": 0.323323130607605, \"sigma_obs\": 160.40977478027344, \"slope\": -0.08473137021064758, \"chain\": 2, \"draw\": 119}, {\"draws\": 519, \"mouse\": 6, \"mu_intercept_per_group\": 5.719256401062012, \"sigma_intercept_per_group\": 0.323323130607605, \"sigma_obs\": 160.40977478027344, \"slope\": -0.08473137021064758, \"chain\": 2, \"draw\": 119}, {\"draws\": 519, \"mouse\": 7, \"mu_intercept_per_group\": 5.6194047927856445, \"sigma_intercept_per_group\": 0.323323130607605, \"sigma_obs\": 160.40977478027344, \"slope\": -0.08473137021064758, \"chain\": 2, \"draw\": 119}, {\"draws\": 520, \"mouse\": 0, \"mu_intercept_per_group\": 7.559803009033203, \"sigma_intercept_per_group\": 0.3270602822303772, \"sigma_obs\": 160.68115234375, \"slope\": -0.08466954529285431, \"chain\": 2, \"draw\": 120}, {\"draws\": 520, \"mouse\": 1, \"mu_intercept_per_group\": 7.423447608947754, \"sigma_intercept_per_group\": 0.3270602822303772, \"sigma_obs\": 160.68115234375, \"slope\": -0.08466954529285431, \"chain\": 2, \"draw\": 120}, {\"draws\": 520, \"mouse\": 2, \"mu_intercept_per_group\": 7.318060398101807, \"sigma_intercept_per_group\": 0.3270602822303772, \"sigma_obs\": 160.68115234375, \"slope\": -0.08466954529285431, \"chain\": 2, \"draw\": 120}, {\"draws\": 520, \"mouse\": 3, \"mu_intercept_per_group\": 6.7566070556640625, \"sigma_intercept_per_group\": 0.3270602822303772, \"sigma_obs\": 160.68115234375, \"slope\": -0.08466954529285431, \"chain\": 2, \"draw\": 120}, {\"draws\": 520, \"mouse\": 4, \"mu_intercept_per_group\": 6.838967800140381, \"sigma_intercept_per_group\": 0.3270602822303772, \"sigma_obs\": 160.68115234375, \"slope\": -0.08466954529285431, \"chain\": 2, \"draw\": 120}, {\"draws\": 520, \"mouse\": 5, \"mu_intercept_per_group\": 6.031294345855713, \"sigma_intercept_per_group\": 0.3270602822303772, \"sigma_obs\": 160.68115234375, \"slope\": -0.08466954529285431, \"chain\": 2, \"draw\": 120}, {\"draws\": 520, \"mouse\": 6, \"mu_intercept_per_group\": 5.848823070526123, \"sigma_intercept_per_group\": 0.3270602822303772, \"sigma_obs\": 160.68115234375, \"slope\": -0.08466954529285431, \"chain\": 2, \"draw\": 120}, {\"draws\": 520, \"mouse\": 7, \"mu_intercept_per_group\": 5.395413875579834, \"sigma_intercept_per_group\": 0.3270602822303772, \"sigma_obs\": 160.68115234375, \"slope\": -0.08466954529285431, \"chain\": 2, \"draw\": 120}, {\"draws\": 521, \"mouse\": 0, \"mu_intercept_per_group\": 7.303988456726074, \"sigma_intercept_per_group\": 0.33835482597351074, \"sigma_obs\": 162.06375122070312, \"slope\": -0.08908247947692871, \"chain\": 2, \"draw\": 121}, {\"draws\": 521, \"mouse\": 1, \"mu_intercept_per_group\": 7.003849029541016, \"sigma_intercept_per_group\": 0.33835482597351074, \"sigma_obs\": 162.06375122070312, \"slope\": -0.08908247947692871, \"chain\": 2, \"draw\": 121}, {\"draws\": 521, \"mouse\": 2, \"mu_intercept_per_group\": 7.011092185974121, \"sigma_intercept_per_group\": 0.33835482597351074, \"sigma_obs\": 162.06375122070312, \"slope\": -0.08908247947692871, \"chain\": 2, \"draw\": 121}, {\"draws\": 521, \"mouse\": 3, \"mu_intercept_per_group\": 6.433393955230713, \"sigma_intercept_per_group\": 0.33835482597351074, \"sigma_obs\": 162.06375122070312, \"slope\": -0.08908247947692871, \"chain\": 2, \"draw\": 121}, {\"draws\": 521, \"mouse\": 4, \"mu_intercept_per_group\": 6.550400257110596, \"sigma_intercept_per_group\": 0.33835482597351074, \"sigma_obs\": 162.06375122070312, \"slope\": -0.08908247947692871, \"chain\": 2, \"draw\": 121}, {\"draws\": 521, \"mouse\": 5, \"mu_intercept_per_group\": 5.756600856781006, \"sigma_intercept_per_group\": 0.33835482597351074, \"sigma_obs\": 162.06375122070312, \"slope\": -0.08908247947692871, \"chain\": 2, \"draw\": 121}, {\"draws\": 521, \"mouse\": 6, \"mu_intercept_per_group\": 5.655100345611572, \"sigma_intercept_per_group\": 0.33835482597351074, \"sigma_obs\": 162.06375122070312, \"slope\": -0.08908247947692871, \"chain\": 2, \"draw\": 121}, {\"draws\": 521, \"mouse\": 7, \"mu_intercept_per_group\": 5.561706066131592, \"sigma_intercept_per_group\": 0.33835482597351074, \"sigma_obs\": 162.06375122070312, \"slope\": -0.08908247947692871, \"chain\": 2, \"draw\": 121}, {\"draws\": 522, \"mouse\": 0, \"mu_intercept_per_group\": 7.373167991638184, \"sigma_intercept_per_group\": 0.3422849178314209, \"sigma_obs\": 161.953369140625, \"slope\": -0.08787720650434494, \"chain\": 2, \"draw\": 122}, {\"draws\": 522, \"mouse\": 1, \"mu_intercept_per_group\": 7.049314022064209, \"sigma_intercept_per_group\": 0.3422849178314209, \"sigma_obs\": 161.953369140625, \"slope\": -0.08787720650434494, \"chain\": 2, \"draw\": 122}, {\"draws\": 522, \"mouse\": 2, \"mu_intercept_per_group\": 6.996840953826904, \"sigma_intercept_per_group\": 0.3422849178314209, \"sigma_obs\": 161.953369140625, \"slope\": -0.08787720650434494, \"chain\": 2, \"draw\": 122}, {\"draws\": 522, \"mouse\": 3, \"mu_intercept_per_group\": 6.443996429443359, \"sigma_intercept_per_group\": 0.3422849178314209, \"sigma_obs\": 161.953369140625, \"slope\": -0.08787720650434494, \"chain\": 2, \"draw\": 122}, {\"draws\": 522, \"mouse\": 4, \"mu_intercept_per_group\": 6.398680210113525, \"sigma_intercept_per_group\": 0.3422849178314209, \"sigma_obs\": 161.953369140625, \"slope\": -0.08787720650434494, \"chain\": 2, \"draw\": 122}, {\"draws\": 522, \"mouse\": 5, \"mu_intercept_per_group\": 6.078075885772705, \"sigma_intercept_per_group\": 0.3422849178314209, \"sigma_obs\": 161.953369140625, \"slope\": -0.08787720650434494, \"chain\": 2, \"draw\": 122}, {\"draws\": 522, \"mouse\": 6, \"mu_intercept_per_group\": 5.464173316955566, \"sigma_intercept_per_group\": 0.3422849178314209, \"sigma_obs\": 161.953369140625, \"slope\": -0.08787720650434494, \"chain\": 2, \"draw\": 122}, {\"draws\": 522, \"mouse\": 7, \"mu_intercept_per_group\": 5.596164226531982, \"sigma_intercept_per_group\": 0.3422849178314209, \"sigma_obs\": 161.953369140625, \"slope\": -0.08787720650434494, \"chain\": 2, \"draw\": 122}, {\"draws\": 523, \"mouse\": 0, \"mu_intercept_per_group\": 7.5051703453063965, \"sigma_intercept_per_group\": 0.3389641046524048, \"sigma_obs\": 163.26187133789062, \"slope\": -0.08977572619915009, \"chain\": 2, \"draw\": 123}, {\"draws\": 523, \"mouse\": 1, \"mu_intercept_per_group\": 7.140849590301514, \"sigma_intercept_per_group\": 0.3389641046524048, \"sigma_obs\": 163.26187133789062, \"slope\": -0.08977572619915009, \"chain\": 2, \"draw\": 123}, {\"draws\": 523, \"mouse\": 2, \"mu_intercept_per_group\": 6.7783522605896, \"sigma_intercept_per_group\": 0.3389641046524048, \"sigma_obs\": 163.26187133789062, \"slope\": -0.08977572619915009, \"chain\": 2, \"draw\": 123}, {\"draws\": 523, \"mouse\": 3, \"mu_intercept_per_group\": 6.553530216217041, \"sigma_intercept_per_group\": 0.3389641046524048, \"sigma_obs\": 163.26187133789062, \"slope\": -0.08977572619915009, \"chain\": 2, \"draw\": 123}, {\"draws\": 523, \"mouse\": 4, \"mu_intercept_per_group\": 6.322073459625244, \"sigma_intercept_per_group\": 0.3389641046524048, \"sigma_obs\": 163.26187133789062, \"slope\": -0.08977572619915009, \"chain\": 2, \"draw\": 123}, {\"draws\": 523, \"mouse\": 5, \"mu_intercept_per_group\": 5.91101598739624, \"sigma_intercept_per_group\": 0.3389641046524048, \"sigma_obs\": 163.26187133789062, \"slope\": -0.08977572619915009, \"chain\": 2, \"draw\": 123}, {\"draws\": 523, \"mouse\": 6, \"mu_intercept_per_group\": 5.750241756439209, \"sigma_intercept_per_group\": 0.3389641046524048, \"sigma_obs\": 163.26187133789062, \"slope\": -0.08977572619915009, \"chain\": 2, \"draw\": 123}, {\"draws\": 523, \"mouse\": 7, \"mu_intercept_per_group\": 5.148121356964111, \"sigma_intercept_per_group\": 0.3389641046524048, \"sigma_obs\": 163.26187133789062, \"slope\": -0.08977572619915009, \"chain\": 2, \"draw\": 123}, {\"draws\": 524, \"mouse\": 0, \"mu_intercept_per_group\": 7.286256790161133, \"sigma_intercept_per_group\": 0.338434100151062, \"sigma_obs\": 163.91461181640625, \"slope\": -0.08996451646089554, \"chain\": 2, \"draw\": 124}, {\"draws\": 524, \"mouse\": 1, \"mu_intercept_per_group\": 7.120361804962158, \"sigma_intercept_per_group\": 0.338434100151062, \"sigma_obs\": 163.91461181640625, \"slope\": -0.08996451646089554, \"chain\": 2, \"draw\": 124}, {\"draws\": 524, \"mouse\": 2, \"mu_intercept_per_group\": 7.04585075378418, \"sigma_intercept_per_group\": 0.338434100151062, \"sigma_obs\": 163.91461181640625, \"slope\": -0.08996451646089554, \"chain\": 2, \"draw\": 124}, {\"draws\": 524, \"mouse\": 3, \"mu_intercept_per_group\": 6.609982013702393, \"sigma_intercept_per_group\": 0.338434100151062, \"sigma_obs\": 163.91461181640625, \"slope\": -0.08996451646089554, \"chain\": 2, \"draw\": 124}, {\"draws\": 524, \"mouse\": 4, \"mu_intercept_per_group\": 6.520452499389648, \"sigma_intercept_per_group\": 0.338434100151062, \"sigma_obs\": 163.91461181640625, \"slope\": -0.08996451646089554, \"chain\": 2, \"draw\": 124}, {\"draws\": 524, \"mouse\": 5, \"mu_intercept_per_group\": 6.0639848709106445, \"sigma_intercept_per_group\": 0.338434100151062, \"sigma_obs\": 163.91461181640625, \"slope\": -0.08996451646089554, \"chain\": 2, \"draw\": 124}, {\"draws\": 524, \"mouse\": 6, \"mu_intercept_per_group\": 5.485245704650879, \"sigma_intercept_per_group\": 0.338434100151062, \"sigma_obs\": 163.91461181640625, \"slope\": -0.08996451646089554, \"chain\": 2, \"draw\": 124}, {\"draws\": 524, \"mouse\": 7, \"mu_intercept_per_group\": 5.402312755584717, \"sigma_intercept_per_group\": 0.338434100151062, \"sigma_obs\": 163.91461181640625, \"slope\": -0.08996451646089554, \"chain\": 2, \"draw\": 124}, {\"draws\": 525, \"mouse\": 0, \"mu_intercept_per_group\": 7.345522403717041, \"sigma_intercept_per_group\": 0.3410136103630066, \"sigma_obs\": 164.64453125, \"slope\": -0.0909029170870781, \"chain\": 2, \"draw\": 125}, {\"draws\": 525, \"mouse\": 1, \"mu_intercept_per_group\": 7.1031599044799805, \"sigma_intercept_per_group\": 0.3410136103630066, \"sigma_obs\": 164.64453125, \"slope\": -0.0909029170870781, \"chain\": 2, \"draw\": 125}, {\"draws\": 525, \"mouse\": 2, \"mu_intercept_per_group\": 6.880637168884277, \"sigma_intercept_per_group\": 0.3410136103630066, \"sigma_obs\": 164.64453125, \"slope\": -0.0909029170870781, \"chain\": 2, \"draw\": 125}, {\"draws\": 525, \"mouse\": 3, \"mu_intercept_per_group\": 6.679596900939941, \"sigma_intercept_per_group\": 0.3410136103630066, \"sigma_obs\": 164.64453125, \"slope\": -0.0909029170870781, \"chain\": 2, \"draw\": 125}, {\"draws\": 525, \"mouse\": 4, \"mu_intercept_per_group\": 6.263970851898193, \"sigma_intercept_per_group\": 0.3410136103630066, \"sigma_obs\": 164.64453125, \"slope\": -0.0909029170870781, \"chain\": 2, \"draw\": 125}, {\"draws\": 525, \"mouse\": 5, \"mu_intercept_per_group\": 5.9806809425354, \"sigma_intercept_per_group\": 0.3410136103630066, \"sigma_obs\": 164.64453125, \"slope\": -0.0909029170870781, \"chain\": 2, \"draw\": 125}, {\"draws\": 525, \"mouse\": 6, \"mu_intercept_per_group\": 5.916065216064453, \"sigma_intercept_per_group\": 0.3410136103630066, \"sigma_obs\": 164.64453125, \"slope\": -0.0909029170870781, \"chain\": 2, \"draw\": 125}, {\"draws\": 525, \"mouse\": 7, \"mu_intercept_per_group\": 5.270811080932617, \"sigma_intercept_per_group\": 0.3410136103630066, \"sigma_obs\": 164.64453125, \"slope\": -0.0909029170870781, \"chain\": 2, \"draw\": 125}, {\"draws\": 526, \"mouse\": 0, \"mu_intercept_per_group\": 7.780086517333984, \"sigma_intercept_per_group\": 0.3201657831668854, \"sigma_obs\": 155.92379760742188, \"slope\": -0.09710702300071716, \"chain\": 2, \"draw\": 126}, {\"draws\": 526, \"mouse\": 1, \"mu_intercept_per_group\": 7.4501752853393555, \"sigma_intercept_per_group\": 0.3201657831668854, \"sigma_obs\": 155.92379760742188, \"slope\": -0.09710702300071716, \"chain\": 2, \"draw\": 126}, {\"draws\": 526, \"mouse\": 2, \"mu_intercept_per_group\": 7.4052934646606445, \"sigma_intercept_per_group\": 0.3201657831668854, \"sigma_obs\": 155.92379760742188, \"slope\": -0.09710702300071716, \"chain\": 2, \"draw\": 126}, {\"draws\": 526, \"mouse\": 3, \"mu_intercept_per_group\": 7.020945072174072, \"sigma_intercept_per_group\": 0.3201657831668854, \"sigma_obs\": 155.92379760742188, \"slope\": -0.09710702300071716, \"chain\": 2, \"draw\": 126}, {\"draws\": 526, \"mouse\": 4, \"mu_intercept_per_group\": 6.595235347747803, \"sigma_intercept_per_group\": 0.3201657831668854, \"sigma_obs\": 155.92379760742188, \"slope\": -0.09710702300071716, \"chain\": 2, \"draw\": 126}, {\"draws\": 526, \"mouse\": 5, \"mu_intercept_per_group\": 6.243092060089111, \"sigma_intercept_per_group\": 0.3201657831668854, \"sigma_obs\": 155.92379760742188, \"slope\": -0.09710702300071716, \"chain\": 2, \"draw\": 126}, {\"draws\": 526, \"mouse\": 6, \"mu_intercept_per_group\": 5.738644599914551, \"sigma_intercept_per_group\": 0.3201657831668854, \"sigma_obs\": 155.92379760742188, \"slope\": -0.09710702300071716, \"chain\": 2, \"draw\": 126}, {\"draws\": 526, \"mouse\": 7, \"mu_intercept_per_group\": 5.584937572479248, \"sigma_intercept_per_group\": 0.3201657831668854, \"sigma_obs\": 155.92379760742188, \"slope\": -0.09710702300071716, \"chain\": 2, \"draw\": 126}, {\"draws\": 527, \"mouse\": 0, \"mu_intercept_per_group\": 10.40320110321045, \"sigma_intercept_per_group\": 0.24575255811214447, \"sigma_obs\": 165.99497985839844, \"slope\": -0.08648914098739624, \"chain\": 2, \"draw\": 127}, {\"draws\": 527, \"mouse\": 1, \"mu_intercept_per_group\": 10.081250190734863, \"sigma_intercept_per_group\": 0.24575255811214447, \"sigma_obs\": 165.99497985839844, \"slope\": -0.08648914098739624, \"chain\": 2, \"draw\": 127}, {\"draws\": 527, \"mouse\": 2, \"mu_intercept_per_group\": 9.750435829162598, \"sigma_intercept_per_group\": 0.24575255811214447, \"sigma_obs\": 165.99497985839844, \"slope\": -0.08648914098739624, \"chain\": 2, \"draw\": 127}, {\"draws\": 527, \"mouse\": 3, \"mu_intercept_per_group\": 9.369353294372559, \"sigma_intercept_per_group\": 0.24575255811214447, \"sigma_obs\": 165.99497985839844, \"slope\": -0.08648914098739624, \"chain\": 2, \"draw\": 127}, {\"draws\": 527, \"mouse\": 4, \"mu_intercept_per_group\": 8.763138771057129, \"sigma_intercept_per_group\": 0.24575255811214447, \"sigma_obs\": 165.99497985839844, \"slope\": -0.08648914098739624, \"chain\": 2, \"draw\": 127}, {\"draws\": 527, \"mouse\": 5, \"mu_intercept_per_group\": 8.570775985717773, \"sigma_intercept_per_group\": 0.24575255811214447, \"sigma_obs\": 165.99497985839844, \"slope\": -0.08648914098739624, \"chain\": 2, \"draw\": 127}, {\"draws\": 527, \"mouse\": 6, \"mu_intercept_per_group\": 7.86264705657959, \"sigma_intercept_per_group\": 0.24575255811214447, \"sigma_obs\": 165.99497985839844, \"slope\": -0.08648914098739624, \"chain\": 2, \"draw\": 127}, {\"draws\": 527, \"mouse\": 7, \"mu_intercept_per_group\": 7.579777240753174, \"sigma_intercept_per_group\": 0.24575255811214447, \"sigma_obs\": 165.99497985839844, \"slope\": -0.08648914098739624, \"chain\": 2, \"draw\": 127}, {\"draws\": 528, \"mouse\": 0, \"mu_intercept_per_group\": 10.313044548034668, \"sigma_intercept_per_group\": 0.2469741851091385, \"sigma_obs\": 166.03836059570312, \"slope\": -0.0877801701426506, \"chain\": 2, \"draw\": 128}, {\"draws\": 528, \"mouse\": 1, \"mu_intercept_per_group\": 9.900859832763672, \"sigma_intercept_per_group\": 0.2469741851091385, \"sigma_obs\": 166.03836059570312, \"slope\": -0.0877801701426506, \"chain\": 2, \"draw\": 128}, {\"draws\": 528, \"mouse\": 2, \"mu_intercept_per_group\": 9.823736190795898, \"sigma_intercept_per_group\": 0.2469741851091385, \"sigma_obs\": 166.03836059570312, \"slope\": -0.0877801701426506, \"chain\": 2, \"draw\": 128}, {\"draws\": 528, \"mouse\": 3, \"mu_intercept_per_group\": 9.144474983215332, \"sigma_intercept_per_group\": 0.2469741851091385, \"sigma_obs\": 166.03836059570312, \"slope\": -0.0877801701426506, \"chain\": 2, \"draw\": 128}, {\"draws\": 528, \"mouse\": 4, \"mu_intercept_per_group\": 9.079707145690918, \"sigma_intercept_per_group\": 0.2469741851091385, \"sigma_obs\": 166.03836059570312, \"slope\": -0.0877801701426506, \"chain\": 2, \"draw\": 128}, {\"draws\": 528, \"mouse\": 5, \"mu_intercept_per_group\": 8.417622566223145, \"sigma_intercept_per_group\": 0.2469741851091385, \"sigma_obs\": 166.03836059570312, \"slope\": -0.0877801701426506, \"chain\": 2, \"draw\": 128}, {\"draws\": 528, \"mouse\": 6, \"mu_intercept_per_group\": 7.56102991104126, \"sigma_intercept_per_group\": 0.2469741851091385, \"sigma_obs\": 166.03836059570312, \"slope\": -0.0877801701426506, \"chain\": 2, \"draw\": 128}, {\"draws\": 528, \"mouse\": 7, \"mu_intercept_per_group\": 7.7327799797058105, \"sigma_intercept_per_group\": 0.2469741851091385, \"sigma_obs\": 166.03836059570312, \"slope\": -0.0877801701426506, \"chain\": 2, \"draw\": 128}, {\"draws\": 529, \"mouse\": 0, \"mu_intercept_per_group\": 9.855706214904785, \"sigma_intercept_per_group\": 0.2590720057487488, \"sigma_obs\": 163.9134521484375, \"slope\": -0.08769107609987259, \"chain\": 2, \"draw\": 129}, {\"draws\": 529, \"mouse\": 1, \"mu_intercept_per_group\": 9.607044219970703, \"sigma_intercept_per_group\": 0.2590720057487488, \"sigma_obs\": 163.9134521484375, \"slope\": -0.08769107609987259, \"chain\": 2, \"draw\": 129}, {\"draws\": 529, \"mouse\": 2, \"mu_intercept_per_group\": 9.008474349975586, \"sigma_intercept_per_group\": 0.2590720057487488, \"sigma_obs\": 163.9134521484375, \"slope\": -0.08769107609987259, \"chain\": 2, \"draw\": 129}, {\"draws\": 529, \"mouse\": 3, \"mu_intercept_per_group\": 8.565225601196289, \"sigma_intercept_per_group\": 0.2590720057487488, \"sigma_obs\": 163.9134521484375, \"slope\": -0.08769107609987259, \"chain\": 2, \"draw\": 129}, {\"draws\": 529, \"mouse\": 4, \"mu_intercept_per_group\": 8.578304290771484, \"sigma_intercept_per_group\": 0.2590720057487488, \"sigma_obs\": 163.9134521484375, \"slope\": -0.08769107609987259, \"chain\": 2, \"draw\": 129}, {\"draws\": 529, \"mouse\": 5, \"mu_intercept_per_group\": 7.98608922958374, \"sigma_intercept_per_group\": 0.2590720057487488, \"sigma_obs\": 163.9134521484375, \"slope\": -0.08769107609987259, \"chain\": 2, \"draw\": 129}, {\"draws\": 529, \"mouse\": 6, \"mu_intercept_per_group\": 6.9436140060424805, \"sigma_intercept_per_group\": 0.2590720057487488, \"sigma_obs\": 163.9134521484375, \"slope\": -0.08769107609987259, \"chain\": 2, \"draw\": 129}, {\"draws\": 529, \"mouse\": 7, \"mu_intercept_per_group\": 7.145823001861572, \"sigma_intercept_per_group\": 0.2590720057487488, \"sigma_obs\": 163.9134521484375, \"slope\": -0.08769107609987259, \"chain\": 2, \"draw\": 129}, {\"draws\": 530, \"mouse\": 0, \"mu_intercept_per_group\": 9.466514587402344, \"sigma_intercept_per_group\": 0.2594931721687317, \"sigma_obs\": 161.00765991210938, \"slope\": -0.08329920470714569, \"chain\": 2, \"draw\": 130}, {\"draws\": 530, \"mouse\": 1, \"mu_intercept_per_group\": 8.877203941345215, \"sigma_intercept_per_group\": 0.2594931721687317, \"sigma_obs\": 161.00765991210938, \"slope\": -0.08329920470714569, \"chain\": 2, \"draw\": 130}, {\"draws\": 530, \"mouse\": 2, \"mu_intercept_per_group\": 9.391940116882324, \"sigma_intercept_per_group\": 0.2594931721687317, \"sigma_obs\": 161.00765991210938, \"slope\": -0.08329920470714569, \"chain\": 2, \"draw\": 130}, {\"draws\": 530, \"mouse\": 3, \"mu_intercept_per_group\": 8.611282348632812, \"sigma_intercept_per_group\": 0.2594931721687317, \"sigma_obs\": 161.00765991210938, \"slope\": -0.08329920470714569, \"chain\": 2, \"draw\": 130}, {\"draws\": 530, \"mouse\": 4, \"mu_intercept_per_group\": 8.175932884216309, \"sigma_intercept_per_group\": 0.2594931721687317, \"sigma_obs\": 161.00765991210938, \"slope\": -0.08329920470714569, \"chain\": 2, \"draw\": 130}, {\"draws\": 530, \"mouse\": 5, \"mu_intercept_per_group\": 7.829325199127197, \"sigma_intercept_per_group\": 0.2594931721687317, \"sigma_obs\": 161.00765991210938, \"slope\": -0.08329920470714569, \"chain\": 2, \"draw\": 130}, {\"draws\": 530, \"mouse\": 6, \"mu_intercept_per_group\": 7.684205532073975, \"sigma_intercept_per_group\": 0.2594931721687317, \"sigma_obs\": 161.00765991210938, \"slope\": -0.08329920470714569, \"chain\": 2, \"draw\": 130}, {\"draws\": 530, \"mouse\": 7, \"mu_intercept_per_group\": 7.01116943359375, \"sigma_intercept_per_group\": 0.2594931721687317, \"sigma_obs\": 161.00765991210938, \"slope\": -0.08329920470714569, \"chain\": 2, \"draw\": 130}, {\"draws\": 531, \"mouse\": 0, \"mu_intercept_per_group\": 9.651363372802734, \"sigma_intercept_per_group\": 0.2594767212867737, \"sigma_obs\": 161.34188842773438, \"slope\": -0.08342956006526947, \"chain\": 2, \"draw\": 131}, {\"draws\": 531, \"mouse\": 1, \"mu_intercept_per_group\": 9.638960838317871, \"sigma_intercept_per_group\": 0.2594767212867737, \"sigma_obs\": 161.34188842773438, \"slope\": -0.08342956006526947, \"chain\": 2, \"draw\": 131}, {\"draws\": 531, \"mouse\": 2, \"mu_intercept_per_group\": 8.566463470458984, \"sigma_intercept_per_group\": 0.2594767212867737, \"sigma_obs\": 161.34188842773438, \"slope\": -0.08342956006526947, \"chain\": 2, \"draw\": 131}, {\"draws\": 531, \"mouse\": 3, \"mu_intercept_per_group\": 8.422289848327637, \"sigma_intercept_per_group\": 0.2594767212867737, \"sigma_obs\": 161.34188842773438, \"slope\": -0.08342956006526947, \"chain\": 2, \"draw\": 131}, {\"draws\": 531, \"mouse\": 4, \"mu_intercept_per_group\": 8.45025634765625, \"sigma_intercept_per_group\": 0.2594767212867737, \"sigma_obs\": 161.34188842773438, \"slope\": -0.08342956006526947, \"chain\": 2, \"draw\": 131}, {\"draws\": 531, \"mouse\": 5, \"mu_intercept_per_group\": 7.895516872406006, \"sigma_intercept_per_group\": 0.2594767212867737, \"sigma_obs\": 161.34188842773438, \"slope\": -0.08342956006526947, \"chain\": 2, \"draw\": 131}, {\"draws\": 531, \"mouse\": 6, \"mu_intercept_per_group\": 7.3455095291137695, \"sigma_intercept_per_group\": 0.2594767212867737, \"sigma_obs\": 161.34188842773438, \"slope\": -0.08342956006526947, \"chain\": 2, \"draw\": 131}, {\"draws\": 531, \"mouse\": 7, \"mu_intercept_per_group\": 6.790279865264893, \"sigma_intercept_per_group\": 0.2594767212867737, \"sigma_obs\": 161.34188842773438, \"slope\": -0.08342956006526947, \"chain\": 2, \"draw\": 131}, {\"draws\": 532, \"mouse\": 0, \"mu_intercept_per_group\": 9.437239646911621, \"sigma_intercept_per_group\": 0.2638469636440277, \"sigma_obs\": 160.55264282226562, \"slope\": -0.08426634967327118, \"chain\": 2, \"draw\": 132}, {\"draws\": 532, \"mouse\": 1, \"mu_intercept_per_group\": 8.950389862060547, \"sigma_intercept_per_group\": 0.2638469636440277, \"sigma_obs\": 160.55264282226562, \"slope\": -0.08426634967327118, \"chain\": 2, \"draw\": 132}, {\"draws\": 532, \"mouse\": 2, \"mu_intercept_per_group\": 9.007231712341309, \"sigma_intercept_per_group\": 0.2638469636440277, \"sigma_obs\": 160.55264282226562, \"slope\": -0.08426634967327118, \"chain\": 2, \"draw\": 132}, {\"draws\": 532, \"mouse\": 3, \"mu_intercept_per_group\": 8.580358505249023, \"sigma_intercept_per_group\": 0.2638469636440277, \"sigma_obs\": 160.55264282226562, \"slope\": -0.08426634967327118, \"chain\": 2, \"draw\": 132}, {\"draws\": 532, \"mouse\": 4, \"mu_intercept_per_group\": 8.121699333190918, \"sigma_intercept_per_group\": 0.2638469636440277, \"sigma_obs\": 160.55264282226562, \"slope\": -0.08426634967327118, \"chain\": 2, \"draw\": 132}, {\"draws\": 532, \"mouse\": 5, \"mu_intercept_per_group\": 7.637857437133789, \"sigma_intercept_per_group\": 0.2638469636440277, \"sigma_obs\": 160.55264282226562, \"slope\": -0.08426634967327118, \"chain\": 2, \"draw\": 132}, {\"draws\": 532, \"mouse\": 6, \"mu_intercept_per_group\": 7.378036022186279, \"sigma_intercept_per_group\": 0.2638469636440277, \"sigma_obs\": 160.55264282226562, \"slope\": -0.08426634967327118, \"chain\": 2, \"draw\": 132}, {\"draws\": 532, \"mouse\": 7, \"mu_intercept_per_group\": 6.64542818069458, \"sigma_intercept_per_group\": 0.2638469636440277, \"sigma_obs\": 160.55264282226562, \"slope\": -0.08426634967327118, \"chain\": 2, \"draw\": 132}, {\"draws\": 533, \"mouse\": 0, \"mu_intercept_per_group\": 9.531576156616211, \"sigma_intercept_per_group\": 0.2637293338775635, \"sigma_obs\": 160.05311584472656, \"slope\": -0.0840953141450882, \"chain\": 2, \"draw\": 133}, {\"draws\": 533, \"mouse\": 1, \"mu_intercept_per_group\": 9.288568496704102, \"sigma_intercept_per_group\": 0.2637293338775635, \"sigma_obs\": 160.05311584472656, \"slope\": -0.0840953141450882, \"chain\": 2, \"draw\": 133}, {\"draws\": 533, \"mouse\": 2, \"mu_intercept_per_group\": 8.898122787475586, \"sigma_intercept_per_group\": 0.2637293338775635, \"sigma_obs\": 160.05311584472656, \"slope\": -0.0840953141450882, \"chain\": 2, \"draw\": 133}, {\"draws\": 533, \"mouse\": 3, \"mu_intercept_per_group\": 8.341806411743164, \"sigma_intercept_per_group\": 0.2637293338775635, \"sigma_obs\": 160.05311584472656, \"slope\": -0.0840953141450882, \"chain\": 2, \"draw\": 133}, {\"draws\": 533, \"mouse\": 4, \"mu_intercept_per_group\": 8.137701988220215, \"sigma_intercept_per_group\": 0.2637293338775635, \"sigma_obs\": 160.05311584472656, \"slope\": -0.0840953141450882, \"chain\": 2, \"draw\": 133}, {\"draws\": 533, \"mouse\": 5, \"mu_intercept_per_group\": 7.551268577575684, \"sigma_intercept_per_group\": 0.2637293338775635, \"sigma_obs\": 160.05311584472656, \"slope\": -0.0840953141450882, \"chain\": 2, \"draw\": 133}, {\"draws\": 533, \"mouse\": 6, \"mu_intercept_per_group\": 7.4352264404296875, \"sigma_intercept_per_group\": 0.2637293338775635, \"sigma_obs\": 160.05311584472656, \"slope\": -0.0840953141450882, \"chain\": 2, \"draw\": 133}, {\"draws\": 533, \"mouse\": 7, \"mu_intercept_per_group\": 6.72640323638916, \"sigma_intercept_per_group\": 0.2637293338775635, \"sigma_obs\": 160.05311584472656, \"slope\": -0.0840953141450882, \"chain\": 2, \"draw\": 133}, {\"draws\": 534, \"mouse\": 0, \"mu_intercept_per_group\": 9.681138038635254, \"sigma_intercept_per_group\": 0.26354485750198364, \"sigma_obs\": 160.69410705566406, \"slope\": -0.08403883874416351, \"chain\": 2, \"draw\": 134}, {\"draws\": 534, \"mouse\": 1, \"mu_intercept_per_group\": 9.015063285827637, \"sigma_intercept_per_group\": 0.26354485750198364, \"sigma_obs\": 160.69410705566406, \"slope\": -0.08403883874416351, \"chain\": 2, \"draw\": 134}, {\"draws\": 534, \"mouse\": 2, \"mu_intercept_per_group\": 8.994569778442383, \"sigma_intercept_per_group\": 0.26354485750198364, \"sigma_obs\": 160.69410705566406, \"slope\": -0.08403883874416351, \"chain\": 2, \"draw\": 134}, {\"draws\": 534, \"mouse\": 3, \"mu_intercept_per_group\": 8.520756721496582, \"sigma_intercept_per_group\": 0.26354485750198364, \"sigma_obs\": 160.69410705566406, \"slope\": -0.08403883874416351, \"chain\": 2, \"draw\": 134}, {\"draws\": 534, \"mouse\": 4, \"mu_intercept_per_group\": 8.024307250976562, \"sigma_intercept_per_group\": 0.26354485750198364, \"sigma_obs\": 160.69410705566406, \"slope\": -0.08403883874416351, \"chain\": 2, \"draw\": 134}, {\"draws\": 534, \"mouse\": 5, \"mu_intercept_per_group\": 7.809106826782227, \"sigma_intercept_per_group\": 0.26354485750198364, \"sigma_obs\": 160.69410705566406, \"slope\": -0.08403883874416351, \"chain\": 2, \"draw\": 134}, {\"draws\": 534, \"mouse\": 6, \"mu_intercept_per_group\": 7.317739486694336, \"sigma_intercept_per_group\": 0.26354485750198364, \"sigma_obs\": 160.69410705566406, \"slope\": -0.08403883874416351, \"chain\": 2, \"draw\": 134}, {\"draws\": 534, \"mouse\": 7, \"mu_intercept_per_group\": 6.5998640060424805, \"sigma_intercept_per_group\": 0.26354485750198364, \"sigma_obs\": 160.69410705566406, \"slope\": -0.08403883874416351, \"chain\": 2, \"draw\": 134}, {\"draws\": 535, \"mouse\": 0, \"mu_intercept_per_group\": 10.770536422729492, \"sigma_intercept_per_group\": 0.22071969509124756, \"sigma_obs\": 146.78785705566406, \"slope\": -0.060397252440452576, \"chain\": 2, \"draw\": 135}, {\"draws\": 535, \"mouse\": 1, \"mu_intercept_per_group\": 10.529034614562988, \"sigma_intercept_per_group\": 0.22071969509124756, \"sigma_obs\": 146.78785705566406, \"slope\": -0.060397252440452576, \"chain\": 2, \"draw\": 135}, {\"draws\": 535, \"mouse\": 2, \"mu_intercept_per_group\": 10.111337661743164, \"sigma_intercept_per_group\": 0.22071969509124756, \"sigma_obs\": 146.78785705566406, \"slope\": -0.060397252440452576, \"chain\": 2, \"draw\": 135}, {\"draws\": 535, \"mouse\": 3, \"mu_intercept_per_group\": 9.811491966247559, \"sigma_intercept_per_group\": 0.22071969509124756, \"sigma_obs\": 146.78785705566406, \"slope\": -0.060397252440452576, \"chain\": 2, \"draw\": 135}, {\"draws\": 535, \"mouse\": 4, \"mu_intercept_per_group\": 8.990636825561523, \"sigma_intercept_per_group\": 0.22071969509124756, \"sigma_obs\": 146.78785705566406, \"slope\": -0.060397252440452576, \"chain\": 2, \"draw\": 135}, {\"draws\": 535, \"mouse\": 5, \"mu_intercept_per_group\": 8.766633033752441, \"sigma_intercept_per_group\": 0.22071969509124756, \"sigma_obs\": 146.78785705566406, \"slope\": -0.060397252440452576, \"chain\": 2, \"draw\": 135}, {\"draws\": 535, \"mouse\": 6, \"mu_intercept_per_group\": 7.85699987411499, \"sigma_intercept_per_group\": 0.22071969509124756, \"sigma_obs\": 146.78785705566406, \"slope\": -0.060397252440452576, \"chain\": 2, \"draw\": 135}, {\"draws\": 535, \"mouse\": 7, \"mu_intercept_per_group\": 7.942844390869141, \"sigma_intercept_per_group\": 0.22071969509124756, \"sigma_obs\": 146.78785705566406, \"slope\": -0.060397252440452576, \"chain\": 2, \"draw\": 135}, {\"draws\": 536, \"mouse\": 0, \"mu_intercept_per_group\": 11.118635177612305, \"sigma_intercept_per_group\": 0.23419439792633057, \"sigma_obs\": 174.20147705078125, \"slope\": -0.06009142845869064, \"chain\": 2, \"draw\": 136}, {\"draws\": 536, \"mouse\": 1, \"mu_intercept_per_group\": 10.58784294128418, \"sigma_intercept_per_group\": 0.23419439792633057, \"sigma_obs\": 174.20147705078125, \"slope\": -0.06009142845869064, \"chain\": 2, \"draw\": 136}, {\"draws\": 536, \"mouse\": 2, \"mu_intercept_per_group\": 10.455123901367188, \"sigma_intercept_per_group\": 0.23419439792633057, \"sigma_obs\": 174.20147705078125, \"slope\": -0.06009142845869064, \"chain\": 2, \"draw\": 136}, {\"draws\": 536, \"mouse\": 3, \"mu_intercept_per_group\": 9.763320922851562, \"sigma_intercept_per_group\": 0.23419439792633057, \"sigma_obs\": 174.20147705078125, \"slope\": -0.06009142845869064, \"chain\": 2, \"draw\": 136}, {\"draws\": 536, \"mouse\": 4, \"mu_intercept_per_group\": 9.185779571533203, \"sigma_intercept_per_group\": 0.23419439792633057, \"sigma_obs\": 174.20147705078125, \"slope\": -0.06009142845869064, \"chain\": 2, \"draw\": 136}, {\"draws\": 536, \"mouse\": 5, \"mu_intercept_per_group\": 8.880731582641602, \"sigma_intercept_per_group\": 0.23419439792633057, \"sigma_obs\": 174.20147705078125, \"slope\": -0.06009142845869064, \"chain\": 2, \"draw\": 136}, {\"draws\": 536, \"mouse\": 6, \"mu_intercept_per_group\": 8.570928573608398, \"sigma_intercept_per_group\": 0.23419439792633057, \"sigma_obs\": 174.20147705078125, \"slope\": -0.06009142845869064, \"chain\": 2, \"draw\": 136}, {\"draws\": 536, \"mouse\": 7, \"mu_intercept_per_group\": 7.715456008911133, \"sigma_intercept_per_group\": 0.23419439792633057, \"sigma_obs\": 174.20147705078125, \"slope\": -0.06009142845869064, \"chain\": 2, \"draw\": 136}, {\"draws\": 537, \"mouse\": 0, \"mu_intercept_per_group\": 11.124883651733398, \"sigma_intercept_per_group\": 0.22859176993370056, \"sigma_obs\": 175.8541259765625, \"slope\": -0.05784047022461891, \"chain\": 2, \"draw\": 137}, {\"draws\": 537, \"mouse\": 1, \"mu_intercept_per_group\": 10.712403297424316, \"sigma_intercept_per_group\": 0.22859176993370056, \"sigma_obs\": 175.8541259765625, \"slope\": -0.05784047022461891, \"chain\": 2, \"draw\": 137}, {\"draws\": 537, \"mouse\": 2, \"mu_intercept_per_group\": 10.226579666137695, \"sigma_intercept_per_group\": 0.22859176993370056, \"sigma_obs\": 175.8541259765625, \"slope\": -0.05784047022461891, \"chain\": 2, \"draw\": 137}, {\"draws\": 537, \"mouse\": 3, \"mu_intercept_per_group\": 9.73715877532959, \"sigma_intercept_per_group\": 0.22859176993370056, \"sigma_obs\": 175.8541259765625, \"slope\": -0.05784047022461891, \"chain\": 2, \"draw\": 137}, {\"draws\": 537, \"mouse\": 4, \"mu_intercept_per_group\": 9.771166801452637, \"sigma_intercept_per_group\": 0.22859176993370056, \"sigma_obs\": 175.8541259765625, \"slope\": -0.05784047022461891, \"chain\": 2, \"draw\": 137}, {\"draws\": 537, \"mouse\": 5, \"mu_intercept_per_group\": 9.112418174743652, \"sigma_intercept_per_group\": 0.22859176993370056, \"sigma_obs\": 175.8541259765625, \"slope\": -0.05784047022461891, \"chain\": 2, \"draw\": 137}, {\"draws\": 537, \"mouse\": 6, \"mu_intercept_per_group\": 8.295903205871582, \"sigma_intercept_per_group\": 0.22859176993370056, \"sigma_obs\": 175.8541259765625, \"slope\": -0.05784047022461891, \"chain\": 2, \"draw\": 137}, {\"draws\": 537, \"mouse\": 7, \"mu_intercept_per_group\": 8.395176887512207, \"sigma_intercept_per_group\": 0.22859176993370056, \"sigma_obs\": 175.8541259765625, \"slope\": -0.05784047022461891, \"chain\": 2, \"draw\": 137}, {\"draws\": 538, \"mouse\": 0, \"mu_intercept_per_group\": 7.989838600158691, \"sigma_intercept_per_group\": 0.29215139150619507, \"sigma_obs\": 141.97720336914062, \"slope\": -0.07416070997714996, \"chain\": 2, \"draw\": 138}, {\"draws\": 538, \"mouse\": 1, \"mu_intercept_per_group\": 7.789745807647705, \"sigma_intercept_per_group\": 0.29215139150619507, \"sigma_obs\": 141.97720336914062, \"slope\": -0.07416070997714996, \"chain\": 2, \"draw\": 138}, {\"draws\": 538, \"mouse\": 2, \"mu_intercept_per_group\": 7.755358695983887, \"sigma_intercept_per_group\": 0.29215139150619507, \"sigma_obs\": 141.97720336914062, \"slope\": -0.07416070997714996, \"chain\": 2, \"draw\": 138}, {\"draws\": 538, \"mouse\": 3, \"mu_intercept_per_group\": 7.1396484375, \"sigma_intercept_per_group\": 0.29215139150619507, \"sigma_obs\": 141.97720336914062, \"slope\": -0.07416070997714996, \"chain\": 2, \"draw\": 138}, {\"draws\": 538, \"mouse\": 4, \"mu_intercept_per_group\": 6.728095054626465, \"sigma_intercept_per_group\": 0.29215139150619507, \"sigma_obs\": 141.97720336914062, \"slope\": -0.07416070997714996, \"chain\": 2, \"draw\": 138}, {\"draws\": 538, \"mouse\": 5, \"mu_intercept_per_group\": 6.404994487762451, \"sigma_intercept_per_group\": 0.29215139150619507, \"sigma_obs\": 141.97720336914062, \"slope\": -0.07416070997714996, \"chain\": 2, \"draw\": 138}, {\"draws\": 538, \"mouse\": 6, \"mu_intercept_per_group\": 6.162466049194336, \"sigma_intercept_per_group\": 0.29215139150619507, \"sigma_obs\": 141.97720336914062, \"slope\": -0.07416070997714996, \"chain\": 2, \"draw\": 138}, {\"draws\": 538, \"mouse\": 7, \"mu_intercept_per_group\": 5.482842922210693, \"sigma_intercept_per_group\": 0.29215139150619507, \"sigma_obs\": 141.97720336914062, \"slope\": -0.07416070997714996, \"chain\": 2, \"draw\": 138}, {\"draws\": 539, \"mouse\": 0, \"mu_intercept_per_group\": 8.013677597045898, \"sigma_intercept_per_group\": 0.30212873220443726, \"sigma_obs\": 144.61029052734375, \"slope\": -0.07771693170070648, \"chain\": 2, \"draw\": 139}, {\"draws\": 539, \"mouse\": 1, \"mu_intercept_per_group\": 7.601891040802002, \"sigma_intercept_per_group\": 0.30212873220443726, \"sigma_obs\": 144.61029052734375, \"slope\": -0.07771693170070648, \"chain\": 2, \"draw\": 139}, {\"draws\": 539, \"mouse\": 2, \"mu_intercept_per_group\": 7.463716506958008, \"sigma_intercept_per_group\": 0.30212873220443726, \"sigma_obs\": 144.61029052734375, \"slope\": -0.07771693170070648, \"chain\": 2, \"draw\": 139}, {\"draws\": 539, \"mouse\": 3, \"mu_intercept_per_group\": 6.901895046234131, \"sigma_intercept_per_group\": 0.30212873220443726, \"sigma_obs\": 144.61029052734375, \"slope\": -0.07771693170070648, \"chain\": 2, \"draw\": 139}, {\"draws\": 539, \"mouse\": 4, \"mu_intercept_per_group\": 6.552860260009766, \"sigma_intercept_per_group\": 0.30212873220443726, \"sigma_obs\": 144.61029052734375, \"slope\": -0.07771693170070648, \"chain\": 2, \"draw\": 139}, {\"draws\": 539, \"mouse\": 5, \"mu_intercept_per_group\": 6.238550186157227, \"sigma_intercept_per_group\": 0.30212873220443726, \"sigma_obs\": 144.61029052734375, \"slope\": -0.07771693170070648, \"chain\": 2, \"draw\": 139}, {\"draws\": 539, \"mouse\": 6, \"mu_intercept_per_group\": 6.068967342376709, \"sigma_intercept_per_group\": 0.30212873220443726, \"sigma_obs\": 144.61029052734375, \"slope\": -0.07771693170070648, \"chain\": 2, \"draw\": 139}, {\"draws\": 539, \"mouse\": 7, \"mu_intercept_per_group\": 5.529538154602051, \"sigma_intercept_per_group\": 0.30212873220443726, \"sigma_obs\": 144.61029052734375, \"slope\": -0.07771693170070648, \"chain\": 2, \"draw\": 139}, {\"draws\": 540, \"mouse\": 0, \"mu_intercept_per_group\": 7.801528453826904, \"sigma_intercept_per_group\": 0.30033814907073975, \"sigma_obs\": 144.59841918945312, \"slope\": -0.07717828452587128, \"chain\": 2, \"draw\": 140}, {\"draws\": 540, \"mouse\": 1, \"mu_intercept_per_group\": 7.725327014923096, \"sigma_intercept_per_group\": 0.30033814907073975, \"sigma_obs\": 144.59841918945312, \"slope\": -0.07717828452587128, \"chain\": 2, \"draw\": 140}, {\"draws\": 540, \"mouse\": 2, \"mu_intercept_per_group\": 7.557785987854004, \"sigma_intercept_per_group\": 0.30033814907073975, \"sigma_obs\": 144.59841918945312, \"slope\": -0.07717828452587128, \"chain\": 2, \"draw\": 140}, {\"draws\": 540, \"mouse\": 3, \"mu_intercept_per_group\": 6.995115280151367, \"sigma_intercept_per_group\": 0.30033814907073975, \"sigma_obs\": 144.59841918945312, \"slope\": -0.07717828452587128, \"chain\": 2, \"draw\": 140}, {\"draws\": 540, \"mouse\": 4, \"mu_intercept_per_group\": 6.922791957855225, \"sigma_intercept_per_group\": 0.30033814907073975, \"sigma_obs\": 144.59841918945312, \"slope\": -0.07717828452587128, \"chain\": 2, \"draw\": 140}, {\"draws\": 540, \"mouse\": 5, \"mu_intercept_per_group\": 6.31776237487793, \"sigma_intercept_per_group\": 0.30033814907073975, \"sigma_obs\": 144.59841918945312, \"slope\": -0.07717828452587128, \"chain\": 2, \"draw\": 140}, {\"draws\": 540, \"mouse\": 6, \"mu_intercept_per_group\": 6.110596179962158, \"sigma_intercept_per_group\": 0.30033814907073975, \"sigma_obs\": 144.59841918945312, \"slope\": -0.07717828452587128, \"chain\": 2, \"draw\": 140}, {\"draws\": 540, \"mouse\": 7, \"mu_intercept_per_group\": 5.503833293914795, \"sigma_intercept_per_group\": 0.30033814907073975, \"sigma_obs\": 144.59841918945312, \"slope\": -0.07717828452587128, \"chain\": 2, \"draw\": 140}, {\"draws\": 541, \"mouse\": 0, \"mu_intercept_per_group\": 7.081995964050293, \"sigma_intercept_per_group\": 0.34085971117019653, \"sigma_obs\": 145.95701599121094, \"slope\": -0.06900744885206223, \"chain\": 2, \"draw\": 141}, {\"draws\": 541, \"mouse\": 1, \"mu_intercept_per_group\": 6.602077007293701, \"sigma_intercept_per_group\": 0.34085971117019653, \"sigma_obs\": 145.95701599121094, \"slope\": -0.06900744885206223, \"chain\": 2, \"draw\": 141}, {\"draws\": 541, \"mouse\": 2, \"mu_intercept_per_group\": 6.501290321350098, \"sigma_intercept_per_group\": 0.34085971117019653, \"sigma_obs\": 145.95701599121094, \"slope\": -0.06900744885206223, \"chain\": 2, \"draw\": 141}, {\"draws\": 541, \"mouse\": 3, \"mu_intercept_per_group\": 6.142017841339111, \"sigma_intercept_per_group\": 0.34085971117019653, \"sigma_obs\": 145.95701599121094, \"slope\": -0.06900744885206223, \"chain\": 2, \"draw\": 141}, {\"draws\": 541, \"mouse\": 4, \"mu_intercept_per_group\": 5.8828277587890625, \"sigma_intercept_per_group\": 0.34085971117019653, \"sigma_obs\": 145.95701599121094, \"slope\": -0.06900744885206223, \"chain\": 2, \"draw\": 141}, {\"draws\": 541, \"mouse\": 5, \"mu_intercept_per_group\": 5.529026031494141, \"sigma_intercept_per_group\": 0.34085971117019653, \"sigma_obs\": 145.95701599121094, \"slope\": -0.06900744885206223, \"chain\": 2, \"draw\": 141}, {\"draws\": 541, \"mouse\": 6, \"mu_intercept_per_group\": 5.179385662078857, \"sigma_intercept_per_group\": 0.34085971117019653, \"sigma_obs\": 145.95701599121094, \"slope\": -0.06900744885206223, \"chain\": 2, \"draw\": 141}, {\"draws\": 541, \"mouse\": 7, \"mu_intercept_per_group\": 5.129514217376709, \"sigma_intercept_per_group\": 0.34085971117019653, \"sigma_obs\": 145.95701599121094, \"slope\": -0.06900744885206223, \"chain\": 2, \"draw\": 141}, {\"draws\": 542, \"mouse\": 0, \"mu_intercept_per_group\": 7.749299049377441, \"sigma_intercept_per_group\": 0.3285941183567047, \"sigma_obs\": 170.80335998535156, \"slope\": -0.08592492341995239, \"chain\": 2, \"draw\": 142}, {\"draws\": 542, \"mouse\": 1, \"mu_intercept_per_group\": 7.412693023681641, \"sigma_intercept_per_group\": 0.3285941183567047, \"sigma_obs\": 170.80335998535156, \"slope\": -0.08592492341995239, \"chain\": 2, \"draw\": 142}, {\"draws\": 542, \"mouse\": 2, \"mu_intercept_per_group\": 7.208711624145508, \"sigma_intercept_per_group\": 0.3285941183567047, \"sigma_obs\": 170.80335998535156, \"slope\": -0.08592492341995239, \"chain\": 2, \"draw\": 142}, {\"draws\": 542, \"mouse\": 3, \"mu_intercept_per_group\": 6.98939323425293, \"sigma_intercept_per_group\": 0.3285941183567047, \"sigma_obs\": 170.80335998535156, \"slope\": -0.08592492341995239, \"chain\": 2, \"draw\": 142}, {\"draws\": 542, \"mouse\": 4, \"mu_intercept_per_group\": 6.656508445739746, \"sigma_intercept_per_group\": 0.3285941183567047, \"sigma_obs\": 170.80335998535156, \"slope\": -0.08592492341995239, \"chain\": 2, \"draw\": 142}, {\"draws\": 542, \"mouse\": 5, \"mu_intercept_per_group\": 6.336836814880371, \"sigma_intercept_per_group\": 0.3285941183567047, \"sigma_obs\": 170.80335998535156, \"slope\": -0.08592492341995239, \"chain\": 2, \"draw\": 142}, {\"draws\": 542, \"mouse\": 6, \"mu_intercept_per_group\": 5.892187118530273, \"sigma_intercept_per_group\": 0.3285941183567047, \"sigma_obs\": 170.80335998535156, \"slope\": -0.08592492341995239, \"chain\": 2, \"draw\": 142}, {\"draws\": 542, \"mouse\": 7, \"mu_intercept_per_group\": 5.657553672790527, \"sigma_intercept_per_group\": 0.3285941183567047, \"sigma_obs\": 170.80335998535156, \"slope\": -0.08592492341995239, \"chain\": 2, \"draw\": 142}, {\"draws\": 543, \"mouse\": 0, \"mu_intercept_per_group\": 7.671998977661133, \"sigma_intercept_per_group\": 0.3324975371360779, \"sigma_obs\": 170.85940551757812, \"slope\": -0.08560220897197723, \"chain\": 2, \"draw\": 143}, {\"draws\": 543, \"mouse\": 1, \"mu_intercept_per_group\": 7.557556629180908, \"sigma_intercept_per_group\": 0.3324975371360779, \"sigma_obs\": 170.85940551757812, \"slope\": -0.08560220897197723, \"chain\": 2, \"draw\": 143}, {\"draws\": 543, \"mouse\": 2, \"mu_intercept_per_group\": 7.241136074066162, \"sigma_intercept_per_group\": 0.3324975371360779, \"sigma_obs\": 170.85940551757812, \"slope\": -0.08560220897197723, \"chain\": 2, \"draw\": 143}, {\"draws\": 543, \"mouse\": 3, \"mu_intercept_per_group\": 6.938681125640869, \"sigma_intercept_per_group\": 0.3324975371360779, \"sigma_obs\": 170.85940551757812, \"slope\": -0.08560220897197723, \"chain\": 2, \"draw\": 143}, {\"draws\": 543, \"mouse\": 4, \"mu_intercept_per_group\": 6.758420467376709, \"sigma_intercept_per_group\": 0.3324975371360779, \"sigma_obs\": 170.85940551757812, \"slope\": -0.08560220897197723, \"chain\": 2, \"draw\": 143}, {\"draws\": 543, \"mouse\": 5, \"mu_intercept_per_group\": 6.346587181091309, \"sigma_intercept_per_group\": 0.3324975371360779, \"sigma_obs\": 170.85940551757812, \"slope\": -0.08560220897197723, \"chain\": 2, \"draw\": 143}, {\"draws\": 543, \"mouse\": 6, \"mu_intercept_per_group\": 5.828512668609619, \"sigma_intercept_per_group\": 0.3324975371360779, \"sigma_obs\": 170.85940551757812, \"slope\": -0.08560220897197723, \"chain\": 2, \"draw\": 143}, {\"draws\": 543, \"mouse\": 7, \"mu_intercept_per_group\": 5.552210330963135, \"sigma_intercept_per_group\": 0.3324975371360779, \"sigma_obs\": 170.85940551757812, \"slope\": -0.08560220897197723, \"chain\": 2, \"draw\": 143}, {\"draws\": 544, \"mouse\": 0, \"mu_intercept_per_group\": 6.8516669273376465, \"sigma_intercept_per_group\": 0.3541420102119446, \"sigma_obs\": 153.4598846435547, \"slope\": -0.06992367655038834, \"chain\": 2, \"draw\": 144}, {\"draws\": 544, \"mouse\": 1, \"mu_intercept_per_group\": 6.606280326843262, \"sigma_intercept_per_group\": 0.3541420102119446, \"sigma_obs\": 153.4598846435547, \"slope\": -0.06992367655038834, \"chain\": 2, \"draw\": 144}, {\"draws\": 544, \"mouse\": 2, \"mu_intercept_per_group\": 6.408456325531006, \"sigma_intercept_per_group\": 0.3541420102119446, \"sigma_obs\": 153.4598846435547, \"slope\": -0.06992367655038834, \"chain\": 2, \"draw\": 144}, {\"draws\": 544, \"mouse\": 3, \"mu_intercept_per_group\": 5.904040813446045, \"sigma_intercept_per_group\": 0.3541420102119446, \"sigma_obs\": 153.4598846435547, \"slope\": -0.06992367655038834, \"chain\": 2, \"draw\": 144}, {\"draws\": 544, \"mouse\": 4, \"mu_intercept_per_group\": 5.921916961669922, \"sigma_intercept_per_group\": 0.3541420102119446, \"sigma_obs\": 153.4598846435547, \"slope\": -0.06992367655038834, \"chain\": 2, \"draw\": 144}, {\"draws\": 544, \"mouse\": 5, \"mu_intercept_per_group\": 5.424777507781982, \"sigma_intercept_per_group\": 0.3541420102119446, \"sigma_obs\": 153.4598846435547, \"slope\": -0.06992367655038834, \"chain\": 2, \"draw\": 144}, {\"draws\": 544, \"mouse\": 6, \"mu_intercept_per_group\": 5.23438835144043, \"sigma_intercept_per_group\": 0.3541420102119446, \"sigma_obs\": 153.4598846435547, \"slope\": -0.06992367655038834, \"chain\": 2, \"draw\": 144}, {\"draws\": 544, \"mouse\": 7, \"mu_intercept_per_group\": 5.147390365600586, \"sigma_intercept_per_group\": 0.3541420102119446, \"sigma_obs\": 153.4598846435547, \"slope\": -0.06992367655038834, \"chain\": 2, \"draw\": 144}, {\"draws\": 545, \"mouse\": 0, \"mu_intercept_per_group\": 6.871808052062988, \"sigma_intercept_per_group\": 0.35294434428215027, \"sigma_obs\": 153.3319549560547, \"slope\": -0.07016610354185104, \"chain\": 2, \"draw\": 145}, {\"draws\": 545, \"mouse\": 1, \"mu_intercept_per_group\": 6.470613956451416, \"sigma_intercept_per_group\": 0.35294434428215027, \"sigma_obs\": 153.3319549560547, \"slope\": -0.07016610354185104, \"chain\": 2, \"draw\": 145}, {\"draws\": 545, \"mouse\": 2, \"mu_intercept_per_group\": 6.474149703979492, \"sigma_intercept_per_group\": 0.35294434428215027, \"sigma_obs\": 153.3319549560547, \"slope\": -0.07016610354185104, \"chain\": 2, \"draw\": 145}, {\"draws\": 545, \"mouse\": 3, \"mu_intercept_per_group\": 6.095311164855957, \"sigma_intercept_per_group\": 0.35294434428215027, \"sigma_obs\": 153.3319549560547, \"slope\": -0.07016610354185104, \"chain\": 2, \"draw\": 145}, {\"draws\": 545, \"mouse\": 4, \"mu_intercept_per_group\": 5.914180755615234, \"sigma_intercept_per_group\": 0.35294434428215027, \"sigma_obs\": 153.3319549560547, \"slope\": -0.07016610354185104, \"chain\": 2, \"draw\": 145}, {\"draws\": 545, \"mouse\": 5, \"mu_intercept_per_group\": 5.506027698516846, \"sigma_intercept_per_group\": 0.35294434428215027, \"sigma_obs\": 153.3319549560547, \"slope\": -0.07016610354185104, \"chain\": 2, \"draw\": 145}, {\"draws\": 545, \"mouse\": 6, \"mu_intercept_per_group\": 5.14856481552124, \"sigma_intercept_per_group\": 0.35294434428215027, \"sigma_obs\": 153.3319549560547, \"slope\": -0.07016610354185104, \"chain\": 2, \"draw\": 145}, {\"draws\": 545, \"mouse\": 7, \"mu_intercept_per_group\": 4.914165019989014, \"sigma_intercept_per_group\": 0.35294434428215027, \"sigma_obs\": 153.3319549560547, \"slope\": -0.07016610354185104, \"chain\": 2, \"draw\": 145}, {\"draws\": 546, \"mouse\": 0, \"mu_intercept_per_group\": 6.400088787078857, \"sigma_intercept_per_group\": 0.3837560713291168, \"sigma_obs\": 163.64511108398438, \"slope\": -0.07030347734689713, \"chain\": 2, \"draw\": 146}, {\"draws\": 546, \"mouse\": 1, \"mu_intercept_per_group\": 6.225781440734863, \"sigma_intercept_per_group\": 0.3837560713291168, \"sigma_obs\": 163.64511108398438, \"slope\": -0.07030347734689713, \"chain\": 2, \"draw\": 146}, {\"draws\": 546, \"mouse\": 2, \"mu_intercept_per_group\": 6.109428882598877, \"sigma_intercept_per_group\": 0.3837560713291168, \"sigma_obs\": 163.64511108398438, \"slope\": -0.07030347734689713, \"chain\": 2, \"draw\": 146}, {\"draws\": 546, \"mouse\": 3, \"mu_intercept_per_group\": 5.7625555992126465, \"sigma_intercept_per_group\": 0.3837560713291168, \"sigma_obs\": 163.64511108398438, \"slope\": -0.07030347734689713, \"chain\": 2, \"draw\": 146}, {\"draws\": 546, \"mouse\": 4, \"mu_intercept_per_group\": 5.654866695404053, \"sigma_intercept_per_group\": 0.3837560713291168, \"sigma_obs\": 163.64511108398438, \"slope\": -0.07030347734689713, \"chain\": 2, \"draw\": 146}, {\"draws\": 546, \"mouse\": 5, \"mu_intercept_per_group\": 5.304009437561035, \"sigma_intercept_per_group\": 0.3837560713291168, \"sigma_obs\": 163.64511108398438, \"slope\": -0.07030347734689713, \"chain\": 2, \"draw\": 146}, {\"draws\": 546, \"mouse\": 6, \"mu_intercept_per_group\": 4.96472692489624, \"sigma_intercept_per_group\": 0.3837560713291168, \"sigma_obs\": 163.64511108398438, \"slope\": -0.07030347734689713, \"chain\": 2, \"draw\": 146}, {\"draws\": 546, \"mouse\": 7, \"mu_intercept_per_group\": 4.721471309661865, \"sigma_intercept_per_group\": 0.3837560713291168, \"sigma_obs\": 163.64511108398438, \"slope\": -0.07030347734689713, \"chain\": 2, \"draw\": 146}, {\"draws\": 547, \"mouse\": 0, \"mu_intercept_per_group\": 7.440324306488037, \"sigma_intercept_per_group\": 0.3420580327510834, \"sigma_obs\": 168.27279663085938, \"slope\": -0.07119455188512802, \"chain\": 2, \"draw\": 147}, {\"draws\": 547, \"mouse\": 1, \"mu_intercept_per_group\": 7.170825004577637, \"sigma_intercept_per_group\": 0.3420580327510834, \"sigma_obs\": 168.27279663085938, \"slope\": -0.07119455188512802, \"chain\": 2, \"draw\": 147}, {\"draws\": 547, \"mouse\": 2, \"mu_intercept_per_group\": 6.883574485778809, \"sigma_intercept_per_group\": 0.3420580327510834, \"sigma_obs\": 168.27279663085938, \"slope\": -0.07119455188512802, \"chain\": 2, \"draw\": 147}, {\"draws\": 547, \"mouse\": 3, \"mu_intercept_per_group\": 6.641986846923828, \"sigma_intercept_per_group\": 0.3420580327510834, \"sigma_obs\": 168.27279663085938, \"slope\": -0.07119455188512802, \"chain\": 2, \"draw\": 147}, {\"draws\": 547, \"mouse\": 4, \"mu_intercept_per_group\": 6.402233600616455, \"sigma_intercept_per_group\": 0.3420580327510834, \"sigma_obs\": 168.27279663085938, \"slope\": -0.07119455188512802, \"chain\": 2, \"draw\": 147}, {\"draws\": 547, \"mouse\": 5, \"mu_intercept_per_group\": 6.051608085632324, \"sigma_intercept_per_group\": 0.3420580327510834, \"sigma_obs\": 168.27279663085938, \"slope\": -0.07119455188512802, \"chain\": 2, \"draw\": 147}, {\"draws\": 547, \"mouse\": 6, \"mu_intercept_per_group\": 5.583316802978516, \"sigma_intercept_per_group\": 0.3420580327510834, \"sigma_obs\": 168.27279663085938, \"slope\": -0.07119455188512802, \"chain\": 2, \"draw\": 147}, {\"draws\": 547, \"mouse\": 7, \"mu_intercept_per_group\": 5.316442966461182, \"sigma_intercept_per_group\": 0.3420580327510834, \"sigma_obs\": 168.27279663085938, \"slope\": -0.07119455188512802, \"chain\": 2, \"draw\": 147}, {\"draws\": 548, \"mouse\": 0, \"mu_intercept_per_group\": 8.660027503967285, \"sigma_intercept_per_group\": 0.2890205681324005, \"sigma_obs\": 160.54995727539062, \"slope\": -0.08160701394081116, \"chain\": 2, \"draw\": 148}, {\"draws\": 548, \"mouse\": 1, \"mu_intercept_per_group\": 8.3992919921875, \"sigma_intercept_per_group\": 0.2890205681324005, \"sigma_obs\": 160.54995727539062, \"slope\": -0.08160701394081116, \"chain\": 2, \"draw\": 148}, {\"draws\": 548, \"mouse\": 2, \"mu_intercept_per_group\": 8.190962791442871, \"sigma_intercept_per_group\": 0.2890205681324005, \"sigma_obs\": 160.54995727539062, \"slope\": -0.08160701394081116, \"chain\": 2, \"draw\": 148}, {\"draws\": 548, \"mouse\": 3, \"mu_intercept_per_group\": 7.8090620040893555, \"sigma_intercept_per_group\": 0.2890205681324005, \"sigma_obs\": 160.54995727539062, \"slope\": -0.08160701394081116, \"chain\": 2, \"draw\": 148}, {\"draws\": 548, \"mouse\": 4, \"mu_intercept_per_group\": 7.386636734008789, \"sigma_intercept_per_group\": 0.2890205681324005, \"sigma_obs\": 160.54995727539062, \"slope\": -0.08160701394081116, \"chain\": 2, \"draw\": 148}, {\"draws\": 548, \"mouse\": 5, \"mu_intercept_per_group\": 7.145017147064209, \"sigma_intercept_per_group\": 0.2890205681324005, \"sigma_obs\": 160.54995727539062, \"slope\": -0.08160701394081116, \"chain\": 2, \"draw\": 148}, {\"draws\": 548, \"mouse\": 6, \"mu_intercept_per_group\": 6.55708646774292, \"sigma_intercept_per_group\": 0.2890205681324005, \"sigma_obs\": 160.54995727539062, \"slope\": -0.08160701394081116, \"chain\": 2, \"draw\": 148}, {\"draws\": 548, \"mouse\": 7, \"mu_intercept_per_group\": 6.226450443267822, \"sigma_intercept_per_group\": 0.2890205681324005, \"sigma_obs\": 160.54995727539062, \"slope\": -0.08160701394081116, \"chain\": 2, \"draw\": 148}, {\"draws\": 549, \"mouse\": 0, \"mu_intercept_per_group\": 8.540653228759766, \"sigma_intercept_per_group\": 0.2871871292591095, \"sigma_obs\": 159.3883819580078, \"slope\": -0.08154712617397308, \"chain\": 2, \"draw\": 149}, {\"draws\": 549, \"mouse\": 1, \"mu_intercept_per_group\": 8.288860321044922, \"sigma_intercept_per_group\": 0.2871871292591095, \"sigma_obs\": 159.3883819580078, \"slope\": -0.08154712617397308, \"chain\": 2, \"draw\": 149}, {\"draws\": 549, \"mouse\": 2, \"mu_intercept_per_group\": 8.016800880432129, \"sigma_intercept_per_group\": 0.2871871292591095, \"sigma_obs\": 159.3883819580078, \"slope\": -0.08154712617397308, \"chain\": 2, \"draw\": 149}, {\"draws\": 549, \"mouse\": 3, \"mu_intercept_per_group\": 7.495214939117432, \"sigma_intercept_per_group\": 0.2871871292591095, \"sigma_obs\": 159.3883819580078, \"slope\": -0.08154712617397308, \"chain\": 2, \"draw\": 149}, {\"draws\": 549, \"mouse\": 4, \"mu_intercept_per_group\": 7.503411769866943, \"sigma_intercept_per_group\": 0.2871871292591095, \"sigma_obs\": 159.3883819580078, \"slope\": -0.08154712617397308, \"chain\": 2, \"draw\": 149}, {\"draws\": 549, \"mouse\": 5, \"mu_intercept_per_group\": 6.850438117980957, \"sigma_intercept_per_group\": 0.2871871292591095, \"sigma_obs\": 159.3883819580078, \"slope\": -0.08154712617397308, \"chain\": 2, \"draw\": 149}, {\"draws\": 549, \"mouse\": 6, \"mu_intercept_per_group\": 6.602152347564697, \"sigma_intercept_per_group\": 0.2871871292591095, \"sigma_obs\": 159.3883819580078, \"slope\": -0.08154712617397308, \"chain\": 2, \"draw\": 149}, {\"draws\": 549, \"mouse\": 7, \"mu_intercept_per_group\": 6.152937412261963, \"sigma_intercept_per_group\": 0.2871871292591095, \"sigma_obs\": 159.3883819580078, \"slope\": -0.08154712617397308, \"chain\": 2, \"draw\": 149}, {\"draws\": 550, \"mouse\": 0, \"mu_intercept_per_group\": 8.345149993896484, \"sigma_intercept_per_group\": 0.29913458228111267, \"sigma_obs\": 157.651611328125, \"slope\": -0.0682559683918953, \"chain\": 2, \"draw\": 150}, {\"draws\": 550, \"mouse\": 1, \"mu_intercept_per_group\": 8.149123191833496, \"sigma_intercept_per_group\": 0.29913458228111267, \"sigma_obs\": 157.651611328125, \"slope\": -0.0682559683918953, \"chain\": 2, \"draw\": 150}, {\"draws\": 550, \"mouse\": 2, \"mu_intercept_per_group\": 7.8802666664123535, \"sigma_intercept_per_group\": 0.29913458228111267, \"sigma_obs\": 157.651611328125, \"slope\": -0.0682559683918953, \"chain\": 2, \"draw\": 150}, {\"draws\": 550, \"mouse\": 3, \"mu_intercept_per_group\": 7.524995803833008, \"sigma_intercept_per_group\": 0.29913458228111267, \"sigma_obs\": 157.651611328125, \"slope\": -0.0682559683918953, \"chain\": 2, \"draw\": 150}, {\"draws\": 550, \"mouse\": 4, \"mu_intercept_per_group\": 7.133269786834717, \"sigma_intercept_per_group\": 0.29913458228111267, \"sigma_obs\": 157.651611328125, \"slope\": -0.0682559683918953, \"chain\": 2, \"draw\": 150}, {\"draws\": 550, \"mouse\": 5, \"mu_intercept_per_group\": 6.599802494049072, \"sigma_intercept_per_group\": 0.29913458228111267, \"sigma_obs\": 157.651611328125, \"slope\": -0.0682559683918953, \"chain\": 2, \"draw\": 150}, {\"draws\": 550, \"mouse\": 6, \"mu_intercept_per_group\": 5.994185447692871, \"sigma_intercept_per_group\": 0.29913458228111267, \"sigma_obs\": 157.651611328125, \"slope\": -0.0682559683918953, \"chain\": 2, \"draw\": 150}, {\"draws\": 550, \"mouse\": 7, \"mu_intercept_per_group\": 5.7724080085754395, \"sigma_intercept_per_group\": 0.29913458228111267, \"sigma_obs\": 157.651611328125, \"slope\": -0.0682559683918953, \"chain\": 2, \"draw\": 150}, {\"draws\": 551, \"mouse\": 0, \"mu_intercept_per_group\": 8.3439359664917, \"sigma_intercept_per_group\": 0.29283276200294495, \"sigma_obs\": 157.7741241455078, \"slope\": -0.06851209700107574, \"chain\": 2, \"draw\": 151}, {\"draws\": 551, \"mouse\": 1, \"mu_intercept_per_group\": 8.014854431152344, \"sigma_intercept_per_group\": 0.29283276200294495, \"sigma_obs\": 157.7741241455078, \"slope\": -0.06851209700107574, \"chain\": 2, \"draw\": 151}, {\"draws\": 551, \"mouse\": 2, \"mu_intercept_per_group\": 7.784595489501953, \"sigma_intercept_per_group\": 0.29283276200294495, \"sigma_obs\": 157.7741241455078, \"slope\": -0.06851209700107574, \"chain\": 2, \"draw\": 151}, {\"draws\": 551, \"mouse\": 3, \"mu_intercept_per_group\": 7.443622589111328, \"sigma_intercept_per_group\": 0.29283276200294495, \"sigma_obs\": 157.7741241455078, \"slope\": -0.06851209700107574, \"chain\": 2, \"draw\": 151}, {\"draws\": 551, \"mouse\": 4, \"mu_intercept_per_group\": 7.195638179779053, \"sigma_intercept_per_group\": 0.29283276200294495, \"sigma_obs\": 157.7741241455078, \"slope\": -0.06851209700107574, \"chain\": 2, \"draw\": 151}, {\"draws\": 551, \"mouse\": 5, \"mu_intercept_per_group\": 6.630795478820801, \"sigma_intercept_per_group\": 0.29283276200294495, \"sigma_obs\": 157.7741241455078, \"slope\": -0.06851209700107574, \"chain\": 2, \"draw\": 151}, {\"draws\": 551, \"mouse\": 6, \"mu_intercept_per_group\": 6.010925769805908, \"sigma_intercept_per_group\": 0.29283276200294495, \"sigma_obs\": 157.7741241455078, \"slope\": -0.06851209700107574, \"chain\": 2, \"draw\": 151}, {\"draws\": 551, \"mouse\": 7, \"mu_intercept_per_group\": 5.801950931549072, \"sigma_intercept_per_group\": 0.29283276200294495, \"sigma_obs\": 157.7741241455078, \"slope\": -0.06851209700107574, \"chain\": 2, \"draw\": 151}, {\"draws\": 552, \"mouse\": 0, \"mu_intercept_per_group\": 8.26267147064209, \"sigma_intercept_per_group\": 0.29366639256477356, \"sigma_obs\": 157.24282836914062, \"slope\": -0.06941746175289154, \"chain\": 2, \"draw\": 152}, {\"draws\": 552, \"mouse\": 1, \"mu_intercept_per_group\": 7.846130847930908, \"sigma_intercept_per_group\": 0.29366639256477356, \"sigma_obs\": 157.24282836914062, \"slope\": -0.06941746175289154, \"chain\": 2, \"draw\": 152}, {\"draws\": 552, \"mouse\": 2, \"mu_intercept_per_group\": 7.696950912475586, \"sigma_intercept_per_group\": 0.29366639256477356, \"sigma_obs\": 157.24282836914062, \"slope\": -0.06941746175289154, \"chain\": 2, \"draw\": 152}, {\"draws\": 552, \"mouse\": 3, \"mu_intercept_per_group\": 7.3756489753723145, \"sigma_intercept_per_group\": 0.29366639256477356, \"sigma_obs\": 157.24282836914062, \"slope\": -0.06941746175289154, \"chain\": 2, \"draw\": 152}, {\"draws\": 552, \"mouse\": 4, \"mu_intercept_per_group\": 6.889017581939697, \"sigma_intercept_per_group\": 0.29366639256477356, \"sigma_obs\": 157.24282836914062, \"slope\": -0.06941746175289154, \"chain\": 2, \"draw\": 152}, {\"draws\": 552, \"mouse\": 5, \"mu_intercept_per_group\": 6.833956241607666, \"sigma_intercept_per_group\": 0.29366639256477356, \"sigma_obs\": 157.24282836914062, \"slope\": -0.06941746175289154, \"chain\": 2, \"draw\": 152}, {\"draws\": 552, \"mouse\": 6, \"mu_intercept_per_group\": 6.174288749694824, \"sigma_intercept_per_group\": 0.29366639256477356, \"sigma_obs\": 157.24282836914062, \"slope\": -0.06941746175289154, \"chain\": 2, \"draw\": 152}, {\"draws\": 552, \"mouse\": 7, \"mu_intercept_per_group\": 5.9870758056640625, \"sigma_intercept_per_group\": 0.29366639256477356, \"sigma_obs\": 157.24282836914062, \"slope\": -0.06941746175289154, \"chain\": 2, \"draw\": 152}, {\"draws\": 553, \"mouse\": 0, \"mu_intercept_per_group\": 8.138147354125977, \"sigma_intercept_per_group\": 0.3040497899055481, \"sigma_obs\": 156.56460571289062, \"slope\": -0.06952698528766632, \"chain\": 2, \"draw\": 153}, {\"draws\": 553, \"mouse\": 1, \"mu_intercept_per_group\": 7.857224941253662, \"sigma_intercept_per_group\": 0.3040497899055481, \"sigma_obs\": 156.56460571289062, \"slope\": -0.06952698528766632, \"chain\": 2, \"draw\": 153}, {\"draws\": 553, \"mouse\": 2, \"mu_intercept_per_group\": 7.591573715209961, \"sigma_intercept_per_group\": 0.3040497899055481, \"sigma_obs\": 156.56460571289062, \"slope\": -0.06952698528766632, \"chain\": 2, \"draw\": 153}, {\"draws\": 553, \"mouse\": 3, \"mu_intercept_per_group\": 7.466479778289795, \"sigma_intercept_per_group\": 0.3040497899055481, \"sigma_obs\": 156.56460571289062, \"slope\": -0.06952698528766632, \"chain\": 2, \"draw\": 153}, {\"draws\": 553, \"mouse\": 4, \"mu_intercept_per_group\": 6.9774041175842285, \"sigma_intercept_per_group\": 0.3040497899055481, \"sigma_obs\": 156.56460571289062, \"slope\": -0.06952698528766632, \"chain\": 2, \"draw\": 153}, {\"draws\": 553, \"mouse\": 5, \"mu_intercept_per_group\": 6.85697078704834, \"sigma_intercept_per_group\": 0.3040497899055481, \"sigma_obs\": 156.56460571289062, \"slope\": -0.06952698528766632, \"chain\": 2, \"draw\": 153}, {\"draws\": 553, \"mouse\": 6, \"mu_intercept_per_group\": 6.117758750915527, \"sigma_intercept_per_group\": 0.3040497899055481, \"sigma_obs\": 156.56460571289062, \"slope\": -0.06952698528766632, \"chain\": 2, \"draw\": 153}, {\"draws\": 553, \"mouse\": 7, \"mu_intercept_per_group\": 5.9294610023498535, \"sigma_intercept_per_group\": 0.3040497899055481, \"sigma_obs\": 156.56460571289062, \"slope\": -0.06952698528766632, \"chain\": 2, \"draw\": 153}, {\"draws\": 554, \"mouse\": 0, \"mu_intercept_per_group\": 8.19081974029541, \"sigma_intercept_per_group\": 0.30015450716018677, \"sigma_obs\": 157.8028564453125, \"slope\": -0.07117126137018204, \"chain\": 2, \"draw\": 154}, {\"draws\": 554, \"mouse\": 1, \"mu_intercept_per_group\": 7.860466480255127, \"sigma_intercept_per_group\": 0.30015450716018677, \"sigma_obs\": 157.8028564453125, \"slope\": -0.07117126137018204, \"chain\": 2, \"draw\": 154}, {\"draws\": 554, \"mouse\": 2, \"mu_intercept_per_group\": 7.665132522583008, \"sigma_intercept_per_group\": 0.30015450716018677, \"sigma_obs\": 157.8028564453125, \"slope\": -0.07117126137018204, \"chain\": 2, \"draw\": 154}, {\"draws\": 554, \"mouse\": 3, \"mu_intercept_per_group\": 6.903379440307617, \"sigma_intercept_per_group\": 0.30015450716018677, \"sigma_obs\": 157.8028564453125, \"slope\": -0.07117126137018204, \"chain\": 2, \"draw\": 154}, {\"draws\": 554, \"mouse\": 4, \"mu_intercept_per_group\": 7.029730319976807, \"sigma_intercept_per_group\": 0.30015450716018677, \"sigma_obs\": 157.8028564453125, \"slope\": -0.07117126137018204, \"chain\": 2, \"draw\": 154}, {\"draws\": 554, \"mouse\": 5, \"mu_intercept_per_group\": 6.452118396759033, \"sigma_intercept_per_group\": 0.30015450716018677, \"sigma_obs\": 157.8028564453125, \"slope\": -0.07117126137018204, \"chain\": 2, \"draw\": 154}, {\"draws\": 554, \"mouse\": 6, \"mu_intercept_per_group\": 6.098598957061768, \"sigma_intercept_per_group\": 0.30015450716018677, \"sigma_obs\": 157.8028564453125, \"slope\": -0.07117126137018204, \"chain\": 2, \"draw\": 154}, {\"draws\": 554, \"mouse\": 7, \"mu_intercept_per_group\": 5.938792705535889, \"sigma_intercept_per_group\": 0.30015450716018677, \"sigma_obs\": 157.8028564453125, \"slope\": -0.07117126137018204, \"chain\": 2, \"draw\": 154}, {\"draws\": 555, \"mouse\": 0, \"mu_intercept_per_group\": 8.766149520874023, \"sigma_intercept_per_group\": 0.29021379351615906, \"sigma_obs\": 163.70895385742188, \"slope\": -0.07268530875444412, \"chain\": 2, \"draw\": 155}, {\"draws\": 555, \"mouse\": 1, \"mu_intercept_per_group\": 8.42089557647705, \"sigma_intercept_per_group\": 0.29021379351615906, \"sigma_obs\": 163.70895385742188, \"slope\": -0.07268530875444412, \"chain\": 2, \"draw\": 155}, {\"draws\": 555, \"mouse\": 2, \"mu_intercept_per_group\": 7.985942363739014, \"sigma_intercept_per_group\": 0.29021379351615906, \"sigma_obs\": 163.70895385742188, \"slope\": -0.07268530875444412, \"chain\": 2, \"draw\": 155}, {\"draws\": 555, \"mouse\": 3, \"mu_intercept_per_group\": 7.942709922790527, \"sigma_intercept_per_group\": 0.29021379351615906, \"sigma_obs\": 163.70895385742188, \"slope\": -0.07268530875444412, \"chain\": 2, \"draw\": 155}, {\"draws\": 555, \"mouse\": 4, \"mu_intercept_per_group\": 7.4336042404174805, \"sigma_intercept_per_group\": 0.29021379351615906, \"sigma_obs\": 163.70895385742188, \"slope\": -0.07268530875444412, \"chain\": 2, \"draw\": 155}, {\"draws\": 555, \"mouse\": 5, \"mu_intercept_per_group\": 7.053036689758301, \"sigma_intercept_per_group\": 0.29021379351615906, \"sigma_obs\": 163.70895385742188, \"slope\": -0.07268530875444412, \"chain\": 2, \"draw\": 155}, {\"draws\": 555, \"mouse\": 6, \"mu_intercept_per_group\": 6.584199905395508, \"sigma_intercept_per_group\": 0.29021379351615906, \"sigma_obs\": 163.70895385742188, \"slope\": -0.07268530875444412, \"chain\": 2, \"draw\": 155}, {\"draws\": 555, \"mouse\": 7, \"mu_intercept_per_group\": 6.242686748504639, \"sigma_intercept_per_group\": 0.29021379351615906, \"sigma_obs\": 163.70895385742188, \"slope\": -0.07268530875444412, \"chain\": 2, \"draw\": 155}, {\"draws\": 556, \"mouse\": 0, \"mu_intercept_per_group\": 8.563368797302246, \"sigma_intercept_per_group\": 0.2863229215145111, \"sigma_obs\": 164.3339385986328, \"slope\": -0.07248442620038986, \"chain\": 2, \"draw\": 156}, {\"draws\": 556, \"mouse\": 1, \"mu_intercept_per_group\": 8.233333587646484, \"sigma_intercept_per_group\": 0.2863229215145111, \"sigma_obs\": 164.3339385986328, \"slope\": -0.07248442620038986, \"chain\": 2, \"draw\": 156}, {\"draws\": 556, \"mouse\": 2, \"mu_intercept_per_group\": 8.27988052368164, \"sigma_intercept_per_group\": 0.2863229215145111, \"sigma_obs\": 164.3339385986328, \"slope\": -0.07248442620038986, \"chain\": 2, \"draw\": 156}, {\"draws\": 556, \"mouse\": 3, \"mu_intercept_per_group\": 7.720411777496338, \"sigma_intercept_per_group\": 0.2863229215145111, \"sigma_obs\": 164.3339385986328, \"slope\": -0.07248442620038986, \"chain\": 2, \"draw\": 156}, {\"draws\": 556, \"mouse\": 4, \"mu_intercept_per_group\": 7.411981105804443, \"sigma_intercept_per_group\": 0.2863229215145111, \"sigma_obs\": 164.3339385986328, \"slope\": -0.07248442620038986, \"chain\": 2, \"draw\": 156}, {\"draws\": 556, \"mouse\": 5, \"mu_intercept_per_group\": 7.093107223510742, \"sigma_intercept_per_group\": 0.2863229215145111, \"sigma_obs\": 164.3339385986328, \"slope\": -0.07248442620038986, \"chain\": 2, \"draw\": 156}, {\"draws\": 556, \"mouse\": 6, \"mu_intercept_per_group\": 6.3813252449035645, \"sigma_intercept_per_group\": 0.2863229215145111, \"sigma_obs\": 164.3339385986328, \"slope\": -0.07248442620038986, \"chain\": 2, \"draw\": 156}, {\"draws\": 556, \"mouse\": 7, \"mu_intercept_per_group\": 6.2278733253479, \"sigma_intercept_per_group\": 0.2863229215145111, \"sigma_obs\": 164.3339385986328, \"slope\": -0.07248442620038986, \"chain\": 2, \"draw\": 156}, {\"draws\": 557, \"mouse\": 0, \"mu_intercept_per_group\": 8.91522216796875, \"sigma_intercept_per_group\": 0.28184401988983154, \"sigma_obs\": 163.84999084472656, \"slope\": -0.05950714275240898, \"chain\": 2, \"draw\": 157}, {\"draws\": 557, \"mouse\": 1, \"mu_intercept_per_group\": 8.274425506591797, \"sigma_intercept_per_group\": 0.28184401988983154, \"sigma_obs\": 163.84999084472656, \"slope\": -0.05950714275240898, \"chain\": 2, \"draw\": 157}, {\"draws\": 557, \"mouse\": 2, \"mu_intercept_per_group\": 8.319779396057129, \"sigma_intercept_per_group\": 0.28184401988983154, \"sigma_obs\": 163.84999084472656, \"slope\": -0.05950714275240898, \"chain\": 2, \"draw\": 157}, {\"draws\": 557, \"mouse\": 3, \"mu_intercept_per_group\": 7.811826229095459, \"sigma_intercept_per_group\": 0.28184401988983154, \"sigma_obs\": 163.84999084472656, \"slope\": -0.05950714275240898, \"chain\": 2, \"draw\": 157}, {\"draws\": 557, \"mouse\": 4, \"mu_intercept_per_group\": 7.605807304382324, \"sigma_intercept_per_group\": 0.28184401988983154, \"sigma_obs\": 163.84999084472656, \"slope\": -0.05950714275240898, \"chain\": 2, \"draw\": 157}, {\"draws\": 557, \"mouse\": 5, \"mu_intercept_per_group\": 7.155366897583008, \"sigma_intercept_per_group\": 0.28184401988983154, \"sigma_obs\": 163.84999084472656, \"slope\": -0.05950714275240898, \"chain\": 2, \"draw\": 157}, {\"draws\": 557, \"mouse\": 6, \"mu_intercept_per_group\": 7.050790786743164, \"sigma_intercept_per_group\": 0.28184401988983154, \"sigma_obs\": 163.84999084472656, \"slope\": -0.05950714275240898, \"chain\": 2, \"draw\": 157}, {\"draws\": 557, \"mouse\": 7, \"mu_intercept_per_group\": 6.374396800994873, \"sigma_intercept_per_group\": 0.28184401988983154, \"sigma_obs\": 163.84999084472656, \"slope\": -0.05950714275240898, \"chain\": 2, \"draw\": 157}, {\"draws\": 558, \"mouse\": 0, \"mu_intercept_per_group\": 9.19686508178711, \"sigma_intercept_per_group\": 0.27632054686546326, \"sigma_obs\": 174.86767578125, \"slope\": -0.0596967376768589, \"chain\": 2, \"draw\": 158}, {\"draws\": 558, \"mouse\": 1, \"mu_intercept_per_group\": 8.615890502929688, \"sigma_intercept_per_group\": 0.27632054686546326, \"sigma_obs\": 174.86767578125, \"slope\": -0.0596967376768589, \"chain\": 2, \"draw\": 158}, {\"draws\": 558, \"mouse\": 2, \"mu_intercept_per_group\": 8.621512413024902, \"sigma_intercept_per_group\": 0.27632054686546326, \"sigma_obs\": 174.86767578125, \"slope\": -0.0596967376768589, \"chain\": 2, \"draw\": 158}, {\"draws\": 558, \"mouse\": 3, \"mu_intercept_per_group\": 8.223742485046387, \"sigma_intercept_per_group\": 0.27632054686546326, \"sigma_obs\": 174.86767578125, \"slope\": -0.0596967376768589, \"chain\": 2, \"draw\": 158}, {\"draws\": 558, \"mouse\": 4, \"mu_intercept_per_group\": 7.843918800354004, \"sigma_intercept_per_group\": 0.27632054686546326, \"sigma_obs\": 174.86767578125, \"slope\": -0.0596967376768589, \"chain\": 2, \"draw\": 158}, {\"draws\": 558, \"mouse\": 5, \"mu_intercept_per_group\": 7.458873748779297, \"sigma_intercept_per_group\": 0.27632054686546326, \"sigma_obs\": 174.86767578125, \"slope\": -0.0596967376768589, \"chain\": 2, \"draw\": 158}, {\"draws\": 558, \"mouse\": 6, \"mu_intercept_per_group\": 6.979064464569092, \"sigma_intercept_per_group\": 0.27632054686546326, \"sigma_obs\": 174.86767578125, \"slope\": -0.0596967376768589, \"chain\": 2, \"draw\": 158}, {\"draws\": 558, \"mouse\": 7, \"mu_intercept_per_group\": 6.596828460693359, \"sigma_intercept_per_group\": 0.27632054686546326, \"sigma_obs\": 174.86767578125, \"slope\": -0.0596967376768589, \"chain\": 2, \"draw\": 158}, {\"draws\": 559, \"mouse\": 0, \"mu_intercept_per_group\": 9.267354965209961, \"sigma_intercept_per_group\": 0.274247407913208, \"sigma_obs\": 174.96859741210938, \"slope\": -0.0602821409702301, \"chain\": 2, \"draw\": 159}, {\"draws\": 559, \"mouse\": 1, \"mu_intercept_per_group\": 8.71514892578125, \"sigma_intercept_per_group\": 0.274247407913208, \"sigma_obs\": 174.96859741210938, \"slope\": -0.0602821409702301, \"chain\": 2, \"draw\": 159}, {\"draws\": 559, \"mouse\": 2, \"mu_intercept_per_group\": 8.56675910949707, \"sigma_intercept_per_group\": 0.274247407913208, \"sigma_obs\": 174.96859741210938, \"slope\": -0.0602821409702301, \"chain\": 2, \"draw\": 159}, {\"draws\": 559, \"mouse\": 3, \"mu_intercept_per_group\": 8.181925773620605, \"sigma_intercept_per_group\": 0.274247407913208, \"sigma_obs\": 174.96859741210938, \"slope\": -0.0602821409702301, \"chain\": 2, \"draw\": 159}, {\"draws\": 559, \"mouse\": 4, \"mu_intercept_per_group\": 8.029313087463379, \"sigma_intercept_per_group\": 0.274247407913208, \"sigma_obs\": 174.96859741210938, \"slope\": -0.0602821409702301, \"chain\": 2, \"draw\": 159}, {\"draws\": 559, \"mouse\": 5, \"mu_intercept_per_group\": 7.401187419891357, \"sigma_intercept_per_group\": 0.274247407913208, \"sigma_obs\": 174.96859741210938, \"slope\": -0.0602821409702301, \"chain\": 2, \"draw\": 159}, {\"draws\": 559, \"mouse\": 6, \"mu_intercept_per_group\": 7.149602890014648, \"sigma_intercept_per_group\": 0.274247407913208, \"sigma_obs\": 174.96859741210938, \"slope\": -0.0602821409702301, \"chain\": 2, \"draw\": 159}, {\"draws\": 559, \"mouse\": 7, \"mu_intercept_per_group\": 6.639034748077393, \"sigma_intercept_per_group\": 0.274247407913208, \"sigma_obs\": 174.96859741210938, \"slope\": -0.0602821409702301, \"chain\": 2, \"draw\": 159}, {\"draws\": 560, \"mouse\": 0, \"mu_intercept_per_group\": 6.726199626922607, \"sigma_intercept_per_group\": 0.362781286239624, \"sigma_obs\": 154.7971649169922, \"slope\": -0.06538812071084976, \"chain\": 2, \"draw\": 160}, {\"draws\": 560, \"mouse\": 1, \"mu_intercept_per_group\": 6.5890398025512695, \"sigma_intercept_per_group\": 0.362781286239624, \"sigma_obs\": 154.7971649169922, \"slope\": -0.06538812071084976, \"chain\": 2, \"draw\": 160}, {\"draws\": 560, \"mouse\": 2, \"mu_intercept_per_group\": 6.535090923309326, \"sigma_intercept_per_group\": 0.362781286239624, \"sigma_obs\": 154.7971649169922, \"slope\": -0.06538812071084976, \"chain\": 2, \"draw\": 160}, {\"draws\": 560, \"mouse\": 3, \"mu_intercept_per_group\": 5.874632835388184, \"sigma_intercept_per_group\": 0.362781286239624, \"sigma_obs\": 154.7971649169922, \"slope\": -0.06538812071084976, \"chain\": 2, \"draw\": 160}, {\"draws\": 560, \"mouse\": 4, \"mu_intercept_per_group\": 5.727394104003906, \"sigma_intercept_per_group\": 0.362781286239624, \"sigma_obs\": 154.7971649169922, \"slope\": -0.06538812071084976, \"chain\": 2, \"draw\": 160}, {\"draws\": 560, \"mouse\": 5, \"mu_intercept_per_group\": 5.536964416503906, \"sigma_intercept_per_group\": 0.362781286239624, \"sigma_obs\": 154.7971649169922, \"slope\": -0.06538812071084976, \"chain\": 2, \"draw\": 160}, {\"draws\": 560, \"mouse\": 6, \"mu_intercept_per_group\": 5.074676513671875, \"sigma_intercept_per_group\": 0.362781286239624, \"sigma_obs\": 154.7971649169922, \"slope\": -0.06538812071084976, \"chain\": 2, \"draw\": 160}, {\"draws\": 560, \"mouse\": 7, \"mu_intercept_per_group\": 4.773346900939941, \"sigma_intercept_per_group\": 0.362781286239624, \"sigma_obs\": 154.7971649169922, \"slope\": -0.06538812071084976, \"chain\": 2, \"draw\": 160}, {\"draws\": 561, \"mouse\": 0, \"mu_intercept_per_group\": 7.078060626983643, \"sigma_intercept_per_group\": 0.35407331585884094, \"sigma_obs\": 158.60482788085938, \"slope\": -0.061614733189344406, \"chain\": 2, \"draw\": 161}, {\"draws\": 561, \"mouse\": 1, \"mu_intercept_per_group\": 6.70522928237915, \"sigma_intercept_per_group\": 0.35407331585884094, \"sigma_obs\": 158.60482788085938, \"slope\": -0.061614733189344406, \"chain\": 2, \"draw\": 161}, {\"draws\": 561, \"mouse\": 2, \"mu_intercept_per_group\": 6.474183082580566, \"sigma_intercept_per_group\": 0.35407331585884094, \"sigma_obs\": 158.60482788085938, \"slope\": -0.061614733189344406, \"chain\": 2, \"draw\": 161}, {\"draws\": 561, \"mouse\": 3, \"mu_intercept_per_group\": 6.183234691619873, \"sigma_intercept_per_group\": 0.35407331585884094, \"sigma_obs\": 158.60482788085938, \"slope\": -0.061614733189344406, \"chain\": 2, \"draw\": 161}, {\"draws\": 561, \"mouse\": 4, \"mu_intercept_per_group\": 5.999497413635254, \"sigma_intercept_per_group\": 0.35407331585884094, \"sigma_obs\": 158.60482788085938, \"slope\": -0.061614733189344406, \"chain\": 2, \"draw\": 161}, {\"draws\": 561, \"mouse\": 5, \"mu_intercept_per_group\": 5.788612365722656, \"sigma_intercept_per_group\": 0.35407331585884094, \"sigma_obs\": 158.60482788085938, \"slope\": -0.061614733189344406, \"chain\": 2, \"draw\": 161}, {\"draws\": 561, \"mouse\": 6, \"mu_intercept_per_group\": 5.293768882751465, \"sigma_intercept_per_group\": 0.35407331585884094, \"sigma_obs\": 158.60482788085938, \"slope\": -0.061614733189344406, \"chain\": 2, \"draw\": 161}, {\"draws\": 561, \"mouse\": 7, \"mu_intercept_per_group\": 4.9165544509887695, \"sigma_intercept_per_group\": 0.35407331585884094, \"sigma_obs\": 158.60482788085938, \"slope\": -0.061614733189344406, \"chain\": 2, \"draw\": 161}, {\"draws\": 562, \"mouse\": 0, \"mu_intercept_per_group\": 6.993017196655273, \"sigma_intercept_per_group\": 0.3460220396518707, \"sigma_obs\": 159.4108123779297, \"slope\": -0.06139012798666954, \"chain\": 2, \"draw\": 162}, {\"draws\": 562, \"mouse\": 1, \"mu_intercept_per_group\": 6.797743320465088, \"sigma_intercept_per_group\": 0.3460220396518707, \"sigma_obs\": 159.4108123779297, \"slope\": -0.06139012798666954, \"chain\": 2, \"draw\": 162}, {\"draws\": 562, \"mouse\": 2, \"mu_intercept_per_group\": 6.733783721923828, \"sigma_intercept_per_group\": 0.3460220396518707, \"sigma_obs\": 159.4108123779297, \"slope\": -0.06139012798666954, \"chain\": 2, \"draw\": 162}, {\"draws\": 562, \"mouse\": 3, \"mu_intercept_per_group\": 6.259893417358398, \"sigma_intercept_per_group\": 0.3460220396518707, \"sigma_obs\": 159.4108123779297, \"slope\": -0.06139012798666954, \"chain\": 2, \"draw\": 162}, {\"draws\": 562, \"mouse\": 4, \"mu_intercept_per_group\": 6.070424556732178, \"sigma_intercept_per_group\": 0.3460220396518707, \"sigma_obs\": 159.4108123779297, \"slope\": -0.06139012798666954, \"chain\": 2, \"draw\": 162}, {\"draws\": 562, \"mouse\": 5, \"mu_intercept_per_group\": 5.652715682983398, \"sigma_intercept_per_group\": 0.3460220396518707, \"sigma_obs\": 159.4108123779297, \"slope\": -0.06139012798666954, \"chain\": 2, \"draw\": 162}, {\"draws\": 562, \"mouse\": 6, \"mu_intercept_per_group\": 5.267130374908447, \"sigma_intercept_per_group\": 0.3460220396518707, \"sigma_obs\": 159.4108123779297, \"slope\": -0.06139012798666954, \"chain\": 2, \"draw\": 162}, {\"draws\": 562, \"mouse\": 7, \"mu_intercept_per_group\": 5.257352352142334, \"sigma_intercept_per_group\": 0.3460220396518707, \"sigma_obs\": 159.4108123779297, \"slope\": -0.06139012798666954, \"chain\": 2, \"draw\": 162}, {\"draws\": 563, \"mouse\": 0, \"mu_intercept_per_group\": 7.2110161781311035, \"sigma_intercept_per_group\": 0.3410559892654419, \"sigma_obs\": 159.77943420410156, \"slope\": -0.06126740202307701, \"chain\": 2, \"draw\": 163}, {\"draws\": 563, \"mouse\": 1, \"mu_intercept_per_group\": 6.862260818481445, \"sigma_intercept_per_group\": 0.3410559892654419, \"sigma_obs\": 159.77943420410156, \"slope\": -0.06126740202307701, \"chain\": 2, \"draw\": 163}, {\"draws\": 563, \"mouse\": 2, \"mu_intercept_per_group\": 6.447991371154785, \"sigma_intercept_per_group\": 0.3410559892654419, \"sigma_obs\": 159.77943420410156, \"slope\": -0.06126740202307701, \"chain\": 2, \"draw\": 163}, {\"draws\": 563, \"mouse\": 3, \"mu_intercept_per_group\": 6.50099515914917, \"sigma_intercept_per_group\": 0.3410559892654419, \"sigma_obs\": 159.77943420410156, \"slope\": -0.06126740202307701, \"chain\": 2, \"draw\": 163}, {\"draws\": 563, \"mouse\": 4, \"mu_intercept_per_group\": 6.173435211181641, \"sigma_intercept_per_group\": 0.3410559892654419, \"sigma_obs\": 159.77943420410156, \"slope\": -0.06126740202307701, \"chain\": 2, \"draw\": 163}, {\"draws\": 563, \"mouse\": 5, \"mu_intercept_per_group\": 5.69912576675415, \"sigma_intercept_per_group\": 0.3410559892654419, \"sigma_obs\": 159.77943420410156, \"slope\": -0.06126740202307701, \"chain\": 2, \"draw\": 163}, {\"draws\": 563, \"mouse\": 6, \"mu_intercept_per_group\": 5.298242568969727, \"sigma_intercept_per_group\": 0.3410559892654419, \"sigma_obs\": 159.77943420410156, \"slope\": -0.06126740202307701, \"chain\": 2, \"draw\": 163}, {\"draws\": 563, \"mouse\": 7, \"mu_intercept_per_group\": 5.36509370803833, \"sigma_intercept_per_group\": 0.3410559892654419, \"sigma_obs\": 159.77943420410156, \"slope\": -0.06126740202307701, \"chain\": 2, \"draw\": 163}, {\"draws\": 564, \"mouse\": 0, \"mu_intercept_per_group\": 7.267584323883057, \"sigma_intercept_per_group\": 0.3421533405780792, \"sigma_obs\": 160.2937774658203, \"slope\": -0.0615241639316082, \"chain\": 2, \"draw\": 164}, {\"draws\": 564, \"mouse\": 1, \"mu_intercept_per_group\": 7.010891914367676, \"sigma_intercept_per_group\": 0.3421533405780792, \"sigma_obs\": 160.2937774658203, \"slope\": -0.0615241639316082, \"chain\": 2, \"draw\": 164}, {\"draws\": 564, \"mouse\": 2, \"mu_intercept_per_group\": 6.934586524963379, \"sigma_intercept_per_group\": 0.3421533405780792, \"sigma_obs\": 160.2937774658203, \"slope\": -0.0615241639316082, \"chain\": 2, \"draw\": 164}, {\"draws\": 564, \"mouse\": 3, \"mu_intercept_per_group\": 6.3297224044799805, \"sigma_intercept_per_group\": 0.3421533405780792, \"sigma_obs\": 160.2937774658203, \"slope\": -0.0615241639316082, \"chain\": 2, \"draw\": 164}, {\"draws\": 564, \"mouse\": 4, \"mu_intercept_per_group\": 6.136019229888916, \"sigma_intercept_per_group\": 0.3421533405780792, \"sigma_obs\": 160.2937774658203, \"slope\": -0.0615241639316082, \"chain\": 2, \"draw\": 164}, {\"draws\": 564, \"mouse\": 5, \"mu_intercept_per_group\": 5.821683883666992, \"sigma_intercept_per_group\": 0.3421533405780792, \"sigma_obs\": 160.2937774658203, \"slope\": -0.0615241639316082, \"chain\": 2, \"draw\": 164}, {\"draws\": 564, \"mouse\": 6, \"mu_intercept_per_group\": 5.1882147789001465, \"sigma_intercept_per_group\": 0.3421533405780792, \"sigma_obs\": 160.2937774658203, \"slope\": -0.0615241639316082, \"chain\": 2, \"draw\": 164}, {\"draws\": 564, \"mouse\": 7, \"mu_intercept_per_group\": 5.418088436126709, \"sigma_intercept_per_group\": 0.3421533405780792, \"sigma_obs\": 160.2937774658203, \"slope\": -0.0615241639316082, \"chain\": 2, \"draw\": 164}, {\"draws\": 565, \"mouse\": 0, \"mu_intercept_per_group\": 7.316530704498291, \"sigma_intercept_per_group\": 0.33317726850509644, \"sigma_obs\": 159.1376190185547, \"slope\": -0.060909658670425415, \"chain\": 2, \"draw\": 165}, {\"draws\": 565, \"mouse\": 1, \"mu_intercept_per_group\": 6.995572090148926, \"sigma_intercept_per_group\": 0.33317726850509644, \"sigma_obs\": 159.1376190185547, \"slope\": -0.060909658670425415, \"chain\": 2, \"draw\": 165}, {\"draws\": 565, \"mouse\": 2, \"mu_intercept_per_group\": 6.62956428527832, \"sigma_intercept_per_group\": 0.33317726850509644, \"sigma_obs\": 159.1376190185547, \"slope\": -0.060909658670425415, \"chain\": 2, \"draw\": 165}, {\"draws\": 565, \"mouse\": 3, \"mu_intercept_per_group\": 6.395594596862793, \"sigma_intercept_per_group\": 0.33317726850509644, \"sigma_obs\": 159.1376190185547, \"slope\": -0.060909658670425415, \"chain\": 2, \"draw\": 165}, {\"draws\": 565, \"mouse\": 4, \"mu_intercept_per_group\": 6.264066696166992, \"sigma_intercept_per_group\": 0.33317726850509644, \"sigma_obs\": 159.1376190185547, \"slope\": -0.060909658670425415, \"chain\": 2, \"draw\": 165}, {\"draws\": 565, \"mouse\": 5, \"mu_intercept_per_group\": 5.926372528076172, \"sigma_intercept_per_group\": 0.33317726850509644, \"sigma_obs\": 159.1376190185547, \"slope\": -0.060909658670425415, \"chain\": 2, \"draw\": 165}, {\"draws\": 565, \"mouse\": 6, \"mu_intercept_per_group\": 5.7065863609313965, \"sigma_intercept_per_group\": 0.33317726850509644, \"sigma_obs\": 159.1376190185547, \"slope\": -0.060909658670425415, \"chain\": 2, \"draw\": 165}, {\"draws\": 565, \"mouse\": 7, \"mu_intercept_per_group\": 5.180669784545898, \"sigma_intercept_per_group\": 0.33317726850509644, \"sigma_obs\": 159.1376190185547, \"slope\": -0.060909658670425415, \"chain\": 2, \"draw\": 165}, {\"draws\": 566, \"mouse\": 0, \"mu_intercept_per_group\": 7.394465923309326, \"sigma_intercept_per_group\": 0.33237484097480774, \"sigma_obs\": 159.03794860839844, \"slope\": -0.06146414577960968, \"chain\": 2, \"draw\": 166}, {\"draws\": 566, \"mouse\": 1, \"mu_intercept_per_group\": 7.084810733795166, \"sigma_intercept_per_group\": 0.33237484097480774, \"sigma_obs\": 159.03794860839844, \"slope\": -0.06146414577960968, \"chain\": 2, \"draw\": 166}, {\"draws\": 566, \"mouse\": 2, \"mu_intercept_per_group\": 7.111217498779297, \"sigma_intercept_per_group\": 0.33237484097480774, \"sigma_obs\": 159.03794860839844, \"slope\": -0.06146414577960968, \"chain\": 2, \"draw\": 166}, {\"draws\": 566, \"mouse\": 3, \"mu_intercept_per_group\": 6.554296016693115, \"sigma_intercept_per_group\": 0.33237484097480774, \"sigma_obs\": 159.03794860839844, \"slope\": -0.06146414577960968, \"chain\": 2, \"draw\": 166}, {\"draws\": 566, \"mouse\": 4, \"mu_intercept_per_group\": 6.3472113609313965, \"sigma_intercept_per_group\": 0.33237484097480774, \"sigma_obs\": 159.03794860839844, \"slope\": -0.06146414577960968, \"chain\": 2, \"draw\": 166}, {\"draws\": 566, \"mouse\": 5, \"mu_intercept_per_group\": 6.01556921005249, \"sigma_intercept_per_group\": 0.33237484097480774, \"sigma_obs\": 159.03794860839844, \"slope\": -0.06146414577960968, \"chain\": 2, \"draw\": 166}, {\"draws\": 566, \"mouse\": 6, \"mu_intercept_per_group\": 5.465827941894531, \"sigma_intercept_per_group\": 0.33237484097480774, \"sigma_obs\": 159.03794860839844, \"slope\": -0.06146414577960968, \"chain\": 2, \"draw\": 166}, {\"draws\": 566, \"mouse\": 7, \"mu_intercept_per_group\": 5.3086066246032715, \"sigma_intercept_per_group\": 0.33237484097480774, \"sigma_obs\": 159.03794860839844, \"slope\": -0.06146414577960968, \"chain\": 2, \"draw\": 166}, {\"draws\": 567, \"mouse\": 0, \"mu_intercept_per_group\": 7.280376434326172, \"sigma_intercept_per_group\": 0.33848488330841064, \"sigma_obs\": 161.84133911132812, \"slope\": -0.07558411359786987, \"chain\": 2, \"draw\": 167}, {\"draws\": 567, \"mouse\": 1, \"mu_intercept_per_group\": 7.2124342918396, \"sigma_intercept_per_group\": 0.33848488330841064, \"sigma_obs\": 161.84133911132812, \"slope\": -0.07558411359786987, \"chain\": 2, \"draw\": 167}, {\"draws\": 567, \"mouse\": 2, \"mu_intercept_per_group\": 7.014129161834717, \"sigma_intercept_per_group\": 0.33848488330841064, \"sigma_obs\": 161.84133911132812, \"slope\": -0.07558411359786987, \"chain\": 2, \"draw\": 167}, {\"draws\": 567, \"mouse\": 3, \"mu_intercept_per_group\": 6.587983131408691, \"sigma_intercept_per_group\": 0.33848488330841064, \"sigma_obs\": 161.84133911132812, \"slope\": -0.07558411359786987, \"chain\": 2, \"draw\": 167}, {\"draws\": 567, \"mouse\": 4, \"mu_intercept_per_group\": 6.268382549285889, \"sigma_intercept_per_group\": 0.33848488330841064, \"sigma_obs\": 161.84133911132812, \"slope\": -0.07558411359786987, \"chain\": 2, \"draw\": 167}, {\"draws\": 567, \"mouse\": 5, \"mu_intercept_per_group\": 5.916647434234619, \"sigma_intercept_per_group\": 0.33848488330841064, \"sigma_obs\": 161.84133911132812, \"slope\": -0.07558411359786987, \"chain\": 2, \"draw\": 167}, {\"draws\": 567, \"mouse\": 6, \"mu_intercept_per_group\": 5.683372497558594, \"sigma_intercept_per_group\": 0.33848488330841064, \"sigma_obs\": 161.84133911132812, \"slope\": -0.07558411359786987, \"chain\": 2, \"draw\": 167}, {\"draws\": 567, \"mouse\": 7, \"mu_intercept_per_group\": 5.5222392082214355, \"sigma_intercept_per_group\": 0.33848488330841064, \"sigma_obs\": 161.84133911132812, \"slope\": -0.07558411359786987, \"chain\": 2, \"draw\": 167}, {\"draws\": 568, \"mouse\": 0, \"mu_intercept_per_group\": 6.665816307067871, \"sigma_intercept_per_group\": 0.3629610240459442, \"sigma_obs\": 158.7001495361328, \"slope\": -0.08173733949661255, \"chain\": 2, \"draw\": 168}, {\"draws\": 568, \"mouse\": 1, \"mu_intercept_per_group\": 6.5665764808654785, \"sigma_intercept_per_group\": 0.3629610240459442, \"sigma_obs\": 158.7001495361328, \"slope\": -0.08173733949661255, \"chain\": 2, \"draw\": 168}, {\"draws\": 568, \"mouse\": 2, \"mu_intercept_per_group\": 6.445687294006348, \"sigma_intercept_per_group\": 0.3629610240459442, \"sigma_obs\": 158.7001495361328, \"slope\": -0.08173733949661255, \"chain\": 2, \"draw\": 168}, {\"draws\": 568, \"mouse\": 3, \"mu_intercept_per_group\": 5.796056270599365, \"sigma_intercept_per_group\": 0.3629610240459442, \"sigma_obs\": 158.7001495361328, \"slope\": -0.08173733949661255, \"chain\": 2, \"draw\": 168}, {\"draws\": 568, \"mouse\": 4, \"mu_intercept_per_group\": 5.92685604095459, \"sigma_intercept_per_group\": 0.3629610240459442, \"sigma_obs\": 158.7001495361328, \"slope\": -0.08173733949661255, \"chain\": 2, \"draw\": 168}, {\"draws\": 568, \"mouse\": 5, \"mu_intercept_per_group\": 5.546988487243652, \"sigma_intercept_per_group\": 0.3629610240459442, \"sigma_obs\": 158.7001495361328, \"slope\": -0.08173733949661255, \"chain\": 2, \"draw\": 168}, {\"draws\": 568, \"mouse\": 6, \"mu_intercept_per_group\": 5.201950550079346, \"sigma_intercept_per_group\": 0.3629610240459442, \"sigma_obs\": 158.7001495361328, \"slope\": -0.08173733949661255, \"chain\": 2, \"draw\": 168}, {\"draws\": 568, \"mouse\": 7, \"mu_intercept_per_group\": 4.944475173950195, \"sigma_intercept_per_group\": 0.3629610240459442, \"sigma_obs\": 158.7001495361328, \"slope\": -0.08173733949661255, \"chain\": 2, \"draw\": 168}, {\"draws\": 569, \"mouse\": 0, \"mu_intercept_per_group\": 6.875725269317627, \"sigma_intercept_per_group\": 0.3696499466896057, \"sigma_obs\": 157.76268005371094, \"slope\": -0.08081834763288498, \"chain\": 2, \"draw\": 169}, {\"draws\": 569, \"mouse\": 1, \"mu_intercept_per_group\": 6.398355960845947, \"sigma_intercept_per_group\": 0.3696499466896057, \"sigma_obs\": 157.76268005371094, \"slope\": -0.08081834763288498, \"chain\": 2, \"draw\": 169}, {\"draws\": 569, \"mouse\": 2, \"mu_intercept_per_group\": 6.15829610824585, \"sigma_intercept_per_group\": 0.3696499466896057, \"sigma_obs\": 157.76268005371094, \"slope\": -0.08081834763288498, \"chain\": 2, \"draw\": 169}, {\"draws\": 569, \"mouse\": 3, \"mu_intercept_per_group\": 6.125241279602051, \"sigma_intercept_per_group\": 0.3696499466896057, \"sigma_obs\": 157.76268005371094, \"slope\": -0.08081834763288498, \"chain\": 2, \"draw\": 169}, {\"draws\": 569, \"mouse\": 4, \"mu_intercept_per_group\": 5.6429948806762695, \"sigma_intercept_per_group\": 0.3696499466896057, \"sigma_obs\": 157.76268005371094, \"slope\": -0.08081834763288498, \"chain\": 2, \"draw\": 169}, {\"draws\": 569, \"mouse\": 5, \"mu_intercept_per_group\": 5.488842010498047, \"sigma_intercept_per_group\": 0.3696499466896057, \"sigma_obs\": 157.76268005371094, \"slope\": -0.08081834763288498, \"chain\": 2, \"draw\": 169}, {\"draws\": 569, \"mouse\": 6, \"mu_intercept_per_group\": 4.853878974914551, \"sigma_intercept_per_group\": 0.3696499466896057, \"sigma_obs\": 157.76268005371094, \"slope\": -0.08081834763288498, \"chain\": 2, \"draw\": 169}, {\"draws\": 569, \"mouse\": 7, \"mu_intercept_per_group\": 4.764561653137207, \"sigma_intercept_per_group\": 0.3696499466896057, \"sigma_obs\": 157.76268005371094, \"slope\": -0.08081834763288498, \"chain\": 2, \"draw\": 169}, {\"draws\": 570, \"mouse\": 0, \"mu_intercept_per_group\": 6.8123698234558105, \"sigma_intercept_per_group\": 0.36933398246765137, \"sigma_obs\": 157.80255126953125, \"slope\": -0.08063934743404388, \"chain\": 2, \"draw\": 170}, {\"draws\": 570, \"mouse\": 1, \"mu_intercept_per_group\": 6.4617533683776855, \"sigma_intercept_per_group\": 0.36933398246765137, \"sigma_obs\": 157.80255126953125, \"slope\": -0.08063934743404388, \"chain\": 2, \"draw\": 170}, {\"draws\": 570, \"mouse\": 2, \"mu_intercept_per_group\": 6.1888885498046875, \"sigma_intercept_per_group\": 0.36933398246765137, \"sigma_obs\": 157.80255126953125, \"slope\": -0.08063934743404388, \"chain\": 2, \"draw\": 170}, {\"draws\": 570, \"mouse\": 3, \"mu_intercept_per_group\": 6.10743522644043, \"sigma_intercept_per_group\": 0.36933398246765137, \"sigma_obs\": 157.80255126953125, \"slope\": -0.08063934743404388, \"chain\": 2, \"draw\": 170}, {\"draws\": 570, \"mouse\": 4, \"mu_intercept_per_group\": 5.666179656982422, \"sigma_intercept_per_group\": 0.36933398246765137, \"sigma_obs\": 157.80255126953125, \"slope\": -0.08063934743404388, \"chain\": 2, \"draw\": 170}, {\"draws\": 570, \"mouse\": 5, \"mu_intercept_per_group\": 5.560751438140869, \"sigma_intercept_per_group\": 0.36933398246765137, \"sigma_obs\": 157.80255126953125, \"slope\": -0.08063934743404388, \"chain\": 2, \"draw\": 170}, {\"draws\": 570, \"mouse\": 6, \"mu_intercept_per_group\": 4.863048553466797, \"sigma_intercept_per_group\": 0.36933398246765137, \"sigma_obs\": 157.80255126953125, \"slope\": -0.08063934743404388, \"chain\": 2, \"draw\": 170}, {\"draws\": 570, \"mouse\": 7, \"mu_intercept_per_group\": 4.786140441894531, \"sigma_intercept_per_group\": 0.36933398246765137, \"sigma_obs\": 157.80255126953125, \"slope\": -0.08063934743404388, \"chain\": 2, \"draw\": 170}, {\"draws\": 571, \"mouse\": 0, \"mu_intercept_per_group\": 6.505817890167236, \"sigma_intercept_per_group\": 0.3821823000907898, \"sigma_obs\": 158.38815307617188, \"slope\": -0.07689960300922394, \"chain\": 2, \"draw\": 171}, {\"draws\": 571, \"mouse\": 1, \"mu_intercept_per_group\": 6.25892972946167, \"sigma_intercept_per_group\": 0.3821823000907898, \"sigma_obs\": 158.38815307617188, \"slope\": -0.07689960300922394, \"chain\": 2, \"draw\": 171}, {\"draws\": 571, \"mouse\": 2, \"mu_intercept_per_group\": 5.9898762702941895, \"sigma_intercept_per_group\": 0.3821823000907898, \"sigma_obs\": 158.38815307617188, \"slope\": -0.07689960300922394, \"chain\": 2, \"draw\": 171}, {\"draws\": 571, \"mouse\": 3, \"mu_intercept_per_group\": 5.759361743927002, \"sigma_intercept_per_group\": 0.3821823000907898, \"sigma_obs\": 158.38815307617188, \"slope\": -0.07689960300922394, \"chain\": 2, \"draw\": 171}, {\"draws\": 571, \"mouse\": 4, \"mu_intercept_per_group\": 5.494572639465332, \"sigma_intercept_per_group\": 0.3821823000907898, \"sigma_obs\": 158.38815307617188, \"slope\": -0.07689960300922394, \"chain\": 2, \"draw\": 171}, {\"draws\": 571, \"mouse\": 5, \"mu_intercept_per_group\": 4.949382305145264, \"sigma_intercept_per_group\": 0.3821823000907898, \"sigma_obs\": 158.38815307617188, \"slope\": -0.07689960300922394, \"chain\": 2, \"draw\": 171}, {\"draws\": 571, \"mouse\": 6, \"mu_intercept_per_group\": 5.095454216003418, \"sigma_intercept_per_group\": 0.3821823000907898, \"sigma_obs\": 158.38815307617188, \"slope\": -0.07689960300922394, \"chain\": 2, \"draw\": 171}, {\"draws\": 571, \"mouse\": 7, \"mu_intercept_per_group\": 4.6787800788879395, \"sigma_intercept_per_group\": 0.3821823000907898, \"sigma_obs\": 158.38815307617188, \"slope\": -0.07689960300922394, \"chain\": 2, \"draw\": 171}, {\"draws\": 572, \"mouse\": 0, \"mu_intercept_per_group\": 6.502560138702393, \"sigma_intercept_per_group\": 0.3798617720603943, \"sigma_obs\": 157.93624877929688, \"slope\": -0.07648714631795883, \"chain\": 2, \"draw\": 172}, {\"draws\": 572, \"mouse\": 1, \"mu_intercept_per_group\": 6.07040548324585, \"sigma_intercept_per_group\": 0.3798617720603943, \"sigma_obs\": 157.93624877929688, \"slope\": -0.07648714631795883, \"chain\": 2, \"draw\": 172}, {\"draws\": 572, \"mouse\": 2, \"mu_intercept_per_group\": 6.1410980224609375, \"sigma_intercept_per_group\": 0.3798617720603943, \"sigma_obs\": 157.93624877929688, \"slope\": -0.07648714631795883, \"chain\": 2, \"draw\": 172}, {\"draws\": 572, \"mouse\": 3, \"mu_intercept_per_group\": 5.742376804351807, \"sigma_intercept_per_group\": 0.3798617720603943, \"sigma_obs\": 157.93624877929688, \"slope\": -0.07648714631795883, \"chain\": 2, \"draw\": 172}, {\"draws\": 572, \"mouse\": 4, \"mu_intercept_per_group\": 5.435659885406494, \"sigma_intercept_per_group\": 0.3798617720603943, \"sigma_obs\": 157.93624877929688, \"slope\": -0.07648714631795883, \"chain\": 2, \"draw\": 172}, {\"draws\": 572, \"mouse\": 5, \"mu_intercept_per_group\": 5.034947872161865, \"sigma_intercept_per_group\": 0.3798617720603943, \"sigma_obs\": 157.93624877929688, \"slope\": -0.07648714631795883, \"chain\": 2, \"draw\": 172}, {\"draws\": 572, \"mouse\": 6, \"mu_intercept_per_group\": 5.137113094329834, \"sigma_intercept_per_group\": 0.3798617720603943, \"sigma_obs\": 157.93624877929688, \"slope\": -0.07648714631795883, \"chain\": 2, \"draw\": 172}, {\"draws\": 572, \"mouse\": 7, \"mu_intercept_per_group\": 4.791214942932129, \"sigma_intercept_per_group\": 0.3798617720603943, \"sigma_obs\": 157.93624877929688, \"slope\": -0.07648714631795883, \"chain\": 2, \"draw\": 172}, {\"draws\": 573, \"mouse\": 0, \"mu_intercept_per_group\": 6.600709915161133, \"sigma_intercept_per_group\": 0.38204699754714966, \"sigma_obs\": 157.82559204101562, \"slope\": -0.07684549689292908, \"chain\": 2, \"draw\": 173}, {\"draws\": 573, \"mouse\": 1, \"mu_intercept_per_group\": 6.1469855308532715, \"sigma_intercept_per_group\": 0.38204699754714966, \"sigma_obs\": 157.82559204101562, \"slope\": -0.07684549689292908, \"chain\": 2, \"draw\": 173}, {\"draws\": 573, \"mouse\": 2, \"mu_intercept_per_group\": 6.082374572753906, \"sigma_intercept_per_group\": 0.38204699754714966, \"sigma_obs\": 157.82559204101562, \"slope\": -0.07684549689292908, \"chain\": 2, \"draw\": 173}, {\"draws\": 573, \"mouse\": 3, \"mu_intercept_per_group\": 5.806753635406494, \"sigma_intercept_per_group\": 0.38204699754714966, \"sigma_obs\": 157.82559204101562, \"slope\": -0.07684549689292908, \"chain\": 2, \"draw\": 173}, {\"draws\": 573, \"mouse\": 4, \"mu_intercept_per_group\": 5.485602378845215, \"sigma_intercept_per_group\": 0.38204699754714966, \"sigma_obs\": 157.82559204101562, \"slope\": -0.07684549689292908, \"chain\": 2, \"draw\": 173}, {\"draws\": 573, \"mouse\": 5, \"mu_intercept_per_group\": 5.041656017303467, \"sigma_intercept_per_group\": 0.38204699754714966, \"sigma_obs\": 157.82559204101562, \"slope\": -0.07684549689292908, \"chain\": 2, \"draw\": 173}, {\"draws\": 573, \"mouse\": 6, \"mu_intercept_per_group\": 5.190553665161133, \"sigma_intercept_per_group\": 0.38204699754714966, \"sigma_obs\": 157.82559204101562, \"slope\": -0.07684549689292908, \"chain\": 2, \"draw\": 173}, {\"draws\": 573, \"mouse\": 7, \"mu_intercept_per_group\": 4.592303276062012, \"sigma_intercept_per_group\": 0.38204699754714966, \"sigma_obs\": 157.82559204101562, \"slope\": -0.07684549689292908, \"chain\": 2, \"draw\": 173}, {\"draws\": 574, \"mouse\": 0, \"mu_intercept_per_group\": 6.403434753417969, \"sigma_intercept_per_group\": 0.3790667951107025, \"sigma_obs\": 157.7740478515625, \"slope\": -0.07571599632501602, \"chain\": 2, \"draw\": 174}, {\"draws\": 574, \"mouse\": 1, \"mu_intercept_per_group\": 6.283817291259766, \"sigma_intercept_per_group\": 0.3790667951107025, \"sigma_obs\": 157.7740478515625, \"slope\": -0.07571599632501602, \"chain\": 2, \"draw\": 174}, {\"draws\": 574, \"mouse\": 2, \"mu_intercept_per_group\": 6.135117530822754, \"sigma_intercept_per_group\": 0.3790667951107025, \"sigma_obs\": 157.7740478515625, \"slope\": -0.07571599632501602, \"chain\": 2, \"draw\": 174}, {\"draws\": 574, \"mouse\": 3, \"mu_intercept_per_group\": 5.7886505126953125, \"sigma_intercept_per_group\": 0.3790667951107025, \"sigma_obs\": 157.7740478515625, \"slope\": -0.07571599632501602, \"chain\": 2, \"draw\": 174}, {\"draws\": 574, \"mouse\": 4, \"mu_intercept_per_group\": 5.567411422729492, \"sigma_intercept_per_group\": 0.3790667951107025, \"sigma_obs\": 157.7740478515625, \"slope\": -0.07571599632501602, \"chain\": 2, \"draw\": 174}, {\"draws\": 574, \"mouse\": 5, \"mu_intercept_per_group\": 5.1575798988342285, \"sigma_intercept_per_group\": 0.3790667951107025, \"sigma_obs\": 157.7740478515625, \"slope\": -0.07571599632501602, \"chain\": 2, \"draw\": 174}, {\"draws\": 574, \"mouse\": 6, \"mu_intercept_per_group\": 4.94981050491333, \"sigma_intercept_per_group\": 0.3790667951107025, \"sigma_obs\": 157.7740478515625, \"slope\": -0.07571599632501602, \"chain\": 2, \"draw\": 174}, {\"draws\": 574, \"mouse\": 7, \"mu_intercept_per_group\": 4.6374592781066895, \"sigma_intercept_per_group\": 0.3790667951107025, \"sigma_obs\": 157.7740478515625, \"slope\": -0.07571599632501602, \"chain\": 2, \"draw\": 174}, {\"draws\": 575, \"mouse\": 0, \"mu_intercept_per_group\": 6.513913154602051, \"sigma_intercept_per_group\": 0.3761572241783142, \"sigma_obs\": 156.54571533203125, \"slope\": -0.0779879242181778, \"chain\": 2, \"draw\": 175}, {\"draws\": 575, \"mouse\": 1, \"mu_intercept_per_group\": 6.401298522949219, \"sigma_intercept_per_group\": 0.3761572241783142, \"sigma_obs\": 156.54571533203125, \"slope\": -0.0779879242181778, \"chain\": 2, \"draw\": 175}, {\"draws\": 575, \"mouse\": 2, \"mu_intercept_per_group\": 6.09372091293335, \"sigma_intercept_per_group\": 0.3761572241783142, \"sigma_obs\": 156.54571533203125, \"slope\": -0.0779879242181778, \"chain\": 2, \"draw\": 175}, {\"draws\": 575, \"mouse\": 3, \"mu_intercept_per_group\": 5.820502758026123, \"sigma_intercept_per_group\": 0.3761572241783142, \"sigma_obs\": 156.54571533203125, \"slope\": -0.0779879242181778, \"chain\": 2, \"draw\": 175}, {\"draws\": 575, \"mouse\": 4, \"mu_intercept_per_group\": 5.639848232269287, \"sigma_intercept_per_group\": 0.3761572241783142, \"sigma_obs\": 156.54571533203125, \"slope\": -0.0779879242181778, \"chain\": 2, \"draw\": 175}, {\"draws\": 575, \"mouse\": 5, \"mu_intercept_per_group\": 5.377632141113281, \"sigma_intercept_per_group\": 0.3761572241783142, \"sigma_obs\": 156.54571533203125, \"slope\": -0.0779879242181778, \"chain\": 2, \"draw\": 175}, {\"draws\": 575, \"mouse\": 6, \"mu_intercept_per_group\": 4.989121913909912, \"sigma_intercept_per_group\": 0.3761572241783142, \"sigma_obs\": 156.54571533203125, \"slope\": -0.0779879242181778, \"chain\": 2, \"draw\": 175}, {\"draws\": 575, \"mouse\": 7, \"mu_intercept_per_group\": 4.775144577026367, \"sigma_intercept_per_group\": 0.3761572241783142, \"sigma_obs\": 156.54571533203125, \"slope\": -0.0779879242181778, \"chain\": 2, \"draw\": 175}, {\"draws\": 576, \"mouse\": 0, \"mu_intercept_per_group\": 8.939000129699707, \"sigma_intercept_per_group\": 0.28446099162101746, \"sigma_obs\": 168.23838806152344, \"slope\": -0.08227061480283737, \"chain\": 2, \"draw\": 176}, {\"draws\": 576, \"mouse\": 1, \"mu_intercept_per_group\": 8.522024154663086, \"sigma_intercept_per_group\": 0.28446099162101746, \"sigma_obs\": 168.23838806152344, \"slope\": -0.08227061480283737, \"chain\": 2, \"draw\": 176}, {\"draws\": 576, \"mouse\": 2, \"mu_intercept_per_group\": 8.33825969696045, \"sigma_intercept_per_group\": 0.28446099162101746, \"sigma_obs\": 168.23838806152344, \"slope\": -0.08227061480283737, \"chain\": 2, \"draw\": 176}, {\"draws\": 576, \"mouse\": 3, \"mu_intercept_per_group\": 7.96980094909668, \"sigma_intercept_per_group\": 0.28446099162101746, \"sigma_obs\": 168.23838806152344, \"slope\": -0.08227061480283737, \"chain\": 2, \"draw\": 176}, {\"draws\": 576, \"mouse\": 4, \"mu_intercept_per_group\": 7.595188140869141, \"sigma_intercept_per_group\": 0.28446099162101746, \"sigma_obs\": 168.23838806152344, \"slope\": -0.08227061480283737, \"chain\": 2, \"draw\": 176}, {\"draws\": 576, \"mouse\": 5, \"mu_intercept_per_group\": 7.250743389129639, \"sigma_intercept_per_group\": 0.28446099162101746, \"sigma_obs\": 168.23838806152344, \"slope\": -0.08227061480283737, \"chain\": 2, \"draw\": 176}, {\"draws\": 576, \"mouse\": 6, \"mu_intercept_per_group\": 6.847686767578125, \"sigma_intercept_per_group\": 0.28446099162101746, \"sigma_obs\": 168.23838806152344, \"slope\": -0.08227061480283737, \"chain\": 2, \"draw\": 176}, {\"draws\": 576, \"mouse\": 7, \"mu_intercept_per_group\": 6.535247325897217, \"sigma_intercept_per_group\": 0.28446099162101746, \"sigma_obs\": 168.23838806152344, \"slope\": -0.08227061480283737, \"chain\": 2, \"draw\": 176}, {\"draws\": 577, \"mouse\": 0, \"mu_intercept_per_group\": 10.812926292419434, \"sigma_intercept_per_group\": 0.235860213637352, \"sigma_obs\": 175.44773864746094, \"slope\": -0.06338699907064438, \"chain\": 2, \"draw\": 177}, {\"draws\": 577, \"mouse\": 1, \"mu_intercept_per_group\": 10.54847526550293, \"sigma_intercept_per_group\": 0.235860213637352, \"sigma_obs\": 175.44773864746094, \"slope\": -0.06338699907064438, \"chain\": 2, \"draw\": 177}, {\"draws\": 577, \"mouse\": 2, \"mu_intercept_per_group\": 10.004850387573242, \"sigma_intercept_per_group\": 0.235860213637352, \"sigma_obs\": 175.44773864746094, \"slope\": -0.06338699907064438, \"chain\": 2, \"draw\": 177}, {\"draws\": 577, \"mouse\": 3, \"mu_intercept_per_group\": 9.72712516784668, \"sigma_intercept_per_group\": 0.235860213637352, \"sigma_obs\": 175.44773864746094, \"slope\": -0.06338699907064438, \"chain\": 2, \"draw\": 177}, {\"draws\": 577, \"mouse\": 4, \"mu_intercept_per_group\": 9.115574836730957, \"sigma_intercept_per_group\": 0.235860213637352, \"sigma_obs\": 175.44773864746094, \"slope\": -0.06338699907064438, \"chain\": 2, \"draw\": 177}, {\"draws\": 577, \"mouse\": 5, \"mu_intercept_per_group\": 8.726448059082031, \"sigma_intercept_per_group\": 0.235860213637352, \"sigma_obs\": 175.44773864746094, \"slope\": -0.06338699907064438, \"chain\": 2, \"draw\": 177}, {\"draws\": 577, \"mouse\": 6, \"mu_intercept_per_group\": 8.304804801940918, \"sigma_intercept_per_group\": 0.235860213637352, \"sigma_obs\": 175.44773864746094, \"slope\": -0.06338699907064438, \"chain\": 2, \"draw\": 177}, {\"draws\": 577, \"mouse\": 7, \"mu_intercept_per_group\": 7.810444355010986, \"sigma_intercept_per_group\": 0.235860213637352, \"sigma_obs\": 175.44773864746094, \"slope\": -0.06338699907064438, \"chain\": 2, \"draw\": 177}, {\"draws\": 578, \"mouse\": 0, \"mu_intercept_per_group\": 10.970190048217773, \"sigma_intercept_per_group\": 0.23367942869663239, \"sigma_obs\": 173.5137176513672, \"slope\": -0.06325386464595795, \"chain\": 2, \"draw\": 178}, {\"draws\": 578, \"mouse\": 1, \"mu_intercept_per_group\": 10.377053260803223, \"sigma_intercept_per_group\": 0.23367942869663239, \"sigma_obs\": 173.5137176513672, \"slope\": -0.06325386464595795, \"chain\": 2, \"draw\": 178}, {\"draws\": 578, \"mouse\": 2, \"mu_intercept_per_group\": 10.33288288116455, \"sigma_intercept_per_group\": 0.23367942869663239, \"sigma_obs\": 173.5137176513672, \"slope\": -0.06325386464595795, \"chain\": 2, \"draw\": 178}, {\"draws\": 578, \"mouse\": 3, \"mu_intercept_per_group\": 9.542760848999023, \"sigma_intercept_per_group\": 0.23367942869663239, \"sigma_obs\": 173.5137176513672, \"slope\": -0.06325386464595795, \"chain\": 2, \"draw\": 178}, {\"draws\": 578, \"mouse\": 4, \"mu_intercept_per_group\": 9.53835678100586, \"sigma_intercept_per_group\": 0.23367942869663239, \"sigma_obs\": 173.5137176513672, \"slope\": -0.06325386464595795, \"chain\": 2, \"draw\": 178}, {\"draws\": 578, \"mouse\": 5, \"mu_intercept_per_group\": 8.968080520629883, \"sigma_intercept_per_group\": 0.23367942869663239, \"sigma_obs\": 173.5137176513672, \"slope\": -0.06325386464595795, \"chain\": 2, \"draw\": 178}, {\"draws\": 578, \"mouse\": 6, \"mu_intercept_per_group\": 8.296401023864746, \"sigma_intercept_per_group\": 0.23367942869663239, \"sigma_obs\": 173.5137176513672, \"slope\": -0.06325386464595795, \"chain\": 2, \"draw\": 178}, {\"draws\": 578, \"mouse\": 7, \"mu_intercept_per_group\": 8.001548767089844, \"sigma_intercept_per_group\": 0.23367942869663239, \"sigma_obs\": 173.5137176513672, \"slope\": -0.06325386464595795, \"chain\": 2, \"draw\": 178}, {\"draws\": 579, \"mouse\": 0, \"mu_intercept_per_group\": 10.578970909118652, \"sigma_intercept_per_group\": 0.23680400848388672, \"sigma_obs\": 161.388671875, \"slope\": -0.06295111775398254, \"chain\": 2, \"draw\": 179}, {\"draws\": 579, \"mouse\": 1, \"mu_intercept_per_group\": 10.005696296691895, \"sigma_intercept_per_group\": 0.23680400848388672, \"sigma_obs\": 161.388671875, \"slope\": -0.06295111775398254, \"chain\": 2, \"draw\": 179}, {\"draws\": 579, \"mouse\": 2, \"mu_intercept_per_group\": 9.779582977294922, \"sigma_intercept_per_group\": 0.23680400848388672, \"sigma_obs\": 161.388671875, \"slope\": -0.06295111775398254, \"chain\": 2, \"draw\": 179}, {\"draws\": 579, \"mouse\": 3, \"mu_intercept_per_group\": 9.330636978149414, \"sigma_intercept_per_group\": 0.23680400848388672, \"sigma_obs\": 161.388671875, \"slope\": -0.06295111775398254, \"chain\": 2, \"draw\": 179}, {\"draws\": 579, \"mouse\": 4, \"mu_intercept_per_group\": 8.86966609954834, \"sigma_intercept_per_group\": 0.23680400848388672, \"sigma_obs\": 161.388671875, \"slope\": -0.06295111775398254, \"chain\": 2, \"draw\": 179}, {\"draws\": 579, \"mouse\": 5, \"mu_intercept_per_group\": 8.285300254821777, \"sigma_intercept_per_group\": 0.23680400848388672, \"sigma_obs\": 161.388671875, \"slope\": -0.06295111775398254, \"chain\": 2, \"draw\": 179}, {\"draws\": 579, \"mouse\": 6, \"mu_intercept_per_group\": 7.918811321258545, \"sigma_intercept_per_group\": 0.23680400848388672, \"sigma_obs\": 161.388671875, \"slope\": -0.06295111775398254, \"chain\": 2, \"draw\": 179}, {\"draws\": 579, \"mouse\": 7, \"mu_intercept_per_group\": 7.663546085357666, \"sigma_intercept_per_group\": 0.23680400848388672, \"sigma_obs\": 161.388671875, \"slope\": -0.06295111775398254, \"chain\": 2, \"draw\": 179}, {\"draws\": 580, \"mouse\": 0, \"mu_intercept_per_group\": 9.79837703704834, \"sigma_intercept_per_group\": 0.24763868749141693, \"sigma_obs\": 151.54550170898438, \"slope\": -0.0692424476146698, \"chain\": 2, \"draw\": 180}, {\"draws\": 580, \"mouse\": 1, \"mu_intercept_per_group\": 9.329174995422363, \"sigma_intercept_per_group\": 0.24763868749141693, \"sigma_obs\": 151.54550170898438, \"slope\": -0.0692424476146698, \"chain\": 2, \"draw\": 180}, {\"draws\": 580, \"mouse\": 2, \"mu_intercept_per_group\": 9.272500991821289, \"sigma_intercept_per_group\": 0.24763868749141693, \"sigma_obs\": 151.54550170898438, \"slope\": -0.0692424476146698, \"chain\": 2, \"draw\": 180}, {\"draws\": 580, \"mouse\": 3, \"mu_intercept_per_group\": 8.392488479614258, \"sigma_intercept_per_group\": 0.24763868749141693, \"sigma_obs\": 151.54550170898438, \"slope\": -0.0692424476146698, \"chain\": 2, \"draw\": 180}, {\"draws\": 580, \"mouse\": 4, \"mu_intercept_per_group\": 8.481561660766602, \"sigma_intercept_per_group\": 0.24763868749141693, \"sigma_obs\": 151.54550170898438, \"slope\": -0.0692424476146698, \"chain\": 2, \"draw\": 180}, {\"draws\": 580, \"mouse\": 5, \"mu_intercept_per_group\": 7.7366814613342285, \"sigma_intercept_per_group\": 0.24763868749141693, \"sigma_obs\": 151.54550170898438, \"slope\": -0.0692424476146698, \"chain\": 2, \"draw\": 180}, {\"draws\": 580, \"mouse\": 6, \"mu_intercept_per_group\": 7.6176371574401855, \"sigma_intercept_per_group\": 0.24763868749141693, \"sigma_obs\": 151.54550170898438, \"slope\": -0.0692424476146698, \"chain\": 2, \"draw\": 180}, {\"draws\": 580, \"mouse\": 7, \"mu_intercept_per_group\": 7.17441987991333, \"sigma_intercept_per_group\": 0.24763868749141693, \"sigma_obs\": 151.54550170898438, \"slope\": -0.0692424476146698, \"chain\": 2, \"draw\": 180}, {\"draws\": 581, \"mouse\": 0, \"mu_intercept_per_group\": 11.099349975585938, \"sigma_intercept_per_group\": 0.22562694549560547, \"sigma_obs\": 156.99557495117188, \"slope\": -0.08871173113584518, \"chain\": 2, \"draw\": 181}, {\"draws\": 581, \"mouse\": 1, \"mu_intercept_per_group\": 10.755790710449219, \"sigma_intercept_per_group\": 0.22562694549560547, \"sigma_obs\": 156.99557495117188, \"slope\": -0.08871173113584518, \"chain\": 2, \"draw\": 181}, {\"draws\": 581, \"mouse\": 2, \"mu_intercept_per_group\": 10.242413520812988, \"sigma_intercept_per_group\": 0.22562694549560547, \"sigma_obs\": 156.99557495117188, \"slope\": -0.08871173113584518, \"chain\": 2, \"draw\": 181}, {\"draws\": 581, \"mouse\": 3, \"mu_intercept_per_group\": 9.557084083557129, \"sigma_intercept_per_group\": 0.22562694549560547, \"sigma_obs\": 156.99557495117188, \"slope\": -0.08871173113584518, \"chain\": 2, \"draw\": 181}, {\"draws\": 581, \"mouse\": 4, \"mu_intercept_per_group\": 9.250614166259766, \"sigma_intercept_per_group\": 0.22562694549560547, \"sigma_obs\": 156.99557495117188, \"slope\": -0.08871173113584518, \"chain\": 2, \"draw\": 181}, {\"draws\": 581, \"mouse\": 5, \"mu_intercept_per_group\": 8.932378768920898, \"sigma_intercept_per_group\": 0.22562694549560547, \"sigma_obs\": 156.99557495117188, \"slope\": -0.08871173113584518, \"chain\": 2, \"draw\": 181}, {\"draws\": 581, \"mouse\": 6, \"mu_intercept_per_group\": 8.386637687683105, \"sigma_intercept_per_group\": 0.22562694549560547, \"sigma_obs\": 156.99557495117188, \"slope\": -0.08871173113584518, \"chain\": 2, \"draw\": 181}, {\"draws\": 581, \"mouse\": 7, \"mu_intercept_per_group\": 8.104625701904297, \"sigma_intercept_per_group\": 0.22562694549560547, \"sigma_obs\": 156.99557495117188, \"slope\": -0.08871173113584518, \"chain\": 2, \"draw\": 181}, {\"draws\": 582, \"mouse\": 0, \"mu_intercept_per_group\": 11.546039581298828, \"sigma_intercept_per_group\": 0.22123295068740845, \"sigma_obs\": 173.96646118164062, \"slope\": -0.08297727257013321, \"chain\": 2, \"draw\": 182}, {\"draws\": 582, \"mouse\": 1, \"mu_intercept_per_group\": 11.245062828063965, \"sigma_intercept_per_group\": 0.22123295068740845, \"sigma_obs\": 173.96646118164062, \"slope\": -0.08297727257013321, \"chain\": 2, \"draw\": 182}, {\"draws\": 582, \"mouse\": 2, \"mu_intercept_per_group\": 10.856532096862793, \"sigma_intercept_per_group\": 0.22123295068740845, \"sigma_obs\": 173.96646118164062, \"slope\": -0.08297727257013321, \"chain\": 2, \"draw\": 182}, {\"draws\": 582, \"mouse\": 3, \"mu_intercept_per_group\": 10.017833709716797, \"sigma_intercept_per_group\": 0.22123295068740845, \"sigma_obs\": 173.96646118164062, \"slope\": -0.08297727257013321, \"chain\": 2, \"draw\": 182}, {\"draws\": 582, \"mouse\": 4, \"mu_intercept_per_group\": 10.15605640411377, \"sigma_intercept_per_group\": 0.22123295068740845, \"sigma_obs\": 173.96646118164062, \"slope\": -0.08297727257013321, \"chain\": 2, \"draw\": 182}, {\"draws\": 582, \"mouse\": 5, \"mu_intercept_per_group\": 9.353255271911621, \"sigma_intercept_per_group\": 0.22123295068740845, \"sigma_obs\": 173.96646118164062, \"slope\": -0.08297727257013321, \"chain\": 2, \"draw\": 182}, {\"draws\": 582, \"mouse\": 6, \"mu_intercept_per_group\": 8.75030517578125, \"sigma_intercept_per_group\": 0.22123295068740845, \"sigma_obs\": 173.96646118164062, \"slope\": -0.08297727257013321, \"chain\": 2, \"draw\": 182}, {\"draws\": 582, \"mouse\": 7, \"mu_intercept_per_group\": 8.587395668029785, \"sigma_intercept_per_group\": 0.22123295068740845, \"sigma_obs\": 173.96646118164062, \"slope\": -0.08297727257013321, \"chain\": 2, \"draw\": 182}, {\"draws\": 583, \"mouse\": 0, \"mu_intercept_per_group\": 11.2684907913208, \"sigma_intercept_per_group\": 0.22604073584079742, \"sigma_obs\": 174.61404418945312, \"slope\": -0.07928775250911713, \"chain\": 2, \"draw\": 183}, {\"draws\": 583, \"mouse\": 1, \"mu_intercept_per_group\": 10.92301082611084, \"sigma_intercept_per_group\": 0.22604073584079742, \"sigma_obs\": 174.61404418945312, \"slope\": -0.07928775250911713, \"chain\": 2, \"draw\": 183}, {\"draws\": 583, \"mouse\": 2, \"mu_intercept_per_group\": 10.642309188842773, \"sigma_intercept_per_group\": 0.22604073584079742, \"sigma_obs\": 174.61404418945312, \"slope\": -0.07928775250911713, \"chain\": 2, \"draw\": 183}, {\"draws\": 583, \"mouse\": 3, \"mu_intercept_per_group\": 9.851088523864746, \"sigma_intercept_per_group\": 0.22604073584079742, \"sigma_obs\": 174.61404418945312, \"slope\": -0.07928775250911713, \"chain\": 2, \"draw\": 183}, {\"draws\": 583, \"mouse\": 4, \"mu_intercept_per_group\": 9.836934089660645, \"sigma_intercept_per_group\": 0.22604073584079742, \"sigma_obs\": 174.61404418945312, \"slope\": -0.07928775250911713, \"chain\": 2, \"draw\": 183}, {\"draws\": 583, \"mouse\": 5, \"mu_intercept_per_group\": 9.140487670898438, \"sigma_intercept_per_group\": 0.22604073584079742, \"sigma_obs\": 174.61404418945312, \"slope\": -0.07928775250911713, \"chain\": 2, \"draw\": 183}, {\"draws\": 583, \"mouse\": 6, \"mu_intercept_per_group\": 8.964550971984863, \"sigma_intercept_per_group\": 0.22604073584079742, \"sigma_obs\": 174.61404418945312, \"slope\": -0.07928775250911713, \"chain\": 2, \"draw\": 183}, {\"draws\": 583, \"mouse\": 7, \"mu_intercept_per_group\": 8.203434944152832, \"sigma_intercept_per_group\": 0.22604073584079742, \"sigma_obs\": 174.61404418945312, \"slope\": -0.07928775250911713, \"chain\": 2, \"draw\": 183}, {\"draws\": 584, \"mouse\": 0, \"mu_intercept_per_group\": 12.293266296386719, \"sigma_intercept_per_group\": 0.2075349986553192, \"sigma_obs\": 159.87112426757812, \"slope\": -0.08716809749603271, \"chain\": 2, \"draw\": 184}, {\"draws\": 584, \"mouse\": 1, \"mu_intercept_per_group\": 11.703648567199707, \"sigma_intercept_per_group\": 0.2075349986553192, \"sigma_obs\": 159.87112426757812, \"slope\": -0.08716809749603271, \"chain\": 2, \"draw\": 184}, {\"draws\": 584, \"mouse\": 2, \"mu_intercept_per_group\": 11.344744682312012, \"sigma_intercept_per_group\": 0.2075349986553192, \"sigma_obs\": 159.87112426757812, \"slope\": -0.08716809749603271, \"chain\": 2, \"draw\": 184}, {\"draws\": 584, \"mouse\": 3, \"mu_intercept_per_group\": 10.7989501953125, \"sigma_intercept_per_group\": 0.2075349986553192, \"sigma_obs\": 159.87112426757812, \"slope\": -0.08716809749603271, \"chain\": 2, \"draw\": 184}, {\"draws\": 584, \"mouse\": 4, \"mu_intercept_per_group\": 10.212386131286621, \"sigma_intercept_per_group\": 0.2075349986553192, \"sigma_obs\": 159.87112426757812, \"slope\": -0.08716809749603271, \"chain\": 2, \"draw\": 184}, {\"draws\": 584, \"mouse\": 5, \"mu_intercept_per_group\": 9.83260726928711, \"sigma_intercept_per_group\": 0.2075349986553192, \"sigma_obs\": 159.87112426757812, \"slope\": -0.08716809749603271, \"chain\": 2, \"draw\": 184}, {\"draws\": 584, \"mouse\": 6, \"mu_intercept_per_group\": 8.99131965637207, \"sigma_intercept_per_group\": 0.2075349986553192, \"sigma_obs\": 159.87112426757812, \"slope\": -0.08716809749603271, \"chain\": 2, \"draw\": 184}, {\"draws\": 584, \"mouse\": 7, \"mu_intercept_per_group\": 8.590600967407227, \"sigma_intercept_per_group\": 0.2075349986553192, \"sigma_obs\": 159.87112426757812, \"slope\": -0.08716809749603271, \"chain\": 2, \"draw\": 184}, {\"draws\": 585, \"mouse\": 0, \"mu_intercept_per_group\": 12.440118789672852, \"sigma_intercept_per_group\": 0.2025134563446045, \"sigma_obs\": 159.57127380371094, \"slope\": -0.08084113150835037, \"chain\": 2, \"draw\": 185}, {\"draws\": 585, \"mouse\": 1, \"mu_intercept_per_group\": 11.983794212341309, \"sigma_intercept_per_group\": 0.2025134563446045, \"sigma_obs\": 159.57127380371094, \"slope\": -0.08084113150835037, \"chain\": 2, \"draw\": 185}, {\"draws\": 585, \"mouse\": 2, \"mu_intercept_per_group\": 11.575582504272461, \"sigma_intercept_per_group\": 0.2025134563446045, \"sigma_obs\": 159.57127380371094, \"slope\": -0.08084113150835037, \"chain\": 2, \"draw\": 185}, {\"draws\": 585, \"mouse\": 3, \"mu_intercept_per_group\": 10.703948974609375, \"sigma_intercept_per_group\": 0.2025134563446045, \"sigma_obs\": 159.57127380371094, \"slope\": -0.08084113150835037, \"chain\": 2, \"draw\": 185}, {\"draws\": 585, \"mouse\": 4, \"mu_intercept_per_group\": 10.291831970214844, \"sigma_intercept_per_group\": 0.2025134563446045, \"sigma_obs\": 159.57127380371094, \"slope\": -0.08084113150835037, \"chain\": 2, \"draw\": 185}, {\"draws\": 585, \"mouse\": 5, \"mu_intercept_per_group\": 9.980964660644531, \"sigma_intercept_per_group\": 0.2025134563446045, \"sigma_obs\": 159.57127380371094, \"slope\": -0.08084113150835037, \"chain\": 2, \"draw\": 185}, {\"draws\": 585, \"mouse\": 6, \"mu_intercept_per_group\": 9.666460037231445, \"sigma_intercept_per_group\": 0.2025134563446045, \"sigma_obs\": 159.57127380371094, \"slope\": -0.08084113150835037, \"chain\": 2, \"draw\": 185}, {\"draws\": 585, \"mouse\": 7, \"mu_intercept_per_group\": 9.076685905456543, \"sigma_intercept_per_group\": 0.2025134563446045, \"sigma_obs\": 159.57127380371094, \"slope\": -0.08084113150835037, \"chain\": 2, \"draw\": 185}, {\"draws\": 586, \"mouse\": 0, \"mu_intercept_per_group\": 12.742076873779297, \"sigma_intercept_per_group\": 0.19916363060474396, \"sigma_obs\": 161.2209930419922, \"slope\": -0.08312004804611206, \"chain\": 2, \"draw\": 186}, {\"draws\": 586, \"mouse\": 1, \"mu_intercept_per_group\": 12.037081718444824, \"sigma_intercept_per_group\": 0.19916363060474396, \"sigma_obs\": 161.2209930419922, \"slope\": -0.08312004804611206, \"chain\": 2, \"draw\": 186}, {\"draws\": 586, \"mouse\": 2, \"mu_intercept_per_group\": 11.72884750366211, \"sigma_intercept_per_group\": 0.19916363060474396, \"sigma_obs\": 161.2209930419922, \"slope\": -0.08312004804611206, \"chain\": 2, \"draw\": 186}, {\"draws\": 586, \"mouse\": 3, \"mu_intercept_per_group\": 11.269041061401367, \"sigma_intercept_per_group\": 0.19916363060474396, \"sigma_obs\": 161.2209930419922, \"slope\": -0.08312004804611206, \"chain\": 2, \"draw\": 186}, {\"draws\": 586, \"mouse\": 4, \"mu_intercept_per_group\": 11.048524856567383, \"sigma_intercept_per_group\": 0.19916363060474396, \"sigma_obs\": 161.2209930419922, \"slope\": -0.08312004804611206, \"chain\": 2, \"draw\": 186}, {\"draws\": 586, \"mouse\": 5, \"mu_intercept_per_group\": 10.270564079284668, \"sigma_intercept_per_group\": 0.19916363060474396, \"sigma_obs\": 161.2209930419922, \"slope\": -0.08312004804611206, \"chain\": 2, \"draw\": 186}, {\"draws\": 586, \"mouse\": 6, \"mu_intercept_per_group\": 9.541996955871582, \"sigma_intercept_per_group\": 0.19916363060474396, \"sigma_obs\": 161.2209930419922, \"slope\": -0.08312004804611206, \"chain\": 2, \"draw\": 186}, {\"draws\": 586, \"mouse\": 7, \"mu_intercept_per_group\": 9.115047454833984, \"sigma_intercept_per_group\": 0.19916363060474396, \"sigma_obs\": 161.2209930419922, \"slope\": -0.08312004804611206, \"chain\": 2, \"draw\": 186}, {\"draws\": 587, \"mouse\": 0, \"mu_intercept_per_group\": 10.837059020996094, \"sigma_intercept_per_group\": 0.22315117716789246, \"sigma_obs\": 144.537353515625, \"slope\": -0.073937326669693, \"chain\": 2, \"draw\": 187}, {\"draws\": 587, \"mouse\": 1, \"mu_intercept_per_group\": 9.962626457214355, \"sigma_intercept_per_group\": 0.22315117716789246, \"sigma_obs\": 144.537353515625, \"slope\": -0.073937326669693, \"chain\": 2, \"draw\": 187}, {\"draws\": 587, \"mouse\": 2, \"mu_intercept_per_group\": 9.897481918334961, \"sigma_intercept_per_group\": 0.22315117716789246, \"sigma_obs\": 144.537353515625, \"slope\": -0.073937326669693, \"chain\": 2, \"draw\": 187}, {\"draws\": 587, \"mouse\": 3, \"mu_intercept_per_group\": 9.025861740112305, \"sigma_intercept_per_group\": 0.22315117716789246, \"sigma_obs\": 144.537353515625, \"slope\": -0.073937326669693, \"chain\": 2, \"draw\": 187}, {\"draws\": 587, \"mouse\": 4, \"mu_intercept_per_group\": 9.25863265991211, \"sigma_intercept_per_group\": 0.22315117716789246, \"sigma_obs\": 144.537353515625, \"slope\": -0.073937326669693, \"chain\": 2, \"draw\": 187}, {\"draws\": 587, \"mouse\": 5, \"mu_intercept_per_group\": 8.564945220947266, \"sigma_intercept_per_group\": 0.22315117716789246, \"sigma_obs\": 144.537353515625, \"slope\": -0.073937326669693, \"chain\": 2, \"draw\": 187}, {\"draws\": 587, \"mouse\": 6, \"mu_intercept_per_group\": 7.871159553527832, \"sigma_intercept_per_group\": 0.22315117716789246, \"sigma_obs\": 144.537353515625, \"slope\": -0.073937326669693, \"chain\": 2, \"draw\": 187}, {\"draws\": 587, \"mouse\": 7, \"mu_intercept_per_group\": 7.483599662780762, \"sigma_intercept_per_group\": 0.22315117716789246, \"sigma_obs\": 144.537353515625, \"slope\": -0.073937326669693, \"chain\": 2, \"draw\": 187}, {\"draws\": 588, \"mouse\": 0, \"mu_intercept_per_group\": 10.139188766479492, \"sigma_intercept_per_group\": 0.22628958523273468, \"sigma_obs\": 145.5918731689453, \"slope\": -0.07375641167163849, \"chain\": 2, \"draw\": 188}, {\"draws\": 588, \"mouse\": 1, \"mu_intercept_per_group\": 10.279836654663086, \"sigma_intercept_per_group\": 0.22628958523273468, \"sigma_obs\": 145.5918731689453, \"slope\": -0.07375641167163849, \"chain\": 2, \"draw\": 188}, {\"draws\": 588, \"mouse\": 2, \"mu_intercept_per_group\": 9.884507179260254, \"sigma_intercept_per_group\": 0.22628958523273468, \"sigma_obs\": 145.5918731689453, \"slope\": -0.07375641167163849, \"chain\": 2, \"draw\": 188}, {\"draws\": 588, \"mouse\": 3, \"mu_intercept_per_group\": 8.933978080749512, \"sigma_intercept_per_group\": 0.22628958523273468, \"sigma_obs\": 145.5918731689453, \"slope\": -0.07375641167163849, \"chain\": 2, \"draw\": 188}, {\"draws\": 588, \"mouse\": 4, \"mu_intercept_per_group\": 9.033592224121094, \"sigma_intercept_per_group\": 0.22628958523273468, \"sigma_obs\": 145.5918731689453, \"slope\": -0.07375641167163849, \"chain\": 2, \"draw\": 188}, {\"draws\": 588, \"mouse\": 5, \"mu_intercept_per_group\": 8.657622337341309, \"sigma_intercept_per_group\": 0.22628958523273468, \"sigma_obs\": 145.5918731689453, \"slope\": -0.07375641167163849, \"chain\": 2, \"draw\": 188}, {\"draws\": 588, \"mouse\": 6, \"mu_intercept_per_group\": 7.560458183288574, \"sigma_intercept_per_group\": 0.22628958523273468, \"sigma_obs\": 145.5918731689453, \"slope\": -0.07375641167163849, \"chain\": 2, \"draw\": 188}, {\"draws\": 588, \"mouse\": 7, \"mu_intercept_per_group\": 7.554704666137695, \"sigma_intercept_per_group\": 0.22628958523273468, \"sigma_obs\": 145.5918731689453, \"slope\": -0.07375641167163849, \"chain\": 2, \"draw\": 188}, {\"draws\": 589, \"mouse\": 0, \"mu_intercept_per_group\": 10.695068359375, \"sigma_intercept_per_group\": 0.23445585370063782, \"sigma_obs\": 152.94180297851562, \"slope\": -0.05946977436542511, \"chain\": 2, \"draw\": 189}, {\"draws\": 589, \"mouse\": 1, \"mu_intercept_per_group\": 9.855642318725586, \"sigma_intercept_per_group\": 0.23445585370063782, \"sigma_obs\": 152.94180297851562, \"slope\": -0.05946977436542511, \"chain\": 2, \"draw\": 189}, {\"draws\": 589, \"mouse\": 2, \"mu_intercept_per_group\": 9.684082984924316, \"sigma_intercept_per_group\": 0.23445585370063782, \"sigma_obs\": 152.94180297851562, \"slope\": -0.05946977436542511, \"chain\": 2, \"draw\": 189}, {\"draws\": 589, \"mouse\": 3, \"mu_intercept_per_group\": 9.075660705566406, \"sigma_intercept_per_group\": 0.23445585370063782, \"sigma_obs\": 152.94180297851562, \"slope\": -0.05946977436542511, \"chain\": 2, \"draw\": 189}, {\"draws\": 589, \"mouse\": 4, \"mu_intercept_per_group\": 8.934730529785156, \"sigma_intercept_per_group\": 0.23445585370063782, \"sigma_obs\": 152.94180297851562, \"slope\": -0.05946977436542511, \"chain\": 2, \"draw\": 189}, {\"draws\": 589, \"mouse\": 5, \"mu_intercept_per_group\": 8.62964153289795, \"sigma_intercept_per_group\": 0.23445585370063782, \"sigma_obs\": 152.94180297851562, \"slope\": -0.05946977436542511, \"chain\": 2, \"draw\": 189}, {\"draws\": 589, \"mouse\": 6, \"mu_intercept_per_group\": 7.510865688323975, \"sigma_intercept_per_group\": 0.23445585370063782, \"sigma_obs\": 152.94180297851562, \"slope\": -0.05946977436542511, \"chain\": 2, \"draw\": 189}, {\"draws\": 589, \"mouse\": 7, \"mu_intercept_per_group\": 7.683887481689453, \"sigma_intercept_per_group\": 0.23445585370063782, \"sigma_obs\": 152.94180297851562, \"slope\": -0.05946977436542511, \"chain\": 2, \"draw\": 189}, {\"draws\": 590, \"mouse\": 0, \"mu_intercept_per_group\": 11.175077438354492, \"sigma_intercept_per_group\": 0.2209552824497223, \"sigma_obs\": 153.28311157226562, \"slope\": -0.06424544006586075, \"chain\": 2, \"draw\": 190}, {\"draws\": 590, \"mouse\": 1, \"mu_intercept_per_group\": 10.432770729064941, \"sigma_intercept_per_group\": 0.2209552824497223, \"sigma_obs\": 153.28311157226562, \"slope\": -0.06424544006586075, \"chain\": 2, \"draw\": 190}, {\"draws\": 590, \"mouse\": 2, \"mu_intercept_per_group\": 10.261001586914062, \"sigma_intercept_per_group\": 0.2209552824497223, \"sigma_obs\": 153.28311157226562, \"slope\": -0.06424544006586075, \"chain\": 2, \"draw\": 190}, {\"draws\": 590, \"mouse\": 3, \"mu_intercept_per_group\": 9.809611320495605, \"sigma_intercept_per_group\": 0.2209552824497223, \"sigma_obs\": 153.28311157226562, \"slope\": -0.06424544006586075, \"chain\": 2, \"draw\": 190}, {\"draws\": 590, \"mouse\": 4, \"mu_intercept_per_group\": 9.356634140014648, \"sigma_intercept_per_group\": 0.2209552824497223, \"sigma_obs\": 153.28311157226562, \"slope\": -0.06424544006586075, \"chain\": 2, \"draw\": 190}, {\"draws\": 590, \"mouse\": 5, \"mu_intercept_per_group\": 8.61705493927002, \"sigma_intercept_per_group\": 0.2209552824497223, \"sigma_obs\": 153.28311157226562, \"slope\": -0.06424544006586075, \"chain\": 2, \"draw\": 190}, {\"draws\": 590, \"mouse\": 6, \"mu_intercept_per_group\": 8.293679237365723, \"sigma_intercept_per_group\": 0.2209552824497223, \"sigma_obs\": 153.28311157226562, \"slope\": -0.06424544006586075, \"chain\": 2, \"draw\": 190}, {\"draws\": 590, \"mouse\": 7, \"mu_intercept_per_group\": 7.528229236602783, \"sigma_intercept_per_group\": 0.2209552824497223, \"sigma_obs\": 153.28311157226562, \"slope\": -0.06424544006586075, \"chain\": 2, \"draw\": 190}, {\"draws\": 591, \"mouse\": 0, \"mu_intercept_per_group\": 11.112967491149902, \"sigma_intercept_per_group\": 0.22328904271125793, \"sigma_obs\": 153.29408264160156, \"slope\": -0.0642000287771225, \"chain\": 2, \"draw\": 191}, {\"draws\": 591, \"mouse\": 1, \"mu_intercept_per_group\": 10.53809642791748, \"sigma_intercept_per_group\": 0.22328904271125793, \"sigma_obs\": 153.29408264160156, \"slope\": -0.0642000287771225, \"chain\": 2, \"draw\": 191}, {\"draws\": 591, \"mouse\": 2, \"mu_intercept_per_group\": 10.272704124450684, \"sigma_intercept_per_group\": 0.22328904271125793, \"sigma_obs\": 153.29408264160156, \"slope\": -0.0642000287771225, \"chain\": 2, \"draw\": 191}, {\"draws\": 591, \"mouse\": 3, \"mu_intercept_per_group\": 9.764004707336426, \"sigma_intercept_per_group\": 0.22328904271125793, \"sigma_obs\": 153.29408264160156, \"slope\": -0.0642000287771225, \"chain\": 2, \"draw\": 191}, {\"draws\": 591, \"mouse\": 4, \"mu_intercept_per_group\": 9.325695991516113, \"sigma_intercept_per_group\": 0.22328904271125793, \"sigma_obs\": 153.29408264160156, \"slope\": -0.0642000287771225, \"chain\": 2, \"draw\": 191}, {\"draws\": 591, \"mouse\": 5, \"mu_intercept_per_group\": 8.666635513305664, \"sigma_intercept_per_group\": 0.22328904271125793, \"sigma_obs\": 153.29408264160156, \"slope\": -0.0642000287771225, \"chain\": 2, \"draw\": 191}, {\"draws\": 591, \"mouse\": 6, \"mu_intercept_per_group\": 8.303585052490234, \"sigma_intercept_per_group\": 0.22328904271125793, \"sigma_obs\": 153.29408264160156, \"slope\": -0.0642000287771225, \"chain\": 2, \"draw\": 191}, {\"draws\": 591, \"mouse\": 7, \"mu_intercept_per_group\": 7.65492582321167, \"sigma_intercept_per_group\": 0.22328904271125793, \"sigma_obs\": 153.29408264160156, \"slope\": -0.0642000287771225, \"chain\": 2, \"draw\": 191}, {\"draws\": 592, \"mouse\": 0, \"mu_intercept_per_group\": 13.3847017288208, \"sigma_intercept_per_group\": 0.1796863079071045, \"sigma_obs\": 164.26687622070312, \"slope\": -0.042731527239084244, \"chain\": 2, \"draw\": 192}, {\"draws\": 592, \"mouse\": 1, \"mu_intercept_per_group\": 13.208111763000488, \"sigma_intercept_per_group\": 0.1796863079071045, \"sigma_obs\": 164.26687622070312, \"slope\": -0.042731527239084244, \"chain\": 2, \"draw\": 192}, {\"draws\": 592, \"mouse\": 2, \"mu_intercept_per_group\": 12.742318153381348, \"sigma_intercept_per_group\": 0.1796863079071045, \"sigma_obs\": 164.26687622070312, \"slope\": -0.042731527239084244, \"chain\": 2, \"draw\": 192}, {\"draws\": 592, \"mouse\": 3, \"mu_intercept_per_group\": 11.987674713134766, \"sigma_intercept_per_group\": 0.1796863079071045, \"sigma_obs\": 164.26687622070312, \"slope\": -0.042731527239084244, \"chain\": 2, \"draw\": 192}, {\"draws\": 592, \"mouse\": 4, \"mu_intercept_per_group\": 11.789298057556152, \"sigma_intercept_per_group\": 0.1796863079071045, \"sigma_obs\": 164.26687622070312, \"slope\": -0.042731527239084244, \"chain\": 2, \"draw\": 192}, {\"draws\": 592, \"mouse\": 5, \"mu_intercept_per_group\": 10.788459777832031, \"sigma_intercept_per_group\": 0.1796863079071045, \"sigma_obs\": 164.26687622070312, \"slope\": -0.042731527239084244, \"chain\": 2, \"draw\": 192}, {\"draws\": 592, \"mouse\": 6, \"mu_intercept_per_group\": 10.66468620300293, \"sigma_intercept_per_group\": 0.1796863079071045, \"sigma_obs\": 164.26687622070312, \"slope\": -0.042731527239084244, \"chain\": 2, \"draw\": 192}, {\"draws\": 592, \"mouse\": 7, \"mu_intercept_per_group\": 9.824830055236816, \"sigma_intercept_per_group\": 0.1796863079071045, \"sigma_obs\": 164.26687622070312, \"slope\": -0.042731527239084244, \"chain\": 2, \"draw\": 192}, {\"draws\": 593, \"mouse\": 0, \"mu_intercept_per_group\": 13.723501205444336, \"sigma_intercept_per_group\": 0.18258023262023926, \"sigma_obs\": 162.70465087890625, \"slope\": -0.04413231834769249, \"chain\": 2, \"draw\": 193}, {\"draws\": 593, \"mouse\": 1, \"mu_intercept_per_group\": 12.857938766479492, \"sigma_intercept_per_group\": 0.18258023262023926, \"sigma_obs\": 162.70465087890625, \"slope\": -0.04413231834769249, \"chain\": 2, \"draw\": 193}, {\"draws\": 593, \"mouse\": 2, \"mu_intercept_per_group\": 12.690993309020996, \"sigma_intercept_per_group\": 0.18258023262023926, \"sigma_obs\": 162.70465087890625, \"slope\": -0.04413231834769249, \"chain\": 2, \"draw\": 193}, {\"draws\": 593, \"mouse\": 3, \"mu_intercept_per_group\": 11.585033416748047, \"sigma_intercept_per_group\": 0.18258023262023926, \"sigma_obs\": 162.70465087890625, \"slope\": -0.04413231834769249, \"chain\": 2, \"draw\": 193}, {\"draws\": 593, \"mouse\": 4, \"mu_intercept_per_group\": 11.53503131866455, \"sigma_intercept_per_group\": 0.18258023262023926, \"sigma_obs\": 162.70465087890625, \"slope\": -0.04413231834769249, \"chain\": 2, \"draw\": 193}, {\"draws\": 593, \"mouse\": 5, \"mu_intercept_per_group\": 11.217619895935059, \"sigma_intercept_per_group\": 0.18258023262023926, \"sigma_obs\": 162.70465087890625, \"slope\": -0.04413231834769249, \"chain\": 2, \"draw\": 193}, {\"draws\": 593, \"mouse\": 6, \"mu_intercept_per_group\": 10.132906913757324, \"sigma_intercept_per_group\": 0.18258023262023926, \"sigma_obs\": 162.70465087890625, \"slope\": -0.04413231834769249, \"chain\": 2, \"draw\": 193}, {\"draws\": 593, \"mouse\": 7, \"mu_intercept_per_group\": 9.827667236328125, \"sigma_intercept_per_group\": 0.18258023262023926, \"sigma_obs\": 162.70465087890625, \"slope\": -0.04413231834769249, \"chain\": 2, \"draw\": 193}, {\"draws\": 594, \"mouse\": 0, \"mu_intercept_per_group\": 11.557750701904297, \"sigma_intercept_per_group\": 0.2079615592956543, \"sigma_obs\": 162.3954620361328, \"slope\": -0.04847292974591255, \"chain\": 2, \"draw\": 194}, {\"draws\": 594, \"mouse\": 1, \"mu_intercept_per_group\": 11.558801651000977, \"sigma_intercept_per_group\": 0.2079615592956543, \"sigma_obs\": 162.3954620361328, \"slope\": -0.04847292974591255, \"chain\": 2, \"draw\": 194}, {\"draws\": 594, \"mouse\": 2, \"mu_intercept_per_group\": 11.143390655517578, \"sigma_intercept_per_group\": 0.2079615592956543, \"sigma_obs\": 162.3954620361328, \"slope\": -0.04847292974591255, \"chain\": 2, \"draw\": 194}, {\"draws\": 594, \"mouse\": 3, \"mu_intercept_per_group\": 10.404725074768066, \"sigma_intercept_per_group\": 0.2079615592956543, \"sigma_obs\": 162.3954620361328, \"slope\": -0.04847292974591255, \"chain\": 2, \"draw\": 194}, {\"draws\": 594, \"mouse\": 4, \"mu_intercept_per_group\": 9.756854057312012, \"sigma_intercept_per_group\": 0.2079615592956543, \"sigma_obs\": 162.3954620361328, \"slope\": -0.04847292974591255, \"chain\": 2, \"draw\": 194}, {\"draws\": 594, \"mouse\": 5, \"mu_intercept_per_group\": 9.355498313903809, \"sigma_intercept_per_group\": 0.2079615592956543, \"sigma_obs\": 162.3954620361328, \"slope\": -0.04847292974591255, \"chain\": 2, \"draw\": 194}, {\"draws\": 594, \"mouse\": 6, \"mu_intercept_per_group\": 9.00258731842041, \"sigma_intercept_per_group\": 0.2079615592956543, \"sigma_obs\": 162.3954620361328, \"slope\": -0.04847292974591255, \"chain\": 2, \"draw\": 194}, {\"draws\": 594, \"mouse\": 7, \"mu_intercept_per_group\": 8.786338806152344, \"sigma_intercept_per_group\": 0.2079615592956543, \"sigma_obs\": 162.3954620361328, \"slope\": -0.04847292974591255, \"chain\": 2, \"draw\": 194}, {\"draws\": 595, \"mouse\": 0, \"mu_intercept_per_group\": 11.275032997131348, \"sigma_intercept_per_group\": 0.21416136622428894, \"sigma_obs\": 162.65972900390625, \"slope\": -0.04886694997549057, \"chain\": 2, \"draw\": 195}, {\"draws\": 595, \"mouse\": 1, \"mu_intercept_per_group\": 10.878833770751953, \"sigma_intercept_per_group\": 0.21416136622428894, \"sigma_obs\": 162.65972900390625, \"slope\": -0.04886694997549057, \"chain\": 2, \"draw\": 195}, {\"draws\": 595, \"mouse\": 2, \"mu_intercept_per_group\": 11.179069519042969, \"sigma_intercept_per_group\": 0.21416136622428894, \"sigma_obs\": 162.65972900390625, \"slope\": -0.04886694997549057, \"chain\": 2, \"draw\": 195}, {\"draws\": 595, \"mouse\": 3, \"mu_intercept_per_group\": 10.045914649963379, \"sigma_intercept_per_group\": 0.21416136622428894, \"sigma_obs\": 162.65972900390625, \"slope\": -0.04886694997549057, \"chain\": 2, \"draw\": 195}, {\"draws\": 595, \"mouse\": 4, \"mu_intercept_per_group\": 9.916609764099121, \"sigma_intercept_per_group\": 0.21416136622428894, \"sigma_obs\": 162.65972900390625, \"slope\": -0.04886694997549057, \"chain\": 2, \"draw\": 195}, {\"draws\": 595, \"mouse\": 5, \"mu_intercept_per_group\": 9.464558601379395, \"sigma_intercept_per_group\": 0.21416136622428894, \"sigma_obs\": 162.65972900390625, \"slope\": -0.04886694997549057, \"chain\": 2, \"draw\": 195}, {\"draws\": 595, \"mouse\": 6, \"mu_intercept_per_group\": 8.573637962341309, \"sigma_intercept_per_group\": 0.21416136622428894, \"sigma_obs\": 162.65972900390625, \"slope\": -0.04886694997549057, \"chain\": 2, \"draw\": 195}, {\"draws\": 595, \"mouse\": 7, \"mu_intercept_per_group\": 7.925633907318115, \"sigma_intercept_per_group\": 0.21416136622428894, \"sigma_obs\": 162.65972900390625, \"slope\": -0.04886694997549057, \"chain\": 2, \"draw\": 195}, {\"draws\": 596, \"mouse\": 0, \"mu_intercept_per_group\": 11.550525665283203, \"sigma_intercept_per_group\": 0.21336442232131958, \"sigma_obs\": 161.79991149902344, \"slope\": -0.048539284616708755, \"chain\": 2, \"draw\": 196}, {\"draws\": 596, \"mouse\": 1, \"mu_intercept_per_group\": 11.106178283691406, \"sigma_intercept_per_group\": 0.21336442232131958, \"sigma_obs\": 161.79991149902344, \"slope\": -0.048539284616708755, \"chain\": 2, \"draw\": 196}, {\"draws\": 596, \"mouse\": 2, \"mu_intercept_per_group\": 10.224672317504883, \"sigma_intercept_per_group\": 0.21336442232131958, \"sigma_obs\": 161.79991149902344, \"slope\": -0.048539284616708755, \"chain\": 2, \"draw\": 196}, {\"draws\": 596, \"mouse\": 3, \"mu_intercept_per_group\": 10.09816837310791, \"sigma_intercept_per_group\": 0.21336442232131958, \"sigma_obs\": 161.79991149902344, \"slope\": -0.048539284616708755, \"chain\": 2, \"draw\": 196}, {\"draws\": 596, \"mouse\": 4, \"mu_intercept_per_group\": 9.712547302246094, \"sigma_intercept_per_group\": 0.21336442232131958, \"sigma_obs\": 161.79991149902344, \"slope\": -0.048539284616708755, \"chain\": 2, \"draw\": 196}, {\"draws\": 596, \"mouse\": 5, \"mu_intercept_per_group\": 9.208794593811035, \"sigma_intercept_per_group\": 0.21336442232131958, \"sigma_obs\": 161.79991149902344, \"slope\": -0.048539284616708755, \"chain\": 2, \"draw\": 196}, {\"draws\": 596, \"mouse\": 6, \"mu_intercept_per_group\": 8.766080856323242, \"sigma_intercept_per_group\": 0.21336442232131958, \"sigma_obs\": 161.79991149902344, \"slope\": -0.048539284616708755, \"chain\": 2, \"draw\": 196}, {\"draws\": 596, \"mouse\": 7, \"mu_intercept_per_group\": 8.622091293334961, \"sigma_intercept_per_group\": 0.21336442232131958, \"sigma_obs\": 161.79991149902344, \"slope\": -0.048539284616708755, \"chain\": 2, \"draw\": 196}, {\"draws\": 597, \"mouse\": 0, \"mu_intercept_per_group\": 9.79592514038086, \"sigma_intercept_per_group\": 0.2445008009672165, \"sigma_obs\": 153.91732788085938, \"slope\": -0.04911205172538757, \"chain\": 2, \"draw\": 197}, {\"draws\": 597, \"mouse\": 1, \"mu_intercept_per_group\": 9.43266773223877, \"sigma_intercept_per_group\": 0.2445008009672165, \"sigma_obs\": 153.91732788085938, \"slope\": -0.04911205172538757, \"chain\": 2, \"draw\": 197}, {\"draws\": 597, \"mouse\": 2, \"mu_intercept_per_group\": 9.2302885055542, \"sigma_intercept_per_group\": 0.2445008009672165, \"sigma_obs\": 153.91732788085938, \"slope\": -0.04911205172538757, \"chain\": 2, \"draw\": 197}, {\"draws\": 597, \"mouse\": 3, \"mu_intercept_per_group\": 8.691308975219727, \"sigma_intercept_per_group\": 0.2445008009672165, \"sigma_obs\": 153.91732788085938, \"slope\": -0.04911205172538757, \"chain\": 2, \"draw\": 197}, {\"draws\": 597, \"mouse\": 4, \"mu_intercept_per_group\": 8.681299209594727, \"sigma_intercept_per_group\": 0.2445008009672165, \"sigma_obs\": 153.91732788085938, \"slope\": -0.04911205172538757, \"chain\": 2, \"draw\": 197}, {\"draws\": 597, \"mouse\": 5, \"mu_intercept_per_group\": 8.106492042541504, \"sigma_intercept_per_group\": 0.2445008009672165, \"sigma_obs\": 153.91732788085938, \"slope\": -0.04911205172538757, \"chain\": 2, \"draw\": 197}, {\"draws\": 597, \"mouse\": 6, \"mu_intercept_per_group\": 7.7226481437683105, \"sigma_intercept_per_group\": 0.2445008009672165, \"sigma_obs\": 153.91732788085938, \"slope\": -0.04911205172538757, \"chain\": 2, \"draw\": 197}, {\"draws\": 597, \"mouse\": 7, \"mu_intercept_per_group\": 6.819150924682617, \"sigma_intercept_per_group\": 0.2445008009672165, \"sigma_obs\": 153.91732788085938, \"slope\": -0.04911205172538757, \"chain\": 2, \"draw\": 197}, {\"draws\": 598, \"mouse\": 0, \"mu_intercept_per_group\": 10.100651741027832, \"sigma_intercept_per_group\": 0.2392650842666626, \"sigma_obs\": 155.014404296875, \"slope\": -0.053909674286842346, \"chain\": 2, \"draw\": 198}, {\"draws\": 598, \"mouse\": 1, \"mu_intercept_per_group\": 10.032960891723633, \"sigma_intercept_per_group\": 0.2392650842666626, \"sigma_obs\": 155.014404296875, \"slope\": -0.053909674286842346, \"chain\": 2, \"draw\": 198}, {\"draws\": 598, \"mouse\": 2, \"mu_intercept_per_group\": 9.581178665161133, \"sigma_intercept_per_group\": 0.2392650842666626, \"sigma_obs\": 155.014404296875, \"slope\": -0.053909674286842346, \"chain\": 2, \"draw\": 198}, {\"draws\": 598, \"mouse\": 3, \"mu_intercept_per_group\": 8.893853187561035, \"sigma_intercept_per_group\": 0.2392650842666626, \"sigma_obs\": 155.014404296875, \"slope\": -0.053909674286842346, \"chain\": 2, \"draw\": 198}, {\"draws\": 598, \"mouse\": 4, \"mu_intercept_per_group\": 8.495819091796875, \"sigma_intercept_per_group\": 0.2392650842666626, \"sigma_obs\": 155.014404296875, \"slope\": -0.053909674286842346, \"chain\": 2, \"draw\": 198}, {\"draws\": 598, \"mouse\": 5, \"mu_intercept_per_group\": 8.051523208618164, \"sigma_intercept_per_group\": 0.2392650842666626, \"sigma_obs\": 155.014404296875, \"slope\": -0.053909674286842346, \"chain\": 2, \"draw\": 198}, {\"draws\": 598, \"mouse\": 6, \"mu_intercept_per_group\": 7.384236812591553, \"sigma_intercept_per_group\": 0.2392650842666626, \"sigma_obs\": 155.014404296875, \"slope\": -0.053909674286842346, \"chain\": 2, \"draw\": 198}, {\"draws\": 598, \"mouse\": 7, \"mu_intercept_per_group\": 7.529572486877441, \"sigma_intercept_per_group\": 0.2392650842666626, \"sigma_obs\": 155.014404296875, \"slope\": -0.053909674286842346, \"chain\": 2, \"draw\": 198}, {\"draws\": 599, \"mouse\": 0, \"mu_intercept_per_group\": 10.286221504211426, \"sigma_intercept_per_group\": 0.23785851895809174, \"sigma_obs\": 155.52178955078125, \"slope\": -0.050962913781404495, \"chain\": 2, \"draw\": 199}, {\"draws\": 599, \"mouse\": 1, \"mu_intercept_per_group\": 9.581782341003418, \"sigma_intercept_per_group\": 0.23785851895809174, \"sigma_obs\": 155.52178955078125, \"slope\": -0.050962913781404495, \"chain\": 2, \"draw\": 199}, {\"draws\": 599, \"mouse\": 2, \"mu_intercept_per_group\": 9.531859397888184, \"sigma_intercept_per_group\": 0.23785851895809174, \"sigma_obs\": 155.52178955078125, \"slope\": -0.050962913781404495, \"chain\": 2, \"draw\": 199}, {\"draws\": 599, \"mouse\": 3, \"mu_intercept_per_group\": 9.106033325195312, \"sigma_intercept_per_group\": 0.23785851895809174, \"sigma_obs\": 155.52178955078125, \"slope\": -0.050962913781404495, \"chain\": 2, \"draw\": 199}, {\"draws\": 599, \"mouse\": 4, \"mu_intercept_per_group\": 8.783105850219727, \"sigma_intercept_per_group\": 0.23785851895809174, \"sigma_obs\": 155.52178955078125, \"slope\": -0.050962913781404495, \"chain\": 2, \"draw\": 199}, {\"draws\": 599, \"mouse\": 5, \"mu_intercept_per_group\": 8.161739349365234, \"sigma_intercept_per_group\": 0.23785851895809174, \"sigma_obs\": 155.52178955078125, \"slope\": -0.050962913781404495, \"chain\": 2, \"draw\": 199}, {\"draws\": 599, \"mouse\": 6, \"mu_intercept_per_group\": 7.50389289855957, \"sigma_intercept_per_group\": 0.23785851895809174, \"sigma_obs\": 155.52178955078125, \"slope\": -0.050962913781404495, \"chain\": 2, \"draw\": 199}, {\"draws\": 599, \"mouse\": 7, \"mu_intercept_per_group\": 7.316534042358398, \"sigma_intercept_per_group\": 0.23785851895809174, \"sigma_obs\": 155.52178955078125, \"slope\": -0.050962913781404495, \"chain\": 2, \"draw\": 199}, {\"draws\": 600, \"mouse\": 0, \"mu_intercept_per_group\": 9.567191123962402, \"sigma_intercept_per_group\": 0.25275918841362, \"sigma_obs\": 156.54055786132812, \"slope\": -0.058683477342128754, \"chain\": 3, \"draw\": 0}, {\"draws\": 600, \"mouse\": 1, \"mu_intercept_per_group\": 9.22066593170166, \"sigma_intercept_per_group\": 0.25275918841362, \"sigma_obs\": 156.54055786132812, \"slope\": -0.058683477342128754, \"chain\": 3, \"draw\": 0}, {\"draws\": 600, \"mouse\": 2, \"mu_intercept_per_group\": 8.81181812286377, \"sigma_intercept_per_group\": 0.25275918841362, \"sigma_obs\": 156.54055786132812, \"slope\": -0.058683477342128754, \"chain\": 3, \"draw\": 0}, {\"draws\": 600, \"mouse\": 3, \"mu_intercept_per_group\": 8.50802230834961, \"sigma_intercept_per_group\": 0.25275918841362, \"sigma_obs\": 156.54055786132812, \"slope\": -0.058683477342128754, \"chain\": 3, \"draw\": 0}, {\"draws\": 600, \"mouse\": 4, \"mu_intercept_per_group\": 8.331591606140137, \"sigma_intercept_per_group\": 0.25275918841362, \"sigma_obs\": 156.54055786132812, \"slope\": -0.058683477342128754, \"chain\": 3, \"draw\": 0}, {\"draws\": 600, \"mouse\": 5, \"mu_intercept_per_group\": 7.91056489944458, \"sigma_intercept_per_group\": 0.25275918841362, \"sigma_obs\": 156.54055786132812, \"slope\": -0.058683477342128754, \"chain\": 3, \"draw\": 0}, {\"draws\": 600, \"mouse\": 6, \"mu_intercept_per_group\": 6.946476459503174, \"sigma_intercept_per_group\": 0.25275918841362, \"sigma_obs\": 156.54055786132812, \"slope\": -0.058683477342128754, \"chain\": 3, \"draw\": 0}, {\"draws\": 600, \"mouse\": 7, \"mu_intercept_per_group\": 6.989222526550293, \"sigma_intercept_per_group\": 0.25275918841362, \"sigma_obs\": 156.54055786132812, \"slope\": -0.058683477342128754, \"chain\": 3, \"draw\": 0}, {\"draws\": 601, \"mouse\": 0, \"mu_intercept_per_group\": 9.747658729553223, \"sigma_intercept_per_group\": 0.2510111629962921, \"sigma_obs\": 156.64898681640625, \"slope\": -0.05807137489318848, \"chain\": 3, \"draw\": 1}, {\"draws\": 601, \"mouse\": 1, \"mu_intercept_per_group\": 9.512351989746094, \"sigma_intercept_per_group\": 0.2510111629962921, \"sigma_obs\": 156.64898681640625, \"slope\": -0.05807137489318848, \"chain\": 3, \"draw\": 1}, {\"draws\": 601, \"mouse\": 2, \"mu_intercept_per_group\": 8.95167064666748, \"sigma_intercept_per_group\": 0.2510111629962921, \"sigma_obs\": 156.64898681640625, \"slope\": -0.05807137489318848, \"chain\": 3, \"draw\": 1}, {\"draws\": 601, \"mouse\": 3, \"mu_intercept_per_group\": 8.461575508117676, \"sigma_intercept_per_group\": 0.2510111629962921, \"sigma_obs\": 156.64898681640625, \"slope\": -0.05807137489318848, \"chain\": 3, \"draw\": 1}, {\"draws\": 601, \"mouse\": 4, \"mu_intercept_per_group\": 8.599263191223145, \"sigma_intercept_per_group\": 0.2510111629962921, \"sigma_obs\": 156.64898681640625, \"slope\": -0.05807137489318848, \"chain\": 3, \"draw\": 1}, {\"draws\": 601, \"mouse\": 5, \"mu_intercept_per_group\": 7.902021408081055, \"sigma_intercept_per_group\": 0.2510111629962921, \"sigma_obs\": 156.64898681640625, \"slope\": -0.05807137489318848, \"chain\": 3, \"draw\": 1}, {\"draws\": 601, \"mouse\": 6, \"mu_intercept_per_group\": 6.792611598968506, \"sigma_intercept_per_group\": 0.2510111629962921, \"sigma_obs\": 156.64898681640625, \"slope\": -0.05807137489318848, \"chain\": 3, \"draw\": 1}, {\"draws\": 601, \"mouse\": 7, \"mu_intercept_per_group\": 7.17497444152832, \"sigma_intercept_per_group\": 0.2510111629962921, \"sigma_obs\": 156.64898681640625, \"slope\": -0.05807137489318848, \"chain\": 3, \"draw\": 1}, {\"draws\": 602, \"mouse\": 0, \"mu_intercept_per_group\": 9.564618110656738, \"sigma_intercept_per_group\": 0.25361377000808716, \"sigma_obs\": 157.14822387695312, \"slope\": -0.05629260092973709, \"chain\": 3, \"draw\": 2}, {\"draws\": 602, \"mouse\": 1, \"mu_intercept_per_group\": 9.11160945892334, \"sigma_intercept_per_group\": 0.25361377000808716, \"sigma_obs\": 157.14822387695312, \"slope\": -0.05629260092973709, \"chain\": 3, \"draw\": 2}, {\"draws\": 602, \"mouse\": 2, \"mu_intercept_per_group\": 9.152937889099121, \"sigma_intercept_per_group\": 0.25361377000808716, \"sigma_obs\": 157.14822387695312, \"slope\": -0.05629260092973709, \"chain\": 3, \"draw\": 2}, {\"draws\": 602, \"mouse\": 3, \"mu_intercept_per_group\": 8.632678985595703, \"sigma_intercept_per_group\": 0.25361377000808716, \"sigma_obs\": 157.14822387695312, \"slope\": -0.05629260092973709, \"chain\": 3, \"draw\": 2}, {\"draws\": 602, \"mouse\": 4, \"mu_intercept_per_group\": 8.180998802185059, \"sigma_intercept_per_group\": 0.25361377000808716, \"sigma_obs\": 157.14822387695312, \"slope\": -0.05629260092973709, \"chain\": 3, \"draw\": 2}, {\"draws\": 602, \"mouse\": 5, \"mu_intercept_per_group\": 7.88315486907959, \"sigma_intercept_per_group\": 0.25361377000808716, \"sigma_obs\": 157.14822387695312, \"slope\": -0.05629260092973709, \"chain\": 3, \"draw\": 2}, {\"draws\": 602, \"mouse\": 6, \"mu_intercept_per_group\": 7.037496089935303, \"sigma_intercept_per_group\": 0.25361377000808716, \"sigma_obs\": 157.14822387695312, \"slope\": -0.05629260092973709, \"chain\": 3, \"draw\": 2}, {\"draws\": 602, \"mouse\": 7, \"mu_intercept_per_group\": 6.949531555175781, \"sigma_intercept_per_group\": 0.25361377000808716, \"sigma_obs\": 157.14822387695312, \"slope\": -0.05629260092973709, \"chain\": 3, \"draw\": 2}, {\"draws\": 603, \"mouse\": 0, \"mu_intercept_per_group\": 9.648880958557129, \"sigma_intercept_per_group\": 0.25717100501060486, \"sigma_obs\": 159.19036865234375, \"slope\": -0.05628903582692146, \"chain\": 3, \"draw\": 3}, {\"draws\": 603, \"mouse\": 1, \"mu_intercept_per_group\": 9.249129295349121, \"sigma_intercept_per_group\": 0.25717100501060486, \"sigma_obs\": 159.19036865234375, \"slope\": -0.05628903582692146, \"chain\": 3, \"draw\": 3}, {\"draws\": 603, \"mouse\": 2, \"mu_intercept_per_group\": 8.757478713989258, \"sigma_intercept_per_group\": 0.25717100501060486, \"sigma_obs\": 159.19036865234375, \"slope\": -0.05628903582692146, \"chain\": 3, \"draw\": 3}, {\"draws\": 603, \"mouse\": 3, \"mu_intercept_per_group\": 8.268332481384277, \"sigma_intercept_per_group\": 0.25717100501060486, \"sigma_obs\": 159.19036865234375, \"slope\": -0.05628903582692146, \"chain\": 3, \"draw\": 3}, {\"draws\": 603, \"mouse\": 4, \"mu_intercept_per_group\": 8.232489585876465, \"sigma_intercept_per_group\": 0.25717100501060486, \"sigma_obs\": 159.19036865234375, \"slope\": -0.05628903582692146, \"chain\": 3, \"draw\": 3}, {\"draws\": 603, \"mouse\": 5, \"mu_intercept_per_group\": 7.537532329559326, \"sigma_intercept_per_group\": 0.25717100501060486, \"sigma_obs\": 159.19036865234375, \"slope\": -0.05628903582692146, \"chain\": 3, \"draw\": 3}, {\"draws\": 603, \"mouse\": 6, \"mu_intercept_per_group\": 7.282715797424316, \"sigma_intercept_per_group\": 0.25717100501060486, \"sigma_obs\": 159.19036865234375, \"slope\": -0.05628903582692146, \"chain\": 3, \"draw\": 3}, {\"draws\": 603, \"mouse\": 7, \"mu_intercept_per_group\": 6.767194747924805, \"sigma_intercept_per_group\": 0.25717100501060486, \"sigma_obs\": 159.19036865234375, \"slope\": -0.05628903582692146, \"chain\": 3, \"draw\": 3}, {\"draws\": 604, \"mouse\": 0, \"mu_intercept_per_group\": 6.272380352020264, \"sigma_intercept_per_group\": 0.38917863368988037, \"sigma_obs\": 157.830322265625, \"slope\": -0.07547380775213242, \"chain\": 3, \"draw\": 4}, {\"draws\": 604, \"mouse\": 1, \"mu_intercept_per_group\": 6.040482044219971, \"sigma_intercept_per_group\": 0.38917863368988037, \"sigma_obs\": 157.830322265625, \"slope\": -0.07547380775213242, \"chain\": 3, \"draw\": 4}, {\"draws\": 604, \"mouse\": 2, \"mu_intercept_per_group\": 6.005608081817627, \"sigma_intercept_per_group\": 0.38917863368988037, \"sigma_obs\": 157.830322265625, \"slope\": -0.07547380775213242, \"chain\": 3, \"draw\": 4}, {\"draws\": 604, \"mouse\": 3, \"mu_intercept_per_group\": 5.549781799316406, \"sigma_intercept_per_group\": 0.38917863368988037, \"sigma_obs\": 157.830322265625, \"slope\": -0.07547380775213242, \"chain\": 3, \"draw\": 4}, {\"draws\": 604, \"mouse\": 4, \"mu_intercept_per_group\": 5.475306987762451, \"sigma_intercept_per_group\": 0.38917863368988037, \"sigma_obs\": 157.830322265625, \"slope\": -0.07547380775213242, \"chain\": 3, \"draw\": 4}, {\"draws\": 604, \"mouse\": 5, \"mu_intercept_per_group\": 5.130631923675537, \"sigma_intercept_per_group\": 0.38917863368988037, \"sigma_obs\": 157.830322265625, \"slope\": -0.07547380775213242, \"chain\": 3, \"draw\": 4}, {\"draws\": 604, \"mouse\": 6, \"mu_intercept_per_group\": 4.719905376434326, \"sigma_intercept_per_group\": 0.38917863368988037, \"sigma_obs\": 157.830322265625, \"slope\": -0.07547380775213242, \"chain\": 3, \"draw\": 4}, {\"draws\": 604, \"mouse\": 7, \"mu_intercept_per_group\": 4.668961524963379, \"sigma_intercept_per_group\": 0.38917863368988037, \"sigma_obs\": 157.830322265625, \"slope\": -0.07547380775213242, \"chain\": 3, \"draw\": 4}, {\"draws\": 605, \"mouse\": 0, \"mu_intercept_per_group\": 6.447900295257568, \"sigma_intercept_per_group\": 0.3842988610267639, \"sigma_obs\": 157.06057739257812, \"slope\": -0.075837142765522, \"chain\": 3, \"draw\": 5}, {\"draws\": 605, \"mouse\": 1, \"mu_intercept_per_group\": 6.150413990020752, \"sigma_intercept_per_group\": 0.3842988610267639, \"sigma_obs\": 157.06057739257812, \"slope\": -0.075837142765522, \"chain\": 3, \"draw\": 5}, {\"draws\": 605, \"mouse\": 2, \"mu_intercept_per_group\": 5.877790451049805, \"sigma_intercept_per_group\": 0.3842988610267639, \"sigma_obs\": 157.06057739257812, \"slope\": -0.075837142765522, \"chain\": 3, \"draw\": 5}, {\"draws\": 605, \"mouse\": 3, \"mu_intercept_per_group\": 5.669108867645264, \"sigma_intercept_per_group\": 0.3842988610267639, \"sigma_obs\": 157.06057739257812, \"slope\": -0.075837142765522, \"chain\": 3, \"draw\": 5}, {\"draws\": 605, \"mouse\": 4, \"mu_intercept_per_group\": 5.400075435638428, \"sigma_intercept_per_group\": 0.3842988610267639, \"sigma_obs\": 157.06057739257812, \"slope\": -0.075837142765522, \"chain\": 3, \"draw\": 5}, {\"draws\": 605, \"mouse\": 5, \"mu_intercept_per_group\": 5.094515800476074, \"sigma_intercept_per_group\": 0.3842988610267639, \"sigma_obs\": 157.06057739257812, \"slope\": -0.075837142765522, \"chain\": 3, \"draw\": 5}, {\"draws\": 605, \"mouse\": 6, \"mu_intercept_per_group\": 5.051644325256348, \"sigma_intercept_per_group\": 0.3842988610267639, \"sigma_obs\": 157.06057739257812, \"slope\": -0.075837142765522, \"chain\": 3, \"draw\": 5}, {\"draws\": 605, \"mouse\": 7, \"mu_intercept_per_group\": 4.497027397155762, \"sigma_intercept_per_group\": 0.3842988610267639, \"sigma_obs\": 157.06057739257812, \"slope\": -0.075837142765522, \"chain\": 3, \"draw\": 5}, {\"draws\": 606, \"mouse\": 0, \"mu_intercept_per_group\": 6.280979156494141, \"sigma_intercept_per_group\": 0.3885711431503296, \"sigma_obs\": 156.6283721923828, \"slope\": -0.07526784390211105, \"chain\": 3, \"draw\": 6}, {\"draws\": 606, \"mouse\": 1, \"mu_intercept_per_group\": 6.040756702423096, \"sigma_intercept_per_group\": 0.3885711431503296, \"sigma_obs\": 156.6283721923828, \"slope\": -0.07526784390211105, \"chain\": 3, \"draw\": 6}, {\"draws\": 606, \"mouse\": 2, \"mu_intercept_per_group\": 5.988601207733154, \"sigma_intercept_per_group\": 0.3885711431503296, \"sigma_obs\": 156.6283721923828, \"slope\": -0.07526784390211105, \"chain\": 3, \"draw\": 6}, {\"draws\": 606, \"mouse\": 3, \"mu_intercept_per_group\": 5.559675693511963, \"sigma_intercept_per_group\": 0.3885711431503296, \"sigma_obs\": 156.6283721923828, \"slope\": -0.07526784390211105, \"chain\": 3, \"draw\": 6}, {\"draws\": 606, \"mouse\": 4, \"mu_intercept_per_group\": 5.506591796875, \"sigma_intercept_per_group\": 0.3885711431503296, \"sigma_obs\": 156.6283721923828, \"slope\": -0.07526784390211105, \"chain\": 3, \"draw\": 6}, {\"draws\": 606, \"mouse\": 5, \"mu_intercept_per_group\": 5.134339809417725, \"sigma_intercept_per_group\": 0.3885711431503296, \"sigma_obs\": 156.6283721923828, \"slope\": -0.07526784390211105, \"chain\": 3, \"draw\": 6}, {\"draws\": 606, \"mouse\": 6, \"mu_intercept_per_group\": 4.626448631286621, \"sigma_intercept_per_group\": 0.3885711431503296, \"sigma_obs\": 156.6283721923828, \"slope\": -0.07526784390211105, \"chain\": 3, \"draw\": 6}, {\"draws\": 606, \"mouse\": 7, \"mu_intercept_per_group\": 4.59506368637085, \"sigma_intercept_per_group\": 0.3885711431503296, \"sigma_obs\": 156.6283721923828, \"slope\": -0.07526784390211105, \"chain\": 3, \"draw\": 6}, {\"draws\": 607, \"mouse\": 0, \"mu_intercept_per_group\": 6.326679229736328, \"sigma_intercept_per_group\": 0.38656166195869446, \"sigma_obs\": 155.25318908691406, \"slope\": -0.07455860823392868, \"chain\": 3, \"draw\": 7}, {\"draws\": 607, \"mouse\": 1, \"mu_intercept_per_group\": 6.085623264312744, \"sigma_intercept_per_group\": 0.38656166195869446, \"sigma_obs\": 155.25318908691406, \"slope\": -0.07455860823392868, \"chain\": 3, \"draw\": 7}, {\"draws\": 607, \"mouse\": 2, \"mu_intercept_per_group\": 6.00860071182251, \"sigma_intercept_per_group\": 0.38656166195869446, \"sigma_obs\": 155.25318908691406, \"slope\": -0.07455860823392868, \"chain\": 3, \"draw\": 7}, {\"draws\": 607, \"mouse\": 3, \"mu_intercept_per_group\": 5.636428356170654, \"sigma_intercept_per_group\": 0.38656166195869446, \"sigma_obs\": 155.25318908691406, \"slope\": -0.07455860823392868, \"chain\": 3, \"draw\": 7}, {\"draws\": 607, \"mouse\": 4, \"mu_intercept_per_group\": 5.422805309295654, \"sigma_intercept_per_group\": 0.38656166195869446, \"sigma_obs\": 155.25318908691406, \"slope\": -0.07455860823392868, \"chain\": 3, \"draw\": 7}, {\"draws\": 607, \"mouse\": 5, \"mu_intercept_per_group\": 5.140575885772705, \"sigma_intercept_per_group\": 0.38656166195869446, \"sigma_obs\": 155.25318908691406, \"slope\": -0.07455860823392868, \"chain\": 3, \"draw\": 7}, {\"draws\": 607, \"mouse\": 6, \"mu_intercept_per_group\": 4.96965217590332, \"sigma_intercept_per_group\": 0.38656166195869446, \"sigma_obs\": 155.25318908691406, \"slope\": -0.07455860823392868, \"chain\": 3, \"draw\": 7}, {\"draws\": 607, \"mouse\": 7, \"mu_intercept_per_group\": 4.482364654541016, \"sigma_intercept_per_group\": 0.38656166195869446, \"sigma_obs\": 155.25318908691406, \"slope\": -0.07455860823392868, \"chain\": 3, \"draw\": 7}, {\"draws\": 608, \"mouse\": 0, \"mu_intercept_per_group\": 6.426768779754639, \"sigma_intercept_per_group\": 0.38452181220054626, \"sigma_obs\": 155.40643310546875, \"slope\": -0.07407012581825256, \"chain\": 3, \"draw\": 8}, {\"draws\": 608, \"mouse\": 1, \"mu_intercept_per_group\": 6.2193989753723145, \"sigma_intercept_per_group\": 0.38452181220054626, \"sigma_obs\": 155.40643310546875, \"slope\": -0.07407012581825256, \"chain\": 3, \"draw\": 8}, {\"draws\": 608, \"mouse\": 2, \"mu_intercept_per_group\": 6.039809703826904, \"sigma_intercept_per_group\": 0.38452181220054626, \"sigma_obs\": 155.40643310546875, \"slope\": -0.07407012581825256, \"chain\": 3, \"draw\": 8}, {\"draws\": 608, \"mouse\": 3, \"mu_intercept_per_group\": 5.680412292480469, \"sigma_intercept_per_group\": 0.38452181220054626, \"sigma_obs\": 155.40643310546875, \"slope\": -0.07407012581825256, \"chain\": 3, \"draw\": 8}, {\"draws\": 608, \"mouse\": 4, \"mu_intercept_per_group\": 5.199459552764893, \"sigma_intercept_per_group\": 0.38452181220054626, \"sigma_obs\": 155.40643310546875, \"slope\": -0.07407012581825256, \"chain\": 3, \"draw\": 8}, {\"draws\": 608, \"mouse\": 5, \"mu_intercept_per_group\": 5.083866596221924, \"sigma_intercept_per_group\": 0.38452181220054626, \"sigma_obs\": 155.40643310546875, \"slope\": -0.07407012581825256, \"chain\": 3, \"draw\": 8}, {\"draws\": 608, \"mouse\": 6, \"mu_intercept_per_group\": 4.815627098083496, \"sigma_intercept_per_group\": 0.38452181220054626, \"sigma_obs\": 155.40643310546875, \"slope\": -0.07407012581825256, \"chain\": 3, \"draw\": 8}, {\"draws\": 608, \"mouse\": 7, \"mu_intercept_per_group\": 4.628861904144287, \"sigma_intercept_per_group\": 0.38452181220054626, \"sigma_obs\": 155.40643310546875, \"slope\": -0.07407012581825256, \"chain\": 3, \"draw\": 8}, {\"draws\": 609, \"mouse\": 0, \"mu_intercept_per_group\": 6.518007278442383, \"sigma_intercept_per_group\": 0.3809606432914734, \"sigma_obs\": 155.49220275878906, \"slope\": -0.07430639863014221, \"chain\": 3, \"draw\": 9}, {\"draws\": 609, \"mouse\": 1, \"mu_intercept_per_group\": 6.371899604797363, \"sigma_intercept_per_group\": 0.3809606432914734, \"sigma_obs\": 155.49220275878906, \"slope\": -0.07430639863014221, \"chain\": 3, \"draw\": 9}, {\"draws\": 609, \"mouse\": 2, \"mu_intercept_per_group\": 6.0481061935424805, \"sigma_intercept_per_group\": 0.3809606432914734, \"sigma_obs\": 155.49220275878906, \"slope\": -0.07430639863014221, \"chain\": 3, \"draw\": 9}, {\"draws\": 609, \"mouse\": 3, \"mu_intercept_per_group\": 5.638171195983887, \"sigma_intercept_per_group\": 0.3809606432914734, \"sigma_obs\": 155.49220275878906, \"slope\": -0.07430639863014221, \"chain\": 3, \"draw\": 9}, {\"draws\": 609, \"mouse\": 4, \"mu_intercept_per_group\": 5.1861724853515625, \"sigma_intercept_per_group\": 0.3809606432914734, \"sigma_obs\": 155.49220275878906, \"slope\": -0.07430639863014221, \"chain\": 3, \"draw\": 9}, {\"draws\": 609, \"mouse\": 5, \"mu_intercept_per_group\": 5.082662582397461, \"sigma_intercept_per_group\": 0.3809606432914734, \"sigma_obs\": 155.49220275878906, \"slope\": -0.07430639863014221, \"chain\": 3, \"draw\": 9}, {\"draws\": 609, \"mouse\": 6, \"mu_intercept_per_group\": 4.84735631942749, \"sigma_intercept_per_group\": 0.3809606432914734, \"sigma_obs\": 155.49220275878906, \"slope\": -0.07430639863014221, \"chain\": 3, \"draw\": 9}, {\"draws\": 609, \"mouse\": 7, \"mu_intercept_per_group\": 4.602806091308594, \"sigma_intercept_per_group\": 0.3809606432914734, \"sigma_obs\": 155.49220275878906, \"slope\": -0.07430639863014221, \"chain\": 3, \"draw\": 9}, {\"draws\": 610, \"mouse\": 0, \"mu_intercept_per_group\": 6.218565464019775, \"sigma_intercept_per_group\": 0.3851282000541687, \"sigma_obs\": 155.19915771484375, \"slope\": -0.07422319799661636, \"chain\": 3, \"draw\": 10}, {\"draws\": 610, \"mouse\": 1, \"mu_intercept_per_group\": 5.923467636108398, \"sigma_intercept_per_group\": 0.3851282000541687, \"sigma_obs\": 155.19915771484375, \"slope\": -0.07422319799661636, \"chain\": 3, \"draw\": 10}, {\"draws\": 610, \"mouse\": 2, \"mu_intercept_per_group\": 5.891469478607178, \"sigma_intercept_per_group\": 0.3851282000541687, \"sigma_obs\": 155.19915771484375, \"slope\": -0.07422319799661636, \"chain\": 3, \"draw\": 10}, {\"draws\": 610, \"mouse\": 3, \"mu_intercept_per_group\": 5.62255859375, \"sigma_intercept_per_group\": 0.3851282000541687, \"sigma_obs\": 155.19915771484375, \"slope\": -0.07422319799661636, \"chain\": 3, \"draw\": 10}, {\"draws\": 610, \"mouse\": 4, \"mu_intercept_per_group\": 5.733725547790527, \"sigma_intercept_per_group\": 0.3851282000541687, \"sigma_obs\": 155.19915771484375, \"slope\": -0.07422319799661636, \"chain\": 3, \"draw\": 10}, {\"draws\": 610, \"mouse\": 5, \"mu_intercept_per_group\": 5.216569900512695, \"sigma_intercept_per_group\": 0.3851282000541687, \"sigma_obs\": 155.19915771484375, \"slope\": -0.07422319799661636, \"chain\": 3, \"draw\": 10}, {\"draws\": 610, \"mouse\": 6, \"mu_intercept_per_group\": 4.7760009765625, \"sigma_intercept_per_group\": 0.3851282000541687, \"sigma_obs\": 155.19915771484375, \"slope\": -0.07422319799661636, \"chain\": 3, \"draw\": 10}, {\"draws\": 610, \"mouse\": 7, \"mu_intercept_per_group\": 4.7769269943237305, \"sigma_intercept_per_group\": 0.3851282000541687, \"sigma_obs\": 155.19915771484375, \"slope\": -0.07422319799661636, \"chain\": 3, \"draw\": 10}, {\"draws\": 611, \"mouse\": 0, \"mu_intercept_per_group\": 6.342747211456299, \"sigma_intercept_per_group\": 0.38743865489959717, \"sigma_obs\": 155.38525390625, \"slope\": -0.07428158819675446, \"chain\": 3, \"draw\": 11}, {\"draws\": 611, \"mouse\": 1, \"mu_intercept_per_group\": 6.146402835845947, \"sigma_intercept_per_group\": 0.38743865489959717, \"sigma_obs\": 155.38525390625, \"slope\": -0.07428158819675446, \"chain\": 3, \"draw\": 11}, {\"draws\": 611, \"mouse\": 2, \"mu_intercept_per_group\": 6.047823905944824, \"sigma_intercept_per_group\": 0.38743865489959717, \"sigma_obs\": 155.38525390625, \"slope\": -0.07428158819675446, \"chain\": 3, \"draw\": 11}, {\"draws\": 611, \"mouse\": 3, \"mu_intercept_per_group\": 5.545507907867432, \"sigma_intercept_per_group\": 0.38743865489959717, \"sigma_obs\": 155.38525390625, \"slope\": -0.07428158819675446, \"chain\": 3, \"draw\": 11}, {\"draws\": 611, \"mouse\": 4, \"mu_intercept_per_group\": 5.545827865600586, \"sigma_intercept_per_group\": 0.38743865489959717, \"sigma_obs\": 155.38525390625, \"slope\": -0.07428158819675446, \"chain\": 3, \"draw\": 11}, {\"draws\": 611, \"mouse\": 5, \"mu_intercept_per_group\": 5.040996551513672, \"sigma_intercept_per_group\": 0.38743865489959717, \"sigma_obs\": 155.38525390625, \"slope\": -0.07428158819675446, \"chain\": 3, \"draw\": 11}, {\"draws\": 611, \"mouse\": 6, \"mu_intercept_per_group\": 4.848405361175537, \"sigma_intercept_per_group\": 0.38743865489959717, \"sigma_obs\": 155.38525390625, \"slope\": -0.07428158819675446, \"chain\": 3, \"draw\": 11}, {\"draws\": 611, \"mouse\": 7, \"mu_intercept_per_group\": 4.574238300323486, \"sigma_intercept_per_group\": 0.38743865489959717, \"sigma_obs\": 155.38525390625, \"slope\": -0.07428158819675446, \"chain\": 3, \"draw\": 11}, {\"draws\": 612, \"mouse\": 0, \"mu_intercept_per_group\": 6.743773460388184, \"sigma_intercept_per_group\": 0.3695283532142639, \"sigma_obs\": 156.78094482421875, \"slope\": -0.06995056569576263, \"chain\": 3, \"draw\": 12}, {\"draws\": 612, \"mouse\": 1, \"mu_intercept_per_group\": 6.451606273651123, \"sigma_intercept_per_group\": 0.3695283532142639, \"sigma_obs\": 156.78094482421875, \"slope\": -0.06995056569576263, \"chain\": 3, \"draw\": 12}, {\"draws\": 612, \"mouse\": 2, \"mu_intercept_per_group\": 6.123181343078613, \"sigma_intercept_per_group\": 0.3695283532142639, \"sigma_obs\": 156.78094482421875, \"slope\": -0.06995056569576263, \"chain\": 3, \"draw\": 12}, {\"draws\": 612, \"mouse\": 3, \"mu_intercept_per_group\": 5.707121849060059, \"sigma_intercept_per_group\": 0.3695283532142639, \"sigma_obs\": 156.78094482421875, \"slope\": -0.06995056569576263, \"chain\": 3, \"draw\": 12}, {\"draws\": 612, \"mouse\": 4, \"mu_intercept_per_group\": 5.685554027557373, \"sigma_intercept_per_group\": 0.3695283532142639, \"sigma_obs\": 156.78094482421875, \"slope\": -0.06995056569576263, \"chain\": 3, \"draw\": 12}, {\"draws\": 612, \"mouse\": 5, \"mu_intercept_per_group\": 5.191104412078857, \"sigma_intercept_per_group\": 0.3695283532142639, \"sigma_obs\": 156.78094482421875, \"slope\": -0.06995056569576263, \"chain\": 3, \"draw\": 12}, {\"draws\": 612, \"mouse\": 6, \"mu_intercept_per_group\": 4.9795756340026855, \"sigma_intercept_per_group\": 0.3695283532142639, \"sigma_obs\": 156.78094482421875, \"slope\": -0.06995056569576263, \"chain\": 3, \"draw\": 12}, {\"draws\": 612, \"mouse\": 7, \"mu_intercept_per_group\": 4.720438480377197, \"sigma_intercept_per_group\": 0.3695283532142639, \"sigma_obs\": 156.78094482421875, \"slope\": -0.06995056569576263, \"chain\": 3, \"draw\": 12}, {\"draws\": 613, \"mouse\": 0, \"mu_intercept_per_group\": 6.24724006652832, \"sigma_intercept_per_group\": 0.3797108829021454, \"sigma_obs\": 156.60260009765625, \"slope\": -0.06775124371051788, \"chain\": 3, \"draw\": 13}, {\"draws\": 613, \"mouse\": 1, \"mu_intercept_per_group\": 6.114496231079102, \"sigma_intercept_per_group\": 0.3797108829021454, \"sigma_obs\": 156.60260009765625, \"slope\": -0.06775124371051788, \"chain\": 3, \"draw\": 13}, {\"draws\": 613, \"mouse\": 2, \"mu_intercept_per_group\": 6.066954612731934, \"sigma_intercept_per_group\": 0.3797108829021454, \"sigma_obs\": 156.60260009765625, \"slope\": -0.06775124371051788, \"chain\": 3, \"draw\": 13}, {\"draws\": 613, \"mouse\": 3, \"mu_intercept_per_group\": 5.824372291564941, \"sigma_intercept_per_group\": 0.3797108829021454, \"sigma_obs\": 156.60260009765625, \"slope\": -0.06775124371051788, \"chain\": 3, \"draw\": 13}, {\"draws\": 613, \"mouse\": 4, \"mu_intercept_per_group\": 5.520506381988525, \"sigma_intercept_per_group\": 0.3797108829021454, \"sigma_obs\": 156.60260009765625, \"slope\": -0.06775124371051788, \"chain\": 3, \"draw\": 13}, {\"draws\": 613, \"mouse\": 5, \"mu_intercept_per_group\": 5.393089294433594, \"sigma_intercept_per_group\": 0.3797108829021454, \"sigma_obs\": 156.60260009765625, \"slope\": -0.06775124371051788, \"chain\": 3, \"draw\": 13}, {\"draws\": 613, \"mouse\": 6, \"mu_intercept_per_group\": 4.770604133605957, \"sigma_intercept_per_group\": 0.3797108829021454, \"sigma_obs\": 156.60260009765625, \"slope\": -0.06775124371051788, \"chain\": 3, \"draw\": 13}, {\"draws\": 613, \"mouse\": 7, \"mu_intercept_per_group\": 4.630069732666016, \"sigma_intercept_per_group\": 0.3797108829021454, \"sigma_obs\": 156.60260009765625, \"slope\": -0.06775124371051788, \"chain\": 3, \"draw\": 13}, {\"draws\": 614, \"mouse\": 0, \"mu_intercept_per_group\": 6.246423244476318, \"sigma_intercept_per_group\": 0.38505783677101135, \"sigma_obs\": 155.9014892578125, \"slope\": -0.062836192548275, \"chain\": 3, \"draw\": 14}, {\"draws\": 614, \"mouse\": 1, \"mu_intercept_per_group\": 6.091341018676758, \"sigma_intercept_per_group\": 0.38505783677101135, \"sigma_obs\": 155.9014892578125, \"slope\": -0.062836192548275, \"chain\": 3, \"draw\": 14}, {\"draws\": 614, \"mouse\": 2, \"mu_intercept_per_group\": 6.0764479637146, \"sigma_intercept_per_group\": 0.38505783677101135, \"sigma_obs\": 155.9014892578125, \"slope\": -0.062836192548275, \"chain\": 3, \"draw\": 14}, {\"draws\": 614, \"mouse\": 3, \"mu_intercept_per_group\": 5.65395450592041, \"sigma_intercept_per_group\": 0.38505783677101135, \"sigma_obs\": 155.9014892578125, \"slope\": -0.062836192548275, \"chain\": 3, \"draw\": 14}, {\"draws\": 614, \"mouse\": 4, \"mu_intercept_per_group\": 5.461277484893799, \"sigma_intercept_per_group\": 0.38505783677101135, \"sigma_obs\": 155.9014892578125, \"slope\": -0.062836192548275, \"chain\": 3, \"draw\": 14}, {\"draws\": 614, \"mouse\": 5, \"mu_intercept_per_group\": 5.202829360961914, \"sigma_intercept_per_group\": 0.38505783677101135, \"sigma_obs\": 155.9014892578125, \"slope\": -0.062836192548275, \"chain\": 3, \"draw\": 14}, {\"draws\": 614, \"mouse\": 6, \"mu_intercept_per_group\": 4.982495307922363, \"sigma_intercept_per_group\": 0.38505783677101135, \"sigma_obs\": 155.9014892578125, \"slope\": -0.062836192548275, \"chain\": 3, \"draw\": 14}, {\"draws\": 614, \"mouse\": 7, \"mu_intercept_per_group\": 4.611384391784668, \"sigma_intercept_per_group\": 0.38505783677101135, \"sigma_obs\": 155.9014892578125, \"slope\": -0.062836192548275, \"chain\": 3, \"draw\": 14}, {\"draws\": 615, \"mouse\": 0, \"mu_intercept_per_group\": 8.402999877929688, \"sigma_intercept_per_group\": 0.2971031069755554, \"sigma_obs\": 158.12306213378906, \"slope\": -0.06372182071208954, \"chain\": 3, \"draw\": 15}, {\"draws\": 615, \"mouse\": 1, \"mu_intercept_per_group\": 8.002828598022461, \"sigma_intercept_per_group\": 0.2971031069755554, \"sigma_obs\": 158.12306213378906, \"slope\": -0.06372182071208954, \"chain\": 3, \"draw\": 15}, {\"draws\": 615, \"mouse\": 2, \"mu_intercept_per_group\": 7.5629353523254395, \"sigma_intercept_per_group\": 0.2971031069755554, \"sigma_obs\": 158.12306213378906, \"slope\": -0.06372182071208954, \"chain\": 3, \"draw\": 15}, {\"draws\": 615, \"mouse\": 3, \"mu_intercept_per_group\": 7.269816875457764, \"sigma_intercept_per_group\": 0.2971031069755554, \"sigma_obs\": 158.12306213378906, \"slope\": -0.06372182071208954, \"chain\": 3, \"draw\": 15}, {\"draws\": 615, \"mouse\": 4, \"mu_intercept_per_group\": 7.137989044189453, \"sigma_intercept_per_group\": 0.2971031069755554, \"sigma_obs\": 158.12306213378906, \"slope\": -0.06372182071208954, \"chain\": 3, \"draw\": 15}, {\"draws\": 615, \"mouse\": 5, \"mu_intercept_per_group\": 6.633379936218262, \"sigma_intercept_per_group\": 0.2971031069755554, \"sigma_obs\": 158.12306213378906, \"slope\": -0.06372182071208954, \"chain\": 3, \"draw\": 15}, {\"draws\": 615, \"mouse\": 6, \"mu_intercept_per_group\": 6.138319492340088, \"sigma_intercept_per_group\": 0.2971031069755554, \"sigma_obs\": 158.12306213378906, \"slope\": -0.06372182071208954, \"chain\": 3, \"draw\": 15}, {\"draws\": 615, \"mouse\": 7, \"mu_intercept_per_group\": 5.762714862823486, \"sigma_intercept_per_group\": 0.2971031069755554, \"sigma_obs\": 158.12306213378906, \"slope\": -0.06372182071208954, \"chain\": 3, \"draw\": 15}, {\"draws\": 616, \"mouse\": 0, \"mu_intercept_per_group\": 8.096854209899902, \"sigma_intercept_per_group\": 0.3044244349002838, \"sigma_obs\": 157.73658752441406, \"slope\": -0.06584974378347397, \"chain\": 3, \"draw\": 16}, {\"draws\": 616, \"mouse\": 1, \"mu_intercept_per_group\": 7.5772504806518555, \"sigma_intercept_per_group\": 0.3044244349002838, \"sigma_obs\": 157.73658752441406, \"slope\": -0.06584974378347397, \"chain\": 3, \"draw\": 16}, {\"draws\": 616, \"mouse\": 2, \"mu_intercept_per_group\": 7.676380157470703, \"sigma_intercept_per_group\": 0.3044244349002838, \"sigma_obs\": 157.73658752441406, \"slope\": -0.06584974378347397, \"chain\": 3, \"draw\": 16}, {\"draws\": 616, \"mouse\": 3, \"mu_intercept_per_group\": 7.128310203552246, \"sigma_intercept_per_group\": 0.3044244349002838, \"sigma_obs\": 157.73658752441406, \"slope\": -0.06584974378347397, \"chain\": 3, \"draw\": 16}, {\"draws\": 616, \"mouse\": 4, \"mu_intercept_per_group\": 6.80349588394165, \"sigma_intercept_per_group\": 0.3044244349002838, \"sigma_obs\": 157.73658752441406, \"slope\": -0.06584974378347397, \"chain\": 3, \"draw\": 16}, {\"draws\": 616, \"mouse\": 5, \"mu_intercept_per_group\": 6.552610397338867, \"sigma_intercept_per_group\": 0.3044244349002838, \"sigma_obs\": 157.73658752441406, \"slope\": -0.06584974378347397, \"chain\": 3, \"draw\": 16}, {\"draws\": 616, \"mouse\": 6, \"mu_intercept_per_group\": 6.289919376373291, \"sigma_intercept_per_group\": 0.3044244349002838, \"sigma_obs\": 157.73658752441406, \"slope\": -0.06584974378347397, \"chain\": 3, \"draw\": 16}, {\"draws\": 616, \"mouse\": 7, \"mu_intercept_per_group\": 5.8170061111450195, \"sigma_intercept_per_group\": 0.3044244349002838, \"sigma_obs\": 157.73658752441406, \"slope\": -0.06584974378347397, \"chain\": 3, \"draw\": 16}, {\"draws\": 617, \"mouse\": 0, \"mu_intercept_per_group\": 8.317630767822266, \"sigma_intercept_per_group\": 0.3020741045475006, \"sigma_obs\": 158.39442443847656, \"slope\": -0.06627041846513748, \"chain\": 3, \"draw\": 17}, {\"draws\": 617, \"mouse\": 1, \"mu_intercept_per_group\": 7.947457313537598, \"sigma_intercept_per_group\": 0.3020741045475006, \"sigma_obs\": 158.39442443847656, \"slope\": -0.06627041846513748, \"chain\": 3, \"draw\": 17}, {\"draws\": 617, \"mouse\": 2, \"mu_intercept_per_group\": 7.667423248291016, \"sigma_intercept_per_group\": 0.3020741045475006, \"sigma_obs\": 158.39442443847656, \"slope\": -0.06627041846513748, \"chain\": 3, \"draw\": 17}, {\"draws\": 617, \"mouse\": 3, \"mu_intercept_per_group\": 7.060757160186768, \"sigma_intercept_per_group\": 0.3020741045475006, \"sigma_obs\": 158.39442443847656, \"slope\": -0.06627041846513748, \"chain\": 3, \"draw\": 17}, {\"draws\": 617, \"mouse\": 4, \"mu_intercept_per_group\": 6.791686534881592, \"sigma_intercept_per_group\": 0.3020741045475006, \"sigma_obs\": 158.39442443847656, \"slope\": -0.06627041846513748, \"chain\": 3, \"draw\": 17}, {\"draws\": 617, \"mouse\": 5, \"mu_intercept_per_group\": 6.622844219207764, \"sigma_intercept_per_group\": 0.3020741045475006, \"sigma_obs\": 158.39442443847656, \"slope\": -0.06627041846513748, \"chain\": 3, \"draw\": 17}, {\"draws\": 617, \"mouse\": 6, \"mu_intercept_per_group\": 6.194840908050537, \"sigma_intercept_per_group\": 0.3020741045475006, \"sigma_obs\": 158.39442443847656, \"slope\": -0.06627041846513748, \"chain\": 3, \"draw\": 17}, {\"draws\": 617, \"mouse\": 7, \"mu_intercept_per_group\": 5.805405616760254, \"sigma_intercept_per_group\": 0.3020741045475006, \"sigma_obs\": 158.39442443847656, \"slope\": -0.06627041846513748, \"chain\": 3, \"draw\": 17}, {\"draws\": 618, \"mouse\": 0, \"mu_intercept_per_group\": 8.031795501708984, \"sigma_intercept_per_group\": 0.30329030752182007, \"sigma_obs\": 159.17990112304688, \"slope\": -0.06636354327201843, \"chain\": 3, \"draw\": 18}, {\"draws\": 618, \"mouse\": 1, \"mu_intercept_per_group\": 7.841182231903076, \"sigma_intercept_per_group\": 0.30329030752182007, \"sigma_obs\": 159.17990112304688, \"slope\": -0.06636354327201843, \"chain\": 3, \"draw\": 18}, {\"draws\": 618, \"mouse\": 2, \"mu_intercept_per_group\": 7.370601177215576, \"sigma_intercept_per_group\": 0.30329030752182007, \"sigma_obs\": 159.17990112304688, \"slope\": -0.06636354327201843, \"chain\": 3, \"draw\": 18}, {\"draws\": 618, \"mouse\": 3, \"mu_intercept_per_group\": 6.927246570587158, \"sigma_intercept_per_group\": 0.30329030752182007, \"sigma_obs\": 159.17990112304688, \"slope\": -0.06636354327201843, \"chain\": 3, \"draw\": 18}, {\"draws\": 618, \"mouse\": 4, \"mu_intercept_per_group\": 6.87087869644165, \"sigma_intercept_per_group\": 0.30329030752182007, \"sigma_obs\": 159.17990112304688, \"slope\": -0.06636354327201843, \"chain\": 3, \"draw\": 18}, {\"draws\": 618, \"mouse\": 5, \"mu_intercept_per_group\": 6.7537665367126465, \"sigma_intercept_per_group\": 0.30329030752182007, \"sigma_obs\": 159.17990112304688, \"slope\": -0.06636354327201843, \"chain\": 3, \"draw\": 18}, {\"draws\": 618, \"mouse\": 6, \"mu_intercept_per_group\": 6.340365886688232, \"sigma_intercept_per_group\": 0.30329030752182007, \"sigma_obs\": 159.17990112304688, \"slope\": -0.06636354327201843, \"chain\": 3, \"draw\": 18}, {\"draws\": 618, \"mouse\": 7, \"mu_intercept_per_group\": 6.1271772384643555, \"sigma_intercept_per_group\": 0.30329030752182007, \"sigma_obs\": 159.17990112304688, \"slope\": -0.06636354327201843, \"chain\": 3, \"draw\": 18}, {\"draws\": 619, \"mouse\": 0, \"mu_intercept_per_group\": 8.015172004699707, \"sigma_intercept_per_group\": 0.3053637444972992, \"sigma_obs\": 158.8363494873047, \"slope\": -0.06681515276432037, \"chain\": 3, \"draw\": 19}, {\"draws\": 619, \"mouse\": 1, \"mu_intercept_per_group\": 7.717623233795166, \"sigma_intercept_per_group\": 0.3053637444972992, \"sigma_obs\": 158.8363494873047, \"slope\": -0.06681515276432037, \"chain\": 3, \"draw\": 19}, {\"draws\": 619, \"mouse\": 2, \"mu_intercept_per_group\": 7.552116870880127, \"sigma_intercept_per_group\": 0.3053637444972992, \"sigma_obs\": 158.8363494873047, \"slope\": -0.06681515276432037, \"chain\": 3, \"draw\": 19}, {\"draws\": 619, \"mouse\": 3, \"mu_intercept_per_group\": 7.0025153160095215, \"sigma_intercept_per_group\": 0.3053637444972992, \"sigma_obs\": 158.8363494873047, \"slope\": -0.06681515276432037, \"chain\": 3, \"draw\": 19}, {\"draws\": 619, \"mouse\": 4, \"mu_intercept_per_group\": 7.089814186096191, \"sigma_intercept_per_group\": 0.3053637444972992, \"sigma_obs\": 158.8363494873047, \"slope\": -0.06681515276432037, \"chain\": 3, \"draw\": 19}, {\"draws\": 619, \"mouse\": 5, \"mu_intercept_per_group\": 6.761794090270996, \"sigma_intercept_per_group\": 0.3053637444972992, \"sigma_obs\": 158.8363494873047, \"slope\": -0.06681515276432037, \"chain\": 3, \"draw\": 19}, {\"draws\": 619, \"mouse\": 6, \"mu_intercept_per_group\": 6.209214210510254, \"sigma_intercept_per_group\": 0.3053637444972992, \"sigma_obs\": 158.8363494873047, \"slope\": -0.06681515276432037, \"chain\": 3, \"draw\": 19}, {\"draws\": 619, \"mouse\": 7, \"mu_intercept_per_group\": 5.9719696044921875, \"sigma_intercept_per_group\": 0.3053637444972992, \"sigma_obs\": 158.8363494873047, \"slope\": -0.06681515276432037, \"chain\": 3, \"draw\": 19}, {\"draws\": 620, \"mouse\": 0, \"mu_intercept_per_group\": 8.068775177001953, \"sigma_intercept_per_group\": 0.30497387051582336, \"sigma_obs\": 158.84347534179688, \"slope\": -0.06651753932237625, \"chain\": 3, \"draw\": 20}, {\"draws\": 620, \"mouse\": 1, \"mu_intercept_per_group\": 7.755598545074463, \"sigma_intercept_per_group\": 0.30497387051582336, \"sigma_obs\": 158.84347534179688, \"slope\": -0.06651753932237625, \"chain\": 3, \"draw\": 20}, {\"draws\": 620, \"mouse\": 2, \"mu_intercept_per_group\": 7.603647232055664, \"sigma_intercept_per_group\": 0.30497387051582336, \"sigma_obs\": 158.84347534179688, \"slope\": -0.06651753932237625, \"chain\": 3, \"draw\": 20}, {\"draws\": 620, \"mouse\": 3, \"mu_intercept_per_group\": 7.115638256072998, \"sigma_intercept_per_group\": 0.30497387051582336, \"sigma_obs\": 158.84347534179688, \"slope\": -0.06651753932237625, \"chain\": 3, \"draw\": 20}, {\"draws\": 620, \"mouse\": 4, \"mu_intercept_per_group\": 6.989217281341553, \"sigma_intercept_per_group\": 0.30497387051582336, \"sigma_obs\": 158.84347534179688, \"slope\": -0.06651753932237625, \"chain\": 3, \"draw\": 20}, {\"draws\": 620, \"mouse\": 5, \"mu_intercept_per_group\": 6.739404678344727, \"sigma_intercept_per_group\": 0.30497387051582336, \"sigma_obs\": 158.84347534179688, \"slope\": -0.06651753932237625, \"chain\": 3, \"draw\": 20}, {\"draws\": 620, \"mouse\": 6, \"mu_intercept_per_group\": 6.219288349151611, \"sigma_intercept_per_group\": 0.30497387051582336, \"sigma_obs\": 158.84347534179688, \"slope\": -0.06651753932237625, \"chain\": 3, \"draw\": 20}, {\"draws\": 620, \"mouse\": 7, \"mu_intercept_per_group\": 5.966530799865723, \"sigma_intercept_per_group\": 0.30497387051582336, \"sigma_obs\": 158.84347534179688, \"slope\": -0.06651753932237625, \"chain\": 3, \"draw\": 20}, {\"draws\": 621, \"mouse\": 0, \"mu_intercept_per_group\": 8.105262756347656, \"sigma_intercept_per_group\": 0.3023236393928528, \"sigma_obs\": 159.08883666992188, \"slope\": -0.0669768825173378, \"chain\": 3, \"draw\": 21}, {\"draws\": 621, \"mouse\": 1, \"mu_intercept_per_group\": 7.8094868659973145, \"sigma_intercept_per_group\": 0.3023236393928528, \"sigma_obs\": 159.08883666992188, \"slope\": -0.0669768825173378, \"chain\": 3, \"draw\": 21}, {\"draws\": 621, \"mouse\": 2, \"mu_intercept_per_group\": 7.456414699554443, \"sigma_intercept_per_group\": 0.3023236393928528, \"sigma_obs\": 159.08883666992188, \"slope\": -0.0669768825173378, \"chain\": 3, \"draw\": 21}, {\"draws\": 621, \"mouse\": 3, \"mu_intercept_per_group\": 7.301642894744873, \"sigma_intercept_per_group\": 0.3023236393928528, \"sigma_obs\": 159.08883666992188, \"slope\": -0.0669768825173378, \"chain\": 3, \"draw\": 21}, {\"draws\": 621, \"mouse\": 4, \"mu_intercept_per_group\": 7.182643890380859, \"sigma_intercept_per_group\": 0.3023236393928528, \"sigma_obs\": 159.08883666992188, \"slope\": -0.0669768825173378, \"chain\": 3, \"draw\": 21}, {\"draws\": 621, \"mouse\": 5, \"mu_intercept_per_group\": 6.624819755554199, \"sigma_intercept_per_group\": 0.3023236393928528, \"sigma_obs\": 159.08883666992188, \"slope\": -0.0669768825173378, \"chain\": 3, \"draw\": 21}, {\"draws\": 621, \"mouse\": 6, \"mu_intercept_per_group\": 6.1327643394470215, \"sigma_intercept_per_group\": 0.3023236393928528, \"sigma_obs\": 159.08883666992188, \"slope\": -0.0669768825173378, \"chain\": 3, \"draw\": 21}, {\"draws\": 621, \"mouse\": 7, \"mu_intercept_per_group\": 5.860397815704346, \"sigma_intercept_per_group\": 0.3023236393928528, \"sigma_obs\": 159.08883666992188, \"slope\": -0.0669768825173378, \"chain\": 3, \"draw\": 21}, {\"draws\": 622, \"mouse\": 0, \"mu_intercept_per_group\": 10.63652515411377, \"sigma_intercept_per_group\": 0.23035159707069397, \"sigma_obs\": 154.33322143554688, \"slope\": -0.060443341732025146, \"chain\": 3, \"draw\": 22}, {\"draws\": 622, \"mouse\": 1, \"mu_intercept_per_group\": 10.181793212890625, \"sigma_intercept_per_group\": 0.23035159707069397, \"sigma_obs\": 154.33322143554688, \"slope\": -0.060443341732025146, \"chain\": 3, \"draw\": 22}, {\"draws\": 622, \"mouse\": 2, \"mu_intercept_per_group\": 9.893183708190918, \"sigma_intercept_per_group\": 0.23035159707069397, \"sigma_obs\": 154.33322143554688, \"slope\": -0.060443341732025146, \"chain\": 3, \"draw\": 22}, {\"draws\": 622, \"mouse\": 3, \"mu_intercept_per_group\": 9.107222557067871, \"sigma_intercept_per_group\": 0.23035159707069397, \"sigma_obs\": 154.33322143554688, \"slope\": -0.060443341732025146, \"chain\": 3, \"draw\": 22}, {\"draws\": 622, \"mouse\": 4, \"mu_intercept_per_group\": 8.98314094543457, \"sigma_intercept_per_group\": 0.23035159707069397, \"sigma_obs\": 154.33322143554688, \"slope\": -0.060443341732025146, \"chain\": 3, \"draw\": 22}, {\"draws\": 622, \"mouse\": 5, \"mu_intercept_per_group\": 8.439205169677734, \"sigma_intercept_per_group\": 0.23035159707069397, \"sigma_obs\": 154.33322143554688, \"slope\": -0.060443341732025146, \"chain\": 3, \"draw\": 22}, {\"draws\": 622, \"mouse\": 6, \"mu_intercept_per_group\": 7.791914463043213, \"sigma_intercept_per_group\": 0.23035159707069397, \"sigma_obs\": 154.33322143554688, \"slope\": -0.060443341732025146, \"chain\": 3, \"draw\": 22}, {\"draws\": 622, \"mouse\": 7, \"mu_intercept_per_group\": 7.348583221435547, \"sigma_intercept_per_group\": 0.23035159707069397, \"sigma_obs\": 154.33322143554688, \"slope\": -0.060443341732025146, \"chain\": 3, \"draw\": 22}, {\"draws\": 623, \"mouse\": 0, \"mu_intercept_per_group\": 12.355905532836914, \"sigma_intercept_per_group\": 0.19680437445640564, \"sigma_obs\": 151.76034545898438, \"slope\": -0.07397546619176865, \"chain\": 3, \"draw\": 23}, {\"draws\": 623, \"mouse\": 1, \"mu_intercept_per_group\": 11.922428131103516, \"sigma_intercept_per_group\": 0.19680437445640564, \"sigma_obs\": 151.76034545898438, \"slope\": -0.07397546619176865, \"chain\": 3, \"draw\": 23}, {\"draws\": 623, \"mouse\": 2, \"mu_intercept_per_group\": 11.422466278076172, \"sigma_intercept_per_group\": 0.19680437445640564, \"sigma_obs\": 151.76034545898438, \"slope\": -0.07397546619176865, \"chain\": 3, \"draw\": 23}, {\"draws\": 623, \"mouse\": 3, \"mu_intercept_per_group\": 11.214725494384766, \"sigma_intercept_per_group\": 0.19680437445640564, \"sigma_obs\": 151.76034545898438, \"slope\": -0.07397546619176865, \"chain\": 3, \"draw\": 23}, {\"draws\": 623, \"mouse\": 4, \"mu_intercept_per_group\": 10.35313892364502, \"sigma_intercept_per_group\": 0.19680437445640564, \"sigma_obs\": 151.76034545898438, \"slope\": -0.07397546619176865, \"chain\": 3, \"draw\": 23}, {\"draws\": 623, \"mouse\": 5, \"mu_intercept_per_group\": 9.916618347167969, \"sigma_intercept_per_group\": 0.19680437445640564, \"sigma_obs\": 151.76034545898438, \"slope\": -0.07397546619176865, \"chain\": 3, \"draw\": 23}, {\"draws\": 623, \"mouse\": 6, \"mu_intercept_per_group\": 8.932032585144043, \"sigma_intercept_per_group\": 0.19680437445640564, \"sigma_obs\": 151.76034545898438, \"slope\": -0.07397546619176865, \"chain\": 3, \"draw\": 23}, {\"draws\": 623, \"mouse\": 7, \"mu_intercept_per_group\": 8.81618881225586, \"sigma_intercept_per_group\": 0.19680437445640564, \"sigma_obs\": 151.76034545898438, \"slope\": -0.07397546619176865, \"chain\": 3, \"draw\": 23}, {\"draws\": 624, \"mouse\": 0, \"mu_intercept_per_group\": 12.15248966217041, \"sigma_intercept_per_group\": 0.19906136393547058, \"sigma_obs\": 151.7274932861328, \"slope\": -0.07415813952684402, \"chain\": 3, \"draw\": 24}, {\"draws\": 624, \"mouse\": 1, \"mu_intercept_per_group\": 11.964059829711914, \"sigma_intercept_per_group\": 0.19906136393547058, \"sigma_obs\": 151.7274932861328, \"slope\": -0.07415813952684402, \"chain\": 3, \"draw\": 24}, {\"draws\": 624, \"mouse\": 2, \"mu_intercept_per_group\": 11.5114164352417, \"sigma_intercept_per_group\": 0.19906136393547058, \"sigma_obs\": 151.7274932861328, \"slope\": -0.07415813952684402, \"chain\": 3, \"draw\": 24}, {\"draws\": 624, \"mouse\": 3, \"mu_intercept_per_group\": 10.911593437194824, \"sigma_intercept_per_group\": 0.19906136393547058, \"sigma_obs\": 151.7274932861328, \"slope\": -0.07415813952684402, \"chain\": 3, \"draw\": 24}, {\"draws\": 624, \"mouse\": 4, \"mu_intercept_per_group\": 10.43575382232666, \"sigma_intercept_per_group\": 0.19906136393547058, \"sigma_obs\": 151.7274932861328, \"slope\": -0.07415813952684402, \"chain\": 3, \"draw\": 24}, {\"draws\": 624, \"mouse\": 5, \"mu_intercept_per_group\": 9.801602363586426, \"sigma_intercept_per_group\": 0.19906136393547058, \"sigma_obs\": 151.7274932861328, \"slope\": -0.07415813952684402, \"chain\": 3, \"draw\": 24}, {\"draws\": 624, \"mouse\": 6, \"mu_intercept_per_group\": 9.07168197631836, \"sigma_intercept_per_group\": 0.19906136393547058, \"sigma_obs\": 151.7274932861328, \"slope\": -0.07415813952684402, \"chain\": 3, \"draw\": 24}, {\"draws\": 624, \"mouse\": 7, \"mu_intercept_per_group\": 8.906899452209473, \"sigma_intercept_per_group\": 0.19906136393547058, \"sigma_obs\": 151.7274932861328, \"slope\": -0.07415813952684402, \"chain\": 3, \"draw\": 24}, {\"draws\": 625, \"mouse\": 0, \"mu_intercept_per_group\": 12.41055965423584, \"sigma_intercept_per_group\": 0.19939656555652618, \"sigma_obs\": 154.2828826904297, \"slope\": -0.06272265315055847, \"chain\": 3, \"draw\": 25}, {\"draws\": 625, \"mouse\": 1, \"mu_intercept_per_group\": 11.924768447875977, \"sigma_intercept_per_group\": 0.19939656555652618, \"sigma_obs\": 154.2828826904297, \"slope\": -0.06272265315055847, \"chain\": 3, \"draw\": 25}, {\"draws\": 625, \"mouse\": 2, \"mu_intercept_per_group\": 11.403365135192871, \"sigma_intercept_per_group\": 0.19939656555652618, \"sigma_obs\": 154.2828826904297, \"slope\": -0.06272265315055847, \"chain\": 3, \"draw\": 25}, {\"draws\": 625, \"mouse\": 3, \"mu_intercept_per_group\": 10.50480842590332, \"sigma_intercept_per_group\": 0.19939656555652618, \"sigma_obs\": 154.2828826904297, \"slope\": -0.06272265315055847, \"chain\": 3, \"draw\": 25}, {\"draws\": 625, \"mouse\": 4, \"mu_intercept_per_group\": 10.291705131530762, \"sigma_intercept_per_group\": 0.19939656555652618, \"sigma_obs\": 154.2828826904297, \"slope\": -0.06272265315055847, \"chain\": 3, \"draw\": 25}, {\"draws\": 625, \"mouse\": 5, \"mu_intercept_per_group\": 9.73351001739502, \"sigma_intercept_per_group\": 0.19939656555652618, \"sigma_obs\": 154.2828826904297, \"slope\": -0.06272265315055847, \"chain\": 3, \"draw\": 25}, {\"draws\": 625, \"mouse\": 6, \"mu_intercept_per_group\": 9.149078369140625, \"sigma_intercept_per_group\": 0.19939656555652618, \"sigma_obs\": 154.2828826904297, \"slope\": -0.06272265315055847, \"chain\": 3, \"draw\": 25}, {\"draws\": 625, \"mouse\": 7, \"mu_intercept_per_group\": 8.87335205078125, \"sigma_intercept_per_group\": 0.19939656555652618, \"sigma_obs\": 154.2828826904297, \"slope\": -0.06272265315055847, \"chain\": 3, \"draw\": 25}, {\"draws\": 626, \"mouse\": 0, \"mu_intercept_per_group\": 12.379714965820312, \"sigma_intercept_per_group\": 0.19682763516902924, \"sigma_obs\": 161.49891662597656, \"slope\": -0.08475339412689209, \"chain\": 3, \"draw\": 26}, {\"draws\": 626, \"mouse\": 1, \"mu_intercept_per_group\": 12.422453880310059, \"sigma_intercept_per_group\": 0.19682763516902924, \"sigma_obs\": 161.49891662597656, \"slope\": -0.08475339412689209, \"chain\": 3, \"draw\": 26}, {\"draws\": 626, \"mouse\": 2, \"mu_intercept_per_group\": 11.944137573242188, \"sigma_intercept_per_group\": 0.19682763516902924, \"sigma_obs\": 161.49891662597656, \"slope\": -0.08475339412689209, \"chain\": 3, \"draw\": 26}, {\"draws\": 626, \"mouse\": 3, \"mu_intercept_per_group\": 10.89665412902832, \"sigma_intercept_per_group\": 0.19682763516902924, \"sigma_obs\": 161.49891662597656, \"slope\": -0.08475339412689209, \"chain\": 3, \"draw\": 26}, {\"draws\": 626, \"mouse\": 4, \"mu_intercept_per_group\": 10.620931625366211, \"sigma_intercept_per_group\": 0.19682763516902924, \"sigma_obs\": 161.49891662597656, \"slope\": -0.08475339412689209, \"chain\": 3, \"draw\": 26}, {\"draws\": 626, \"mouse\": 5, \"mu_intercept_per_group\": 10.335612297058105, \"sigma_intercept_per_group\": 0.19682763516902924, \"sigma_obs\": 161.49891662597656, \"slope\": -0.08475339412689209, \"chain\": 3, \"draw\": 26}, {\"draws\": 626, \"mouse\": 6, \"mu_intercept_per_group\": 9.439434051513672, \"sigma_intercept_per_group\": 0.19682763516902924, \"sigma_obs\": 161.49891662597656, \"slope\": -0.08475339412689209, \"chain\": 3, \"draw\": 26}, {\"draws\": 626, \"mouse\": 7, \"mu_intercept_per_group\": 9.07543659210205, \"sigma_intercept_per_group\": 0.19682763516902924, \"sigma_obs\": 161.49891662597656, \"slope\": -0.08475339412689209, \"chain\": 3, \"draw\": 26}, {\"draws\": 627, \"mouse\": 0, \"mu_intercept_per_group\": 12.079679489135742, \"sigma_intercept_per_group\": 0.20832426846027374, \"sigma_obs\": 163.73924255371094, \"slope\": -0.08796888589859009, \"chain\": 3, \"draw\": 27}, {\"draws\": 627, \"mouse\": 1, \"mu_intercept_per_group\": 11.893685340881348, \"sigma_intercept_per_group\": 0.20832426846027374, \"sigma_obs\": 163.73924255371094, \"slope\": -0.08796888589859009, \"chain\": 3, \"draw\": 27}, {\"draws\": 627, \"mouse\": 2, \"mu_intercept_per_group\": 11.03127384185791, \"sigma_intercept_per_group\": 0.20832426846027374, \"sigma_obs\": 163.73924255371094, \"slope\": -0.08796888589859009, \"chain\": 3, \"draw\": 27}, {\"draws\": 627, \"mouse\": 3, \"mu_intercept_per_group\": 10.933551788330078, \"sigma_intercept_per_group\": 0.20832426846027374, \"sigma_obs\": 163.73924255371094, \"slope\": -0.08796888589859009, \"chain\": 3, \"draw\": 27}, {\"draws\": 627, \"mouse\": 4, \"mu_intercept_per_group\": 10.945788383483887, \"sigma_intercept_per_group\": 0.20832426846027374, \"sigma_obs\": 163.73924255371094, \"slope\": -0.08796888589859009, \"chain\": 3, \"draw\": 27}, {\"draws\": 627, \"mouse\": 5, \"mu_intercept_per_group\": 10.02033519744873, \"sigma_intercept_per_group\": 0.20832426846027374, \"sigma_obs\": 163.73924255371094, \"slope\": -0.08796888589859009, \"chain\": 3, \"draw\": 27}, {\"draws\": 627, \"mouse\": 6, \"mu_intercept_per_group\": 9.51424789428711, \"sigma_intercept_per_group\": 0.20832426846027374, \"sigma_obs\": 163.73924255371094, \"slope\": -0.08796888589859009, \"chain\": 3, \"draw\": 27}, {\"draws\": 627, \"mouse\": 7, \"mu_intercept_per_group\": 8.858007431030273, \"sigma_intercept_per_group\": 0.20832426846027374, \"sigma_obs\": 163.73924255371094, \"slope\": -0.08796888589859009, \"chain\": 3, \"draw\": 27}, {\"draws\": 628, \"mouse\": 0, \"mu_intercept_per_group\": 12.529230117797852, \"sigma_intercept_per_group\": 0.20244958996772766, \"sigma_obs\": 163.9332275390625, \"slope\": -0.08629661798477173, \"chain\": 3, \"draw\": 28}, {\"draws\": 628, \"mouse\": 1, \"mu_intercept_per_group\": 11.831846237182617, \"sigma_intercept_per_group\": 0.20244958996772766, \"sigma_obs\": 163.9332275390625, \"slope\": -0.08629661798477173, \"chain\": 3, \"draw\": 28}, {\"draws\": 628, \"mouse\": 2, \"mu_intercept_per_group\": 11.908169746398926, \"sigma_intercept_per_group\": 0.20244958996772766, \"sigma_obs\": 163.9332275390625, \"slope\": -0.08629661798477173, \"chain\": 3, \"draw\": 28}, {\"draws\": 628, \"mouse\": 3, \"mu_intercept_per_group\": 10.857256889343262, \"sigma_intercept_per_group\": 0.20244958996772766, \"sigma_obs\": 163.9332275390625, \"slope\": -0.08629661798477173, \"chain\": 3, \"draw\": 28}, {\"draws\": 628, \"mouse\": 4, \"mu_intercept_per_group\": 10.333227157592773, \"sigma_intercept_per_group\": 0.20244958996772766, \"sigma_obs\": 163.9332275390625, \"slope\": -0.08629661798477173, \"chain\": 3, \"draw\": 28}, {\"draws\": 628, \"mouse\": 5, \"mu_intercept_per_group\": 10.08115005493164, \"sigma_intercept_per_group\": 0.20244958996772766, \"sigma_obs\": 163.9332275390625, \"slope\": -0.08629661798477173, \"chain\": 3, \"draw\": 28}, {\"draws\": 628, \"mouse\": 6, \"mu_intercept_per_group\": 9.250786781311035, \"sigma_intercept_per_group\": 0.20244958996772766, \"sigma_obs\": 163.9332275390625, \"slope\": -0.08629661798477173, \"chain\": 3, \"draw\": 28}, {\"draws\": 628, \"mouse\": 7, \"mu_intercept_per_group\": 9.13144302368164, \"sigma_intercept_per_group\": 0.20244958996772766, \"sigma_obs\": 163.9332275390625, \"slope\": -0.08629661798477173, \"chain\": 3, \"draw\": 28}, {\"draws\": 629, \"mouse\": 0, \"mu_intercept_per_group\": 12.470256805419922, \"sigma_intercept_per_group\": 0.2067335546016693, \"sigma_obs\": 162.52273559570312, \"slope\": -0.09689773619174957, \"chain\": 3, \"draw\": 29}, {\"draws\": 629, \"mouse\": 1, \"mu_intercept_per_group\": 11.816271781921387, \"sigma_intercept_per_group\": 0.2067335546016693, \"sigma_obs\": 162.52273559570312, \"slope\": -0.09689773619174957, \"chain\": 3, \"draw\": 29}, {\"draws\": 629, \"mouse\": 2, \"mu_intercept_per_group\": 11.670877456665039, \"sigma_intercept_per_group\": 0.2067335546016693, \"sigma_obs\": 162.52273559570312, \"slope\": -0.09689773619174957, \"chain\": 3, \"draw\": 29}, {\"draws\": 629, \"mouse\": 3, \"mu_intercept_per_group\": 10.660325050354004, \"sigma_intercept_per_group\": 0.2067335546016693, \"sigma_obs\": 162.52273559570312, \"slope\": -0.09689773619174957, \"chain\": 3, \"draw\": 29}, {\"draws\": 629, \"mouse\": 4, \"mu_intercept_per_group\": 10.825642585754395, \"sigma_intercept_per_group\": 0.2067335546016693, \"sigma_obs\": 162.52273559570312, \"slope\": -0.09689773619174957, \"chain\": 3, \"draw\": 29}, {\"draws\": 629, \"mouse\": 5, \"mu_intercept_per_group\": 9.648846626281738, \"sigma_intercept_per_group\": 0.2067335546016693, \"sigma_obs\": 162.52273559570312, \"slope\": -0.09689773619174957, \"chain\": 3, \"draw\": 29}, {\"draws\": 629, \"mouse\": 6, \"mu_intercept_per_group\": 9.433323860168457, \"sigma_intercept_per_group\": 0.2067335546016693, \"sigma_obs\": 162.52273559570312, \"slope\": -0.09689773619174957, \"chain\": 3, \"draw\": 29}, {\"draws\": 629, \"mouse\": 7, \"mu_intercept_per_group\": 8.608820915222168, \"sigma_intercept_per_group\": 0.2067335546016693, \"sigma_obs\": 162.52273559570312, \"slope\": -0.09689773619174957, \"chain\": 3, \"draw\": 29}, {\"draws\": 630, \"mouse\": 0, \"mu_intercept_per_group\": 12.077754020690918, \"sigma_intercept_per_group\": 0.2088034749031067, \"sigma_obs\": 164.01438903808594, \"slope\": -0.0981077179312706, \"chain\": 3, \"draw\": 30}, {\"draws\": 630, \"mouse\": 1, \"mu_intercept_per_group\": 11.770718574523926, \"sigma_intercept_per_group\": 0.2088034749031067, \"sigma_obs\": 164.01438903808594, \"slope\": -0.0981077179312706, \"chain\": 3, \"draw\": 30}, {\"draws\": 630, \"mouse\": 2, \"mu_intercept_per_group\": 11.333057403564453, \"sigma_intercept_per_group\": 0.2088034749031067, \"sigma_obs\": 164.01438903808594, \"slope\": -0.0981077179312706, \"chain\": 3, \"draw\": 30}, {\"draws\": 630, \"mouse\": 3, \"mu_intercept_per_group\": 10.972949981689453, \"sigma_intercept_per_group\": 0.2088034749031067, \"sigma_obs\": 164.01438903808594, \"slope\": -0.0981077179312706, \"chain\": 3, \"draw\": 30}, {\"draws\": 630, \"mouse\": 4, \"mu_intercept_per_group\": 10.412496566772461, \"sigma_intercept_per_group\": 0.2088034749031067, \"sigma_obs\": 164.01438903808594, \"slope\": -0.0981077179312706, \"chain\": 3, \"draw\": 30}, {\"draws\": 630, \"mouse\": 5, \"mu_intercept_per_group\": 10.107831001281738, \"sigma_intercept_per_group\": 0.2088034749031067, \"sigma_obs\": 164.01438903808594, \"slope\": -0.0981077179312706, \"chain\": 3, \"draw\": 30}, {\"draws\": 630, \"mouse\": 6, \"mu_intercept_per_group\": 9.091657638549805, \"sigma_intercept_per_group\": 0.2088034749031067, \"sigma_obs\": 164.01438903808594, \"slope\": -0.0981077179312706, \"chain\": 3, \"draw\": 30}, {\"draws\": 630, \"mouse\": 7, \"mu_intercept_per_group\": 8.603425025939941, \"sigma_intercept_per_group\": 0.2088034749031067, \"sigma_obs\": 164.01438903808594, \"slope\": -0.0981077179312706, \"chain\": 3, \"draw\": 30}, {\"draws\": 631, \"mouse\": 0, \"mu_intercept_per_group\": 6.4304914474487305, \"sigma_intercept_per_group\": 0.3793681561946869, \"sigma_obs\": 157.00778198242188, \"slope\": -0.04577075317502022, \"chain\": 3, \"draw\": 31}, {\"draws\": 631, \"mouse\": 1, \"mu_intercept_per_group\": 6.163496494293213, \"sigma_intercept_per_group\": 0.3793681561946869, \"sigma_obs\": 157.00778198242188, \"slope\": -0.04577075317502022, \"chain\": 3, \"draw\": 31}, {\"draws\": 631, \"mouse\": 2, \"mu_intercept_per_group\": 5.9586262702941895, \"sigma_intercept_per_group\": 0.3793681561946869, \"sigma_obs\": 157.00778198242188, \"slope\": -0.04577075317502022, \"chain\": 3, \"draw\": 31}, {\"draws\": 631, \"mouse\": 3, \"mu_intercept_per_group\": 5.51161527633667, \"sigma_intercept_per_group\": 0.3793681561946869, \"sigma_obs\": 157.00778198242188, \"slope\": -0.04577075317502022, \"chain\": 3, \"draw\": 31}, {\"draws\": 631, \"mouse\": 4, \"mu_intercept_per_group\": 5.346264362335205, \"sigma_intercept_per_group\": 0.3793681561946869, \"sigma_obs\": 157.00778198242188, \"slope\": -0.04577075317502022, \"chain\": 3, \"draw\": 31}, {\"draws\": 631, \"mouse\": 5, \"mu_intercept_per_group\": 5.184458255767822, \"sigma_intercept_per_group\": 0.3793681561946869, \"sigma_obs\": 157.00778198242188, \"slope\": -0.04577075317502022, \"chain\": 3, \"draw\": 31}, {\"draws\": 631, \"mouse\": 6, \"mu_intercept_per_group\": 4.709381103515625, \"sigma_intercept_per_group\": 0.3793681561946869, \"sigma_obs\": 157.00778198242188, \"slope\": -0.04577075317502022, \"chain\": 3, \"draw\": 31}, {\"draws\": 631, \"mouse\": 7, \"mu_intercept_per_group\": 4.6340250968933105, \"sigma_intercept_per_group\": 0.3793681561946869, \"sigma_obs\": 157.00778198242188, \"slope\": -0.04577075317502022, \"chain\": 3, \"draw\": 31}, {\"draws\": 632, \"mouse\": 0, \"mu_intercept_per_group\": 9.112715721130371, \"sigma_intercept_per_group\": 0.26946258544921875, \"sigma_obs\": 156.9292755126953, \"slope\": -0.0796416625380516, \"chain\": 3, \"draw\": 32}, {\"draws\": 632, \"mouse\": 1, \"mu_intercept_per_group\": 8.911646842956543, \"sigma_intercept_per_group\": 0.26946258544921875, \"sigma_obs\": 156.9292755126953, \"slope\": -0.0796416625380516, \"chain\": 3, \"draw\": 32}, {\"draws\": 632, \"mouse\": 2, \"mu_intercept_per_group\": 8.455743789672852, \"sigma_intercept_per_group\": 0.26946258544921875, \"sigma_obs\": 156.9292755126953, \"slope\": -0.0796416625380516, \"chain\": 3, \"draw\": 32}, {\"draws\": 632, \"mouse\": 3, \"mu_intercept_per_group\": 8.272784233093262, \"sigma_intercept_per_group\": 0.26946258544921875, \"sigma_obs\": 156.9292755126953, \"slope\": -0.0796416625380516, \"chain\": 3, \"draw\": 32}, {\"draws\": 632, \"mouse\": 4, \"mu_intercept_per_group\": 7.81766939163208, \"sigma_intercept_per_group\": 0.26946258544921875, \"sigma_obs\": 156.9292755126953, \"slope\": -0.0796416625380516, \"chain\": 3, \"draw\": 32}, {\"draws\": 632, \"mouse\": 5, \"mu_intercept_per_group\": 7.42979621887207, \"sigma_intercept_per_group\": 0.26946258544921875, \"sigma_obs\": 156.9292755126953, \"slope\": -0.0796416625380516, \"chain\": 3, \"draw\": 32}, {\"draws\": 632, \"mouse\": 6, \"mu_intercept_per_group\": 6.92149543762207, \"sigma_intercept_per_group\": 0.26946258544921875, \"sigma_obs\": 156.9292755126953, \"slope\": -0.0796416625380516, \"chain\": 3, \"draw\": 32}, {\"draws\": 632, \"mouse\": 7, \"mu_intercept_per_group\": 6.4563374519348145, \"sigma_intercept_per_group\": 0.26946258544921875, \"sigma_obs\": 156.9292755126953, \"slope\": -0.0796416625380516, \"chain\": 3, \"draw\": 32}, {\"draws\": 633, \"mouse\": 0, \"mu_intercept_per_group\": 9.582212448120117, \"sigma_intercept_per_group\": 0.2552053928375244, \"sigma_obs\": 152.2623748779297, \"slope\": -0.0931721106171608, \"chain\": 3, \"draw\": 33}, {\"draws\": 633, \"mouse\": 1, \"mu_intercept_per_group\": 9.407100677490234, \"sigma_intercept_per_group\": 0.2552053928375244, \"sigma_obs\": 152.2623748779297, \"slope\": -0.0931721106171608, \"chain\": 3, \"draw\": 33}, {\"draws\": 633, \"mouse\": 2, \"mu_intercept_per_group\": 9.013545989990234, \"sigma_intercept_per_group\": 0.2552053928375244, \"sigma_obs\": 152.2623748779297, \"slope\": -0.0931721106171608, \"chain\": 3, \"draw\": 33}, {\"draws\": 633, \"mouse\": 3, \"mu_intercept_per_group\": 8.276387214660645, \"sigma_intercept_per_group\": 0.2552053928375244, \"sigma_obs\": 152.2623748779297, \"slope\": -0.0931721106171608, \"chain\": 3, \"draw\": 33}, {\"draws\": 633, \"mouse\": 4, \"mu_intercept_per_group\": 8.408561706542969, \"sigma_intercept_per_group\": 0.2552053928375244, \"sigma_obs\": 152.2623748779297, \"slope\": -0.0931721106171608, \"chain\": 3, \"draw\": 33}, {\"draws\": 633, \"mouse\": 5, \"mu_intercept_per_group\": 7.694674015045166, \"sigma_intercept_per_group\": 0.2552053928375244, \"sigma_obs\": 152.2623748779297, \"slope\": -0.0931721106171608, \"chain\": 3, \"draw\": 33}, {\"draws\": 633, \"mouse\": 6, \"mu_intercept_per_group\": 7.380815029144287, \"sigma_intercept_per_group\": 0.2552053928375244, \"sigma_obs\": 152.2623748779297, \"slope\": -0.0931721106171608, \"chain\": 3, \"draw\": 33}, {\"draws\": 633, \"mouse\": 7, \"mu_intercept_per_group\": 6.792831897735596, \"sigma_intercept_per_group\": 0.2552053928375244, \"sigma_obs\": 152.2623748779297, \"slope\": -0.0931721106171608, \"chain\": 3, \"draw\": 33}, {\"draws\": 634, \"mouse\": 0, \"mu_intercept_per_group\": 10.655858993530273, \"sigma_intercept_per_group\": 0.2203543335199356, \"sigma_obs\": 140.07884216308594, \"slope\": -0.07707113772630692, \"chain\": 3, \"draw\": 34}, {\"draws\": 634, \"mouse\": 1, \"mu_intercept_per_group\": 10.344094276428223, \"sigma_intercept_per_group\": 0.2203543335199356, \"sigma_obs\": 140.07884216308594, \"slope\": -0.07707113772630692, \"chain\": 3, \"draw\": 34}, {\"draws\": 634, \"mouse\": 2, \"mu_intercept_per_group\": 9.835336685180664, \"sigma_intercept_per_group\": 0.2203543335199356, \"sigma_obs\": 140.07884216308594, \"slope\": -0.07707113772630692, \"chain\": 3, \"draw\": 34}, {\"draws\": 634, \"mouse\": 3, \"mu_intercept_per_group\": 9.525359153747559, \"sigma_intercept_per_group\": 0.2203543335199356, \"sigma_obs\": 140.07884216308594, \"slope\": -0.07707113772630692, \"chain\": 3, \"draw\": 34}, {\"draws\": 634, \"mouse\": 4, \"mu_intercept_per_group\": 8.865493774414062, \"sigma_intercept_per_group\": 0.2203543335199356, \"sigma_obs\": 140.07884216308594, \"slope\": -0.07707113772630692, \"chain\": 3, \"draw\": 34}, {\"draws\": 634, \"mouse\": 5, \"mu_intercept_per_group\": 8.466951370239258, \"sigma_intercept_per_group\": 0.2203543335199356, \"sigma_obs\": 140.07884216308594, \"slope\": -0.07707113772630692, \"chain\": 3, \"draw\": 34}, {\"draws\": 634, \"mouse\": 6, \"mu_intercept_per_group\": 8.015277862548828, \"sigma_intercept_per_group\": 0.2203543335199356, \"sigma_obs\": 140.07884216308594, \"slope\": -0.07707113772630692, \"chain\": 3, \"draw\": 34}, {\"draws\": 634, \"mouse\": 7, \"mu_intercept_per_group\": 7.823418617248535, \"sigma_intercept_per_group\": 0.2203543335199356, \"sigma_obs\": 140.07884216308594, \"slope\": -0.07707113772630692, \"chain\": 3, \"draw\": 34}, {\"draws\": 635, \"mouse\": 0, \"mu_intercept_per_group\": 10.789499282836914, \"sigma_intercept_per_group\": 0.215985506772995, \"sigma_obs\": 137.1995391845703, \"slope\": -0.07463309913873672, \"chain\": 3, \"draw\": 35}, {\"draws\": 635, \"mouse\": 1, \"mu_intercept_per_group\": 10.247411727905273, \"sigma_intercept_per_group\": 0.215985506772995, \"sigma_obs\": 137.1995391845703, \"slope\": -0.07463309913873672, \"chain\": 3, \"draw\": 35}, {\"draws\": 635, \"mouse\": 2, \"mu_intercept_per_group\": 10.263104438781738, \"sigma_intercept_per_group\": 0.215985506772995, \"sigma_obs\": 137.1995391845703, \"slope\": -0.07463309913873672, \"chain\": 3, \"draw\": 35}, {\"draws\": 635, \"mouse\": 3, \"mu_intercept_per_group\": 9.345789909362793, \"sigma_intercept_per_group\": 0.215985506772995, \"sigma_obs\": 137.1995391845703, \"slope\": -0.07463309913873672, \"chain\": 3, \"draw\": 35}, {\"draws\": 635, \"mouse\": 4, \"mu_intercept_per_group\": 9.417060852050781, \"sigma_intercept_per_group\": 0.215985506772995, \"sigma_obs\": 137.1995391845703, \"slope\": -0.07463309913873672, \"chain\": 3, \"draw\": 35}, {\"draws\": 635, \"mouse\": 5, \"mu_intercept_per_group\": 8.844149589538574, \"sigma_intercept_per_group\": 0.215985506772995, \"sigma_obs\": 137.1995391845703, \"slope\": -0.07463309913873672, \"chain\": 3, \"draw\": 35}, {\"draws\": 635, \"mouse\": 6, \"mu_intercept_per_group\": 8.0488920211792, \"sigma_intercept_per_group\": 0.215985506772995, \"sigma_obs\": 137.1995391845703, \"slope\": -0.07463309913873672, \"chain\": 3, \"draw\": 35}, {\"draws\": 635, \"mouse\": 7, \"mu_intercept_per_group\": 7.458919048309326, \"sigma_intercept_per_group\": 0.215985506772995, \"sigma_obs\": 137.1995391845703, \"slope\": -0.07463309913873672, \"chain\": 3, \"draw\": 35}, {\"draws\": 636, \"mouse\": 0, \"mu_intercept_per_group\": 11.019827842712402, \"sigma_intercept_per_group\": 0.21367134153842926, \"sigma_obs\": 136.752197265625, \"slope\": -0.07654011249542236, \"chain\": 3, \"draw\": 36}, {\"draws\": 636, \"mouse\": 1, \"mu_intercept_per_group\": 10.748201370239258, \"sigma_intercept_per_group\": 0.21367134153842926, \"sigma_obs\": 136.752197265625, \"slope\": -0.07654011249542236, \"chain\": 3, \"draw\": 36}, {\"draws\": 636, \"mouse\": 2, \"mu_intercept_per_group\": 10.167494773864746, \"sigma_intercept_per_group\": 0.21367134153842926, \"sigma_obs\": 136.752197265625, \"slope\": -0.07654011249542236, \"chain\": 3, \"draw\": 36}, {\"draws\": 636, \"mouse\": 3, \"mu_intercept_per_group\": 9.335482597351074, \"sigma_intercept_per_group\": 0.21367134153842926, \"sigma_obs\": 136.752197265625, \"slope\": -0.07654011249542236, \"chain\": 3, \"draw\": 36}, {\"draws\": 636, \"mouse\": 4, \"mu_intercept_per_group\": 9.284844398498535, \"sigma_intercept_per_group\": 0.21367134153842926, \"sigma_obs\": 136.752197265625, \"slope\": -0.07654011249542236, \"chain\": 3, \"draw\": 36}, {\"draws\": 636, \"mouse\": 5, \"mu_intercept_per_group\": 8.761554718017578, \"sigma_intercept_per_group\": 0.21367134153842926, \"sigma_obs\": 136.752197265625, \"slope\": -0.07654011249542236, \"chain\": 3, \"draw\": 36}, {\"draws\": 636, \"mouse\": 6, \"mu_intercept_per_group\": 8.147503852844238, \"sigma_intercept_per_group\": 0.21367134153842926, \"sigma_obs\": 136.752197265625, \"slope\": -0.07654011249542236, \"chain\": 3, \"draw\": 36}, {\"draws\": 636, \"mouse\": 7, \"mu_intercept_per_group\": 7.394556522369385, \"sigma_intercept_per_group\": 0.21367134153842926, \"sigma_obs\": 136.752197265625, \"slope\": -0.07654011249542236, \"chain\": 3, \"draw\": 36}, {\"draws\": 637, \"mouse\": 0, \"mu_intercept_per_group\": 10.991358757019043, \"sigma_intercept_per_group\": 0.2136537879705429, \"sigma_obs\": 136.62411499023438, \"slope\": -0.07728315144777298, \"chain\": 3, \"draw\": 37}, {\"draws\": 637, \"mouse\": 1, \"mu_intercept_per_group\": 10.409515380859375, \"sigma_intercept_per_group\": 0.2136537879705429, \"sigma_obs\": 136.62411499023438, \"slope\": -0.07728315144777298, \"chain\": 3, \"draw\": 37}, {\"draws\": 637, \"mouse\": 2, \"mu_intercept_per_group\": 10.18025016784668, \"sigma_intercept_per_group\": 0.2136537879705429, \"sigma_obs\": 136.62411499023438, \"slope\": -0.07728315144777298, \"chain\": 3, \"draw\": 37}, {\"draws\": 637, \"mouse\": 3, \"mu_intercept_per_group\": 9.825712203979492, \"sigma_intercept_per_group\": 0.2136537879705429, \"sigma_obs\": 136.62411499023438, \"slope\": -0.07728315144777298, \"chain\": 3, \"draw\": 37}, {\"draws\": 637, \"mouse\": 4, \"mu_intercept_per_group\": 9.375346183776855, \"sigma_intercept_per_group\": 0.2136537879705429, \"sigma_obs\": 136.62411499023438, \"slope\": -0.07728315144777298, \"chain\": 3, \"draw\": 37}, {\"draws\": 637, \"mouse\": 5, \"mu_intercept_per_group\": 8.688446998596191, \"sigma_intercept_per_group\": 0.2136537879705429, \"sigma_obs\": 136.62411499023438, \"slope\": -0.07728315144777298, \"chain\": 3, \"draw\": 37}, {\"draws\": 637, \"mouse\": 6, \"mu_intercept_per_group\": 8.196284294128418, \"sigma_intercept_per_group\": 0.2136537879705429, \"sigma_obs\": 136.62411499023438, \"slope\": -0.07728315144777298, \"chain\": 3, \"draw\": 37}, {\"draws\": 637, \"mouse\": 7, \"mu_intercept_per_group\": 7.553134918212891, \"sigma_intercept_per_group\": 0.2136537879705429, \"sigma_obs\": 136.62411499023438, \"slope\": -0.07728315144777298, \"chain\": 3, \"draw\": 37}, {\"draws\": 638, \"mouse\": 0, \"mu_intercept_per_group\": 9.968367576599121, \"sigma_intercept_per_group\": 0.23653891682624817, \"sigma_obs\": 145.52947998046875, \"slope\": -0.07970781624317169, \"chain\": 3, \"draw\": 38}, {\"draws\": 638, \"mouse\": 1, \"mu_intercept_per_group\": 9.764054298400879, \"sigma_intercept_per_group\": 0.23653891682624817, \"sigma_obs\": 145.52947998046875, \"slope\": -0.07970781624317169, \"chain\": 3, \"draw\": 38}, {\"draws\": 638, \"mouse\": 2, \"mu_intercept_per_group\": 9.480262756347656, \"sigma_intercept_per_group\": 0.23653891682624817, \"sigma_obs\": 145.52947998046875, \"slope\": -0.07970781624317169, \"chain\": 3, \"draw\": 38}, {\"draws\": 638, \"mouse\": 3, \"mu_intercept_per_group\": 8.930115699768066, \"sigma_intercept_per_group\": 0.23653891682624817, \"sigma_obs\": 145.52947998046875, \"slope\": -0.07970781624317169, \"chain\": 3, \"draw\": 38}, {\"draws\": 638, \"mouse\": 4, \"mu_intercept_per_group\": 8.599649429321289, \"sigma_intercept_per_group\": 0.23653891682624817, \"sigma_obs\": 145.52947998046875, \"slope\": -0.07970781624317169, \"chain\": 3, \"draw\": 38}, {\"draws\": 638, \"mouse\": 5, \"mu_intercept_per_group\": 8.255816459655762, \"sigma_intercept_per_group\": 0.23653891682624817, \"sigma_obs\": 145.52947998046875, \"slope\": -0.07970781624317169, \"chain\": 3, \"draw\": 38}, {\"draws\": 638, \"mouse\": 6, \"mu_intercept_per_group\": 7.637923240661621, \"sigma_intercept_per_group\": 0.23653891682624817, \"sigma_obs\": 145.52947998046875, \"slope\": -0.07970781624317169, \"chain\": 3, \"draw\": 38}, {\"draws\": 638, \"mouse\": 7, \"mu_intercept_per_group\": 7.504669189453125, \"sigma_intercept_per_group\": 0.23653891682624817, \"sigma_obs\": 145.52947998046875, \"slope\": -0.07970781624317169, \"chain\": 3, \"draw\": 38}, {\"draws\": 639, \"mouse\": 0, \"mu_intercept_per_group\": 9.809822082519531, \"sigma_intercept_per_group\": 0.24497279524803162, \"sigma_obs\": 145.1079559326172, \"slope\": -0.08034254610538483, \"chain\": 3, \"draw\": 39}, {\"draws\": 639, \"mouse\": 1, \"mu_intercept_per_group\": 9.260549545288086, \"sigma_intercept_per_group\": 0.24497279524803162, \"sigma_obs\": 145.1079559326172, \"slope\": -0.08034254610538483, \"chain\": 3, \"draw\": 39}, {\"draws\": 639, \"mouse\": 2, \"mu_intercept_per_group\": 9.167030334472656, \"sigma_intercept_per_group\": 0.24497279524803162, \"sigma_obs\": 145.1079559326172, \"slope\": -0.08034254610538483, \"chain\": 3, \"draw\": 39}, {\"draws\": 639, \"mouse\": 3, \"mu_intercept_per_group\": 8.439026832580566, \"sigma_intercept_per_group\": 0.24497279524803162, \"sigma_obs\": 145.1079559326172, \"slope\": -0.08034254610538483, \"chain\": 3, \"draw\": 39}, {\"draws\": 639, \"mouse\": 4, \"mu_intercept_per_group\": 8.5310640335083, \"sigma_intercept_per_group\": 0.24497279524803162, \"sigma_obs\": 145.1079559326172, \"slope\": -0.08034254610538483, \"chain\": 3, \"draw\": 39}, {\"draws\": 639, \"mouse\": 5, \"mu_intercept_per_group\": 7.784132957458496, \"sigma_intercept_per_group\": 0.24497279524803162, \"sigma_obs\": 145.1079559326172, \"slope\": -0.08034254610538483, \"chain\": 3, \"draw\": 39}, {\"draws\": 639, \"mouse\": 6, \"mu_intercept_per_group\": 7.342451095581055, \"sigma_intercept_per_group\": 0.24497279524803162, \"sigma_obs\": 145.1079559326172, \"slope\": -0.08034254610538483, \"chain\": 3, \"draw\": 39}, {\"draws\": 639, \"mouse\": 7, \"mu_intercept_per_group\": 6.6576032638549805, \"sigma_intercept_per_group\": 0.24497279524803162, \"sigma_obs\": 145.1079559326172, \"slope\": -0.08034254610538483, \"chain\": 3, \"draw\": 39}, {\"draws\": 640, \"mouse\": 0, \"mu_intercept_per_group\": 7.516387462615967, \"sigma_intercept_per_group\": 0.3220468759536743, \"sigma_obs\": 153.681396484375, \"slope\": -0.07284707576036453, \"chain\": 3, \"draw\": 40}, {\"draws\": 640, \"mouse\": 1, \"mu_intercept_per_group\": 7.309369087219238, \"sigma_intercept_per_group\": 0.3220468759536743, \"sigma_obs\": 153.681396484375, \"slope\": -0.07284707576036453, \"chain\": 3, \"draw\": 40}, {\"draws\": 640, \"mouse\": 2, \"mu_intercept_per_group\": 7.176274299621582, \"sigma_intercept_per_group\": 0.3220468759536743, \"sigma_obs\": 153.681396484375, \"slope\": -0.07284707576036453, \"chain\": 3, \"draw\": 40}, {\"draws\": 640, \"mouse\": 3, \"mu_intercept_per_group\": 6.782723426818848, \"sigma_intercept_per_group\": 0.3220468759536743, \"sigma_obs\": 153.681396484375, \"slope\": -0.07284707576036453, \"chain\": 3, \"draw\": 40}, {\"draws\": 640, \"mouse\": 4, \"mu_intercept_per_group\": 6.62546443939209, \"sigma_intercept_per_group\": 0.3220468759536743, \"sigma_obs\": 153.681396484375, \"slope\": -0.07284707576036453, \"chain\": 3, \"draw\": 40}, {\"draws\": 640, \"mouse\": 5, \"mu_intercept_per_group\": 6.248480319976807, \"sigma_intercept_per_group\": 0.3220468759536743, \"sigma_obs\": 153.681396484375, \"slope\": -0.07284707576036453, \"chain\": 3, \"draw\": 40}, {\"draws\": 640, \"mouse\": 6, \"mu_intercept_per_group\": 5.824257850646973, \"sigma_intercept_per_group\": 0.3220468759536743, \"sigma_obs\": 153.681396484375, \"slope\": -0.07284707576036453, \"chain\": 3, \"draw\": 40}, {\"draws\": 640, \"mouse\": 7, \"mu_intercept_per_group\": 5.252965927124023, \"sigma_intercept_per_group\": 0.3220468759536743, \"sigma_obs\": 153.681396484375, \"slope\": -0.07284707576036453, \"chain\": 3, \"draw\": 40}, {\"draws\": 641, \"mouse\": 0, \"mu_intercept_per_group\": 7.841986179351807, \"sigma_intercept_per_group\": 0.3144895136356354, \"sigma_obs\": 153.91534423828125, \"slope\": -0.07286152988672256, \"chain\": 3, \"draw\": 41}, {\"draws\": 641, \"mouse\": 1, \"mu_intercept_per_group\": 7.526483058929443, \"sigma_intercept_per_group\": 0.3144895136356354, \"sigma_obs\": 153.91534423828125, \"slope\": -0.07286152988672256, \"chain\": 3, \"draw\": 41}, {\"draws\": 641, \"mouse\": 2, \"mu_intercept_per_group\": 7.125767230987549, \"sigma_intercept_per_group\": 0.3144895136356354, \"sigma_obs\": 153.91534423828125, \"slope\": -0.07286152988672256, \"chain\": 3, \"draw\": 41}, {\"draws\": 641, \"mouse\": 3, \"mu_intercept_per_group\": 6.581087112426758, \"sigma_intercept_per_group\": 0.3144895136356354, \"sigma_obs\": 153.91534423828125, \"slope\": -0.07286152988672256, \"chain\": 3, \"draw\": 41}, {\"draws\": 641, \"mouse\": 4, \"mu_intercept_per_group\": 6.564442157745361, \"sigma_intercept_per_group\": 0.3144895136356354, \"sigma_obs\": 153.91534423828125, \"slope\": -0.07286152988672256, \"chain\": 3, \"draw\": 41}, {\"draws\": 641, \"mouse\": 5, \"mu_intercept_per_group\": 6.078890323638916, \"sigma_intercept_per_group\": 0.3144895136356354, \"sigma_obs\": 153.91534423828125, \"slope\": -0.07286152988672256, \"chain\": 3, \"draw\": 41}, {\"draws\": 641, \"mouse\": 6, \"mu_intercept_per_group\": 5.829608917236328, \"sigma_intercept_per_group\": 0.3144895136356354, \"sigma_obs\": 153.91534423828125, \"slope\": -0.07286152988672256, \"chain\": 3, \"draw\": 41}, {\"draws\": 641, \"mouse\": 7, \"mu_intercept_per_group\": 5.461090564727783, \"sigma_intercept_per_group\": 0.3144895136356354, \"sigma_obs\": 153.91534423828125, \"slope\": -0.07286152988672256, \"chain\": 3, \"draw\": 41}, {\"draws\": 642, \"mouse\": 0, \"mu_intercept_per_group\": 7.297159194946289, \"sigma_intercept_per_group\": 0.3226001262664795, \"sigma_obs\": 153.46009826660156, \"slope\": -0.07201393693685532, \"chain\": 3, \"draw\": 42}, {\"draws\": 642, \"mouse\": 1, \"mu_intercept_per_group\": 7.061487674713135, \"sigma_intercept_per_group\": 0.3226001262664795, \"sigma_obs\": 153.46009826660156, \"slope\": -0.07201393693685532, \"chain\": 3, \"draw\": 42}, {\"draws\": 642, \"mouse\": 2, \"mu_intercept_per_group\": 7.059835910797119, \"sigma_intercept_per_group\": 0.3226001262664795, \"sigma_obs\": 153.46009826660156, \"slope\": -0.07201393693685532, \"chain\": 3, \"draw\": 42}, {\"draws\": 642, \"mouse\": 3, \"mu_intercept_per_group\": 6.69674015045166, \"sigma_intercept_per_group\": 0.3226001262664795, \"sigma_obs\": 153.46009826660156, \"slope\": -0.07201393693685532, \"chain\": 3, \"draw\": 42}, {\"draws\": 642, \"mouse\": 4, \"mu_intercept_per_group\": 6.519297122955322, \"sigma_intercept_per_group\": 0.3226001262664795, \"sigma_obs\": 153.46009826660156, \"slope\": -0.07201393693685532, \"chain\": 3, \"draw\": 42}, {\"draws\": 642, \"mouse\": 5, \"mu_intercept_per_group\": 6.0919508934021, \"sigma_intercept_per_group\": 0.3226001262664795, \"sigma_obs\": 153.46009826660156, \"slope\": -0.07201393693685532, \"chain\": 3, \"draw\": 42}, {\"draws\": 642, \"mouse\": 6, \"mu_intercept_per_group\": 5.657279968261719, \"sigma_intercept_per_group\": 0.3226001262664795, \"sigma_obs\": 153.46009826660156, \"slope\": -0.07201393693685532, \"chain\": 3, \"draw\": 42}, {\"draws\": 642, \"mouse\": 7, \"mu_intercept_per_group\": 5.732651710510254, \"sigma_intercept_per_group\": 0.3226001262664795, \"sigma_obs\": 153.46009826660156, \"slope\": -0.07201393693685532, \"chain\": 3, \"draw\": 42}, {\"draws\": 643, \"mouse\": 0, \"mu_intercept_per_group\": 7.2913312911987305, \"sigma_intercept_per_group\": 0.32341504096984863, \"sigma_obs\": 153.40171813964844, \"slope\": -0.0719662606716156, \"chain\": 3, \"draw\": 43}, {\"draws\": 643, \"mouse\": 1, \"mu_intercept_per_group\": 7.11761999130249, \"sigma_intercept_per_group\": 0.32341504096984863, \"sigma_obs\": 153.40171813964844, \"slope\": -0.0719662606716156, \"chain\": 3, \"draw\": 43}, {\"draws\": 643, \"mouse\": 2, \"mu_intercept_per_group\": 7.077873229980469, \"sigma_intercept_per_group\": 0.32341504096984863, \"sigma_obs\": 153.40171813964844, \"slope\": -0.0719662606716156, \"chain\": 3, \"draw\": 43}, {\"draws\": 643, \"mouse\": 3, \"mu_intercept_per_group\": 6.738454818725586, \"sigma_intercept_per_group\": 0.32341504096984863, \"sigma_obs\": 153.40171813964844, \"slope\": -0.0719662606716156, \"chain\": 3, \"draw\": 43}, {\"draws\": 643, \"mouse\": 4, \"mu_intercept_per_group\": 6.472561836242676, \"sigma_intercept_per_group\": 0.32341504096984863, \"sigma_obs\": 153.40171813964844, \"slope\": -0.0719662606716156, \"chain\": 3, \"draw\": 43}, {\"draws\": 643, \"mouse\": 5, \"mu_intercept_per_group\": 6.112044334411621, \"sigma_intercept_per_group\": 0.32341504096984863, \"sigma_obs\": 153.40171813964844, \"slope\": -0.0719662606716156, \"chain\": 3, \"draw\": 43}, {\"draws\": 643, \"mouse\": 6, \"mu_intercept_per_group\": 5.641627311706543, \"sigma_intercept_per_group\": 0.32341504096984863, \"sigma_obs\": 153.40171813964844, \"slope\": -0.0719662606716156, \"chain\": 3, \"draw\": 43}, {\"draws\": 643, \"mouse\": 7, \"mu_intercept_per_group\": 5.746239185333252, \"sigma_intercept_per_group\": 0.32341504096984863, \"sigma_obs\": 153.40171813964844, \"slope\": -0.0719662606716156, \"chain\": 3, \"draw\": 43}, {\"draws\": 644, \"mouse\": 0, \"mu_intercept_per_group\": 7.583577632904053, \"sigma_intercept_per_group\": 0.3331006169319153, \"sigma_obs\": 159.961181640625, \"slope\": -0.08416654914617538, \"chain\": 3, \"draw\": 44}, {\"draws\": 644, \"mouse\": 1, \"mu_intercept_per_group\": 7.183538436889648, \"sigma_intercept_per_group\": 0.3331006169319153, \"sigma_obs\": 159.961181640625, \"slope\": -0.08416654914617538, \"chain\": 3, \"draw\": 44}, {\"draws\": 644, \"mouse\": 2, \"mu_intercept_per_group\": 6.858323574066162, \"sigma_intercept_per_group\": 0.3331006169319153, \"sigma_obs\": 159.961181640625, \"slope\": -0.08416654914617538, \"chain\": 3, \"draw\": 44}, {\"draws\": 644, \"mouse\": 3, \"mu_intercept_per_group\": 6.703623294830322, \"sigma_intercept_per_group\": 0.3331006169319153, \"sigma_obs\": 159.961181640625, \"slope\": -0.08416654914617538, \"chain\": 3, \"draw\": 44}, {\"draws\": 644, \"mouse\": 4, \"mu_intercept_per_group\": 6.516486644744873, \"sigma_intercept_per_group\": 0.3331006169319153, \"sigma_obs\": 159.961181640625, \"slope\": -0.08416654914617538, \"chain\": 3, \"draw\": 44}, {\"draws\": 644, \"mouse\": 5, \"mu_intercept_per_group\": 6.207400321960449, \"sigma_intercept_per_group\": 0.3331006169319153, \"sigma_obs\": 159.961181640625, \"slope\": -0.08416654914617538, \"chain\": 3, \"draw\": 44}, {\"draws\": 644, \"mouse\": 6, \"mu_intercept_per_group\": 5.749669551849365, \"sigma_intercept_per_group\": 0.3331006169319153, \"sigma_obs\": 159.961181640625, \"slope\": -0.08416654914617538, \"chain\": 3, \"draw\": 44}, {\"draws\": 644, \"mouse\": 7, \"mu_intercept_per_group\": 5.166900157928467, \"sigma_intercept_per_group\": 0.3331006169319153, \"sigma_obs\": 159.961181640625, \"slope\": -0.08416654914617538, \"chain\": 3, \"draw\": 44}, {\"draws\": 645, \"mouse\": 0, \"mu_intercept_per_group\": 7.422779083251953, \"sigma_intercept_per_group\": 0.3337811827659607, \"sigma_obs\": 160.1918487548828, \"slope\": -0.08361785113811493, \"chain\": 3, \"draw\": 45}, {\"draws\": 645, \"mouse\": 1, \"mu_intercept_per_group\": 7.236363887786865, \"sigma_intercept_per_group\": 0.3337811827659607, \"sigma_obs\": 160.1918487548828, \"slope\": -0.08361785113811493, \"chain\": 3, \"draw\": 45}, {\"draws\": 645, \"mouse\": 2, \"mu_intercept_per_group\": 7.151386260986328, \"sigma_intercept_per_group\": 0.3337811827659607, \"sigma_obs\": 160.1918487548828, \"slope\": -0.08361785113811493, \"chain\": 3, \"draw\": 45}, {\"draws\": 645, \"mouse\": 3, \"mu_intercept_per_group\": 6.508066177368164, \"sigma_intercept_per_group\": 0.3337811827659607, \"sigma_obs\": 160.1918487548828, \"slope\": -0.08361785113811493, \"chain\": 3, \"draw\": 45}, {\"draws\": 645, \"mouse\": 4, \"mu_intercept_per_group\": 6.329521179199219, \"sigma_intercept_per_group\": 0.3337811827659607, \"sigma_obs\": 160.1918487548828, \"slope\": -0.08361785113811493, \"chain\": 3, \"draw\": 45}, {\"draws\": 645, \"mouse\": 5, \"mu_intercept_per_group\": 5.959726333618164, \"sigma_intercept_per_group\": 0.3337811827659607, \"sigma_obs\": 160.1918487548828, \"slope\": -0.08361785113811493, \"chain\": 3, \"draw\": 45}, {\"draws\": 645, \"mouse\": 6, \"mu_intercept_per_group\": 5.851258277893066, \"sigma_intercept_per_group\": 0.3337811827659607, \"sigma_obs\": 160.1918487548828, \"slope\": -0.08361785113811493, \"chain\": 3, \"draw\": 45}, {\"draws\": 645, \"mouse\": 7, \"mu_intercept_per_group\": 5.433037281036377, \"sigma_intercept_per_group\": 0.3337811827659607, \"sigma_obs\": 160.1918487548828, \"slope\": -0.08361785113811493, \"chain\": 3, \"draw\": 45}, {\"draws\": 646, \"mouse\": 0, \"mu_intercept_per_group\": 7.466848850250244, \"sigma_intercept_per_group\": 0.33304673433303833, \"sigma_obs\": 160.6607666015625, \"slope\": -0.08350682258605957, \"chain\": 3, \"draw\": 46}, {\"draws\": 646, \"mouse\": 1, \"mu_intercept_per_group\": 7.1347198486328125, \"sigma_intercept_per_group\": 0.33304673433303833, \"sigma_obs\": 160.6607666015625, \"slope\": -0.08350682258605957, \"chain\": 3, \"draw\": 46}, {\"draws\": 646, \"mouse\": 2, \"mu_intercept_per_group\": 7.098388195037842, \"sigma_intercept_per_group\": 0.33304673433303833, \"sigma_obs\": 160.6607666015625, \"slope\": -0.08350682258605957, \"chain\": 3, \"draw\": 46}, {\"draws\": 646, \"mouse\": 3, \"mu_intercept_per_group\": 6.337357044219971, \"sigma_intercept_per_group\": 0.33304673433303833, \"sigma_obs\": 160.6607666015625, \"slope\": -0.08350682258605957, \"chain\": 3, \"draw\": 46}, {\"draws\": 646, \"mouse\": 4, \"mu_intercept_per_group\": 6.48411226272583, \"sigma_intercept_per_group\": 0.33304673433303833, \"sigma_obs\": 160.6607666015625, \"slope\": -0.08350682258605957, \"chain\": 3, \"draw\": 46}, {\"draws\": 646, \"mouse\": 5, \"mu_intercept_per_group\": 6.021250247955322, \"sigma_intercept_per_group\": 0.33304673433303833, \"sigma_obs\": 160.6607666015625, \"slope\": -0.08350682258605957, \"chain\": 3, \"draw\": 46}, {\"draws\": 646, \"mouse\": 6, \"mu_intercept_per_group\": 5.670238018035889, \"sigma_intercept_per_group\": 0.33304673433303833, \"sigma_obs\": 160.6607666015625, \"slope\": -0.08350682258605957, \"chain\": 3, \"draw\": 46}, {\"draws\": 646, \"mouse\": 7, \"mu_intercept_per_group\": 5.581024646759033, \"sigma_intercept_per_group\": 0.33304673433303833, \"sigma_obs\": 160.6607666015625, \"slope\": -0.08350682258605957, \"chain\": 3, \"draw\": 46}, {\"draws\": 647, \"mouse\": 0, \"mu_intercept_per_group\": 8.13996696472168, \"sigma_intercept_per_group\": 0.3187931180000305, \"sigma_obs\": 180.346923828125, \"slope\": -0.0637379065155983, \"chain\": 3, \"draw\": 47}, {\"draws\": 647, \"mouse\": 1, \"mu_intercept_per_group\": 7.898650646209717, \"sigma_intercept_per_group\": 0.3187931180000305, \"sigma_obs\": 180.346923828125, \"slope\": -0.0637379065155983, \"chain\": 3, \"draw\": 47}, {\"draws\": 647, \"mouse\": 2, \"mu_intercept_per_group\": 7.616738319396973, \"sigma_intercept_per_group\": 0.3187931180000305, \"sigma_obs\": 180.346923828125, \"slope\": -0.0637379065155983, \"chain\": 3, \"draw\": 47}, {\"draws\": 647, \"mouse\": 3, \"mu_intercept_per_group\": 7.078994274139404, \"sigma_intercept_per_group\": 0.3187931180000305, \"sigma_obs\": 180.346923828125, \"slope\": -0.0637379065155983, \"chain\": 3, \"draw\": 47}, {\"draws\": 647, \"mouse\": 4, \"mu_intercept_per_group\": 6.811342239379883, \"sigma_intercept_per_group\": 0.3187931180000305, \"sigma_obs\": 180.346923828125, \"slope\": -0.0637379065155983, \"chain\": 3, \"draw\": 47}, {\"draws\": 647, \"mouse\": 5, \"mu_intercept_per_group\": 6.592156887054443, \"sigma_intercept_per_group\": 0.3187931180000305, \"sigma_obs\": 180.346923828125, \"slope\": -0.0637379065155983, \"chain\": 3, \"draw\": 47}, {\"draws\": 647, \"mouse\": 6, \"mu_intercept_per_group\": 6.124887466430664, \"sigma_intercept_per_group\": 0.3187931180000305, \"sigma_obs\": 180.346923828125, \"slope\": -0.0637379065155983, \"chain\": 3, \"draw\": 47}, {\"draws\": 647, \"mouse\": 7, \"mu_intercept_per_group\": 5.883071422576904, \"sigma_intercept_per_group\": 0.3187931180000305, \"sigma_obs\": 180.346923828125, \"slope\": -0.0637379065155983, \"chain\": 3, \"draw\": 47}, {\"draws\": 648, \"mouse\": 0, \"mu_intercept_per_group\": 7.874083995819092, \"sigma_intercept_per_group\": 0.3175503611564636, \"sigma_obs\": 180.54000854492188, \"slope\": -0.06457583606243134, \"chain\": 3, \"draw\": 48}, {\"draws\": 648, \"mouse\": 1, \"mu_intercept_per_group\": 7.706193447113037, \"sigma_intercept_per_group\": 0.3175503611564636, \"sigma_obs\": 180.54000854492188, \"slope\": -0.06457583606243134, \"chain\": 3, \"draw\": 48}, {\"draws\": 648, \"mouse\": 2, \"mu_intercept_per_group\": 7.578788757324219, \"sigma_intercept_per_group\": 0.3175503611564636, \"sigma_obs\": 180.54000854492188, \"slope\": -0.06457583606243134, \"chain\": 3, \"draw\": 48}, {\"draws\": 648, \"mouse\": 3, \"mu_intercept_per_group\": 7.239501476287842, \"sigma_intercept_per_group\": 0.3175503611564636, \"sigma_obs\": 180.54000854492188, \"slope\": -0.06457583606243134, \"chain\": 3, \"draw\": 48}, {\"draws\": 648, \"mouse\": 4, \"mu_intercept_per_group\": 7.1095991134643555, \"sigma_intercept_per_group\": 0.3175503611564636, \"sigma_obs\": 180.54000854492188, \"slope\": -0.06457583606243134, \"chain\": 3, \"draw\": 48}, {\"draws\": 648, \"mouse\": 5, \"mu_intercept_per_group\": 6.877355575561523, \"sigma_intercept_per_group\": 0.3175503611564636, \"sigma_obs\": 180.54000854492188, \"slope\": -0.06457583606243134, \"chain\": 3, \"draw\": 48}, {\"draws\": 648, \"mouse\": 6, \"mu_intercept_per_group\": 6.1889824867248535, \"sigma_intercept_per_group\": 0.3175503611564636, \"sigma_obs\": 180.54000854492188, \"slope\": -0.06457583606243134, \"chain\": 3, \"draw\": 48}, {\"draws\": 648, \"mouse\": 7, \"mu_intercept_per_group\": 5.8901143074035645, \"sigma_intercept_per_group\": 0.3175503611564636, \"sigma_obs\": 180.54000854492188, \"slope\": -0.06457583606243134, \"chain\": 3, \"draw\": 48}, {\"draws\": 649, \"mouse\": 0, \"mu_intercept_per_group\": 14.009804725646973, \"sigma_intercept_per_group\": 0.16816174983978271, \"sigma_obs\": 145.61936950683594, \"slope\": -0.07307063788175583, \"chain\": 3, \"draw\": 49}, {\"draws\": 649, \"mouse\": 1, \"mu_intercept_per_group\": 13.788511276245117, \"sigma_intercept_per_group\": 0.16816174983978271, \"sigma_obs\": 145.61936950683594, \"slope\": -0.07307063788175583, \"chain\": 3, \"draw\": 49}, {\"draws\": 649, \"mouse\": 2, \"mu_intercept_per_group\": 13.084921836853027, \"sigma_intercept_per_group\": 0.16816174983978271, \"sigma_obs\": 145.61936950683594, \"slope\": -0.07307063788175583, \"chain\": 3, \"draw\": 49}, {\"draws\": 649, \"mouse\": 3, \"mu_intercept_per_group\": 12.73154067993164, \"sigma_intercept_per_group\": 0.16816174983978271, \"sigma_obs\": 145.61936950683594, \"slope\": -0.07307063788175583, \"chain\": 3, \"draw\": 49}, {\"draws\": 649, \"mouse\": 4, \"mu_intercept_per_group\": 12.182080268859863, \"sigma_intercept_per_group\": 0.16816174983978271, \"sigma_obs\": 145.61936950683594, \"slope\": -0.07307063788175583, \"chain\": 3, \"draw\": 49}, {\"draws\": 649, \"mouse\": 5, \"mu_intercept_per_group\": 11.254697799682617, \"sigma_intercept_per_group\": 0.16816174983978271, \"sigma_obs\": 145.61936950683594, \"slope\": -0.07307063788175583, \"chain\": 3, \"draw\": 49}, {\"draws\": 649, \"mouse\": 6, \"mu_intercept_per_group\": 10.48405933380127, \"sigma_intercept_per_group\": 0.16816174983978271, \"sigma_obs\": 145.61936950683594, \"slope\": -0.07307063788175583, \"chain\": 3, \"draw\": 49}, {\"draws\": 649, \"mouse\": 7, \"mu_intercept_per_group\": 10.141775131225586, \"sigma_intercept_per_group\": 0.16816174983978271, \"sigma_obs\": 145.61936950683594, \"slope\": -0.07307063788175583, \"chain\": 3, \"draw\": 49}, {\"draws\": 650, \"mouse\": 0, \"mu_intercept_per_group\": 13.208691596984863, \"sigma_intercept_per_group\": 0.18222537636756897, \"sigma_obs\": 145.67764282226562, \"slope\": -0.07845651358366013, \"chain\": 3, \"draw\": 50}, {\"draws\": 650, \"mouse\": 1, \"mu_intercept_per_group\": 12.325952529907227, \"sigma_intercept_per_group\": 0.18222537636756897, \"sigma_obs\": 145.67764282226562, \"slope\": -0.07845651358366013, \"chain\": 3, \"draw\": 50}, {\"draws\": 650, \"mouse\": 2, \"mu_intercept_per_group\": 12.275399208068848, \"sigma_intercept_per_group\": 0.18222537636756897, \"sigma_obs\": 145.67764282226562, \"slope\": -0.07845651358366013, \"chain\": 3, \"draw\": 50}, {\"draws\": 650, \"mouse\": 3, \"mu_intercept_per_group\": 11.351882934570312, \"sigma_intercept_per_group\": 0.18222537636756897, \"sigma_obs\": 145.67764282226562, \"slope\": -0.07845651358366013, \"chain\": 3, \"draw\": 50}, {\"draws\": 650, \"mouse\": 4, \"mu_intercept_per_group\": 11.471955299377441, \"sigma_intercept_per_group\": 0.18222537636756897, \"sigma_obs\": 145.67764282226562, \"slope\": -0.07845651358366013, \"chain\": 3, \"draw\": 50}, {\"draws\": 650, \"mouse\": 5, \"mu_intercept_per_group\": 10.203558921813965, \"sigma_intercept_per_group\": 0.18222537636756897, \"sigma_obs\": 145.67764282226562, \"slope\": -0.07845651358366013, \"chain\": 3, \"draw\": 50}, {\"draws\": 650, \"mouse\": 6, \"mu_intercept_per_group\": 9.692432403564453, \"sigma_intercept_per_group\": 0.18222537636756897, \"sigma_obs\": 145.67764282226562, \"slope\": -0.07845651358366013, \"chain\": 3, \"draw\": 50}, {\"draws\": 650, \"mouse\": 7, \"mu_intercept_per_group\": 9.459940910339355, \"sigma_intercept_per_group\": 0.18222537636756897, \"sigma_obs\": 145.67764282226562, \"slope\": -0.07845651358366013, \"chain\": 3, \"draw\": 50}, {\"draws\": 651, \"mouse\": 0, \"mu_intercept_per_group\": 12.764071464538574, \"sigma_intercept_per_group\": 0.18851961195468903, \"sigma_obs\": 145.286865234375, \"slope\": -0.08372781425714493, \"chain\": 3, \"draw\": 51}, {\"draws\": 651, \"mouse\": 1, \"mu_intercept_per_group\": 12.643967628479004, \"sigma_intercept_per_group\": 0.18851961195468903, \"sigma_obs\": 145.286865234375, \"slope\": -0.08372781425714493, \"chain\": 3, \"draw\": 51}, {\"draws\": 651, \"mouse\": 2, \"mu_intercept_per_group\": 12.001760482788086, \"sigma_intercept_per_group\": 0.18851961195468903, \"sigma_obs\": 145.286865234375, \"slope\": -0.08372781425714493, \"chain\": 3, \"draw\": 51}, {\"draws\": 651, \"mouse\": 3, \"mu_intercept_per_group\": 11.569960594177246, \"sigma_intercept_per_group\": 0.18851961195468903, \"sigma_obs\": 145.286865234375, \"slope\": -0.08372781425714493, \"chain\": 3, \"draw\": 51}, {\"draws\": 651, \"mouse\": 4, \"mu_intercept_per_group\": 10.844111442565918, \"sigma_intercept_per_group\": 0.18851961195468903, \"sigma_obs\": 145.286865234375, \"slope\": -0.08372781425714493, \"chain\": 3, \"draw\": 51}, {\"draws\": 651, \"mouse\": 5, \"mu_intercept_per_group\": 10.114401817321777, \"sigma_intercept_per_group\": 0.18851961195468903, \"sigma_obs\": 145.286865234375, \"slope\": -0.08372781425714493, \"chain\": 3, \"draw\": 51}, {\"draws\": 651, \"mouse\": 6, \"mu_intercept_per_group\": 9.564103126525879, \"sigma_intercept_per_group\": 0.18851961195468903, \"sigma_obs\": 145.286865234375, \"slope\": -0.08372781425714493, \"chain\": 3, \"draw\": 51}, {\"draws\": 651, \"mouse\": 7, \"mu_intercept_per_group\": 8.899406433105469, \"sigma_intercept_per_group\": 0.18851961195468903, \"sigma_obs\": 145.286865234375, \"slope\": -0.08372781425714493, \"chain\": 3, \"draw\": 51}, {\"draws\": 652, \"mouse\": 0, \"mu_intercept_per_group\": 18.324462890625, \"sigma_intercept_per_group\": 0.13964466750621796, \"sigma_obs\": 174.7315673828125, \"slope\": -0.05714608356356621, \"chain\": 3, \"draw\": 52}, {\"draws\": 652, \"mouse\": 1, \"mu_intercept_per_group\": 17.386478424072266, \"sigma_intercept_per_group\": 0.13964466750621796, \"sigma_obs\": 174.7315673828125, \"slope\": -0.05714608356356621, \"chain\": 3, \"draw\": 52}, {\"draws\": 652, \"mouse\": 2, \"mu_intercept_per_group\": 16.972803115844727, \"sigma_intercept_per_group\": 0.13964466750621796, \"sigma_obs\": 174.7315673828125, \"slope\": -0.05714608356356621, \"chain\": 3, \"draw\": 52}, {\"draws\": 652, \"mouse\": 3, \"mu_intercept_per_group\": 16.27655792236328, \"sigma_intercept_per_group\": 0.13964466750621796, \"sigma_obs\": 174.7315673828125, \"slope\": -0.05714608356356621, \"chain\": 3, \"draw\": 52}, {\"draws\": 652, \"mouse\": 4, \"mu_intercept_per_group\": 15.845391273498535, \"sigma_intercept_per_group\": 0.13964466750621796, \"sigma_obs\": 174.7315673828125, \"slope\": -0.05714608356356621, \"chain\": 3, \"draw\": 52}, {\"draws\": 652, \"mouse\": 5, \"mu_intercept_per_group\": 14.891383171081543, \"sigma_intercept_per_group\": 0.13964466750621796, \"sigma_obs\": 174.7315673828125, \"slope\": -0.05714608356356621, \"chain\": 3, \"draw\": 52}, {\"draws\": 652, \"mouse\": 6, \"mu_intercept_per_group\": 14.072863578796387, \"sigma_intercept_per_group\": 0.13964466750621796, \"sigma_obs\": 174.7315673828125, \"slope\": -0.05714608356356621, \"chain\": 3, \"draw\": 52}, {\"draws\": 652, \"mouse\": 7, \"mu_intercept_per_group\": 13.177882194519043, \"sigma_intercept_per_group\": 0.13964466750621796, \"sigma_obs\": 174.7315673828125, \"slope\": -0.05714608356356621, \"chain\": 3, \"draw\": 52}, {\"draws\": 653, \"mouse\": 0, \"mu_intercept_per_group\": 15.096160888671875, \"sigma_intercept_per_group\": 0.16371050477027893, \"sigma_obs\": 159.5950164794922, \"slope\": -0.08747484534978867, \"chain\": 3, \"draw\": 53}, {\"draws\": 653, \"mouse\": 1, \"mu_intercept_per_group\": 14.672307014465332, \"sigma_intercept_per_group\": 0.16371050477027893, \"sigma_obs\": 159.5950164794922, \"slope\": -0.08747484534978867, \"chain\": 3, \"draw\": 53}, {\"draws\": 653, \"mouse\": 2, \"mu_intercept_per_group\": 14.035477638244629, \"sigma_intercept_per_group\": 0.16371050477027893, \"sigma_obs\": 159.5950164794922, \"slope\": -0.08747484534978867, \"chain\": 3, \"draw\": 53}, {\"draws\": 653, \"mouse\": 3, \"mu_intercept_per_group\": 13.687369346618652, \"sigma_intercept_per_group\": 0.16371050477027893, \"sigma_obs\": 159.5950164794922, \"slope\": -0.08747484534978867, \"chain\": 3, \"draw\": 53}, {\"draws\": 653, \"mouse\": 4, \"mu_intercept_per_group\": 13.241888999938965, \"sigma_intercept_per_group\": 0.16371050477027893, \"sigma_obs\": 159.5950164794922, \"slope\": -0.08747484534978867, \"chain\": 3, \"draw\": 53}, {\"draws\": 653, \"mouse\": 5, \"mu_intercept_per_group\": 12.113798141479492, \"sigma_intercept_per_group\": 0.16371050477027893, \"sigma_obs\": 159.5950164794922, \"slope\": -0.08747484534978867, \"chain\": 3, \"draw\": 53}, {\"draws\": 653, \"mouse\": 6, \"mu_intercept_per_group\": 11.591754913330078, \"sigma_intercept_per_group\": 0.16371050477027893, \"sigma_obs\": 159.5950164794922, \"slope\": -0.08747484534978867, \"chain\": 3, \"draw\": 53}, {\"draws\": 653, \"mouse\": 7, \"mu_intercept_per_group\": 11.17113971710205, \"sigma_intercept_per_group\": 0.16371050477027893, \"sigma_obs\": 159.5950164794922, \"slope\": -0.08747484534978867, \"chain\": 3, \"draw\": 53}, {\"draws\": 654, \"mouse\": 0, \"mu_intercept_per_group\": 14.692925453186035, \"sigma_intercept_per_group\": 0.17615267634391785, \"sigma_obs\": 181.82850646972656, \"slope\": -0.054299887269735336, \"chain\": 3, \"draw\": 54}, {\"draws\": 654, \"mouse\": 1, \"mu_intercept_per_group\": 14.068815231323242, \"sigma_intercept_per_group\": 0.17615267634391785, \"sigma_obs\": 181.82850646972656, \"slope\": -0.054299887269735336, \"chain\": 3, \"draw\": 54}, {\"draws\": 654, \"mouse\": 2, \"mu_intercept_per_group\": 13.647320747375488, \"sigma_intercept_per_group\": 0.17615267634391785, \"sigma_obs\": 181.82850646972656, \"slope\": -0.054299887269735336, \"chain\": 3, \"draw\": 54}, {\"draws\": 654, \"mouse\": 3, \"mu_intercept_per_group\": 12.78087329864502, \"sigma_intercept_per_group\": 0.17615267634391785, \"sigma_obs\": 181.82850646972656, \"slope\": -0.054299887269735336, \"chain\": 3, \"draw\": 54}, {\"draws\": 654, \"mouse\": 4, \"mu_intercept_per_group\": 12.792211532592773, \"sigma_intercept_per_group\": 0.17615267634391785, \"sigma_obs\": 181.82850646972656, \"slope\": -0.054299887269735336, \"chain\": 3, \"draw\": 54}, {\"draws\": 654, \"mouse\": 5, \"mu_intercept_per_group\": 11.743481636047363, \"sigma_intercept_per_group\": 0.17615267634391785, \"sigma_obs\": 181.82850646972656, \"slope\": -0.054299887269735336, \"chain\": 3, \"draw\": 54}, {\"draws\": 654, \"mouse\": 6, \"mu_intercept_per_group\": 10.917033195495605, \"sigma_intercept_per_group\": 0.17615267634391785, \"sigma_obs\": 181.82850646972656, \"slope\": -0.054299887269735336, \"chain\": 3, \"draw\": 54}, {\"draws\": 654, \"mouse\": 7, \"mu_intercept_per_group\": 10.611836433410645, \"sigma_intercept_per_group\": 0.17615267634391785, \"sigma_obs\": 181.82850646972656, \"slope\": -0.054299887269735336, \"chain\": 3, \"draw\": 54}, {\"draws\": 655, \"mouse\": 0, \"mu_intercept_per_group\": 13.671229362487793, \"sigma_intercept_per_group\": 0.1866370290517807, \"sigma_obs\": 169.62841796875, \"slope\": -0.07255291938781738, \"chain\": 3, \"draw\": 55}, {\"draws\": 655, \"mouse\": 1, \"mu_intercept_per_group\": 13.164140701293945, \"sigma_intercept_per_group\": 0.1866370290517807, \"sigma_obs\": 169.62841796875, \"slope\": -0.07255291938781738, \"chain\": 3, \"draw\": 55}, {\"draws\": 655, \"mouse\": 2, \"mu_intercept_per_group\": 12.790521621704102, \"sigma_intercept_per_group\": 0.1866370290517807, \"sigma_obs\": 169.62841796875, \"slope\": -0.07255291938781738, \"chain\": 3, \"draw\": 55}, {\"draws\": 655, \"mouse\": 3, \"mu_intercept_per_group\": 11.768488883972168, \"sigma_intercept_per_group\": 0.1866370290517807, \"sigma_obs\": 169.62841796875, \"slope\": -0.07255291938781738, \"chain\": 3, \"draw\": 55}, {\"draws\": 655, \"mouse\": 4, \"mu_intercept_per_group\": 11.388837814331055, \"sigma_intercept_per_group\": 0.1866370290517807, \"sigma_obs\": 169.62841796875, \"slope\": -0.07255291938781738, \"chain\": 3, \"draw\": 55}, {\"draws\": 655, \"mouse\": 5, \"mu_intercept_per_group\": 11.183297157287598, \"sigma_intercept_per_group\": 0.1866370290517807, \"sigma_obs\": 169.62841796875, \"slope\": -0.07255291938781738, \"chain\": 3, \"draw\": 55}, {\"draws\": 655, \"mouse\": 6, \"mu_intercept_per_group\": 10.14992618560791, \"sigma_intercept_per_group\": 0.1866370290517807, \"sigma_obs\": 169.62841796875, \"slope\": -0.07255291938781738, \"chain\": 3, \"draw\": 55}, {\"draws\": 655, \"mouse\": 7, \"mu_intercept_per_group\": 9.959717750549316, \"sigma_intercept_per_group\": 0.1866370290517807, \"sigma_obs\": 169.62841796875, \"slope\": -0.07255291938781738, \"chain\": 3, \"draw\": 55}, {\"draws\": 656, \"mouse\": 0, \"mu_intercept_per_group\": 13.031752586364746, \"sigma_intercept_per_group\": 0.19105379283428192, \"sigma_obs\": 168.74856567382812, \"slope\": -0.0775461196899414, \"chain\": 3, \"draw\": 56}, {\"draws\": 656, \"mouse\": 1, \"mu_intercept_per_group\": 12.916136741638184, \"sigma_intercept_per_group\": 0.19105379283428192, \"sigma_obs\": 168.74856567382812, \"slope\": -0.0775461196899414, \"chain\": 3, \"draw\": 56}, {\"draws\": 656, \"mouse\": 2, \"mu_intercept_per_group\": 12.407660484313965, \"sigma_intercept_per_group\": 0.19105379283428192, \"sigma_obs\": 168.74856567382812, \"slope\": -0.0775461196899414, \"chain\": 3, \"draw\": 56}, {\"draws\": 656, \"mouse\": 3, \"mu_intercept_per_group\": 12.133349418640137, \"sigma_intercept_per_group\": 0.19105379283428192, \"sigma_obs\": 168.74856567382812, \"slope\": -0.0775461196899414, \"chain\": 3, \"draw\": 56}, {\"draws\": 656, \"mouse\": 4, \"mu_intercept_per_group\": 11.770365715026855, \"sigma_intercept_per_group\": 0.19105379283428192, \"sigma_obs\": 168.74856567382812, \"slope\": -0.0775461196899414, \"chain\": 3, \"draw\": 56}, {\"draws\": 656, \"mouse\": 5, \"mu_intercept_per_group\": 10.710883140563965, \"sigma_intercept_per_group\": 0.19105379283428192, \"sigma_obs\": 168.74856567382812, \"slope\": -0.0775461196899414, \"chain\": 3, \"draw\": 56}, {\"draws\": 656, \"mouse\": 6, \"mu_intercept_per_group\": 10.424701690673828, \"sigma_intercept_per_group\": 0.19105379283428192, \"sigma_obs\": 168.74856567382812, \"slope\": -0.0775461196899414, \"chain\": 3, \"draw\": 56}, {\"draws\": 656, \"mouse\": 7, \"mu_intercept_per_group\": 9.71083927154541, \"sigma_intercept_per_group\": 0.19105379283428192, \"sigma_obs\": 168.74856567382812, \"slope\": -0.0775461196899414, \"chain\": 3, \"draw\": 56}, {\"draws\": 657, \"mouse\": 0, \"mu_intercept_per_group\": 13.795843124389648, \"sigma_intercept_per_group\": 0.18673747777938843, \"sigma_obs\": 166.10614013671875, \"slope\": -0.08145559579133987, \"chain\": 3, \"draw\": 57}, {\"draws\": 657, \"mouse\": 1, \"mu_intercept_per_group\": 13.168041229248047, \"sigma_intercept_per_group\": 0.18673747777938843, \"sigma_obs\": 166.10614013671875, \"slope\": -0.08145559579133987, \"chain\": 3, \"draw\": 57}, {\"draws\": 657, \"mouse\": 2, \"mu_intercept_per_group\": 12.902673721313477, \"sigma_intercept_per_group\": 0.18673747777938843, \"sigma_obs\": 166.10614013671875, \"slope\": -0.08145559579133987, \"chain\": 3, \"draw\": 57}, {\"draws\": 657, \"mouse\": 3, \"mu_intercept_per_group\": 11.758995056152344, \"sigma_intercept_per_group\": 0.18673747777938843, \"sigma_obs\": 166.10614013671875, \"slope\": -0.08145559579133987, \"chain\": 3, \"draw\": 57}, {\"draws\": 657, \"mouse\": 4, \"mu_intercept_per_group\": 11.462298393249512, \"sigma_intercept_per_group\": 0.18673747777938843, \"sigma_obs\": 166.10614013671875, \"slope\": -0.08145559579133987, \"chain\": 3, \"draw\": 57}, {\"draws\": 657, \"mouse\": 5, \"mu_intercept_per_group\": 11.283203125, \"sigma_intercept_per_group\": 0.18673747777938843, \"sigma_obs\": 166.10614013671875, \"slope\": -0.08145559579133987, \"chain\": 3, \"draw\": 57}, {\"draws\": 657, \"mouse\": 6, \"mu_intercept_per_group\": 10.028109550476074, \"sigma_intercept_per_group\": 0.18673747777938843, \"sigma_obs\": 166.10614013671875, \"slope\": -0.08145559579133987, \"chain\": 3, \"draw\": 57}, {\"draws\": 657, \"mouse\": 7, \"mu_intercept_per_group\": 9.949028968811035, \"sigma_intercept_per_group\": 0.18673747777938843, \"sigma_obs\": 166.10614013671875, \"slope\": -0.08145559579133987, \"chain\": 3, \"draw\": 57}, {\"draws\": 658, \"mouse\": 0, \"mu_intercept_per_group\": 13.681821823120117, \"sigma_intercept_per_group\": 0.17953455448150635, \"sigma_obs\": 173.373046875, \"slope\": -0.060141172260046005, \"chain\": 3, \"draw\": 58}, {\"draws\": 658, \"mouse\": 1, \"mu_intercept_per_group\": 13.718287467956543, \"sigma_intercept_per_group\": 0.17953455448150635, \"sigma_obs\": 173.373046875, \"slope\": -0.060141172260046005, \"chain\": 3, \"draw\": 58}, {\"draws\": 658, \"mouse\": 2, \"mu_intercept_per_group\": 13.253610610961914, \"sigma_intercept_per_group\": 0.17953455448150635, \"sigma_obs\": 173.373046875, \"slope\": -0.060141172260046005, \"chain\": 3, \"draw\": 58}, {\"draws\": 658, \"mouse\": 3, \"mu_intercept_per_group\": 12.945109367370605, \"sigma_intercept_per_group\": 0.17953455448150635, \"sigma_obs\": 173.373046875, \"slope\": -0.060141172260046005, \"chain\": 3, \"draw\": 58}, {\"draws\": 658, \"mouse\": 4, \"mu_intercept_per_group\": 12.125371932983398, \"sigma_intercept_per_group\": 0.17953455448150635, \"sigma_obs\": 173.373046875, \"slope\": -0.060141172260046005, \"chain\": 3, \"draw\": 58}, {\"draws\": 658, \"mouse\": 5, \"mu_intercept_per_group\": 11.506599426269531, \"sigma_intercept_per_group\": 0.17953455448150635, \"sigma_obs\": 173.373046875, \"slope\": -0.060141172260046005, \"chain\": 3, \"draw\": 58}, {\"draws\": 658, \"mouse\": 6, \"mu_intercept_per_group\": 10.45541763305664, \"sigma_intercept_per_group\": 0.17953455448150635, \"sigma_obs\": 173.373046875, \"slope\": -0.060141172260046005, \"chain\": 3, \"draw\": 58}, {\"draws\": 658, \"mouse\": 7, \"mu_intercept_per_group\": 10.247442245483398, \"sigma_intercept_per_group\": 0.17953455448150635, \"sigma_obs\": 173.373046875, \"slope\": -0.060141172260046005, \"chain\": 3, \"draw\": 58}, {\"draws\": 659, \"mouse\": 0, \"mu_intercept_per_group\": 11.816917419433594, \"sigma_intercept_per_group\": 0.205328568816185, \"sigma_obs\": 141.50611877441406, \"slope\": -0.062175456434488297, \"chain\": 3, \"draw\": 59}, {\"draws\": 659, \"mouse\": 1, \"mu_intercept_per_group\": 10.869636535644531, \"sigma_intercept_per_group\": 0.205328568816185, \"sigma_obs\": 141.50611877441406, \"slope\": -0.062175456434488297, \"chain\": 3, \"draw\": 59}, {\"draws\": 659, \"mouse\": 2, \"mu_intercept_per_group\": 10.476235389709473, \"sigma_intercept_per_group\": 0.205328568816185, \"sigma_obs\": 141.50611877441406, \"slope\": -0.062175456434488297, \"chain\": 3, \"draw\": 59}, {\"draws\": 659, \"mouse\": 3, \"mu_intercept_per_group\": 9.776257514953613, \"sigma_intercept_per_group\": 0.205328568816185, \"sigma_obs\": 141.50611877441406, \"slope\": -0.062175456434488297, \"chain\": 3, \"draw\": 59}, {\"draws\": 659, \"mouse\": 4, \"mu_intercept_per_group\": 9.875697135925293, \"sigma_intercept_per_group\": 0.205328568816185, \"sigma_obs\": 141.50611877441406, \"slope\": -0.062175456434488297, \"chain\": 3, \"draw\": 59}, {\"draws\": 659, \"mouse\": 5, \"mu_intercept_per_group\": 9.224738121032715, \"sigma_intercept_per_group\": 0.205328568816185, \"sigma_obs\": 141.50611877441406, \"slope\": -0.062175456434488297, \"chain\": 3, \"draw\": 59}, {\"draws\": 659, \"mouse\": 6, \"mu_intercept_per_group\": 8.424288749694824, \"sigma_intercept_per_group\": 0.205328568816185, \"sigma_obs\": 141.50611877441406, \"slope\": -0.062175456434488297, \"chain\": 3, \"draw\": 59}, {\"draws\": 659, \"mouse\": 7, \"mu_intercept_per_group\": 7.989787578582764, \"sigma_intercept_per_group\": 0.205328568816185, \"sigma_obs\": 141.50611877441406, \"slope\": -0.062175456434488297, \"chain\": 3, \"draw\": 59}, {\"draws\": 660, \"mouse\": 0, \"mu_intercept_per_group\": 10.967185974121094, \"sigma_intercept_per_group\": 0.20748433470726013, \"sigma_obs\": 143.0489959716797, \"slope\": -0.06017552316188812, \"chain\": 3, \"draw\": 60}, {\"draws\": 660, \"mouse\": 1, \"mu_intercept_per_group\": 11.00589370727539, \"sigma_intercept_per_group\": 0.20748433470726013, \"sigma_obs\": 143.0489959716797, \"slope\": -0.06017552316188812, \"chain\": 3, \"draw\": 60}, {\"draws\": 660, \"mouse\": 2, \"mu_intercept_per_group\": 10.770357131958008, \"sigma_intercept_per_group\": 0.20748433470726013, \"sigma_obs\": 143.0489959716797, \"slope\": -0.06017552316188812, \"chain\": 3, \"draw\": 60}, {\"draws\": 660, \"mouse\": 3, \"mu_intercept_per_group\": 10.240622520446777, \"sigma_intercept_per_group\": 0.20748433470726013, \"sigma_obs\": 143.0489959716797, \"slope\": -0.06017552316188812, \"chain\": 3, \"draw\": 60}, {\"draws\": 660, \"mouse\": 4, \"mu_intercept_per_group\": 9.528128623962402, \"sigma_intercept_per_group\": 0.20748433470726013, \"sigma_obs\": 143.0489959716797, \"slope\": -0.06017552316188812, \"chain\": 3, \"draw\": 60}, {\"draws\": 660, \"mouse\": 5, \"mu_intercept_per_group\": 8.865442276000977, \"sigma_intercept_per_group\": 0.20748433470726013, \"sigma_obs\": 143.0489959716797, \"slope\": -0.06017552316188812, \"chain\": 3, \"draw\": 60}, {\"draws\": 660, \"mouse\": 6, \"mu_intercept_per_group\": 8.881627082824707, \"sigma_intercept_per_group\": 0.20748433470726013, \"sigma_obs\": 143.0489959716797, \"slope\": -0.06017552316188812, \"chain\": 3, \"draw\": 60}, {\"draws\": 660, \"mouse\": 7, \"mu_intercept_per_group\": 7.800745487213135, \"sigma_intercept_per_group\": 0.20748433470726013, \"sigma_obs\": 143.0489959716797, \"slope\": -0.06017552316188812, \"chain\": 3, \"draw\": 60}, {\"draws\": 661, \"mouse\": 0, \"mu_intercept_per_group\": 11.206521987915039, \"sigma_intercept_per_group\": 0.2094716727733612, \"sigma_obs\": 142.48423767089844, \"slope\": -0.06020447984337807, \"chain\": 3, \"draw\": 61}, {\"draws\": 661, \"mouse\": 1, \"mu_intercept_per_group\": 10.721281051635742, \"sigma_intercept_per_group\": 0.2094716727733612, \"sigma_obs\": 142.48423767089844, \"slope\": -0.06020447984337807, \"chain\": 3, \"draw\": 61}, {\"draws\": 661, \"mouse\": 2, \"mu_intercept_per_group\": 10.441017150878906, \"sigma_intercept_per_group\": 0.2094716727733612, \"sigma_obs\": 142.48423767089844, \"slope\": -0.06020447984337807, \"chain\": 3, \"draw\": 61}, {\"draws\": 661, \"mouse\": 3, \"mu_intercept_per_group\": 9.87387466430664, \"sigma_intercept_per_group\": 0.2094716727733612, \"sigma_obs\": 142.48423767089844, \"slope\": -0.06020447984337807, \"chain\": 3, \"draw\": 61}, {\"draws\": 661, \"mouse\": 4, \"mu_intercept_per_group\": 9.372884750366211, \"sigma_intercept_per_group\": 0.2094716727733612, \"sigma_obs\": 142.48423767089844, \"slope\": -0.06020447984337807, \"chain\": 3, \"draw\": 61}, {\"draws\": 661, \"mouse\": 5, \"mu_intercept_per_group\": 9.079140663146973, \"sigma_intercept_per_group\": 0.2094716727733612, \"sigma_obs\": 142.48423767089844, \"slope\": -0.06020447984337807, \"chain\": 3, \"draw\": 61}, {\"draws\": 661, \"mouse\": 6, \"mu_intercept_per_group\": 8.623063087463379, \"sigma_intercept_per_group\": 0.2094716727733612, \"sigma_obs\": 142.48423767089844, \"slope\": -0.06020447984337807, \"chain\": 3, \"draw\": 61}, {\"draws\": 661, \"mouse\": 7, \"mu_intercept_per_group\": 7.995114803314209, \"sigma_intercept_per_group\": 0.2094716727733612, \"sigma_obs\": 142.48423767089844, \"slope\": -0.06020447984337807, \"chain\": 3, \"draw\": 61}, {\"draws\": 662, \"mouse\": 0, \"mu_intercept_per_group\": 11.198236465454102, \"sigma_intercept_per_group\": 0.20766329765319824, \"sigma_obs\": 142.7471466064453, \"slope\": -0.059183087199926376, \"chain\": 3, \"draw\": 62}, {\"draws\": 662, \"mouse\": 1, \"mu_intercept_per_group\": 11.01557731628418, \"sigma_intercept_per_group\": 0.20766329765319824, \"sigma_obs\": 142.7471466064453, \"slope\": -0.059183087199926376, \"chain\": 3, \"draw\": 62}, {\"draws\": 662, \"mouse\": 2, \"mu_intercept_per_group\": 10.644552230834961, \"sigma_intercept_per_group\": 0.20766329765319824, \"sigma_obs\": 142.7471466064453, \"slope\": -0.059183087199926376, \"chain\": 3, \"draw\": 62}, {\"draws\": 662, \"mouse\": 3, \"mu_intercept_per_group\": 9.695648193359375, \"sigma_intercept_per_group\": 0.20766329765319824, \"sigma_obs\": 142.7471466064453, \"slope\": -0.059183087199926376, \"chain\": 3, \"draw\": 62}, {\"draws\": 662, \"mouse\": 4, \"mu_intercept_per_group\": 9.483048439025879, \"sigma_intercept_per_group\": 0.20766329765319824, \"sigma_obs\": 142.7471466064453, \"slope\": -0.059183087199926376, \"chain\": 3, \"draw\": 62}, {\"draws\": 662, \"mouse\": 5, \"mu_intercept_per_group\": 9.035122871398926, \"sigma_intercept_per_group\": 0.20766329765319824, \"sigma_obs\": 142.7471466064453, \"slope\": -0.059183087199926376, \"chain\": 3, \"draw\": 62}, {\"draws\": 662, \"mouse\": 6, \"mu_intercept_per_group\": 8.710533142089844, \"sigma_intercept_per_group\": 0.20766329765319824, \"sigma_obs\": 142.7471466064453, \"slope\": -0.059183087199926376, \"chain\": 3, \"draw\": 62}, {\"draws\": 662, \"mouse\": 7, \"mu_intercept_per_group\": 7.671764373779297, \"sigma_intercept_per_group\": 0.20766329765319824, \"sigma_obs\": 142.7471466064453, \"slope\": -0.059183087199926376, \"chain\": 3, \"draw\": 62}, {\"draws\": 663, \"mouse\": 0, \"mu_intercept_per_group\": 11.098451614379883, \"sigma_intercept_per_group\": 0.21115586161613464, \"sigma_obs\": 142.91046142578125, \"slope\": -0.060376785695552826, \"chain\": 3, \"draw\": 63}, {\"draws\": 663, \"mouse\": 1, \"mu_intercept_per_group\": 10.661829948425293, \"sigma_intercept_per_group\": 0.21115586161613464, \"sigma_obs\": 142.91046142578125, \"slope\": -0.060376785695552826, \"chain\": 3, \"draw\": 63}, {\"draws\": 663, \"mouse\": 2, \"mu_intercept_per_group\": 10.18913745880127, \"sigma_intercept_per_group\": 0.21115586161613464, \"sigma_obs\": 142.91046142578125, \"slope\": -0.060376785695552826, \"chain\": 3, \"draw\": 63}, {\"draws\": 663, \"mouse\": 3, \"mu_intercept_per_group\": 9.945117950439453, \"sigma_intercept_per_group\": 0.21115586161613464, \"sigma_obs\": 142.91046142578125, \"slope\": -0.060376785695552826, \"chain\": 3, \"draw\": 63}, {\"draws\": 663, \"mouse\": 4, \"mu_intercept_per_group\": 9.37351131439209, \"sigma_intercept_per_group\": 0.21115586161613464, \"sigma_obs\": 142.91046142578125, \"slope\": -0.060376785695552826, \"chain\": 3, \"draw\": 63}, {\"draws\": 663, \"mouse\": 5, \"mu_intercept_per_group\": 9.350954055786133, \"sigma_intercept_per_group\": 0.21115586161613464, \"sigma_obs\": 142.91046142578125, \"slope\": -0.060376785695552826, \"chain\": 3, \"draw\": 63}, {\"draws\": 663, \"mouse\": 6, \"mu_intercept_per_group\": 8.20662784576416, \"sigma_intercept_per_group\": 0.21115586161613464, \"sigma_obs\": 142.91046142578125, \"slope\": -0.060376785695552826, \"chain\": 3, \"draw\": 63}, {\"draws\": 663, \"mouse\": 7, \"mu_intercept_per_group\": 8.096782684326172, \"sigma_intercept_per_group\": 0.21115586161613464, \"sigma_obs\": 142.91046142578125, \"slope\": -0.060376785695552826, \"chain\": 3, \"draw\": 63}, {\"draws\": 664, \"mouse\": 0, \"mu_intercept_per_group\": 11.12854290008545, \"sigma_intercept_per_group\": 0.2128167450428009, \"sigma_obs\": 150.0403594970703, \"slope\": -0.06239495053887367, \"chain\": 3, \"draw\": 64}, {\"draws\": 664, \"mouse\": 1, \"mu_intercept_per_group\": 10.97875690460205, \"sigma_intercept_per_group\": 0.2128167450428009, \"sigma_obs\": 150.0403594970703, \"slope\": -0.06239495053887367, \"chain\": 3, \"draw\": 64}, {\"draws\": 664, \"mouse\": 2, \"mu_intercept_per_group\": 10.457480430603027, \"sigma_intercept_per_group\": 0.2128167450428009, \"sigma_obs\": 150.0403594970703, \"slope\": -0.06239495053887367, \"chain\": 3, \"draw\": 64}, {\"draws\": 664, \"mouse\": 3, \"mu_intercept_per_group\": 10.064508438110352, \"sigma_intercept_per_group\": 0.2128167450428009, \"sigma_obs\": 150.0403594970703, \"slope\": -0.06239495053887367, \"chain\": 3, \"draw\": 64}, {\"draws\": 664, \"mouse\": 4, \"mu_intercept_per_group\": 10.161297798156738, \"sigma_intercept_per_group\": 0.2128167450428009, \"sigma_obs\": 150.0403594970703, \"slope\": -0.06239495053887367, \"chain\": 3, \"draw\": 64}, {\"draws\": 664, \"mouse\": 5, \"mu_intercept_per_group\": 8.920136451721191, \"sigma_intercept_per_group\": 0.2128167450428009, \"sigma_obs\": 150.0403594970703, \"slope\": -0.06239495053887367, \"chain\": 3, \"draw\": 64}, {\"draws\": 664, \"mouse\": 6, \"mu_intercept_per_group\": 8.561622619628906, \"sigma_intercept_per_group\": 0.2128167450428009, \"sigma_obs\": 150.0403594970703, \"slope\": -0.06239495053887367, \"chain\": 3, \"draw\": 64}, {\"draws\": 664, \"mouse\": 7, \"mu_intercept_per_group\": 7.751131057739258, \"sigma_intercept_per_group\": 0.2128167450428009, \"sigma_obs\": 150.0403594970703, \"slope\": -0.06239495053887367, \"chain\": 3, \"draw\": 64}, {\"draws\": 665, \"mouse\": 0, \"mu_intercept_per_group\": 9.174652099609375, \"sigma_intercept_per_group\": 0.26689019799232483, \"sigma_obs\": 156.07205200195312, \"slope\": -0.08453785628080368, \"chain\": 3, \"draw\": 65}, {\"draws\": 665, \"mouse\": 1, \"mu_intercept_per_group\": 9.075743675231934, \"sigma_intercept_per_group\": 0.26689019799232483, \"sigma_obs\": 156.07205200195312, \"slope\": -0.08453785628080368, \"chain\": 3, \"draw\": 65}, {\"draws\": 665, \"mouse\": 2, \"mu_intercept_per_group\": 8.872404098510742, \"sigma_intercept_per_group\": 0.26689019799232483, \"sigma_obs\": 156.07205200195312, \"slope\": -0.08453785628080368, \"chain\": 3, \"draw\": 65}, {\"draws\": 665, \"mouse\": 3, \"mu_intercept_per_group\": 8.087916374206543, \"sigma_intercept_per_group\": 0.26689019799232483, \"sigma_obs\": 156.07205200195312, \"slope\": -0.08453785628080368, \"chain\": 3, \"draw\": 65}, {\"draws\": 665, \"mouse\": 4, \"mu_intercept_per_group\": 8.139359474182129, \"sigma_intercept_per_group\": 0.26689019799232483, \"sigma_obs\": 156.07205200195312, \"slope\": -0.08453785628080368, \"chain\": 3, \"draw\": 65}, {\"draws\": 665, \"mouse\": 5, \"mu_intercept_per_group\": 7.383843898773193, \"sigma_intercept_per_group\": 0.26689019799232483, \"sigma_obs\": 156.07205200195312, \"slope\": -0.08453785628080368, \"chain\": 3, \"draw\": 65}, {\"draws\": 665, \"mouse\": 6, \"mu_intercept_per_group\": 7.115469455718994, \"sigma_intercept_per_group\": 0.26689019799232483, \"sigma_obs\": 156.07205200195312, \"slope\": -0.08453785628080368, \"chain\": 3, \"draw\": 65}, {\"draws\": 665, \"mouse\": 7, \"mu_intercept_per_group\": 6.400485038757324, \"sigma_intercept_per_group\": 0.26689019799232483, \"sigma_obs\": 156.07205200195312, \"slope\": -0.08453785628080368, \"chain\": 3, \"draw\": 65}, {\"draws\": 666, \"mouse\": 0, \"mu_intercept_per_group\": 9.076475143432617, \"sigma_intercept_per_group\": 0.2726147770881653, \"sigma_obs\": 156.16436767578125, \"slope\": -0.08794310688972473, \"chain\": 3, \"draw\": 66}, {\"draws\": 666, \"mouse\": 1, \"mu_intercept_per_group\": 8.637456893920898, \"sigma_intercept_per_group\": 0.2726147770881653, \"sigma_obs\": 156.16436767578125, \"slope\": -0.08794310688972473, \"chain\": 3, \"draw\": 66}, {\"draws\": 666, \"mouse\": 2, \"mu_intercept_per_group\": 8.602280616760254, \"sigma_intercept_per_group\": 0.2726147770881653, \"sigma_obs\": 156.16436767578125, \"slope\": -0.08794310688972473, \"chain\": 3, \"draw\": 66}, {\"draws\": 666, \"mouse\": 3, \"mu_intercept_per_group\": 8.166240692138672, \"sigma_intercept_per_group\": 0.2726147770881653, \"sigma_obs\": 156.16436767578125, \"slope\": -0.08794310688972473, \"chain\": 3, \"draw\": 66}, {\"draws\": 666, \"mouse\": 4, \"mu_intercept_per_group\": 7.879997730255127, \"sigma_intercept_per_group\": 0.2726147770881653, \"sigma_obs\": 156.16436767578125, \"slope\": -0.08794310688972473, \"chain\": 3, \"draw\": 66}, {\"draws\": 666, \"mouse\": 5, \"mu_intercept_per_group\": 7.557807922363281, \"sigma_intercept_per_group\": 0.2726147770881653, \"sigma_obs\": 156.16436767578125, \"slope\": -0.08794310688972473, \"chain\": 3, \"draw\": 66}, {\"draws\": 666, \"mouse\": 6, \"mu_intercept_per_group\": 6.910303592681885, \"sigma_intercept_per_group\": 0.2726147770881653, \"sigma_obs\": 156.16436767578125, \"slope\": -0.08794310688972473, \"chain\": 3, \"draw\": 66}, {\"draws\": 666, \"mouse\": 7, \"mu_intercept_per_group\": 6.83172607421875, \"sigma_intercept_per_group\": 0.2726147770881653, \"sigma_obs\": 156.16436767578125, \"slope\": -0.08794310688972473, \"chain\": 3, \"draw\": 66}, {\"draws\": 667, \"mouse\": 0, \"mu_intercept_per_group\": 9.175751686096191, \"sigma_intercept_per_group\": 0.2620755732059479, \"sigma_obs\": 154.1353759765625, \"slope\": -0.0847899541258812, \"chain\": 3, \"draw\": 67}, {\"draws\": 667, \"mouse\": 1, \"mu_intercept_per_group\": 9.199674606323242, \"sigma_intercept_per_group\": 0.2620755732059479, \"sigma_obs\": 154.1353759765625, \"slope\": -0.0847899541258812, \"chain\": 3, \"draw\": 67}, {\"draws\": 667, \"mouse\": 2, \"mu_intercept_per_group\": 8.979799270629883, \"sigma_intercept_per_group\": 0.2620755732059479, \"sigma_obs\": 154.1353759765625, \"slope\": -0.0847899541258812, \"chain\": 3, \"draw\": 67}, {\"draws\": 667, \"mouse\": 3, \"mu_intercept_per_group\": 8.10037899017334, \"sigma_intercept_per_group\": 0.2620755732059479, \"sigma_obs\": 154.1353759765625, \"slope\": -0.0847899541258812, \"chain\": 3, \"draw\": 67}, {\"draws\": 667, \"mouse\": 4, \"mu_intercept_per_group\": 7.992546558380127, \"sigma_intercept_per_group\": 0.2620755732059479, \"sigma_obs\": 154.1353759765625, \"slope\": -0.0847899541258812, \"chain\": 3, \"draw\": 67}, {\"draws\": 667, \"mouse\": 5, \"mu_intercept_per_group\": 7.454502105712891, \"sigma_intercept_per_group\": 0.2620755732059479, \"sigma_obs\": 154.1353759765625, \"slope\": -0.0847899541258812, \"chain\": 3, \"draw\": 67}, {\"draws\": 667, \"mouse\": 6, \"mu_intercept_per_group\": 7.027205944061279, \"sigma_intercept_per_group\": 0.2620755732059479, \"sigma_obs\": 154.1353759765625, \"slope\": -0.0847899541258812, \"chain\": 3, \"draw\": 67}, {\"draws\": 667, \"mouse\": 7, \"mu_intercept_per_group\": 6.503286361694336, \"sigma_intercept_per_group\": 0.2620755732059479, \"sigma_obs\": 154.1353759765625, \"slope\": -0.0847899541258812, \"chain\": 3, \"draw\": 67}, {\"draws\": 668, \"mouse\": 0, \"mu_intercept_per_group\": 9.813298225402832, \"sigma_intercept_per_group\": 0.2531535029411316, \"sigma_obs\": 150.0589599609375, \"slope\": -0.07910747826099396, \"chain\": 3, \"draw\": 68}, {\"draws\": 668, \"mouse\": 1, \"mu_intercept_per_group\": 9.032204627990723, \"sigma_intercept_per_group\": 0.2531535029411316, \"sigma_obs\": 150.0589599609375, \"slope\": -0.07910747826099396, \"chain\": 3, \"draw\": 68}, {\"draws\": 668, \"mouse\": 2, \"mu_intercept_per_group\": 8.727121353149414, \"sigma_intercept_per_group\": 0.2531535029411316, \"sigma_obs\": 150.0589599609375, \"slope\": -0.07910747826099396, \"chain\": 3, \"draw\": 68}, {\"draws\": 668, \"mouse\": 3, \"mu_intercept_per_group\": 8.670095443725586, \"sigma_intercept_per_group\": 0.2531535029411316, \"sigma_obs\": 150.0589599609375, \"slope\": -0.07910747826099396, \"chain\": 3, \"draw\": 68}, {\"draws\": 668, \"mouse\": 4, \"mu_intercept_per_group\": 8.33114242553711, \"sigma_intercept_per_group\": 0.2531535029411316, \"sigma_obs\": 150.0589599609375, \"slope\": -0.07910747826099396, \"chain\": 3, \"draw\": 68}, {\"draws\": 668, \"mouse\": 5, \"mu_intercept_per_group\": 7.74614143371582, \"sigma_intercept_per_group\": 0.2531535029411316, \"sigma_obs\": 150.0589599609375, \"slope\": -0.07910747826099396, \"chain\": 3, \"draw\": 68}, {\"draws\": 668, \"mouse\": 6, \"mu_intercept_per_group\": 7.21904182434082, \"sigma_intercept_per_group\": 0.2531535029411316, \"sigma_obs\": 150.0589599609375, \"slope\": -0.07910747826099396, \"chain\": 3, \"draw\": 68}, {\"draws\": 668, \"mouse\": 7, \"mu_intercept_per_group\": 6.796102523803711, \"sigma_intercept_per_group\": 0.2531535029411316, \"sigma_obs\": 150.0589599609375, \"slope\": -0.07910747826099396, \"chain\": 3, \"draw\": 68}, {\"draws\": 669, \"mouse\": 0, \"mu_intercept_per_group\": 10.115290641784668, \"sigma_intercept_per_group\": 0.26422250270843506, \"sigma_obs\": 180.46546936035156, \"slope\": -0.07509912550449371, \"chain\": 3, \"draw\": 69}, {\"draws\": 669, \"mouse\": 1, \"mu_intercept_per_group\": 9.5841703414917, \"sigma_intercept_per_group\": 0.26422250270843506, \"sigma_obs\": 180.46546936035156, \"slope\": -0.07509912550449371, \"chain\": 3, \"draw\": 69}, {\"draws\": 669, \"mouse\": 2, \"mu_intercept_per_group\": 9.354303359985352, \"sigma_intercept_per_group\": 0.26422250270843506, \"sigma_obs\": 180.46546936035156, \"slope\": -0.07509912550449371, \"chain\": 3, \"draw\": 69}, {\"draws\": 669, \"mouse\": 3, \"mu_intercept_per_group\": 8.821122169494629, \"sigma_intercept_per_group\": 0.26422250270843506, \"sigma_obs\": 180.46546936035156, \"slope\": -0.07509912550449371, \"chain\": 3, \"draw\": 69}, {\"draws\": 669, \"mouse\": 4, \"mu_intercept_per_group\": 8.590519905090332, \"sigma_intercept_per_group\": 0.26422250270843506, \"sigma_obs\": 180.46546936035156, \"slope\": -0.07509912550449371, \"chain\": 3, \"draw\": 69}, {\"draws\": 669, \"mouse\": 5, \"mu_intercept_per_group\": 8.21575927734375, \"sigma_intercept_per_group\": 0.26422250270843506, \"sigma_obs\": 180.46546936035156, \"slope\": -0.07509912550449371, \"chain\": 3, \"draw\": 69}, {\"draws\": 669, \"mouse\": 6, \"mu_intercept_per_group\": 7.5339202880859375, \"sigma_intercept_per_group\": 0.26422250270843506, \"sigma_obs\": 180.46546936035156, \"slope\": -0.07509912550449371, \"chain\": 3, \"draw\": 69}, {\"draws\": 669, \"mouse\": 7, \"mu_intercept_per_group\": 7.2474212646484375, \"sigma_intercept_per_group\": 0.26422250270843506, \"sigma_obs\": 180.46546936035156, \"slope\": -0.07509912550449371, \"chain\": 3, \"draw\": 69}, {\"draws\": 670, \"mouse\": 0, \"mu_intercept_per_group\": 9.922126770019531, \"sigma_intercept_per_group\": 0.26510635018348694, \"sigma_obs\": 174.87718200683594, \"slope\": -0.08140897750854492, \"chain\": 3, \"draw\": 70}, {\"draws\": 670, \"mouse\": 1, \"mu_intercept_per_group\": 9.521866798400879, \"sigma_intercept_per_group\": 0.26510635018348694, \"sigma_obs\": 174.87718200683594, \"slope\": -0.08140897750854492, \"chain\": 3, \"draw\": 70}, {\"draws\": 670, \"mouse\": 2, \"mu_intercept_per_group\": 9.316265106201172, \"sigma_intercept_per_group\": 0.26510635018348694, \"sigma_obs\": 174.87718200683594, \"slope\": -0.08140897750854492, \"chain\": 3, \"draw\": 70}, {\"draws\": 670, \"mouse\": 3, \"mu_intercept_per_group\": 8.835197448730469, \"sigma_intercept_per_group\": 0.26510635018348694, \"sigma_obs\": 174.87718200683594, \"slope\": -0.08140897750854492, \"chain\": 3, \"draw\": 70}, {\"draws\": 670, \"mouse\": 4, \"mu_intercept_per_group\": 8.225146293640137, \"sigma_intercept_per_group\": 0.26510635018348694, \"sigma_obs\": 174.87718200683594, \"slope\": -0.08140897750854492, \"chain\": 3, \"draw\": 70}, {\"draws\": 670, \"mouse\": 5, \"mu_intercept_per_group\": 8.063446998596191, \"sigma_intercept_per_group\": 0.26510635018348694, \"sigma_obs\": 174.87718200683594, \"slope\": -0.08140897750854492, \"chain\": 3, \"draw\": 70}, {\"draws\": 670, \"mouse\": 6, \"mu_intercept_per_group\": 7.445769309997559, \"sigma_intercept_per_group\": 0.26510635018348694, \"sigma_obs\": 174.87718200683594, \"slope\": -0.08140897750854492, \"chain\": 3, \"draw\": 70}, {\"draws\": 670, \"mouse\": 7, \"mu_intercept_per_group\": 6.957677364349365, \"sigma_intercept_per_group\": 0.26510635018348694, \"sigma_obs\": 174.87718200683594, \"slope\": -0.08140897750854492, \"chain\": 3, \"draw\": 70}, {\"draws\": 671, \"mouse\": 0, \"mu_intercept_per_group\": 7.538448810577393, \"sigma_intercept_per_group\": 0.30916884541511536, \"sigma_obs\": 143.38436889648438, \"slope\": -0.06995773315429688, \"chain\": 3, \"draw\": 71}, {\"draws\": 671, \"mouse\": 1, \"mu_intercept_per_group\": 7.226232051849365, \"sigma_intercept_per_group\": 0.30916884541511536, \"sigma_obs\": 143.38436889648438, \"slope\": -0.06995773315429688, \"chain\": 3, \"draw\": 71}, {\"draws\": 671, \"mouse\": 2, \"mu_intercept_per_group\": 6.976126194000244, \"sigma_intercept_per_group\": 0.30916884541511536, \"sigma_obs\": 143.38436889648438, \"slope\": -0.06995773315429688, \"chain\": 3, \"draw\": 71}, {\"draws\": 671, \"mouse\": 3, \"mu_intercept_per_group\": 6.594161510467529, \"sigma_intercept_per_group\": 0.30916884541511536, \"sigma_obs\": 143.38436889648438, \"slope\": -0.06995773315429688, \"chain\": 3, \"draw\": 71}, {\"draws\": 671, \"mouse\": 4, \"mu_intercept_per_group\": 6.477233409881592, \"sigma_intercept_per_group\": 0.30916884541511536, \"sigma_obs\": 143.38436889648438, \"slope\": -0.06995773315429688, \"chain\": 3, \"draw\": 71}, {\"draws\": 671, \"mouse\": 5, \"mu_intercept_per_group\": 6.007547378540039, \"sigma_intercept_per_group\": 0.30916884541511536, \"sigma_obs\": 143.38436889648438, \"slope\": -0.06995773315429688, \"chain\": 3, \"draw\": 71}, {\"draws\": 671, \"mouse\": 6, \"mu_intercept_per_group\": 5.804911136627197, \"sigma_intercept_per_group\": 0.30916884541511536, \"sigma_obs\": 143.38436889648438, \"slope\": -0.06995773315429688, \"chain\": 3, \"draw\": 71}, {\"draws\": 671, \"mouse\": 7, \"mu_intercept_per_group\": 5.209953784942627, \"sigma_intercept_per_group\": 0.30916884541511536, \"sigma_obs\": 143.38436889648438, \"slope\": -0.06995773315429688, \"chain\": 3, \"draw\": 71}, {\"draws\": 672, \"mouse\": 0, \"mu_intercept_per_group\": 10.22244644165039, \"sigma_intercept_per_group\": 0.24600446224212646, \"sigma_obs\": 170.2254180908203, \"slope\": -0.08386950939893723, \"chain\": 3, \"draw\": 72}, {\"draws\": 672, \"mouse\": 1, \"mu_intercept_per_group\": 10.204021453857422, \"sigma_intercept_per_group\": 0.24600446224212646, \"sigma_obs\": 170.2254180908203, \"slope\": -0.08386950939893723, \"chain\": 3, \"draw\": 72}, {\"draws\": 672, \"mouse\": 2, \"mu_intercept_per_group\": 9.789319038391113, \"sigma_intercept_per_group\": 0.24600446224212646, \"sigma_obs\": 170.2254180908203, \"slope\": -0.08386950939893723, \"chain\": 3, \"draw\": 72}, {\"draws\": 672, \"mouse\": 3, \"mu_intercept_per_group\": 9.209997177124023, \"sigma_intercept_per_group\": 0.24600446224212646, \"sigma_obs\": 170.2254180908203, \"slope\": -0.08386950939893723, \"chain\": 3, \"draw\": 72}, {\"draws\": 672, \"mouse\": 4, \"mu_intercept_per_group\": 9.125587463378906, \"sigma_intercept_per_group\": 0.24600446224212646, \"sigma_obs\": 170.2254180908203, \"slope\": -0.08386950939893723, \"chain\": 3, \"draw\": 72}, {\"draws\": 672, \"mouse\": 5, \"mu_intercept_per_group\": 8.549914360046387, \"sigma_intercept_per_group\": 0.24600446224212646, \"sigma_obs\": 170.2254180908203, \"slope\": -0.08386950939893723, \"chain\": 3, \"draw\": 72}, {\"draws\": 672, \"mouse\": 6, \"mu_intercept_per_group\": 7.954006195068359, \"sigma_intercept_per_group\": 0.24600446224212646, \"sigma_obs\": 170.2254180908203, \"slope\": -0.08386950939893723, \"chain\": 3, \"draw\": 72}, {\"draws\": 672, \"mouse\": 7, \"mu_intercept_per_group\": 7.613287448883057, \"sigma_intercept_per_group\": 0.24600446224212646, \"sigma_obs\": 170.2254180908203, \"slope\": -0.08386950939893723, \"chain\": 3, \"draw\": 72}, {\"draws\": 673, \"mouse\": 0, \"mu_intercept_per_group\": 10.237679481506348, \"sigma_intercept_per_group\": 0.25276240706443787, \"sigma_obs\": 166.64236450195312, \"slope\": -0.07209307700395584, \"chain\": 3, \"draw\": 73}, {\"draws\": 673, \"mouse\": 1, \"mu_intercept_per_group\": 9.549104690551758, \"sigma_intercept_per_group\": 0.25276240706443787, \"sigma_obs\": 166.64236450195312, \"slope\": -0.07209307700395584, \"chain\": 3, \"draw\": 73}, {\"draws\": 673, \"mouse\": 2, \"mu_intercept_per_group\": 9.17506217956543, \"sigma_intercept_per_group\": 0.25276240706443787, \"sigma_obs\": 166.64236450195312, \"slope\": -0.07209307700395584, \"chain\": 3, \"draw\": 73}, {\"draws\": 673, \"mouse\": 3, \"mu_intercept_per_group\": 8.739713668823242, \"sigma_intercept_per_group\": 0.25276240706443787, \"sigma_obs\": 166.64236450195312, \"slope\": -0.07209307700395584, \"chain\": 3, \"draw\": 73}, {\"draws\": 673, \"mouse\": 4, \"mu_intercept_per_group\": 8.50218677520752, \"sigma_intercept_per_group\": 0.25276240706443787, \"sigma_obs\": 166.64236450195312, \"slope\": -0.07209307700395584, \"chain\": 3, \"draw\": 73}, {\"draws\": 673, \"mouse\": 5, \"mu_intercept_per_group\": 8.28067398071289, \"sigma_intercept_per_group\": 0.25276240706443787, \"sigma_obs\": 166.64236450195312, \"slope\": -0.07209307700395584, \"chain\": 3, \"draw\": 73}, {\"draws\": 673, \"mouse\": 6, \"mu_intercept_per_group\": 7.6285552978515625, \"sigma_intercept_per_group\": 0.25276240706443787, \"sigma_obs\": 166.64236450195312, \"slope\": -0.07209307700395584, \"chain\": 3, \"draw\": 73}, {\"draws\": 673, \"mouse\": 7, \"mu_intercept_per_group\": 7.499063491821289, \"sigma_intercept_per_group\": 0.25276240706443787, \"sigma_obs\": 166.64236450195312, \"slope\": -0.07209307700395584, \"chain\": 3, \"draw\": 73}, {\"draws\": 674, \"mouse\": 0, \"mu_intercept_per_group\": 10.193291664123535, \"sigma_intercept_per_group\": 0.2523881793022156, \"sigma_obs\": 165.8280487060547, \"slope\": -0.07262774556875229, \"chain\": 3, \"draw\": 74}, {\"draws\": 674, \"mouse\": 1, \"mu_intercept_per_group\": 9.620611190795898, \"sigma_intercept_per_group\": 0.2523881793022156, \"sigma_obs\": 165.8280487060547, \"slope\": -0.07262774556875229, \"chain\": 3, \"draw\": 74}, {\"draws\": 674, \"mouse\": 2, \"mu_intercept_per_group\": 9.300177574157715, \"sigma_intercept_per_group\": 0.2523881793022156, \"sigma_obs\": 165.8280487060547, \"slope\": -0.07262774556875229, \"chain\": 3, \"draw\": 74}, {\"draws\": 674, \"mouse\": 3, \"mu_intercept_per_group\": 8.83814525604248, \"sigma_intercept_per_group\": 0.2523881793022156, \"sigma_obs\": 165.8280487060547, \"slope\": -0.07262774556875229, \"chain\": 3, \"draw\": 74}, {\"draws\": 674, \"mouse\": 4, \"mu_intercept_per_group\": 8.823851585388184, \"sigma_intercept_per_group\": 0.2523881793022156, \"sigma_obs\": 165.8280487060547, \"slope\": -0.07262774556875229, \"chain\": 3, \"draw\": 74}, {\"draws\": 674, \"mouse\": 5, \"mu_intercept_per_group\": 7.964545249938965, \"sigma_intercept_per_group\": 0.2523881793022156, \"sigma_obs\": 165.8280487060547, \"slope\": -0.07262774556875229, \"chain\": 3, \"draw\": 74}, {\"draws\": 674, \"mouse\": 6, \"mu_intercept_per_group\": 7.595711708068848, \"sigma_intercept_per_group\": 0.2523881793022156, \"sigma_obs\": 165.8280487060547, \"slope\": -0.07262774556875229, \"chain\": 3, \"draw\": 74}, {\"draws\": 674, \"mouse\": 7, \"mu_intercept_per_group\": 6.990022659301758, \"sigma_intercept_per_group\": 0.2523881793022156, \"sigma_obs\": 165.8280487060547, \"slope\": -0.07262774556875229, \"chain\": 3, \"draw\": 74}, {\"draws\": 675, \"mouse\": 0, \"mu_intercept_per_group\": 10.454704284667969, \"sigma_intercept_per_group\": 0.2327507734298706, \"sigma_obs\": 158.84567260742188, \"slope\": -0.06094088405370712, \"chain\": 3, \"draw\": 75}, {\"draws\": 675, \"mouse\": 1, \"mu_intercept_per_group\": 10.432723999023438, \"sigma_intercept_per_group\": 0.2327507734298706, \"sigma_obs\": 158.84567260742188, \"slope\": -0.06094088405370712, \"chain\": 3, \"draw\": 75}, {\"draws\": 675, \"mouse\": 2, \"mu_intercept_per_group\": 9.921161651611328, \"sigma_intercept_per_group\": 0.2327507734298706, \"sigma_obs\": 158.84567260742188, \"slope\": -0.06094088405370712, \"chain\": 3, \"draw\": 75}, {\"draws\": 675, \"mouse\": 3, \"mu_intercept_per_group\": 9.4241304397583, \"sigma_intercept_per_group\": 0.2327507734298706, \"sigma_obs\": 158.84567260742188, \"slope\": -0.06094088405370712, \"chain\": 3, \"draw\": 75}, {\"draws\": 675, \"mouse\": 4, \"mu_intercept_per_group\": 8.928492546081543, \"sigma_intercept_per_group\": 0.2327507734298706, \"sigma_obs\": 158.84567260742188, \"slope\": -0.06094088405370712, \"chain\": 3, \"draw\": 75}, {\"draws\": 675, \"mouse\": 5, \"mu_intercept_per_group\": 8.91254997253418, \"sigma_intercept_per_group\": 0.2327507734298706, \"sigma_obs\": 158.84567260742188, \"slope\": -0.06094088405370712, \"chain\": 3, \"draw\": 75}, {\"draws\": 675, \"mouse\": 6, \"mu_intercept_per_group\": 8.190057754516602, \"sigma_intercept_per_group\": 0.2327507734298706, \"sigma_obs\": 158.84567260742188, \"slope\": -0.06094088405370712, \"chain\": 3, \"draw\": 75}, {\"draws\": 675, \"mouse\": 7, \"mu_intercept_per_group\": 7.682645797729492, \"sigma_intercept_per_group\": 0.2327507734298706, \"sigma_obs\": 158.84567260742188, \"slope\": -0.06094088405370712, \"chain\": 3, \"draw\": 75}, {\"draws\": 676, \"mouse\": 0, \"mu_intercept_per_group\": 10.55433177947998, \"sigma_intercept_per_group\": 0.22851327061653137, \"sigma_obs\": 159.4444122314453, \"slope\": -0.06106148660182953, \"chain\": 3, \"draw\": 76}, {\"draws\": 676, \"mouse\": 1, \"mu_intercept_per_group\": 10.21072769165039, \"sigma_intercept_per_group\": 0.22851327061653137, \"sigma_obs\": 159.4444122314453, \"slope\": -0.06106148660182953, \"chain\": 3, \"draw\": 76}, {\"draws\": 676, \"mouse\": 2, \"mu_intercept_per_group\": 9.834756851196289, \"sigma_intercept_per_group\": 0.22851327061653137, \"sigma_obs\": 159.4444122314453, \"slope\": -0.06106148660182953, \"chain\": 3, \"draw\": 76}, {\"draws\": 676, \"mouse\": 3, \"mu_intercept_per_group\": 9.704940795898438, \"sigma_intercept_per_group\": 0.22851327061653137, \"sigma_obs\": 159.4444122314453, \"slope\": -0.06106148660182953, \"chain\": 3, \"draw\": 76}, {\"draws\": 676, \"mouse\": 4, \"mu_intercept_per_group\": 8.954280853271484, \"sigma_intercept_per_group\": 0.22851327061653137, \"sigma_obs\": 159.4444122314453, \"slope\": -0.06106148660182953, \"chain\": 3, \"draw\": 76}, {\"draws\": 676, \"mouse\": 5, \"mu_intercept_per_group\": 8.712479591369629, \"sigma_intercept_per_group\": 0.22851327061653137, \"sigma_obs\": 159.4444122314453, \"slope\": -0.06106148660182953, \"chain\": 3, \"draw\": 76}, {\"draws\": 676, \"mouse\": 6, \"mu_intercept_per_group\": 8.069299697875977, \"sigma_intercept_per_group\": 0.22851327061653137, \"sigma_obs\": 159.4444122314453, \"slope\": -0.06106148660182953, \"chain\": 3, \"draw\": 76}, {\"draws\": 676, \"mouse\": 7, \"mu_intercept_per_group\": 7.714715480804443, \"sigma_intercept_per_group\": 0.22851327061653137, \"sigma_obs\": 159.4444122314453, \"slope\": -0.06106148660182953, \"chain\": 3, \"draw\": 76}, {\"draws\": 677, \"mouse\": 0, \"mu_intercept_per_group\": 10.661014556884766, \"sigma_intercept_per_group\": 0.2281937599182129, \"sigma_obs\": 160.50021362304688, \"slope\": -0.0635005459189415, \"chain\": 3, \"draw\": 77}, {\"draws\": 677, \"mouse\": 1, \"mu_intercept_per_group\": 10.344658851623535, \"sigma_intercept_per_group\": 0.2281937599182129, \"sigma_obs\": 160.50021362304688, \"slope\": -0.0635005459189415, \"chain\": 3, \"draw\": 77}, {\"draws\": 677, \"mouse\": 2, \"mu_intercept_per_group\": 10.169604301452637, \"sigma_intercept_per_group\": 0.2281937599182129, \"sigma_obs\": 160.50021362304688, \"slope\": -0.0635005459189415, \"chain\": 3, \"draw\": 77}, {\"draws\": 677, \"mouse\": 3, \"mu_intercept_per_group\": 9.109335899353027, \"sigma_intercept_per_group\": 0.2281937599182129, \"sigma_obs\": 160.50021362304688, \"slope\": -0.0635005459189415, \"chain\": 3, \"draw\": 77}, {\"draws\": 677, \"mouse\": 4, \"mu_intercept_per_group\": 9.277899742126465, \"sigma_intercept_per_group\": 0.2281937599182129, \"sigma_obs\": 160.50021362304688, \"slope\": -0.0635005459189415, \"chain\": 3, \"draw\": 77}, {\"draws\": 677, \"mouse\": 5, \"mu_intercept_per_group\": 8.658357620239258, \"sigma_intercept_per_group\": 0.2281937599182129, \"sigma_obs\": 160.50021362304688, \"slope\": -0.0635005459189415, \"chain\": 3, \"draw\": 77}, {\"draws\": 677, \"mouse\": 6, \"mu_intercept_per_group\": 8.192850112915039, \"sigma_intercept_per_group\": 0.2281937599182129, \"sigma_obs\": 160.50021362304688, \"slope\": -0.0635005459189415, \"chain\": 3, \"draw\": 77}, {\"draws\": 677, \"mouse\": 7, \"mu_intercept_per_group\": 7.64922571182251, \"sigma_intercept_per_group\": 0.2281937599182129, \"sigma_obs\": 160.50021362304688, \"slope\": -0.0635005459189415, \"chain\": 3, \"draw\": 77}, {\"draws\": 678, \"mouse\": 0, \"mu_intercept_per_group\": 10.125508308410645, \"sigma_intercept_per_group\": 0.24196404218673706, \"sigma_obs\": 167.3629608154297, \"slope\": -0.07233691215515137, \"chain\": 3, \"draw\": 78}, {\"draws\": 678, \"mouse\": 1, \"mu_intercept_per_group\": 9.694284439086914, \"sigma_intercept_per_group\": 0.24196404218673706, \"sigma_obs\": 167.3629608154297, \"slope\": -0.07233691215515137, \"chain\": 3, \"draw\": 78}, {\"draws\": 678, \"mouse\": 2, \"mu_intercept_per_group\": 9.671182632446289, \"sigma_intercept_per_group\": 0.24196404218673706, \"sigma_obs\": 167.3629608154297, \"slope\": -0.07233691215515137, \"chain\": 3, \"draw\": 78}, {\"draws\": 678, \"mouse\": 3, \"mu_intercept_per_group\": 9.358421325683594, \"sigma_intercept_per_group\": 0.24196404218673706, \"sigma_obs\": 167.3629608154297, \"slope\": -0.07233691215515137, \"chain\": 3, \"draw\": 78}, {\"draws\": 678, \"mouse\": 4, \"mu_intercept_per_group\": 8.784011840820312, \"sigma_intercept_per_group\": 0.24196404218673706, \"sigma_obs\": 167.3629608154297, \"slope\": -0.07233691215515137, \"chain\": 3, \"draw\": 78}, {\"draws\": 678, \"mouse\": 5, \"mu_intercept_per_group\": 8.308963775634766, \"sigma_intercept_per_group\": 0.24196404218673706, \"sigma_obs\": 167.3629608154297, \"slope\": -0.07233691215515137, \"chain\": 3, \"draw\": 78}, {\"draws\": 678, \"mouse\": 6, \"mu_intercept_per_group\": 8.09433650970459, \"sigma_intercept_per_group\": 0.24196404218673706, \"sigma_obs\": 167.3629608154297, \"slope\": -0.07233691215515137, \"chain\": 3, \"draw\": 78}, {\"draws\": 678, \"mouse\": 7, \"mu_intercept_per_group\": 7.557103157043457, \"sigma_intercept_per_group\": 0.24196404218673706, \"sigma_obs\": 167.3629608154297, \"slope\": -0.07233691215515137, \"chain\": 3, \"draw\": 78}, {\"draws\": 679, \"mouse\": 0, \"mu_intercept_per_group\": 12.515840530395508, \"sigma_intercept_per_group\": 0.20277485251426697, \"sigma_obs\": 173.69285583496094, \"slope\": -0.0675603374838829, \"chain\": 3, \"draw\": 79}, {\"draws\": 679, \"mouse\": 1, \"mu_intercept_per_group\": 12.203567504882812, \"sigma_intercept_per_group\": 0.20277485251426697, \"sigma_obs\": 173.69285583496094, \"slope\": -0.0675603374838829, \"chain\": 3, \"draw\": 79}, {\"draws\": 679, \"mouse\": 2, \"mu_intercept_per_group\": 11.909448623657227, \"sigma_intercept_per_group\": 0.20277485251426697, \"sigma_obs\": 173.69285583496094, \"slope\": -0.0675603374838829, \"chain\": 3, \"draw\": 79}, {\"draws\": 679, \"mouse\": 3, \"mu_intercept_per_group\": 11.041351318359375, \"sigma_intercept_per_group\": 0.20277485251426697, \"sigma_obs\": 173.69285583496094, \"slope\": -0.0675603374838829, \"chain\": 3, \"draw\": 79}, {\"draws\": 679, \"mouse\": 4, \"mu_intercept_per_group\": 10.41771125793457, \"sigma_intercept_per_group\": 0.20277485251426697, \"sigma_obs\": 173.69285583496094, \"slope\": -0.0675603374838829, \"chain\": 3, \"draw\": 79}, {\"draws\": 679, \"mouse\": 5, \"mu_intercept_per_group\": 10.145309448242188, \"sigma_intercept_per_group\": 0.20277485251426697, \"sigma_obs\": 173.69285583496094, \"slope\": -0.0675603374838829, \"chain\": 3, \"draw\": 79}, {\"draws\": 679, \"mouse\": 6, \"mu_intercept_per_group\": 9.229713439941406, \"sigma_intercept_per_group\": 0.20277485251426697, \"sigma_obs\": 173.69285583496094, \"slope\": -0.0675603374838829, \"chain\": 3, \"draw\": 79}, {\"draws\": 679, \"mouse\": 7, \"mu_intercept_per_group\": 9.107576370239258, \"sigma_intercept_per_group\": 0.20277485251426697, \"sigma_obs\": 173.69285583496094, \"slope\": -0.0675603374838829, \"chain\": 3, \"draw\": 79}, {\"draws\": 680, \"mouse\": 0, \"mu_intercept_per_group\": 12.168757438659668, \"sigma_intercept_per_group\": 0.20960691571235657, \"sigma_obs\": 176.47396850585938, \"slope\": -0.0690036416053772, \"chain\": 3, \"draw\": 80}, {\"draws\": 680, \"mouse\": 1, \"mu_intercept_per_group\": 11.837481498718262, \"sigma_intercept_per_group\": 0.20960691571235657, \"sigma_obs\": 176.47396850585938, \"slope\": -0.0690036416053772, \"chain\": 3, \"draw\": 80}, {\"draws\": 680, \"mouse\": 2, \"mu_intercept_per_group\": 11.384891510009766, \"sigma_intercept_per_group\": 0.20960691571235657, \"sigma_obs\": 176.47396850585938, \"slope\": -0.0690036416053772, \"chain\": 3, \"draw\": 80}, {\"draws\": 680, \"mouse\": 3, \"mu_intercept_per_group\": 10.482497215270996, \"sigma_intercept_per_group\": 0.20960691571235657, \"sigma_obs\": 176.47396850585938, \"slope\": -0.0690036416053772, \"chain\": 3, \"draw\": 80}, {\"draws\": 680, \"mouse\": 4, \"mu_intercept_per_group\": 10.793181419372559, \"sigma_intercept_per_group\": 0.20960691571235657, \"sigma_obs\": 176.47396850585938, \"slope\": -0.0690036416053772, \"chain\": 3, \"draw\": 80}, {\"draws\": 680, \"mouse\": 5, \"mu_intercept_per_group\": 10.478838920593262, \"sigma_intercept_per_group\": 0.20960691571235657, \"sigma_obs\": 176.47396850585938, \"slope\": -0.0690036416053772, \"chain\": 3, \"draw\": 80}, {\"draws\": 680, \"mouse\": 6, \"mu_intercept_per_group\": 9.435885429382324, \"sigma_intercept_per_group\": 0.20960691571235657, \"sigma_obs\": 176.47396850585938, \"slope\": -0.0690036416053772, \"chain\": 3, \"draw\": 80}, {\"draws\": 680, \"mouse\": 7, \"mu_intercept_per_group\": 9.242801666259766, \"sigma_intercept_per_group\": 0.20960691571235657, \"sigma_obs\": 176.47396850585938, \"slope\": -0.0690036416053772, \"chain\": 3, \"draw\": 80}, {\"draws\": 681, \"mouse\": 0, \"mu_intercept_per_group\": 11.680614471435547, \"sigma_intercept_per_group\": 0.2116483896970749, \"sigma_obs\": 168.79241943359375, \"slope\": -0.06519971787929535, \"chain\": 3, \"draw\": 81}, {\"draws\": 681, \"mouse\": 1, \"mu_intercept_per_group\": 11.521001815795898, \"sigma_intercept_per_group\": 0.2116483896970749, \"sigma_obs\": 168.79241943359375, \"slope\": -0.06519971787929535, \"chain\": 3, \"draw\": 81}, {\"draws\": 681, \"mouse\": 2, \"mu_intercept_per_group\": 11.008821487426758, \"sigma_intercept_per_group\": 0.2116483896970749, \"sigma_obs\": 168.79241943359375, \"slope\": -0.06519971787929535, \"chain\": 3, \"draw\": 81}, {\"draws\": 681, \"mouse\": 3, \"mu_intercept_per_group\": 10.108328819274902, \"sigma_intercept_per_group\": 0.2116483896970749, \"sigma_obs\": 168.79241943359375, \"slope\": -0.06519971787929535, \"chain\": 3, \"draw\": 81}, {\"draws\": 681, \"mouse\": 4, \"mu_intercept_per_group\": 10.440095901489258, \"sigma_intercept_per_group\": 0.2116483896970749, \"sigma_obs\": 168.79241943359375, \"slope\": -0.06519971787929535, \"chain\": 3, \"draw\": 81}, {\"draws\": 681, \"mouse\": 5, \"mu_intercept_per_group\": 10.055951118469238, \"sigma_intercept_per_group\": 0.2116483896970749, \"sigma_obs\": 168.79241943359375, \"slope\": -0.06519971787929535, \"chain\": 3, \"draw\": 81}, {\"draws\": 681, \"mouse\": 6, \"mu_intercept_per_group\": 8.941112518310547, \"sigma_intercept_per_group\": 0.2116483896970749, \"sigma_obs\": 168.79241943359375, \"slope\": -0.06519971787929535, \"chain\": 3, \"draw\": 81}, {\"draws\": 681, \"mouse\": 7, \"mu_intercept_per_group\": 8.739035606384277, \"sigma_intercept_per_group\": 0.2116483896970749, \"sigma_obs\": 168.79241943359375, \"slope\": -0.06519971787929535, \"chain\": 3, \"draw\": 81}, {\"draws\": 682, \"mouse\": 0, \"mu_intercept_per_group\": 11.993330955505371, \"sigma_intercept_per_group\": 0.21196997165679932, \"sigma_obs\": 169.455810546875, \"slope\": -0.06453429907560349, \"chain\": 3, \"draw\": 82}, {\"draws\": 682, \"mouse\": 1, \"mu_intercept_per_group\": 11.311503410339355, \"sigma_intercept_per_group\": 0.21196997165679932, \"sigma_obs\": 169.455810546875, \"slope\": -0.06453429907560349, \"chain\": 3, \"draw\": 82}, {\"draws\": 682, \"mouse\": 2, \"mu_intercept_per_group\": 11.086390495300293, \"sigma_intercept_per_group\": 0.21196997165679932, \"sigma_obs\": 169.455810546875, \"slope\": -0.06453429907560349, \"chain\": 3, \"draw\": 82}, {\"draws\": 682, \"mouse\": 3, \"mu_intercept_per_group\": 10.684553146362305, \"sigma_intercept_per_group\": 0.21196997165679932, \"sigma_obs\": 169.455810546875, \"slope\": -0.06453429907560349, \"chain\": 3, \"draw\": 82}, {\"draws\": 682, \"mouse\": 4, \"mu_intercept_per_group\": 10.046187400817871, \"sigma_intercept_per_group\": 0.21196997165679932, \"sigma_obs\": 169.455810546875, \"slope\": -0.06453429907560349, \"chain\": 3, \"draw\": 82}, {\"draws\": 682, \"mouse\": 5, \"mu_intercept_per_group\": 9.705168724060059, \"sigma_intercept_per_group\": 0.21196997165679932, \"sigma_obs\": 169.455810546875, \"slope\": -0.06453429907560349, \"chain\": 3, \"draw\": 82}, {\"draws\": 682, \"mouse\": 6, \"mu_intercept_per_group\": 8.89029312133789, \"sigma_intercept_per_group\": 0.21196997165679932, \"sigma_obs\": 169.455810546875, \"slope\": -0.06453429907560349, \"chain\": 3, \"draw\": 82}, {\"draws\": 682, \"mouse\": 7, \"mu_intercept_per_group\": 8.30931282043457, \"sigma_intercept_per_group\": 0.21196997165679932, \"sigma_obs\": 169.455810546875, \"slope\": -0.06453429907560349, \"chain\": 3, \"draw\": 82}, {\"draws\": 683, \"mouse\": 0, \"mu_intercept_per_group\": 9.635986328125, \"sigma_intercept_per_group\": 0.25103428959846497, \"sigma_obs\": 160.65005493164062, \"slope\": -0.0592687726020813, \"chain\": 3, \"draw\": 83}, {\"draws\": 683, \"mouse\": 1, \"mu_intercept_per_group\": 9.566672325134277, \"sigma_intercept_per_group\": 0.25103428959846497, \"sigma_obs\": 160.65005493164062, \"slope\": -0.0592687726020813, \"chain\": 3, \"draw\": 83}, {\"draws\": 683, \"mouse\": 2, \"mu_intercept_per_group\": 9.14818000793457, \"sigma_intercept_per_group\": 0.25103428959846497, \"sigma_obs\": 160.65005493164062, \"slope\": -0.0592687726020813, \"chain\": 3, \"draw\": 83}, {\"draws\": 683, \"mouse\": 3, \"mu_intercept_per_group\": 8.691167831420898, \"sigma_intercept_per_group\": 0.25103428959846497, \"sigma_obs\": 160.65005493164062, \"slope\": -0.0592687726020813, \"chain\": 3, \"draw\": 83}, {\"draws\": 683, \"mouse\": 4, \"mu_intercept_per_group\": 8.555302619934082, \"sigma_intercept_per_group\": 0.25103428959846497, \"sigma_obs\": 160.65005493164062, \"slope\": -0.0592687726020813, \"chain\": 3, \"draw\": 83}, {\"draws\": 683, \"mouse\": 5, \"mu_intercept_per_group\": 8.084519386291504, \"sigma_intercept_per_group\": 0.25103428959846497, \"sigma_obs\": 160.65005493164062, \"slope\": -0.0592687726020813, \"chain\": 3, \"draw\": 83}, {\"draws\": 683, \"mouse\": 6, \"mu_intercept_per_group\": 7.116130828857422, \"sigma_intercept_per_group\": 0.25103428959846497, \"sigma_obs\": 160.65005493164062, \"slope\": -0.0592687726020813, \"chain\": 3, \"draw\": 83}, {\"draws\": 683, \"mouse\": 7, \"mu_intercept_per_group\": 6.786601543426514, \"sigma_intercept_per_group\": 0.25103428959846497, \"sigma_obs\": 160.65005493164062, \"slope\": -0.0592687726020813, \"chain\": 3, \"draw\": 83}, {\"draws\": 684, \"mouse\": 0, \"mu_intercept_per_group\": 9.835841178894043, \"sigma_intercept_per_group\": 0.2540420889854431, \"sigma_obs\": 162.29458618164062, \"slope\": -0.06096929311752319, \"chain\": 3, \"draw\": 84}, {\"draws\": 684, \"mouse\": 1, \"mu_intercept_per_group\": 9.293910026550293, \"sigma_intercept_per_group\": 0.2540420889854431, \"sigma_obs\": 162.29458618164062, \"slope\": -0.06096929311752319, \"chain\": 3, \"draw\": 84}, {\"draws\": 684, \"mouse\": 2, \"mu_intercept_per_group\": 9.220657348632812, \"sigma_intercept_per_group\": 0.2540420889854431, \"sigma_obs\": 162.29458618164062, \"slope\": -0.06096929311752319, \"chain\": 3, \"draw\": 84}, {\"draws\": 684, \"mouse\": 3, \"mu_intercept_per_group\": 8.574594497680664, \"sigma_intercept_per_group\": 0.2540420889854431, \"sigma_obs\": 162.29458618164062, \"slope\": -0.06096929311752319, \"chain\": 3, \"draw\": 84}, {\"draws\": 684, \"mouse\": 4, \"mu_intercept_per_group\": 8.23180103302002, \"sigma_intercept_per_group\": 0.2540420889854431, \"sigma_obs\": 162.29458618164062, \"slope\": -0.06096929311752319, \"chain\": 3, \"draw\": 84}, {\"draws\": 684, \"mouse\": 5, \"mu_intercept_per_group\": 7.772029399871826, \"sigma_intercept_per_group\": 0.2540420889854431, \"sigma_obs\": 162.29458618164062, \"slope\": -0.06096929311752319, \"chain\": 3, \"draw\": 84}, {\"draws\": 684, \"mouse\": 6, \"mu_intercept_per_group\": 7.74286413192749, \"sigma_intercept_per_group\": 0.2540420889854431, \"sigma_obs\": 162.29458618164062, \"slope\": -0.06096929311752319, \"chain\": 3, \"draw\": 84}, {\"draws\": 684, \"mouse\": 7, \"mu_intercept_per_group\": 7.209532260894775, \"sigma_intercept_per_group\": 0.2540420889854431, \"sigma_obs\": 162.29458618164062, \"slope\": -0.06096929311752319, \"chain\": 3, \"draw\": 84}, {\"draws\": 685, \"mouse\": 0, \"mu_intercept_per_group\": 9.567814826965332, \"sigma_intercept_per_group\": 0.2540839910507202, \"sigma_obs\": 160.70635986328125, \"slope\": -0.06116534024477005, \"chain\": 3, \"draw\": 85}, {\"draws\": 685, \"mouse\": 1, \"mu_intercept_per_group\": 9.36334228515625, \"sigma_intercept_per_group\": 0.2540839910507202, \"sigma_obs\": 160.70635986328125, \"slope\": -0.06116534024477005, \"chain\": 3, \"draw\": 85}, {\"draws\": 685, \"mouse\": 2, \"mu_intercept_per_group\": 8.994667053222656, \"sigma_intercept_per_group\": 0.2540839910507202, \"sigma_obs\": 160.70635986328125, \"slope\": -0.06116534024477005, \"chain\": 3, \"draw\": 85}, {\"draws\": 685, \"mouse\": 3, \"mu_intercept_per_group\": 8.524514198303223, \"sigma_intercept_per_group\": 0.2540839910507202, \"sigma_obs\": 160.70635986328125, \"slope\": -0.06116534024477005, \"chain\": 3, \"draw\": 85}, {\"draws\": 685, \"mouse\": 4, \"mu_intercept_per_group\": 8.5121488571167, \"sigma_intercept_per_group\": 0.2540839910507202, \"sigma_obs\": 160.70635986328125, \"slope\": -0.06116534024477005, \"chain\": 3, \"draw\": 85}, {\"draws\": 685, \"mouse\": 5, \"mu_intercept_per_group\": 8.012930870056152, \"sigma_intercept_per_group\": 0.2540839910507202, \"sigma_obs\": 160.70635986328125, \"slope\": -0.06116534024477005, \"chain\": 3, \"draw\": 85}, {\"draws\": 685, \"mouse\": 6, \"mu_intercept_per_group\": 7.427149772644043, \"sigma_intercept_per_group\": 0.2540839910507202, \"sigma_obs\": 160.70635986328125, \"slope\": -0.06116534024477005, \"chain\": 3, \"draw\": 85}, {\"draws\": 685, \"mouse\": 7, \"mu_intercept_per_group\": 7.000852584838867, \"sigma_intercept_per_group\": 0.2540839910507202, \"sigma_obs\": 160.70635986328125, \"slope\": -0.06116534024477005, \"chain\": 3, \"draw\": 85}, {\"draws\": 686, \"mouse\": 0, \"mu_intercept_per_group\": 10.392919540405273, \"sigma_intercept_per_group\": 0.2401902973651886, \"sigma_obs\": 165.23353576660156, \"slope\": -0.06618384271860123, \"chain\": 3, \"draw\": 86}, {\"draws\": 686, \"mouse\": 1, \"mu_intercept_per_group\": 10.184377670288086, \"sigma_intercept_per_group\": 0.2401902973651886, \"sigma_obs\": 165.23353576660156, \"slope\": -0.06618384271860123, \"chain\": 3, \"draw\": 86}, {\"draws\": 686, \"mouse\": 2, \"mu_intercept_per_group\": 9.651921272277832, \"sigma_intercept_per_group\": 0.2401902973651886, \"sigma_obs\": 165.23353576660156, \"slope\": -0.06618384271860123, \"chain\": 3, \"draw\": 86}, {\"draws\": 686, \"mouse\": 3, \"mu_intercept_per_group\": 8.995262145996094, \"sigma_intercept_per_group\": 0.2401902973651886, \"sigma_obs\": 165.23353576660156, \"slope\": -0.06618384271860123, \"chain\": 3, \"draw\": 86}, {\"draws\": 686, \"mouse\": 4, \"mu_intercept_per_group\": 8.945588111877441, \"sigma_intercept_per_group\": 0.2401902973651886, \"sigma_obs\": 165.23353576660156, \"slope\": -0.06618384271860123, \"chain\": 3, \"draw\": 86}, {\"draws\": 686, \"mouse\": 5, \"mu_intercept_per_group\": 8.477322578430176, \"sigma_intercept_per_group\": 0.2401902973651886, \"sigma_obs\": 165.23353576660156, \"slope\": -0.06618384271860123, \"chain\": 3, \"draw\": 86}, {\"draws\": 686, \"mouse\": 6, \"mu_intercept_per_group\": 8.066384315490723, \"sigma_intercept_per_group\": 0.2401902973651886, \"sigma_obs\": 165.23353576660156, \"slope\": -0.06618384271860123, \"chain\": 3, \"draw\": 86}, {\"draws\": 686, \"mouse\": 7, \"mu_intercept_per_group\": 7.5656867027282715, \"sigma_intercept_per_group\": 0.2401902973651886, \"sigma_obs\": 165.23353576660156, \"slope\": -0.06618384271860123, \"chain\": 3, \"draw\": 86}, {\"draws\": 687, \"mouse\": 0, \"mu_intercept_per_group\": 10.685380935668945, \"sigma_intercept_per_group\": 0.23575584590435028, \"sigma_obs\": 163.14833068847656, \"slope\": -0.06876713782548904, \"chain\": 3, \"draw\": 87}, {\"draws\": 687, \"mouse\": 1, \"mu_intercept_per_group\": 10.097228050231934, \"sigma_intercept_per_group\": 0.23575584590435028, \"sigma_obs\": 163.14833068847656, \"slope\": -0.06876713782548904, \"chain\": 3, \"draw\": 87}, {\"draws\": 687, \"mouse\": 2, \"mu_intercept_per_group\": 9.949347496032715, \"sigma_intercept_per_group\": 0.23575584590435028, \"sigma_obs\": 163.14833068847656, \"slope\": -0.06876713782548904, \"chain\": 3, \"draw\": 87}, {\"draws\": 687, \"mouse\": 3, \"mu_intercept_per_group\": 9.603270530700684, \"sigma_intercept_per_group\": 0.23575584590435028, \"sigma_obs\": 163.14833068847656, \"slope\": -0.06876713782548904, \"chain\": 3, \"draw\": 87}, {\"draws\": 687, \"mouse\": 4, \"mu_intercept_per_group\": 9.10660457611084, \"sigma_intercept_per_group\": 0.23575584590435028, \"sigma_obs\": 163.14833068847656, \"slope\": -0.06876713782548904, \"chain\": 3, \"draw\": 87}, {\"draws\": 687, \"mouse\": 5, \"mu_intercept_per_group\": 8.604942321777344, \"sigma_intercept_per_group\": 0.23575584590435028, \"sigma_obs\": 163.14833068847656, \"slope\": -0.06876713782548904, \"chain\": 3, \"draw\": 87}, {\"draws\": 687, \"mouse\": 6, \"mu_intercept_per_group\": 8.03746509552002, \"sigma_intercept_per_group\": 0.23575584590435028, \"sigma_obs\": 163.14833068847656, \"slope\": -0.06876713782548904, \"chain\": 3, \"draw\": 87}, {\"draws\": 687, \"mouse\": 7, \"mu_intercept_per_group\": 7.346071720123291, \"sigma_intercept_per_group\": 0.23575584590435028, \"sigma_obs\": 163.14833068847656, \"slope\": -0.06876713782548904, \"chain\": 3, \"draw\": 87}, {\"draws\": 688, \"mouse\": 0, \"mu_intercept_per_group\": 10.665520668029785, \"sigma_intercept_per_group\": 0.23122595250606537, \"sigma_obs\": 163.33087158203125, \"slope\": -0.06746244430541992, \"chain\": 3, \"draw\": 88}, {\"draws\": 688, \"mouse\": 1, \"mu_intercept_per_group\": 10.48688793182373, \"sigma_intercept_per_group\": 0.23122595250606537, \"sigma_obs\": 163.33087158203125, \"slope\": -0.06746244430541992, \"chain\": 3, \"draw\": 88}, {\"draws\": 688, \"mouse\": 2, \"mu_intercept_per_group\": 9.960738182067871, \"sigma_intercept_per_group\": 0.23122595250606537, \"sigma_obs\": 163.33087158203125, \"slope\": -0.06746244430541992, \"chain\": 3, \"draw\": 88}, {\"draws\": 688, \"mouse\": 3, \"mu_intercept_per_group\": 9.416228294372559, \"sigma_intercept_per_group\": 0.23122595250606537, \"sigma_obs\": 163.33087158203125, \"slope\": -0.06746244430541992, \"chain\": 3, \"draw\": 88}, {\"draws\": 688, \"mouse\": 4, \"mu_intercept_per_group\": 9.354046821594238, \"sigma_intercept_per_group\": 0.23122595250606537, \"sigma_obs\": 163.33087158203125, \"slope\": -0.06746244430541992, \"chain\": 3, \"draw\": 88}, {\"draws\": 688, \"mouse\": 5, \"mu_intercept_per_group\": 9.17443561553955, \"sigma_intercept_per_group\": 0.23122595250606537, \"sigma_obs\": 163.33087158203125, \"slope\": -0.06746244430541992, \"chain\": 3, \"draw\": 88}, {\"draws\": 688, \"mouse\": 6, \"mu_intercept_per_group\": 8.448212623596191, \"sigma_intercept_per_group\": 0.23122595250606537, \"sigma_obs\": 163.33087158203125, \"slope\": -0.06746244430541992, \"chain\": 3, \"draw\": 88}, {\"draws\": 688, \"mouse\": 7, \"mu_intercept_per_group\": 7.170266151428223, \"sigma_intercept_per_group\": 0.23122595250606537, \"sigma_obs\": 163.33087158203125, \"slope\": -0.06746244430541992, \"chain\": 3, \"draw\": 88}, {\"draws\": 689, \"mouse\": 0, \"mu_intercept_per_group\": 10.910341262817383, \"sigma_intercept_per_group\": 0.22906947135925293, \"sigma_obs\": 163.0486297607422, \"slope\": -0.06873010098934174, \"chain\": 3, \"draw\": 89}, {\"draws\": 689, \"mouse\": 1, \"mu_intercept_per_group\": 10.2843599319458, \"sigma_intercept_per_group\": 0.22906947135925293, \"sigma_obs\": 163.0486297607422, \"slope\": -0.06873010098934174, \"chain\": 3, \"draw\": 89}, {\"draws\": 689, \"mouse\": 2, \"mu_intercept_per_group\": 10.23095989227295, \"sigma_intercept_per_group\": 0.22906947135925293, \"sigma_obs\": 163.0486297607422, \"slope\": -0.06873010098934174, \"chain\": 3, \"draw\": 89}, {\"draws\": 689, \"mouse\": 3, \"mu_intercept_per_group\": 9.674063682556152, \"sigma_intercept_per_group\": 0.22906947135925293, \"sigma_obs\": 163.0486297607422, \"slope\": -0.06873010098934174, \"chain\": 3, \"draw\": 89}, {\"draws\": 689, \"mouse\": 4, \"mu_intercept_per_group\": 9.153410911560059, \"sigma_intercept_per_group\": 0.22906947135925293, \"sigma_obs\": 163.0486297607422, \"slope\": -0.06873010098934174, \"chain\": 3, \"draw\": 89}, {\"draws\": 689, \"mouse\": 5, \"mu_intercept_per_group\": 8.609185218811035, \"sigma_intercept_per_group\": 0.22906947135925293, \"sigma_obs\": 163.0486297607422, \"slope\": -0.06873010098934174, \"chain\": 3, \"draw\": 89}, {\"draws\": 689, \"mouse\": 6, \"mu_intercept_per_group\": 8.059002876281738, \"sigma_intercept_per_group\": 0.22906947135925293, \"sigma_obs\": 163.0486297607422, \"slope\": -0.06873010098934174, \"chain\": 3, \"draw\": 89}, {\"draws\": 689, \"mouse\": 7, \"mu_intercept_per_group\": 7.929531574249268, \"sigma_intercept_per_group\": 0.22906947135925293, \"sigma_obs\": 163.0486297607422, \"slope\": -0.06873010098934174, \"chain\": 3, \"draw\": 89}, {\"draws\": 690, \"mouse\": 0, \"mu_intercept_per_group\": 10.567790985107422, \"sigma_intercept_per_group\": 0.2309294193983078, \"sigma_obs\": 159.94508361816406, \"slope\": -0.06957269459962845, \"chain\": 3, \"draw\": 90}, {\"draws\": 690, \"mouse\": 1, \"mu_intercept_per_group\": 10.243082046508789, \"sigma_intercept_per_group\": 0.2309294193983078, \"sigma_obs\": 159.94508361816406, \"slope\": -0.06957269459962845, \"chain\": 3, \"draw\": 90}, {\"draws\": 690, \"mouse\": 2, \"mu_intercept_per_group\": 9.991070747375488, \"sigma_intercept_per_group\": 0.2309294193983078, \"sigma_obs\": 159.94508361816406, \"slope\": -0.06957269459962845, \"chain\": 3, \"draw\": 90}, {\"draws\": 690, \"mouse\": 3, \"mu_intercept_per_group\": 9.338399887084961, \"sigma_intercept_per_group\": 0.2309294193983078, \"sigma_obs\": 159.94508361816406, \"slope\": -0.06957269459962845, \"chain\": 3, \"draw\": 90}, {\"draws\": 690, \"mouse\": 4, \"mu_intercept_per_group\": 9.284063339233398, \"sigma_intercept_per_group\": 0.2309294193983078, \"sigma_obs\": 159.94508361816406, \"slope\": -0.06957269459962845, \"chain\": 3, \"draw\": 90}, {\"draws\": 690, \"mouse\": 5, \"mu_intercept_per_group\": 8.832879066467285, \"sigma_intercept_per_group\": 0.2309294193983078, \"sigma_obs\": 159.94508361816406, \"slope\": -0.06957269459962845, \"chain\": 3, \"draw\": 90}, {\"draws\": 690, \"mouse\": 6, \"mu_intercept_per_group\": 8.092517852783203, \"sigma_intercept_per_group\": 0.2309294193983078, \"sigma_obs\": 159.94508361816406, \"slope\": -0.06957269459962845, \"chain\": 3, \"draw\": 90}, {\"draws\": 690, \"mouse\": 7, \"mu_intercept_per_group\": 7.780060768127441, \"sigma_intercept_per_group\": 0.2309294193983078, \"sigma_obs\": 159.94508361816406, \"slope\": -0.06957269459962845, \"chain\": 3, \"draw\": 90}, {\"draws\": 691, \"mouse\": 0, \"mu_intercept_per_group\": 10.410961151123047, \"sigma_intercept_per_group\": 0.2320382297039032, \"sigma_obs\": 159.32296752929688, \"slope\": -0.06955060362815857, \"chain\": 3, \"draw\": 91}, {\"draws\": 691, \"mouse\": 1, \"mu_intercept_per_group\": 10.441855430603027, \"sigma_intercept_per_group\": 0.2320382297039032, \"sigma_obs\": 159.32296752929688, \"slope\": -0.06955060362815857, \"chain\": 3, \"draw\": 91}, {\"draws\": 691, \"mouse\": 2, \"mu_intercept_per_group\": 9.916263580322266, \"sigma_intercept_per_group\": 0.2320382297039032, \"sigma_obs\": 159.32296752929688, \"slope\": -0.06955060362815857, \"chain\": 3, \"draw\": 91}, {\"draws\": 691, \"mouse\": 3, \"mu_intercept_per_group\": 9.353832244873047, \"sigma_intercept_per_group\": 0.2320382297039032, \"sigma_obs\": 159.32296752929688, \"slope\": -0.06955060362815857, \"chain\": 3, \"draw\": 91}, {\"draws\": 691, \"mouse\": 4, \"mu_intercept_per_group\": 9.0321626663208, \"sigma_intercept_per_group\": 0.2320382297039032, \"sigma_obs\": 159.32296752929688, \"slope\": -0.06955060362815857, \"chain\": 3, \"draw\": 91}, {\"draws\": 691, \"mouse\": 5, \"mu_intercept_per_group\": 8.613014221191406, \"sigma_intercept_per_group\": 0.2320382297039032, \"sigma_obs\": 159.32296752929688, \"slope\": -0.06955060362815857, \"chain\": 3, \"draw\": 91}, {\"draws\": 691, \"mouse\": 6, \"mu_intercept_per_group\": 8.030950546264648, \"sigma_intercept_per_group\": 0.2320382297039032, \"sigma_obs\": 159.32296752929688, \"slope\": -0.06955060362815857, \"chain\": 3, \"draw\": 91}, {\"draws\": 691, \"mouse\": 7, \"mu_intercept_per_group\": 7.797095775604248, \"sigma_intercept_per_group\": 0.2320382297039032, \"sigma_obs\": 159.32296752929688, \"slope\": -0.06955060362815857, \"chain\": 3, \"draw\": 91}, {\"draws\": 692, \"mouse\": 0, \"mu_intercept_per_group\": 13.586115837097168, \"sigma_intercept_per_group\": 0.17984578013420105, \"sigma_obs\": 157.45327758789062, \"slope\": -0.0768202394247055, \"chain\": 3, \"draw\": 92}, {\"draws\": 692, \"mouse\": 1, \"mu_intercept_per_group\": 13.270939826965332, \"sigma_intercept_per_group\": 0.17984578013420105, \"sigma_obs\": 157.45327758789062, \"slope\": -0.0768202394247055, \"chain\": 3, \"draw\": 92}, {\"draws\": 692, \"mouse\": 2, \"mu_intercept_per_group\": 13.05946159362793, \"sigma_intercept_per_group\": 0.17984578013420105, \"sigma_obs\": 157.45327758789062, \"slope\": -0.0768202394247055, \"chain\": 3, \"draw\": 92}, {\"draws\": 692, \"mouse\": 3, \"mu_intercept_per_group\": 12.181306838989258, \"sigma_intercept_per_group\": 0.17984578013420105, \"sigma_obs\": 157.45327758789062, \"slope\": -0.0768202394247055, \"chain\": 3, \"draw\": 92}, {\"draws\": 692, \"mouse\": 4, \"mu_intercept_per_group\": 11.888028144836426, \"sigma_intercept_per_group\": 0.17984578013420105, \"sigma_obs\": 157.45327758789062, \"slope\": -0.0768202394247055, \"chain\": 3, \"draw\": 92}, {\"draws\": 692, \"mouse\": 5, \"mu_intercept_per_group\": 11.171670913696289, \"sigma_intercept_per_group\": 0.17984578013420105, \"sigma_obs\": 157.45327758789062, \"slope\": -0.0768202394247055, \"chain\": 3, \"draw\": 92}, {\"draws\": 692, \"mouse\": 6, \"mu_intercept_per_group\": 10.37688159942627, \"sigma_intercept_per_group\": 0.17984578013420105, \"sigma_obs\": 157.45327758789062, \"slope\": -0.0768202394247055, \"chain\": 3, \"draw\": 92}, {\"draws\": 692, \"mouse\": 7, \"mu_intercept_per_group\": 9.78870677947998, \"sigma_intercept_per_group\": 0.17984578013420105, \"sigma_obs\": 157.45327758789062, \"slope\": -0.0768202394247055, \"chain\": 3, \"draw\": 92}, {\"draws\": 693, \"mouse\": 0, \"mu_intercept_per_group\": 16.527469635009766, \"sigma_intercept_per_group\": 0.1522252857685089, \"sigma_obs\": 159.77227783203125, \"slope\": -0.07978038489818573, \"chain\": 3, \"draw\": 93}, {\"draws\": 693, \"mouse\": 1, \"mu_intercept_per_group\": 15.606293678283691, \"sigma_intercept_per_group\": 0.1522252857685089, \"sigma_obs\": 159.77227783203125, \"slope\": -0.07978038489818573, \"chain\": 3, \"draw\": 93}, {\"draws\": 693, \"mouse\": 2, \"mu_intercept_per_group\": 15.260826110839844, \"sigma_intercept_per_group\": 0.1522252857685089, \"sigma_obs\": 159.77227783203125, \"slope\": -0.07978038489818573, \"chain\": 3, \"draw\": 93}, {\"draws\": 693, \"mouse\": 3, \"mu_intercept_per_group\": 14.513884544372559, \"sigma_intercept_per_group\": 0.1522252857685089, \"sigma_obs\": 159.77227783203125, \"slope\": -0.07978038489818573, \"chain\": 3, \"draw\": 93}, {\"draws\": 693, \"mouse\": 4, \"mu_intercept_per_group\": 14.070598602294922, \"sigma_intercept_per_group\": 0.1522252857685089, \"sigma_obs\": 159.77227783203125, \"slope\": -0.07978038489818573, \"chain\": 3, \"draw\": 93}, {\"draws\": 693, \"mouse\": 5, \"mu_intercept_per_group\": 13.261995315551758, \"sigma_intercept_per_group\": 0.1522252857685089, \"sigma_obs\": 159.77227783203125, \"slope\": -0.07978038489818573, \"chain\": 3, \"draw\": 93}, {\"draws\": 693, \"mouse\": 6, \"mu_intercept_per_group\": 12.348052978515625, \"sigma_intercept_per_group\": 0.1522252857685089, \"sigma_obs\": 159.77227783203125, \"slope\": -0.07978038489818573, \"chain\": 3, \"draw\": 93}, {\"draws\": 693, \"mouse\": 7, \"mu_intercept_per_group\": 11.912753105163574, \"sigma_intercept_per_group\": 0.1522252857685089, \"sigma_obs\": 159.77227783203125, \"slope\": -0.07978038489818573, \"chain\": 3, \"draw\": 93}, {\"draws\": 694, \"mouse\": 0, \"mu_intercept_per_group\": 13.938034057617188, \"sigma_intercept_per_group\": 0.17815932631492615, \"sigma_obs\": 160.695556640625, \"slope\": -0.06643393635749817, \"chain\": 3, \"draw\": 94}, {\"draws\": 694, \"mouse\": 1, \"mu_intercept_per_group\": 13.715538024902344, \"sigma_intercept_per_group\": 0.17815932631492615, \"sigma_obs\": 160.695556640625, \"slope\": -0.06643393635749817, \"chain\": 3, \"draw\": 94}, {\"draws\": 694, \"mouse\": 2, \"mu_intercept_per_group\": 13.100170135498047, \"sigma_intercept_per_group\": 0.17815932631492615, \"sigma_obs\": 160.695556640625, \"slope\": -0.06643393635749817, \"chain\": 3, \"draw\": 94}, {\"draws\": 694, \"mouse\": 3, \"mu_intercept_per_group\": 12.367731094360352, \"sigma_intercept_per_group\": 0.17815932631492615, \"sigma_obs\": 160.695556640625, \"slope\": -0.06643393635749817, \"chain\": 3, \"draw\": 94}, {\"draws\": 694, \"mouse\": 4, \"mu_intercept_per_group\": 12.202498435974121, \"sigma_intercept_per_group\": 0.17815932631492615, \"sigma_obs\": 160.695556640625, \"slope\": -0.06643393635749817, \"chain\": 3, \"draw\": 94}, {\"draws\": 694, \"mouse\": 5, \"mu_intercept_per_group\": 11.32050609588623, \"sigma_intercept_per_group\": 0.17815932631492615, \"sigma_obs\": 160.695556640625, \"slope\": -0.06643393635749817, \"chain\": 3, \"draw\": 94}, {\"draws\": 694, \"mouse\": 6, \"mu_intercept_per_group\": 10.703512191772461, \"sigma_intercept_per_group\": 0.17815932631492615, \"sigma_obs\": 160.695556640625, \"slope\": -0.06643393635749817, \"chain\": 3, \"draw\": 94}, {\"draws\": 694, \"mouse\": 7, \"mu_intercept_per_group\": 10.32466983795166, \"sigma_intercept_per_group\": 0.17815932631492615, \"sigma_obs\": 160.695556640625, \"slope\": -0.06643393635749817, \"chain\": 3, \"draw\": 94}, {\"draws\": 695, \"mouse\": 0, \"mu_intercept_per_group\": 12.226156234741211, \"sigma_intercept_per_group\": 0.1959359347820282, \"sigma_obs\": 156.06163024902344, \"slope\": -0.07053085416555405, \"chain\": 3, \"draw\": 95}, {\"draws\": 695, \"mouse\": 1, \"mu_intercept_per_group\": 11.967692375183105, \"sigma_intercept_per_group\": 0.1959359347820282, \"sigma_obs\": 156.06163024902344, \"slope\": -0.07053085416555405, \"chain\": 3, \"draw\": 95}, {\"draws\": 695, \"mouse\": 2, \"mu_intercept_per_group\": 11.508787155151367, \"sigma_intercept_per_group\": 0.1959359347820282, \"sigma_obs\": 156.06163024902344, \"slope\": -0.07053085416555405, \"chain\": 3, \"draw\": 95}, {\"draws\": 695, \"mouse\": 3, \"mu_intercept_per_group\": 10.798867225646973, \"sigma_intercept_per_group\": 0.1959359347820282, \"sigma_obs\": 156.06163024902344, \"slope\": -0.07053085416555405, \"chain\": 3, \"draw\": 95}, {\"draws\": 695, \"mouse\": 4, \"mu_intercept_per_group\": 10.633325576782227, \"sigma_intercept_per_group\": 0.1959359347820282, \"sigma_obs\": 156.06163024902344, \"slope\": -0.07053085416555405, \"chain\": 3, \"draw\": 95}, {\"draws\": 695, \"mouse\": 5, \"mu_intercept_per_group\": 10.140810012817383, \"sigma_intercept_per_group\": 0.1959359347820282, \"sigma_obs\": 156.06163024902344, \"slope\": -0.07053085416555405, \"chain\": 3, \"draw\": 95}, {\"draws\": 695, \"mouse\": 6, \"mu_intercept_per_group\": 9.10625171661377, \"sigma_intercept_per_group\": 0.1959359347820282, \"sigma_obs\": 156.06163024902344, \"slope\": -0.07053085416555405, \"chain\": 3, \"draw\": 95}, {\"draws\": 695, \"mouse\": 7, \"mu_intercept_per_group\": 9.071441650390625, \"sigma_intercept_per_group\": 0.1959359347820282, \"sigma_obs\": 156.06163024902344, \"slope\": -0.07053085416555405, \"chain\": 3, \"draw\": 95}, {\"draws\": 696, \"mouse\": 0, \"mu_intercept_per_group\": 12.521736145019531, \"sigma_intercept_per_group\": 0.19895440340042114, \"sigma_obs\": 154.870849609375, \"slope\": -0.07005226612091064, \"chain\": 3, \"draw\": 96}, {\"draws\": 696, \"mouse\": 1, \"mu_intercept_per_group\": 12.016180038452148, \"sigma_intercept_per_group\": 0.19895440340042114, \"sigma_obs\": 154.870849609375, \"slope\": -0.07005226612091064, \"chain\": 3, \"draw\": 96}, {\"draws\": 696, \"mouse\": 2, \"mu_intercept_per_group\": 11.639815330505371, \"sigma_intercept_per_group\": 0.19895440340042114, \"sigma_obs\": 154.870849609375, \"slope\": -0.07005226612091064, \"chain\": 3, \"draw\": 96}, {\"draws\": 696, \"mouse\": 3, \"mu_intercept_per_group\": 10.8386869430542, \"sigma_intercept_per_group\": 0.19895440340042114, \"sigma_obs\": 154.870849609375, \"slope\": -0.07005226612091064, \"chain\": 3, \"draw\": 96}, {\"draws\": 696, \"mouse\": 4, \"mu_intercept_per_group\": 10.48665714263916, \"sigma_intercept_per_group\": 0.19895440340042114, \"sigma_obs\": 154.870849609375, \"slope\": -0.07005226612091064, \"chain\": 3, \"draw\": 96}, {\"draws\": 696, \"mouse\": 5, \"mu_intercept_per_group\": 10.308728218078613, \"sigma_intercept_per_group\": 0.19895440340042114, \"sigma_obs\": 154.870849609375, \"slope\": -0.07005226612091064, \"chain\": 3, \"draw\": 96}, {\"draws\": 696, \"mouse\": 6, \"mu_intercept_per_group\": 9.518831253051758, \"sigma_intercept_per_group\": 0.19895440340042114, \"sigma_obs\": 154.870849609375, \"slope\": -0.07005226612091064, \"chain\": 3, \"draw\": 96}, {\"draws\": 696, \"mouse\": 7, \"mu_intercept_per_group\": 8.61746883392334, \"sigma_intercept_per_group\": 0.19895440340042114, \"sigma_obs\": 154.870849609375, \"slope\": -0.07005226612091064, \"chain\": 3, \"draw\": 96}, {\"draws\": 697, \"mouse\": 0, \"mu_intercept_per_group\": 12.750441551208496, \"sigma_intercept_per_group\": 0.19613929092884064, \"sigma_obs\": 154.83297729492188, \"slope\": -0.07095962762832642, \"chain\": 3, \"draw\": 97}, {\"draws\": 697, \"mouse\": 1, \"mu_intercept_per_group\": 11.8975830078125, \"sigma_intercept_per_group\": 0.19613929092884064, \"sigma_obs\": 154.83297729492188, \"slope\": -0.07095962762832642, \"chain\": 3, \"draw\": 97}, {\"draws\": 697, \"mouse\": 2, \"mu_intercept_per_group\": 11.473518371582031, \"sigma_intercept_per_group\": 0.19613929092884064, \"sigma_obs\": 154.83297729492188, \"slope\": -0.07095962762832642, \"chain\": 3, \"draw\": 97}, {\"draws\": 697, \"mouse\": 3, \"mu_intercept_per_group\": 10.864344596862793, \"sigma_intercept_per_group\": 0.19613929092884064, \"sigma_obs\": 154.83297729492188, \"slope\": -0.07095962762832642, \"chain\": 3, \"draw\": 97}, {\"draws\": 697, \"mouse\": 4, \"mu_intercept_per_group\": 10.49545955657959, \"sigma_intercept_per_group\": 0.19613929092884064, \"sigma_obs\": 154.83297729492188, \"slope\": -0.07095962762832642, \"chain\": 3, \"draw\": 97}, {\"draws\": 697, \"mouse\": 5, \"mu_intercept_per_group\": 10.208623886108398, \"sigma_intercept_per_group\": 0.19613929092884064, \"sigma_obs\": 154.83297729492188, \"slope\": -0.07095962762832642, \"chain\": 3, \"draw\": 97}, {\"draws\": 697, \"mouse\": 6, \"mu_intercept_per_group\": 9.768170356750488, \"sigma_intercept_per_group\": 0.19613929092884064, \"sigma_obs\": 154.83297729492188, \"slope\": -0.07095962762832642, \"chain\": 3, \"draw\": 97}, {\"draws\": 697, \"mouse\": 7, \"mu_intercept_per_group\": 8.562328338623047, \"sigma_intercept_per_group\": 0.19613929092884064, \"sigma_obs\": 154.83297729492188, \"slope\": -0.07095962762832642, \"chain\": 3, \"draw\": 97}, {\"draws\": 698, \"mouse\": 0, \"mu_intercept_per_group\": 11.931238174438477, \"sigma_intercept_per_group\": 0.20198962092399597, \"sigma_obs\": 155.4669952392578, \"slope\": -0.07281769067049026, \"chain\": 3, \"draw\": 98}, {\"draws\": 698, \"mouse\": 1, \"mu_intercept_per_group\": 11.611428260803223, \"sigma_intercept_per_group\": 0.20198962092399597, \"sigma_obs\": 155.4669952392578, \"slope\": -0.07281769067049026, \"chain\": 3, \"draw\": 98}, {\"draws\": 698, \"mouse\": 2, \"mu_intercept_per_group\": 11.537107467651367, \"sigma_intercept_per_group\": 0.20198962092399597, \"sigma_obs\": 155.4669952392578, \"slope\": -0.07281769067049026, \"chain\": 3, \"draw\": 98}, {\"draws\": 698, \"mouse\": 3, \"mu_intercept_per_group\": 10.770739555358887, \"sigma_intercept_per_group\": 0.20198962092399597, \"sigma_obs\": 155.4669952392578, \"slope\": -0.07281769067049026, \"chain\": 3, \"draw\": 98}, {\"draws\": 698, \"mouse\": 4, \"mu_intercept_per_group\": 10.528009414672852, \"sigma_intercept_per_group\": 0.20198962092399597, \"sigma_obs\": 155.4669952392578, \"slope\": -0.07281769067049026, \"chain\": 3, \"draw\": 98}, {\"draws\": 698, \"mouse\": 5, \"mu_intercept_per_group\": 9.675675392150879, \"sigma_intercept_per_group\": 0.20198962092399597, \"sigma_obs\": 155.4669952392578, \"slope\": -0.07281769067049026, \"chain\": 3, \"draw\": 98}, {\"draws\": 698, \"mouse\": 6, \"mu_intercept_per_group\": 8.714077949523926, \"sigma_intercept_per_group\": 0.20198962092399597, \"sigma_obs\": 155.4669952392578, \"slope\": -0.07281769067049026, \"chain\": 3, \"draw\": 98}, {\"draws\": 698, \"mouse\": 7, \"mu_intercept_per_group\": 9.201233863830566, \"sigma_intercept_per_group\": 0.20198962092399597, \"sigma_obs\": 155.4669952392578, \"slope\": -0.07281769067049026, \"chain\": 3, \"draw\": 98}, {\"draws\": 699, \"mouse\": 0, \"mu_intercept_per_group\": 13.469940185546875, \"sigma_intercept_per_group\": 0.18837997317314148, \"sigma_obs\": 161.19601440429688, \"slope\": -0.07880105823278427, \"chain\": 3, \"draw\": 99}, {\"draws\": 699, \"mouse\": 1, \"mu_intercept_per_group\": 12.766261100769043, \"sigma_intercept_per_group\": 0.18837997317314148, \"sigma_obs\": 161.19601440429688, \"slope\": -0.07880105823278427, \"chain\": 3, \"draw\": 99}, {\"draws\": 699, \"mouse\": 2, \"mu_intercept_per_group\": 12.121954917907715, \"sigma_intercept_per_group\": 0.18837997317314148, \"sigma_obs\": 161.19601440429688, \"slope\": -0.07880105823278427, \"chain\": 3, \"draw\": 99}, {\"draws\": 699, \"mouse\": 3, \"mu_intercept_per_group\": 11.617159843444824, \"sigma_intercept_per_group\": 0.18837997317314148, \"sigma_obs\": 161.19601440429688, \"slope\": -0.07880105823278427, \"chain\": 3, \"draw\": 99}, {\"draws\": 699, \"mouse\": 4, \"mu_intercept_per_group\": 11.263167381286621, \"sigma_intercept_per_group\": 0.18837997317314148, \"sigma_obs\": 161.19601440429688, \"slope\": -0.07880105823278427, \"chain\": 3, \"draw\": 99}, {\"draws\": 699, \"mouse\": 5, \"mu_intercept_per_group\": 10.958150863647461, \"sigma_intercept_per_group\": 0.18837997317314148, \"sigma_obs\": 161.19601440429688, \"slope\": -0.07880105823278427, \"chain\": 3, \"draw\": 99}, {\"draws\": 699, \"mouse\": 6, \"mu_intercept_per_group\": 9.569791793823242, \"sigma_intercept_per_group\": 0.18837997317314148, \"sigma_obs\": 161.19601440429688, \"slope\": -0.07880105823278427, \"chain\": 3, \"draw\": 99}, {\"draws\": 699, \"mouse\": 7, \"mu_intercept_per_group\": 10.072407722473145, \"sigma_intercept_per_group\": 0.18837997317314148, \"sigma_obs\": 161.19601440429688, \"slope\": -0.07880105823278427, \"chain\": 3, \"draw\": 99}, {\"draws\": 700, \"mouse\": 0, \"mu_intercept_per_group\": 12.972743034362793, \"sigma_intercept_per_group\": 0.19065555930137634, \"sigma_obs\": 162.10247802734375, \"slope\": -0.07788621634244919, \"chain\": 3, \"draw\": 100}, {\"draws\": 700, \"mouse\": 1, \"mu_intercept_per_group\": 12.612091064453125, \"sigma_intercept_per_group\": 0.19065555930137634, \"sigma_obs\": 162.10247802734375, \"slope\": -0.07788621634244919, \"chain\": 3, \"draw\": 100}, {\"draws\": 700, \"mouse\": 2, \"mu_intercept_per_group\": 12.527408599853516, \"sigma_intercept_per_group\": 0.19065555930137634, \"sigma_obs\": 162.10247802734375, \"slope\": -0.07788621634244919, \"chain\": 3, \"draw\": 100}, {\"draws\": 700, \"mouse\": 3, \"mu_intercept_per_group\": 11.68178653717041, \"sigma_intercept_per_group\": 0.19065555930137634, \"sigma_obs\": 162.10247802734375, \"slope\": -0.07788621634244919, \"chain\": 3, \"draw\": 100}, {\"draws\": 700, \"mouse\": 4, \"mu_intercept_per_group\": 11.282403945922852, \"sigma_intercept_per_group\": 0.19065555930137634, \"sigma_obs\": 162.10247802734375, \"slope\": -0.07788621634244919, \"chain\": 3, \"draw\": 100}, {\"draws\": 700, \"mouse\": 5, \"mu_intercept_per_group\": 10.617273330688477, \"sigma_intercept_per_group\": 0.19065555930137634, \"sigma_obs\": 162.10247802734375, \"slope\": -0.07788621634244919, \"chain\": 3, \"draw\": 100}, {\"draws\": 700, \"mouse\": 6, \"mu_intercept_per_group\": 10.467635154724121, \"sigma_intercept_per_group\": 0.19065555930137634, \"sigma_obs\": 162.10247802734375, \"slope\": -0.07788621634244919, \"chain\": 3, \"draw\": 100}, {\"draws\": 700, \"mouse\": 7, \"mu_intercept_per_group\": 9.385442733764648, \"sigma_intercept_per_group\": 0.19065555930137634, \"sigma_obs\": 162.10247802734375, \"slope\": -0.07788621634244919, \"chain\": 3, \"draw\": 100}, {\"draws\": 701, \"mouse\": 0, \"mu_intercept_per_group\": 13.555981636047363, \"sigma_intercept_per_group\": 0.18864816427230835, \"sigma_obs\": 165.43212890625, \"slope\": -0.07853367179632187, \"chain\": 3, \"draw\": 101}, {\"draws\": 701, \"mouse\": 1, \"mu_intercept_per_group\": 13.113069534301758, \"sigma_intercept_per_group\": 0.18864816427230835, \"sigma_obs\": 165.43212890625, \"slope\": -0.07853367179632187, \"chain\": 3, \"draw\": 101}, {\"draws\": 701, \"mouse\": 2, \"mu_intercept_per_group\": 12.227062225341797, \"sigma_intercept_per_group\": 0.18864816427230835, \"sigma_obs\": 165.43212890625, \"slope\": -0.07853367179632187, \"chain\": 3, \"draw\": 101}, {\"draws\": 701, \"mouse\": 3, \"mu_intercept_per_group\": 11.818963050842285, \"sigma_intercept_per_group\": 0.18864816427230835, \"sigma_obs\": 165.43212890625, \"slope\": -0.07853367179632187, \"chain\": 3, \"draw\": 101}, {\"draws\": 701, \"mouse\": 4, \"mu_intercept_per_group\": 11.500083923339844, \"sigma_intercept_per_group\": 0.18864816427230835, \"sigma_obs\": 165.43212890625, \"slope\": -0.07853367179632187, \"chain\": 3, \"draw\": 101}, {\"draws\": 701, \"mouse\": 5, \"mu_intercept_per_group\": 10.805482864379883, \"sigma_intercept_per_group\": 0.18864816427230835, \"sigma_obs\": 165.43212890625, \"slope\": -0.07853367179632187, \"chain\": 3, \"draw\": 101}, {\"draws\": 701, \"mouse\": 6, \"mu_intercept_per_group\": 9.992773056030273, \"sigma_intercept_per_group\": 0.18864816427230835, \"sigma_obs\": 165.43212890625, \"slope\": -0.07853367179632187, \"chain\": 3, \"draw\": 101}, {\"draws\": 701, \"mouse\": 7, \"mu_intercept_per_group\": 9.931489944458008, \"sigma_intercept_per_group\": 0.18864816427230835, \"sigma_obs\": 165.43212890625, \"slope\": -0.07853367179632187, \"chain\": 3, \"draw\": 101}, {\"draws\": 702, \"mouse\": 0, \"mu_intercept_per_group\": 8.03601360321045, \"sigma_intercept_per_group\": 0.31555822491645813, \"sigma_obs\": 165.22409057617188, \"slope\": -0.06327978521585464, \"chain\": 3, \"draw\": 102}, {\"draws\": 702, \"mouse\": 1, \"mu_intercept_per_group\": 7.919544219970703, \"sigma_intercept_per_group\": 0.31555822491645813, \"sigma_obs\": 165.22409057617188, \"slope\": -0.06327978521585464, \"chain\": 3, \"draw\": 102}, {\"draws\": 702, \"mouse\": 2, \"mu_intercept_per_group\": 7.37980318069458, \"sigma_intercept_per_group\": 0.31555822491645813, \"sigma_obs\": 165.22409057617188, \"slope\": -0.06327978521585464, \"chain\": 3, \"draw\": 102}, {\"draws\": 702, \"mouse\": 3, \"mu_intercept_per_group\": 6.894975662231445, \"sigma_intercept_per_group\": 0.31555822491645813, \"sigma_obs\": 165.22409057617188, \"slope\": -0.06327978521585464, \"chain\": 3, \"draw\": 102}, {\"draws\": 702, \"mouse\": 4, \"mu_intercept_per_group\": 6.745880126953125, \"sigma_intercept_per_group\": 0.31555822491645813, \"sigma_obs\": 165.22409057617188, \"slope\": -0.06327978521585464, \"chain\": 3, \"draw\": 102}, {\"draws\": 702, \"mouse\": 5, \"mu_intercept_per_group\": 6.491019248962402, \"sigma_intercept_per_group\": 0.31555822491645813, \"sigma_obs\": 165.22409057617188, \"slope\": -0.06327978521585464, \"chain\": 3, \"draw\": 102}, {\"draws\": 702, \"mouse\": 6, \"mu_intercept_per_group\": 6.087193489074707, \"sigma_intercept_per_group\": 0.31555822491645813, \"sigma_obs\": 165.22409057617188, \"slope\": -0.06327978521585464, \"chain\": 3, \"draw\": 102}, {\"draws\": 702, \"mouse\": 7, \"mu_intercept_per_group\": 5.525079250335693, \"sigma_intercept_per_group\": 0.31555822491645813, \"sigma_obs\": 165.22409057617188, \"slope\": -0.06327978521585464, \"chain\": 3, \"draw\": 102}, {\"draws\": 703, \"mouse\": 0, \"mu_intercept_per_group\": 8.101272583007812, \"sigma_intercept_per_group\": 0.31356334686279297, \"sigma_obs\": 167.7554168701172, \"slope\": -0.05519695207476616, \"chain\": 3, \"draw\": 103}, {\"draws\": 703, \"mouse\": 1, \"mu_intercept_per_group\": 7.668111324310303, \"sigma_intercept_per_group\": 0.31356334686279297, \"sigma_obs\": 167.7554168701172, \"slope\": -0.05519695207476616, \"chain\": 3, \"draw\": 103}, {\"draws\": 703, \"mouse\": 2, \"mu_intercept_per_group\": 7.438447952270508, \"sigma_intercept_per_group\": 0.31356334686279297, \"sigma_obs\": 167.7554168701172, \"slope\": -0.05519695207476616, \"chain\": 3, \"draw\": 103}, {\"draws\": 703, \"mouse\": 3, \"mu_intercept_per_group\": 6.796632289886475, \"sigma_intercept_per_group\": 0.31356334686279297, \"sigma_obs\": 167.7554168701172, \"slope\": -0.05519695207476616, \"chain\": 3, \"draw\": 103}, {\"draws\": 703, \"mouse\": 4, \"mu_intercept_per_group\": 6.741459369659424, \"sigma_intercept_per_group\": 0.31356334686279297, \"sigma_obs\": 167.7554168701172, \"slope\": -0.05519695207476616, \"chain\": 3, \"draw\": 103}, {\"draws\": 703, \"mouse\": 5, \"mu_intercept_per_group\": 6.320254802703857, \"sigma_intercept_per_group\": 0.31356334686279297, \"sigma_obs\": 167.7554168701172, \"slope\": -0.05519695207476616, \"chain\": 3, \"draw\": 103}, {\"draws\": 703, \"mouse\": 6, \"mu_intercept_per_group\": 6.219668865203857, \"sigma_intercept_per_group\": 0.31356334686279297, \"sigma_obs\": 167.7554168701172, \"slope\": -0.05519695207476616, \"chain\": 3, \"draw\": 103}, {\"draws\": 703, \"mouse\": 7, \"mu_intercept_per_group\": 5.7396769523620605, \"sigma_intercept_per_group\": 0.31356334686279297, \"sigma_obs\": 167.7554168701172, \"slope\": -0.05519695207476616, \"chain\": 3, \"draw\": 103}, {\"draws\": 704, \"mouse\": 0, \"mu_intercept_per_group\": 8.439202308654785, \"sigma_intercept_per_group\": 0.2844087779521942, \"sigma_obs\": 160.43600463867188, \"slope\": -0.0656730979681015, \"chain\": 3, \"draw\": 104}, {\"draws\": 704, \"mouse\": 1, \"mu_intercept_per_group\": 8.34524917602539, \"sigma_intercept_per_group\": 0.2844087779521942, \"sigma_obs\": 160.43600463867188, \"slope\": -0.0656730979681015, \"chain\": 3, \"draw\": 104}, {\"draws\": 704, \"mouse\": 2, \"mu_intercept_per_group\": 8.27180290222168, \"sigma_intercept_per_group\": 0.2844087779521942, \"sigma_obs\": 160.43600463867188, \"slope\": -0.0656730979681015, \"chain\": 3, \"draw\": 104}, {\"draws\": 704, \"mouse\": 3, \"mu_intercept_per_group\": 7.575584411621094, \"sigma_intercept_per_group\": 0.2844087779521942, \"sigma_obs\": 160.43600463867188, \"slope\": -0.0656730979681015, \"chain\": 3, \"draw\": 104}, {\"draws\": 704, \"mouse\": 4, \"mu_intercept_per_group\": 7.490611553192139, \"sigma_intercept_per_group\": 0.2844087779521942, \"sigma_obs\": 160.43600463867188, \"slope\": -0.0656730979681015, \"chain\": 3, \"draw\": 104}, {\"draws\": 704, \"mouse\": 5, \"mu_intercept_per_group\": 6.9743146896362305, \"sigma_intercept_per_group\": 0.2844087779521942, \"sigma_obs\": 160.43600463867188, \"slope\": -0.0656730979681015, \"chain\": 3, \"draw\": 104}, {\"draws\": 704, \"mouse\": 6, \"mu_intercept_per_group\": 6.167158603668213, \"sigma_intercept_per_group\": 0.2844087779521942, \"sigma_obs\": 160.43600463867188, \"slope\": -0.0656730979681015, \"chain\": 3, \"draw\": 104}, {\"draws\": 704, \"mouse\": 7, \"mu_intercept_per_group\": 6.1360015869140625, \"sigma_intercept_per_group\": 0.2844087779521942, \"sigma_obs\": 160.43600463867188, \"slope\": -0.0656730979681015, \"chain\": 3, \"draw\": 104}, {\"draws\": 705, \"mouse\": 0, \"mu_intercept_per_group\": 8.787735939025879, \"sigma_intercept_per_group\": 0.28325000405311584, \"sigma_obs\": 159.36117553710938, \"slope\": -0.06517139822244644, \"chain\": 3, \"draw\": 105}, {\"draws\": 705, \"mouse\": 1, \"mu_intercept_per_group\": 8.266382217407227, \"sigma_intercept_per_group\": 0.28325000405311584, \"sigma_obs\": 159.36117553710938, \"slope\": -0.06517139822244644, \"chain\": 3, \"draw\": 105}, {\"draws\": 705, \"mouse\": 2, \"mu_intercept_per_group\": 7.792327404022217, \"sigma_intercept_per_group\": 0.28325000405311584, \"sigma_obs\": 159.36117553710938, \"slope\": -0.06517139822244644, \"chain\": 3, \"draw\": 105}, {\"draws\": 705, \"mouse\": 3, \"mu_intercept_per_group\": 7.651821613311768, \"sigma_intercept_per_group\": 0.28325000405311584, \"sigma_obs\": 159.36117553710938, \"slope\": -0.06517139822244644, \"chain\": 3, \"draw\": 105}, {\"draws\": 705, \"mouse\": 4, \"mu_intercept_per_group\": 7.489997863769531, \"sigma_intercept_per_group\": 0.28325000405311584, \"sigma_obs\": 159.36117553710938, \"slope\": -0.06517139822244644, \"chain\": 3, \"draw\": 105}, {\"draws\": 705, \"mouse\": 5, \"mu_intercept_per_group\": 7.033120155334473, \"sigma_intercept_per_group\": 0.28325000405311584, \"sigma_obs\": 159.36117553710938, \"slope\": -0.06517139822244644, \"chain\": 3, \"draw\": 105}, {\"draws\": 705, \"mouse\": 6, \"mu_intercept_per_group\": 6.239534854888916, \"sigma_intercept_per_group\": 0.28325000405311584, \"sigma_obs\": 159.36117553710938, \"slope\": -0.06517139822244644, \"chain\": 3, \"draw\": 105}, {\"draws\": 705, \"mouse\": 7, \"mu_intercept_per_group\": 6.408059597015381, \"sigma_intercept_per_group\": 0.28325000405311584, \"sigma_obs\": 159.36117553710938, \"slope\": -0.06517139822244644, \"chain\": 3, \"draw\": 105}, {\"draws\": 706, \"mouse\": 0, \"mu_intercept_per_group\": 8.532052993774414, \"sigma_intercept_per_group\": 0.2868294417858124, \"sigma_obs\": 159.11668395996094, \"slope\": -0.06416012346744537, \"chain\": 3, \"draw\": 106}, {\"draws\": 706, \"mouse\": 1, \"mu_intercept_per_group\": 8.409750938415527, \"sigma_intercept_per_group\": 0.2868294417858124, \"sigma_obs\": 159.11668395996094, \"slope\": -0.06416012346744537, \"chain\": 3, \"draw\": 106}, {\"draws\": 706, \"mouse\": 2, \"mu_intercept_per_group\": 8.00597095489502, \"sigma_intercept_per_group\": 0.2868294417858124, \"sigma_obs\": 159.11668395996094, \"slope\": -0.06416012346744537, \"chain\": 3, \"draw\": 106}, {\"draws\": 706, \"mouse\": 3, \"mu_intercept_per_group\": 7.5984015464782715, \"sigma_intercept_per_group\": 0.2868294417858124, \"sigma_obs\": 159.11668395996094, \"slope\": -0.06416012346744537, \"chain\": 3, \"draw\": 106}, {\"draws\": 706, \"mouse\": 4, \"mu_intercept_per_group\": 7.2795820236206055, \"sigma_intercept_per_group\": 0.2868294417858124, \"sigma_obs\": 159.11668395996094, \"slope\": -0.06416012346744537, \"chain\": 3, \"draw\": 106}, {\"draws\": 706, \"mouse\": 5, \"mu_intercept_per_group\": 6.990439414978027, \"sigma_intercept_per_group\": 0.2868294417858124, \"sigma_obs\": 159.11668395996094, \"slope\": -0.06416012346744537, \"chain\": 3, \"draw\": 106}, {\"draws\": 706, \"mouse\": 6, \"mu_intercept_per_group\": 6.386778354644775, \"sigma_intercept_per_group\": 0.2868294417858124, \"sigma_obs\": 159.11668395996094, \"slope\": -0.06416012346744537, \"chain\": 3, \"draw\": 106}, {\"draws\": 706, \"mouse\": 7, \"mu_intercept_per_group\": 6.21146821975708, \"sigma_intercept_per_group\": 0.2868294417858124, \"sigma_obs\": 159.11668395996094, \"slope\": -0.06416012346744537, \"chain\": 3, \"draw\": 106}, {\"draws\": 707, \"mouse\": 0, \"mu_intercept_per_group\": 8.203600883483887, \"sigma_intercept_per_group\": 0.3004336953163147, \"sigma_obs\": 164.178466796875, \"slope\": -0.07220299541950226, \"chain\": 3, \"draw\": 107}, {\"draws\": 707, \"mouse\": 1, \"mu_intercept_per_group\": 8.081392288208008, \"sigma_intercept_per_group\": 0.3004336953163147, \"sigma_obs\": 164.178466796875, \"slope\": -0.07220299541950226, \"chain\": 3, \"draw\": 107}, {\"draws\": 707, \"mouse\": 2, \"mu_intercept_per_group\": 7.758854866027832, \"sigma_intercept_per_group\": 0.3004336953163147, \"sigma_obs\": 164.178466796875, \"slope\": -0.07220299541950226, \"chain\": 3, \"draw\": 107}, {\"draws\": 707, \"mouse\": 3, \"mu_intercept_per_group\": 7.440274715423584, \"sigma_intercept_per_group\": 0.3004336953163147, \"sigma_obs\": 164.178466796875, \"slope\": -0.07220299541950226, \"chain\": 3, \"draw\": 107}, {\"draws\": 707, \"mouse\": 4, \"mu_intercept_per_group\": 7.352148532867432, \"sigma_intercept_per_group\": 0.3004336953163147, \"sigma_obs\": 164.178466796875, \"slope\": -0.07220299541950226, \"chain\": 3, \"draw\": 107}, {\"draws\": 707, \"mouse\": 5, \"mu_intercept_per_group\": 6.695154190063477, \"sigma_intercept_per_group\": 0.3004336953163147, \"sigma_obs\": 164.178466796875, \"slope\": -0.07220299541950226, \"chain\": 3, \"draw\": 107}, {\"draws\": 707, \"mouse\": 6, \"mu_intercept_per_group\": 6.363480091094971, \"sigma_intercept_per_group\": 0.3004336953163147, \"sigma_obs\": 164.178466796875, \"slope\": -0.07220299541950226, \"chain\": 3, \"draw\": 107}, {\"draws\": 707, \"mouse\": 7, \"mu_intercept_per_group\": 6.2811994552612305, \"sigma_intercept_per_group\": 0.3004336953163147, \"sigma_obs\": 164.178466796875, \"slope\": -0.07220299541950226, \"chain\": 3, \"draw\": 107}, {\"draws\": 708, \"mouse\": 0, \"mu_intercept_per_group\": 8.583470344543457, \"sigma_intercept_per_group\": 0.29352277517318726, \"sigma_obs\": 164.87017822265625, \"slope\": -0.07220770418643951, \"chain\": 3, \"draw\": 108}, {\"draws\": 708, \"mouse\": 1, \"mu_intercept_per_group\": 8.385435104370117, \"sigma_intercept_per_group\": 0.29352277517318726, \"sigma_obs\": 164.87017822265625, \"slope\": -0.07220770418643951, \"chain\": 3, \"draw\": 108}, {\"draws\": 708, \"mouse\": 2, \"mu_intercept_per_group\": 8.220475196838379, \"sigma_intercept_per_group\": 0.29352277517318726, \"sigma_obs\": 164.87017822265625, \"slope\": -0.07220770418643951, \"chain\": 3, \"draw\": 108}, {\"draws\": 708, \"mouse\": 3, \"mu_intercept_per_group\": 7.643004417419434, \"sigma_intercept_per_group\": 0.29352277517318726, \"sigma_obs\": 164.87017822265625, \"slope\": -0.07220770418643951, \"chain\": 3, \"draw\": 108}, {\"draws\": 708, \"mouse\": 4, \"mu_intercept_per_group\": 7.177272796630859, \"sigma_intercept_per_group\": 0.29352277517318726, \"sigma_obs\": 164.87017822265625, \"slope\": -0.07220770418643951, \"chain\": 3, \"draw\": 108}, {\"draws\": 708, \"mouse\": 5, \"mu_intercept_per_group\": 7.131890773773193, \"sigma_intercept_per_group\": 0.29352277517318726, \"sigma_obs\": 164.87017822265625, \"slope\": -0.07220770418643951, \"chain\": 3, \"draw\": 108}, {\"draws\": 708, \"mouse\": 6, \"mu_intercept_per_group\": 6.528716087341309, \"sigma_intercept_per_group\": 0.29352277517318726, \"sigma_obs\": 164.87017822265625, \"slope\": -0.07220770418643951, \"chain\": 3, \"draw\": 108}, {\"draws\": 708, \"mouse\": 7, \"mu_intercept_per_group\": 6.005707263946533, \"sigma_intercept_per_group\": 0.29352277517318726, \"sigma_obs\": 164.87017822265625, \"slope\": -0.07220770418643951, \"chain\": 3, \"draw\": 108}, {\"draws\": 709, \"mouse\": 0, \"mu_intercept_per_group\": 8.7086763381958, \"sigma_intercept_per_group\": 0.2937953472137451, \"sigma_obs\": 165.84007263183594, \"slope\": -0.07113921642303467, \"chain\": 3, \"draw\": 109}, {\"draws\": 709, \"mouse\": 1, \"mu_intercept_per_group\": 8.280083656311035, \"sigma_intercept_per_group\": 0.2937953472137451, \"sigma_obs\": 165.84007263183594, \"slope\": -0.07113921642303467, \"chain\": 3, \"draw\": 109}, {\"draws\": 709, \"mouse\": 2, \"mu_intercept_per_group\": 7.996737480163574, \"sigma_intercept_per_group\": 0.2937953472137451, \"sigma_obs\": 165.84007263183594, \"slope\": -0.07113921642303467, \"chain\": 3, \"draw\": 109}, {\"draws\": 709, \"mouse\": 3, \"mu_intercept_per_group\": 7.6227545738220215, \"sigma_intercept_per_group\": 0.2937953472137451, \"sigma_obs\": 165.84007263183594, \"slope\": -0.07113921642303467, \"chain\": 3, \"draw\": 109}, {\"draws\": 709, \"mouse\": 4, \"mu_intercept_per_group\": 7.534966945648193, \"sigma_intercept_per_group\": 0.2937953472137451, \"sigma_obs\": 165.84007263183594, \"slope\": -0.07113921642303467, \"chain\": 3, \"draw\": 109}, {\"draws\": 709, \"mouse\": 5, \"mu_intercept_per_group\": 7.046771049499512, \"sigma_intercept_per_group\": 0.2937953472137451, \"sigma_obs\": 165.84007263183594, \"slope\": -0.07113921642303467, \"chain\": 3, \"draw\": 109}, {\"draws\": 709, \"mouse\": 6, \"mu_intercept_per_group\": 6.629114151000977, \"sigma_intercept_per_group\": 0.2937953472137451, \"sigma_obs\": 165.84007263183594, \"slope\": -0.07113921642303467, \"chain\": 3, \"draw\": 109}, {\"draws\": 709, \"mouse\": 7, \"mu_intercept_per_group\": 5.986168384552002, \"sigma_intercept_per_group\": 0.2937953472137451, \"sigma_obs\": 165.84007263183594, \"slope\": -0.07113921642303467, \"chain\": 3, \"draw\": 109}, {\"draws\": 710, \"mouse\": 0, \"mu_intercept_per_group\": 13.379154205322266, \"sigma_intercept_per_group\": 0.18414855003356934, \"sigma_obs\": 159.9661407470703, \"slope\": -0.0860406830906868, \"chain\": 3, \"draw\": 110}, {\"draws\": 710, \"mouse\": 1, \"mu_intercept_per_group\": 13.112638473510742, \"sigma_intercept_per_group\": 0.18414855003356934, \"sigma_obs\": 159.9661407470703, \"slope\": -0.0860406830906868, \"chain\": 3, \"draw\": 110}, {\"draws\": 710, \"mouse\": 2, \"mu_intercept_per_group\": 12.72862720489502, \"sigma_intercept_per_group\": 0.18414855003356934, \"sigma_obs\": 159.9661407470703, \"slope\": -0.0860406830906868, \"chain\": 3, \"draw\": 110}, {\"draws\": 710, \"mouse\": 3, \"mu_intercept_per_group\": 11.881535530090332, \"sigma_intercept_per_group\": 0.18414855003356934, \"sigma_obs\": 159.9661407470703, \"slope\": -0.0860406830906868, \"chain\": 3, \"draw\": 110}, {\"draws\": 710, \"mouse\": 4, \"mu_intercept_per_group\": 11.685079574584961, \"sigma_intercept_per_group\": 0.18414855003356934, \"sigma_obs\": 159.9661407470703, \"slope\": -0.0860406830906868, \"chain\": 3, \"draw\": 110}, {\"draws\": 710, \"mouse\": 5, \"mu_intercept_per_group\": 10.93259334564209, \"sigma_intercept_per_group\": 0.18414855003356934, \"sigma_obs\": 159.9661407470703, \"slope\": -0.0860406830906868, \"chain\": 3, \"draw\": 110}, {\"draws\": 710, \"mouse\": 6, \"mu_intercept_per_group\": 10.273069381713867, \"sigma_intercept_per_group\": 0.18414855003356934, \"sigma_obs\": 159.9661407470703, \"slope\": -0.0860406830906868, \"chain\": 3, \"draw\": 110}, {\"draws\": 710, \"mouse\": 7, \"mu_intercept_per_group\": 9.602235794067383, \"sigma_intercept_per_group\": 0.18414855003356934, \"sigma_obs\": 159.9661407470703, \"slope\": -0.0860406830906868, \"chain\": 3, \"draw\": 110}, {\"draws\": 711, \"mouse\": 0, \"mu_intercept_per_group\": 10.35270881652832, \"sigma_intercept_per_group\": 0.2478889673948288, \"sigma_obs\": 169.98500061035156, \"slope\": -0.05943537876009941, \"chain\": 3, \"draw\": 111}, {\"draws\": 711, \"mouse\": 1, \"mu_intercept_per_group\": 9.770573616027832, \"sigma_intercept_per_group\": 0.2478889673948288, \"sigma_obs\": 169.98500061035156, \"slope\": -0.05943537876009941, \"chain\": 3, \"draw\": 111}, {\"draws\": 711, \"mouse\": 2, \"mu_intercept_per_group\": 9.484972953796387, \"sigma_intercept_per_group\": 0.2478889673948288, \"sigma_obs\": 169.98500061035156, \"slope\": -0.05943537876009941, \"chain\": 3, \"draw\": 111}, {\"draws\": 711, \"mouse\": 3, \"mu_intercept_per_group\": 8.969080924987793, \"sigma_intercept_per_group\": 0.2478889673948288, \"sigma_obs\": 169.98500061035156, \"slope\": -0.05943537876009941, \"chain\": 3, \"draw\": 111}, {\"draws\": 711, \"mouse\": 4, \"mu_intercept_per_group\": 8.683941841125488, \"sigma_intercept_per_group\": 0.2478889673948288, \"sigma_obs\": 169.98500061035156, \"slope\": -0.05943537876009941, \"chain\": 3, \"draw\": 111}, {\"draws\": 711, \"mouse\": 5, \"mu_intercept_per_group\": 8.086746215820312, \"sigma_intercept_per_group\": 0.2478889673948288, \"sigma_obs\": 169.98500061035156, \"slope\": -0.05943537876009941, \"chain\": 3, \"draw\": 111}, {\"draws\": 711, \"mouse\": 6, \"mu_intercept_per_group\": 7.586483955383301, \"sigma_intercept_per_group\": 0.2478889673948288, \"sigma_obs\": 169.98500061035156, \"slope\": -0.05943537876009941, \"chain\": 3, \"draw\": 111}, {\"draws\": 711, \"mouse\": 7, \"mu_intercept_per_group\": 7.388605117797852, \"sigma_intercept_per_group\": 0.2478889673948288, \"sigma_obs\": 169.98500061035156, \"slope\": -0.05943537876009941, \"chain\": 3, \"draw\": 111}, {\"draws\": 712, \"mouse\": 0, \"mu_intercept_per_group\": 10.81450080871582, \"sigma_intercept_per_group\": 0.23614442348480225, \"sigma_obs\": 164.83920288085938, \"slope\": -0.08890493214130402, \"chain\": 3, \"draw\": 112}, {\"draws\": 712, \"mouse\": 1, \"mu_intercept_per_group\": 10.289278030395508, \"sigma_intercept_per_group\": 0.23614442348480225, \"sigma_obs\": 164.83920288085938, \"slope\": -0.08890493214130402, \"chain\": 3, \"draw\": 112}, {\"draws\": 712, \"mouse\": 2, \"mu_intercept_per_group\": 9.904525756835938, \"sigma_intercept_per_group\": 0.23614442348480225, \"sigma_obs\": 164.83920288085938, \"slope\": -0.08890493214130402, \"chain\": 3, \"draw\": 112}, {\"draws\": 712, \"mouse\": 3, \"mu_intercept_per_group\": 9.39586353302002, \"sigma_intercept_per_group\": 0.23614442348480225, \"sigma_obs\": 164.83920288085938, \"slope\": -0.08890493214130402, \"chain\": 3, \"draw\": 112}, {\"draws\": 712, \"mouse\": 4, \"mu_intercept_per_group\": 9.339347839355469, \"sigma_intercept_per_group\": 0.23614442348480225, \"sigma_obs\": 164.83920288085938, \"slope\": -0.08890493214130402, \"chain\": 3, \"draw\": 112}, {\"draws\": 712, \"mouse\": 5, \"mu_intercept_per_group\": 8.590340614318848, \"sigma_intercept_per_group\": 0.23614442348480225, \"sigma_obs\": 164.83920288085938, \"slope\": -0.08890493214130402, \"chain\": 3, \"draw\": 112}, {\"draws\": 712, \"mouse\": 6, \"mu_intercept_per_group\": 8.126359939575195, \"sigma_intercept_per_group\": 0.23614442348480225, \"sigma_obs\": 164.83920288085938, \"slope\": -0.08890493214130402, \"chain\": 3, \"draw\": 112}, {\"draws\": 712, \"mouse\": 7, \"mu_intercept_per_group\": 7.636571407318115, \"sigma_intercept_per_group\": 0.23614442348480225, \"sigma_obs\": 164.83920288085938, \"slope\": -0.08890493214130402, \"chain\": 3, \"draw\": 112}, {\"draws\": 713, \"mouse\": 0, \"mu_intercept_per_group\": 7.79883337020874, \"sigma_intercept_per_group\": 0.32166457176208496, \"sigma_obs\": 169.46365356445312, \"slope\": -0.07523075491189957, \"chain\": 3, \"draw\": 113}, {\"draws\": 713, \"mouse\": 1, \"mu_intercept_per_group\": 7.59574031829834, \"sigma_intercept_per_group\": 0.32166457176208496, \"sigma_obs\": 169.46365356445312, \"slope\": -0.07523075491189957, \"chain\": 3, \"draw\": 113}, {\"draws\": 713, \"mouse\": 2, \"mu_intercept_per_group\": 7.361110210418701, \"sigma_intercept_per_group\": 0.32166457176208496, \"sigma_obs\": 169.46365356445312, \"slope\": -0.07523075491189957, \"chain\": 3, \"draw\": 113}, {\"draws\": 713, \"mouse\": 3, \"mu_intercept_per_group\": 6.841595649719238, \"sigma_intercept_per_group\": 0.32166457176208496, \"sigma_obs\": 169.46365356445312, \"slope\": -0.07523075491189957, \"chain\": 3, \"draw\": 113}, {\"draws\": 713, \"mouse\": 4, \"mu_intercept_per_group\": 6.836913108825684, \"sigma_intercept_per_group\": 0.32166457176208496, \"sigma_obs\": 169.46365356445312, \"slope\": -0.07523075491189957, \"chain\": 3, \"draw\": 113}, {\"draws\": 713, \"mouse\": 5, \"mu_intercept_per_group\": 6.5628437995910645, \"sigma_intercept_per_group\": 0.32166457176208496, \"sigma_obs\": 169.46365356445312, \"slope\": -0.07523075491189957, \"chain\": 3, \"draw\": 113}, {\"draws\": 713, \"mouse\": 6, \"mu_intercept_per_group\": 6.079121112823486, \"sigma_intercept_per_group\": 0.32166457176208496, \"sigma_obs\": 169.46365356445312, \"slope\": -0.07523075491189957, \"chain\": 3, \"draw\": 113}, {\"draws\": 713, \"mouse\": 7, \"mu_intercept_per_group\": 5.751165866851807, \"sigma_intercept_per_group\": 0.32166457176208496, \"sigma_obs\": 169.46365356445312, \"slope\": -0.07523075491189957, \"chain\": 3, \"draw\": 113}, {\"draws\": 714, \"mouse\": 0, \"mu_intercept_per_group\": 7.851067543029785, \"sigma_intercept_per_group\": 0.32275599241256714, \"sigma_obs\": 170.08351135253906, \"slope\": -0.07653433829545975, \"chain\": 3, \"draw\": 114}, {\"draws\": 714, \"mouse\": 1, \"mu_intercept_per_group\": 7.688016414642334, \"sigma_intercept_per_group\": 0.32275599241256714, \"sigma_obs\": 170.08351135253906, \"slope\": -0.07653433829545975, \"chain\": 3, \"draw\": 114}, {\"draws\": 714, \"mouse\": 2, \"mu_intercept_per_group\": 7.468356132507324, \"sigma_intercept_per_group\": 0.32275599241256714, \"sigma_obs\": 170.08351135253906, \"slope\": -0.07653433829545975, \"chain\": 3, \"draw\": 114}, {\"draws\": 714, \"mouse\": 3, \"mu_intercept_per_group\": 7.102958679199219, \"sigma_intercept_per_group\": 0.32275599241256714, \"sigma_obs\": 170.08351135253906, \"slope\": -0.07653433829545975, \"chain\": 3, \"draw\": 114}, {\"draws\": 714, \"mouse\": 4, \"mu_intercept_per_group\": 6.911688327789307, \"sigma_intercept_per_group\": 0.32275599241256714, \"sigma_obs\": 170.08351135253906, \"slope\": -0.07653433829545975, \"chain\": 3, \"draw\": 114}, {\"draws\": 714, \"mouse\": 5, \"mu_intercept_per_group\": 6.373284816741943, \"sigma_intercept_per_group\": 0.32275599241256714, \"sigma_obs\": 170.08351135253906, \"slope\": -0.07653433829545975, \"chain\": 3, \"draw\": 114}, {\"draws\": 714, \"mouse\": 6, \"mu_intercept_per_group\": 6.022170543670654, \"sigma_intercept_per_group\": 0.32275599241256714, \"sigma_obs\": 170.08351135253906, \"slope\": -0.07653433829545975, \"chain\": 3, \"draw\": 114}, {\"draws\": 714, \"mouse\": 7, \"mu_intercept_per_group\": 5.772102355957031, \"sigma_intercept_per_group\": 0.32275599241256714, \"sigma_obs\": 170.08351135253906, \"slope\": -0.07653433829545975, \"chain\": 3, \"draw\": 114}, {\"draws\": 715, \"mouse\": 0, \"mu_intercept_per_group\": 5.680667877197266, \"sigma_intercept_per_group\": 0.445340633392334, \"sigma_obs\": 161.29412841796875, \"slope\": -0.07063069939613342, \"chain\": 3, \"draw\": 115}, {\"draws\": 715, \"mouse\": 1, \"mu_intercept_per_group\": 5.37485408782959, \"sigma_intercept_per_group\": 0.445340633392334, \"sigma_obs\": 161.29412841796875, \"slope\": -0.07063069939613342, \"chain\": 3, \"draw\": 115}, {\"draws\": 715, \"mouse\": 2, \"mu_intercept_per_group\": 5.228455543518066, \"sigma_intercept_per_group\": 0.445340633392334, \"sigma_obs\": 161.29412841796875, \"slope\": -0.07063069939613342, \"chain\": 3, \"draw\": 115}, {\"draws\": 715, \"mouse\": 3, \"mu_intercept_per_group\": 4.839939594268799, \"sigma_intercept_per_group\": 0.445340633392334, \"sigma_obs\": 161.29412841796875, \"slope\": -0.07063069939613342, \"chain\": 3, \"draw\": 115}, {\"draws\": 715, \"mouse\": 4, \"mu_intercept_per_group\": 4.781132221221924, \"sigma_intercept_per_group\": 0.445340633392334, \"sigma_obs\": 161.29412841796875, \"slope\": -0.07063069939613342, \"chain\": 3, \"draw\": 115}, {\"draws\": 715, \"mouse\": 5, \"mu_intercept_per_group\": 4.348383903503418, \"sigma_intercept_per_group\": 0.445340633392334, \"sigma_obs\": 161.29412841796875, \"slope\": -0.07063069939613342, \"chain\": 3, \"draw\": 115}, {\"draws\": 715, \"mouse\": 6, \"mu_intercept_per_group\": 4.206712245941162, \"sigma_intercept_per_group\": 0.445340633392334, \"sigma_obs\": 161.29412841796875, \"slope\": -0.07063069939613342, \"chain\": 3, \"draw\": 115}, {\"draws\": 715, \"mouse\": 7, \"mu_intercept_per_group\": 4.009535789489746, \"sigma_intercept_per_group\": 0.445340633392334, \"sigma_obs\": 161.29412841796875, \"slope\": -0.07063069939613342, \"chain\": 3, \"draw\": 115}, {\"draws\": 716, \"mouse\": 0, \"mu_intercept_per_group\": 5.443851470947266, \"sigma_intercept_per_group\": 0.4463951885700226, \"sigma_obs\": 161.65870666503906, \"slope\": -0.07035281509160995, \"chain\": 3, \"draw\": 116}, {\"draws\": 716, \"mouse\": 1, \"mu_intercept_per_group\": 5.3428215980529785, \"sigma_intercept_per_group\": 0.4463951885700226, \"sigma_obs\": 161.65870666503906, \"slope\": -0.07035281509160995, \"chain\": 3, \"draw\": 116}, {\"draws\": 716, \"mouse\": 2, \"mu_intercept_per_group\": 5.210019588470459, \"sigma_intercept_per_group\": 0.4463951885700226, \"sigma_obs\": 161.65870666503906, \"slope\": -0.07035281509160995, \"chain\": 3, \"draw\": 116}, {\"draws\": 716, \"mouse\": 3, \"mu_intercept_per_group\": 4.993533134460449, \"sigma_intercept_per_group\": 0.4463951885700226, \"sigma_obs\": 161.65870666503906, \"slope\": -0.07035281509160995, \"chain\": 3, \"draw\": 116}, {\"draws\": 716, \"mouse\": 4, \"mu_intercept_per_group\": 4.690954208374023, \"sigma_intercept_per_group\": 0.4463951885700226, \"sigma_obs\": 161.65870666503906, \"slope\": -0.07035281509160995, \"chain\": 3, \"draw\": 116}, {\"draws\": 716, \"mouse\": 5, \"mu_intercept_per_group\": 4.610355377197266, \"sigma_intercept_per_group\": 0.4463951885700226, \"sigma_obs\": 161.65870666503906, \"slope\": -0.07035281509160995, \"chain\": 3, \"draw\": 116}, {\"draws\": 716, \"mouse\": 6, \"mu_intercept_per_group\": 4.268767833709717, \"sigma_intercept_per_group\": 0.4463951885700226, \"sigma_obs\": 161.65870666503906, \"slope\": -0.07035281509160995, \"chain\": 3, \"draw\": 116}, {\"draws\": 716, \"mouse\": 7, \"mu_intercept_per_group\": 4.021905899047852, \"sigma_intercept_per_group\": 0.4463951885700226, \"sigma_obs\": 161.65870666503906, \"slope\": -0.07035281509160995, \"chain\": 3, \"draw\": 116}, {\"draws\": 717, \"mouse\": 0, \"mu_intercept_per_group\": 5.7789692878723145, \"sigma_intercept_per_group\": 0.4427318274974823, \"sigma_obs\": 165.7140655517578, \"slope\": -0.07755880057811737, \"chain\": 3, \"draw\": 117}, {\"draws\": 717, \"mouse\": 1, \"mu_intercept_per_group\": 5.470065593719482, \"sigma_intercept_per_group\": 0.4427318274974823, \"sigma_obs\": 165.7140655517578, \"slope\": -0.07755880057811737, \"chain\": 3, \"draw\": 117}, {\"draws\": 717, \"mouse\": 2, \"mu_intercept_per_group\": 5.22836446762085, \"sigma_intercept_per_group\": 0.4427318274974823, \"sigma_obs\": 165.7140655517578, \"slope\": -0.07755880057811737, \"chain\": 3, \"draw\": 117}, {\"draws\": 717, \"mouse\": 3, \"mu_intercept_per_group\": 5.065729141235352, \"sigma_intercept_per_group\": 0.4427318274974823, \"sigma_obs\": 165.7140655517578, \"slope\": -0.07755880057811737, \"chain\": 3, \"draw\": 117}, {\"draws\": 717, \"mouse\": 4, \"mu_intercept_per_group\": 4.729498386383057, \"sigma_intercept_per_group\": 0.4427318274974823, \"sigma_obs\": 165.7140655517578, \"slope\": -0.07755880057811737, \"chain\": 3, \"draw\": 117}, {\"draws\": 717, \"mouse\": 5, \"mu_intercept_per_group\": 4.7072882652282715, \"sigma_intercept_per_group\": 0.4427318274974823, \"sigma_obs\": 165.7140655517578, \"slope\": -0.07755880057811737, \"chain\": 3, \"draw\": 117}, {\"draws\": 717, \"mouse\": 6, \"mu_intercept_per_group\": 4.3405303955078125, \"sigma_intercept_per_group\": 0.4427318274974823, \"sigma_obs\": 165.7140655517578, \"slope\": -0.07755880057811737, \"chain\": 3, \"draw\": 117}, {\"draws\": 717, \"mouse\": 7, \"mu_intercept_per_group\": 4.253227710723877, \"sigma_intercept_per_group\": 0.4427318274974823, \"sigma_obs\": 165.7140655517578, \"slope\": -0.07755880057811737, \"chain\": 3, \"draw\": 117}, {\"draws\": 718, \"mouse\": 0, \"mu_intercept_per_group\": 5.466380596160889, \"sigma_intercept_per_group\": 0.4454134702682495, \"sigma_obs\": 166.07540893554688, \"slope\": -0.07736702263355255, \"chain\": 3, \"draw\": 118}, {\"draws\": 718, \"mouse\": 1, \"mu_intercept_per_group\": 5.392990589141846, \"sigma_intercept_per_group\": 0.4454134702682495, \"sigma_obs\": 166.07540893554688, \"slope\": -0.07736702263355255, \"chain\": 3, \"draw\": 118}, {\"draws\": 718, \"mouse\": 2, \"mu_intercept_per_group\": 5.310288429260254, \"sigma_intercept_per_group\": 0.4454134702682495, \"sigma_obs\": 166.07540893554688, \"slope\": -0.07736702263355255, \"chain\": 3, \"draw\": 118}, {\"draws\": 718, \"mouse\": 3, \"mu_intercept_per_group\": 4.923353672027588, \"sigma_intercept_per_group\": 0.4454134702682495, \"sigma_obs\": 166.07540893554688, \"slope\": -0.07736702263355255, \"chain\": 3, \"draw\": 118}, {\"draws\": 718, \"mouse\": 4, \"mu_intercept_per_group\": 4.996286392211914, \"sigma_intercept_per_group\": 0.4454134702682495, \"sigma_obs\": 166.07540893554688, \"slope\": -0.07736702263355255, \"chain\": 3, \"draw\": 118}, {\"draws\": 718, \"mouse\": 5, \"mu_intercept_per_group\": 4.588623046875, \"sigma_intercept_per_group\": 0.4454134702682495, \"sigma_obs\": 166.07540893554688, \"slope\": -0.07736702263355255, \"chain\": 3, \"draw\": 118}, {\"draws\": 718, \"mouse\": 6, \"mu_intercept_per_group\": 4.3032989501953125, \"sigma_intercept_per_group\": 0.4454134702682495, \"sigma_obs\": 166.07540893554688, \"slope\": -0.07736702263355255, \"chain\": 3, \"draw\": 118}, {\"draws\": 718, \"mouse\": 7, \"mu_intercept_per_group\": 3.9840149879455566, \"sigma_intercept_per_group\": 0.4454134702682495, \"sigma_obs\": 166.07540893554688, \"slope\": -0.07736702263355255, \"chain\": 3, \"draw\": 118}, {\"draws\": 719, \"mouse\": 0, \"mu_intercept_per_group\": 6.742616176605225, \"sigma_intercept_per_group\": 0.35631150007247925, \"sigma_obs\": 147.43849182128906, \"slope\": -0.07488876581192017, \"chain\": 3, \"draw\": 119}, {\"draws\": 719, \"mouse\": 1, \"mu_intercept_per_group\": 6.380300521850586, \"sigma_intercept_per_group\": 0.35631150007247925, \"sigma_obs\": 147.43849182128906, \"slope\": -0.07488876581192017, \"chain\": 3, \"draw\": 119}, {\"draws\": 719, \"mouse\": 2, \"mu_intercept_per_group\": 6.2799072265625, \"sigma_intercept_per_group\": 0.35631150007247925, \"sigma_obs\": 147.43849182128906, \"slope\": -0.07488876581192017, \"chain\": 3, \"draw\": 119}, {\"draws\": 719, \"mouse\": 3, \"mu_intercept_per_group\": 5.895434379577637, \"sigma_intercept_per_group\": 0.35631150007247925, \"sigma_obs\": 147.43849182128906, \"slope\": -0.07488876581192017, \"chain\": 3, \"draw\": 119}, {\"draws\": 719, \"mouse\": 4, \"mu_intercept_per_group\": 5.770888805389404, \"sigma_intercept_per_group\": 0.35631150007247925, \"sigma_obs\": 147.43849182128906, \"slope\": -0.07488876581192017, \"chain\": 3, \"draw\": 119}, {\"draws\": 719, \"mouse\": 5, \"mu_intercept_per_group\": 5.385948657989502, \"sigma_intercept_per_group\": 0.35631150007247925, \"sigma_obs\": 147.43849182128906, \"slope\": -0.07488876581192017, \"chain\": 3, \"draw\": 119}, {\"draws\": 719, \"mouse\": 6, \"mu_intercept_per_group\": 4.949998378753662, \"sigma_intercept_per_group\": 0.35631150007247925, \"sigma_obs\": 147.43849182128906, \"slope\": -0.07488876581192017, \"chain\": 3, \"draw\": 119}, {\"draws\": 719, \"mouse\": 7, \"mu_intercept_per_group\": 4.8575639724731445, \"sigma_intercept_per_group\": 0.35631150007247925, \"sigma_obs\": 147.43849182128906, \"slope\": -0.07488876581192017, \"chain\": 3, \"draw\": 119}, {\"draws\": 720, \"mouse\": 0, \"mu_intercept_per_group\": 7.818080425262451, \"sigma_intercept_per_group\": 0.3246852457523346, \"sigma_obs\": 160.87925720214844, \"slope\": -0.0825750008225441, \"chain\": 3, \"draw\": 120}, {\"draws\": 720, \"mouse\": 1, \"mu_intercept_per_group\": 7.4357218742370605, \"sigma_intercept_per_group\": 0.3246852457523346, \"sigma_obs\": 160.87925720214844, \"slope\": -0.0825750008225441, \"chain\": 3, \"draw\": 120}, {\"draws\": 720, \"mouse\": 2, \"mu_intercept_per_group\": 7.39962911605835, \"sigma_intercept_per_group\": 0.3246852457523346, \"sigma_obs\": 160.87925720214844, \"slope\": -0.0825750008225441, \"chain\": 3, \"draw\": 120}, {\"draws\": 720, \"mouse\": 3, \"mu_intercept_per_group\": 6.762288570404053, \"sigma_intercept_per_group\": 0.3246852457523346, \"sigma_obs\": 160.87925720214844, \"slope\": -0.0825750008225441, \"chain\": 3, \"draw\": 120}, {\"draws\": 720, \"mouse\": 4, \"mu_intercept_per_group\": 6.433946132659912, \"sigma_intercept_per_group\": 0.3246852457523346, \"sigma_obs\": 160.87925720214844, \"slope\": -0.0825750008225441, \"chain\": 3, \"draw\": 120}, {\"draws\": 720, \"mouse\": 5, \"mu_intercept_per_group\": 6.464746475219727, \"sigma_intercept_per_group\": 0.3246852457523346, \"sigma_obs\": 160.87925720214844, \"slope\": -0.0825750008225441, \"chain\": 3, \"draw\": 120}, {\"draws\": 720, \"mouse\": 6, \"mu_intercept_per_group\": 5.7504119873046875, \"sigma_intercept_per_group\": 0.3246852457523346, \"sigma_obs\": 160.87925720214844, \"slope\": -0.0825750008225441, \"chain\": 3, \"draw\": 120}, {\"draws\": 720, \"mouse\": 7, \"mu_intercept_per_group\": 5.715418338775635, \"sigma_intercept_per_group\": 0.3246852457523346, \"sigma_obs\": 160.87925720214844, \"slope\": -0.0825750008225441, \"chain\": 3, \"draw\": 120}, {\"draws\": 721, \"mouse\": 0, \"mu_intercept_per_group\": 7.433793544769287, \"sigma_intercept_per_group\": 0.3368793725967407, \"sigma_obs\": 164.69895935058594, \"slope\": -0.08267704397439957, \"chain\": 3, \"draw\": 121}, {\"draws\": 721, \"mouse\": 1, \"mu_intercept_per_group\": 7.236450672149658, \"sigma_intercept_per_group\": 0.3368793725967407, \"sigma_obs\": 164.69895935058594, \"slope\": -0.08267704397439957, \"chain\": 3, \"draw\": 121}, {\"draws\": 721, \"mouse\": 2, \"mu_intercept_per_group\": 7.0605549812316895, \"sigma_intercept_per_group\": 0.3368793725967407, \"sigma_obs\": 164.69895935058594, \"slope\": -0.08267704397439957, \"chain\": 3, \"draw\": 121}, {\"draws\": 721, \"mouse\": 3, \"mu_intercept_per_group\": 6.5038676261901855, \"sigma_intercept_per_group\": 0.3368793725967407, \"sigma_obs\": 164.69895935058594, \"slope\": -0.08267704397439957, \"chain\": 3, \"draw\": 121}, {\"draws\": 721, \"mouse\": 4, \"mu_intercept_per_group\": 6.365169525146484, \"sigma_intercept_per_group\": 0.3368793725967407, \"sigma_obs\": 164.69895935058594, \"slope\": -0.08267704397439957, \"chain\": 3, \"draw\": 121}, {\"draws\": 721, \"mouse\": 5, \"mu_intercept_per_group\": 5.756040573120117, \"sigma_intercept_per_group\": 0.3368793725967407, \"sigma_obs\": 164.69895935058594, \"slope\": -0.08267704397439957, \"chain\": 3, \"draw\": 121}, {\"draws\": 721, \"mouse\": 6, \"mu_intercept_per_group\": 5.639249324798584, \"sigma_intercept_per_group\": 0.3368793725967407, \"sigma_obs\": 164.69895935058594, \"slope\": -0.08267704397439957, \"chain\": 3, \"draw\": 121}, {\"draws\": 721, \"mouse\": 7, \"mu_intercept_per_group\": 5.357180595397949, \"sigma_intercept_per_group\": 0.3368793725967407, \"sigma_obs\": 164.69895935058594, \"slope\": -0.08267704397439957, \"chain\": 3, \"draw\": 121}, {\"draws\": 722, \"mouse\": 0, \"mu_intercept_per_group\": 7.749496936798096, \"sigma_intercept_per_group\": 0.3247654438018799, \"sigma_obs\": 161.578857421875, \"slope\": -0.08279862254858017, \"chain\": 3, \"draw\": 122}, {\"draws\": 722, \"mouse\": 1, \"mu_intercept_per_group\": 7.480750560760498, \"sigma_intercept_per_group\": 0.3247654438018799, \"sigma_obs\": 161.578857421875, \"slope\": -0.08279862254858017, \"chain\": 3, \"draw\": 122}, {\"draws\": 722, \"mouse\": 2, \"mu_intercept_per_group\": 7.240921974182129, \"sigma_intercept_per_group\": 0.3247654438018799, \"sigma_obs\": 161.578857421875, \"slope\": -0.08279862254858017, \"chain\": 3, \"draw\": 122}, {\"draws\": 722, \"mouse\": 3, \"mu_intercept_per_group\": 6.784447193145752, \"sigma_intercept_per_group\": 0.3247654438018799, \"sigma_obs\": 161.578857421875, \"slope\": -0.08279862254858017, \"chain\": 3, \"draw\": 122}, {\"draws\": 722, \"mouse\": 4, \"mu_intercept_per_group\": 6.597101211547852, \"sigma_intercept_per_group\": 0.3247654438018799, \"sigma_obs\": 161.578857421875, \"slope\": -0.08279862254858017, \"chain\": 3, \"draw\": 122}, {\"draws\": 722, \"mouse\": 5, \"mu_intercept_per_group\": 5.95136833190918, \"sigma_intercept_per_group\": 0.3247654438018799, \"sigma_obs\": 161.578857421875, \"slope\": -0.08279862254858017, \"chain\": 3, \"draw\": 122}, {\"draws\": 722, \"mouse\": 6, \"mu_intercept_per_group\": 5.642911911010742, \"sigma_intercept_per_group\": 0.3247654438018799, \"sigma_obs\": 161.578857421875, \"slope\": -0.08279862254858017, \"chain\": 3, \"draw\": 122}, {\"draws\": 722, \"mouse\": 7, \"mu_intercept_per_group\": 5.752845764160156, \"sigma_intercept_per_group\": 0.3247654438018799, \"sigma_obs\": 161.578857421875, \"slope\": -0.08279862254858017, \"chain\": 3, \"draw\": 122}, {\"draws\": 723, \"mouse\": 0, \"mu_intercept_per_group\": 7.5274529457092285, \"sigma_intercept_per_group\": 0.329562783241272, \"sigma_obs\": 160.2779541015625, \"slope\": -0.08382833003997803, \"chain\": 3, \"draw\": 123}, {\"draws\": 723, \"mouse\": 1, \"mu_intercept_per_group\": 7.294741630554199, \"sigma_intercept_per_group\": 0.329562783241272, \"sigma_obs\": 160.2779541015625, \"slope\": -0.08382833003997803, \"chain\": 3, \"draw\": 123}, {\"draws\": 723, \"mouse\": 2, \"mu_intercept_per_group\": 6.994338512420654, \"sigma_intercept_per_group\": 0.329562783241272, \"sigma_obs\": 160.2779541015625, \"slope\": -0.08382833003997803, \"chain\": 3, \"draw\": 123}, {\"draws\": 723, \"mouse\": 3, \"mu_intercept_per_group\": 6.805785179138184, \"sigma_intercept_per_group\": 0.329562783241272, \"sigma_obs\": 160.2779541015625, \"slope\": -0.08382833003997803, \"chain\": 3, \"draw\": 123}, {\"draws\": 723, \"mouse\": 4, \"mu_intercept_per_group\": 6.422175884246826, \"sigma_intercept_per_group\": 0.329562783241272, \"sigma_obs\": 160.2779541015625, \"slope\": -0.08382833003997803, \"chain\": 3, \"draw\": 123}, {\"draws\": 723, \"mouse\": 5, \"mu_intercept_per_group\": 6.2988996505737305, \"sigma_intercept_per_group\": 0.329562783241272, \"sigma_obs\": 160.2779541015625, \"slope\": -0.08382833003997803, \"chain\": 3, \"draw\": 123}, {\"draws\": 723, \"mouse\": 6, \"mu_intercept_per_group\": 5.851719856262207, \"sigma_intercept_per_group\": 0.329562783241272, \"sigma_obs\": 160.2779541015625, \"slope\": -0.08382833003997803, \"chain\": 3, \"draw\": 123}, {\"draws\": 723, \"mouse\": 7, \"mu_intercept_per_group\": 5.566346645355225, \"sigma_intercept_per_group\": 0.329562783241272, \"sigma_obs\": 160.2779541015625, \"slope\": -0.08382833003997803, \"chain\": 3, \"draw\": 123}, {\"draws\": 724, \"mouse\": 0, \"mu_intercept_per_group\": 7.654702663421631, \"sigma_intercept_per_group\": 0.32857879996299744, \"sigma_obs\": 160.24838256835938, \"slope\": -0.08348911255598068, \"chain\": 3, \"draw\": 124}, {\"draws\": 724, \"mouse\": 1, \"mu_intercept_per_group\": 7.121582984924316, \"sigma_intercept_per_group\": 0.32857879996299744, \"sigma_obs\": 160.24838256835938, \"slope\": -0.08348911255598068, \"chain\": 3, \"draw\": 124}, {\"draws\": 724, \"mouse\": 2, \"mu_intercept_per_group\": 6.9912028312683105, \"sigma_intercept_per_group\": 0.32857879996299744, \"sigma_obs\": 160.24838256835938, \"slope\": -0.08348911255598068, \"chain\": 3, \"draw\": 124}, {\"draws\": 724, \"mouse\": 3, \"mu_intercept_per_group\": 6.736692905426025, \"sigma_intercept_per_group\": 0.32857879996299744, \"sigma_obs\": 160.24838256835938, \"slope\": -0.08348911255598068, \"chain\": 3, \"draw\": 124}, {\"draws\": 724, \"mouse\": 4, \"mu_intercept_per_group\": 6.564523220062256, \"sigma_intercept_per_group\": 0.32857879996299744, \"sigma_obs\": 160.24838256835938, \"slope\": -0.08348911255598068, \"chain\": 3, \"draw\": 124}, {\"draws\": 724, \"mouse\": 5, \"mu_intercept_per_group\": 6.323498249053955, \"sigma_intercept_per_group\": 0.32857879996299744, \"sigma_obs\": 160.24838256835938, \"slope\": -0.08348911255598068, \"chain\": 3, \"draw\": 124}, {\"draws\": 724, \"mouse\": 6, \"mu_intercept_per_group\": 5.8549652099609375, \"sigma_intercept_per_group\": 0.32857879996299744, \"sigma_obs\": 160.24838256835938, \"slope\": -0.08348911255598068, \"chain\": 3, \"draw\": 124}, {\"draws\": 724, \"mouse\": 7, \"mu_intercept_per_group\": 5.608260631561279, \"sigma_intercept_per_group\": 0.32857879996299744, \"sigma_obs\": 160.24838256835938, \"slope\": -0.08348911255598068, \"chain\": 3, \"draw\": 124}, {\"draws\": 725, \"mouse\": 0, \"mu_intercept_per_group\": 7.6543684005737305, \"sigma_intercept_per_group\": 0.32595378160476685, \"sigma_obs\": 160.109375, \"slope\": -0.08349984884262085, \"chain\": 3, \"draw\": 125}, {\"draws\": 725, \"mouse\": 1, \"mu_intercept_per_group\": 7.122897148132324, \"sigma_intercept_per_group\": 0.32595378160476685, \"sigma_obs\": 160.109375, \"slope\": -0.08349984884262085, \"chain\": 3, \"draw\": 125}, {\"draws\": 725, \"mouse\": 2, \"mu_intercept_per_group\": 7.022068023681641, \"sigma_intercept_per_group\": 0.32595378160476685, \"sigma_obs\": 160.109375, \"slope\": -0.08349984884262085, \"chain\": 3, \"draw\": 125}, {\"draws\": 725, \"mouse\": 3, \"mu_intercept_per_group\": 6.691606044769287, \"sigma_intercept_per_group\": 0.32595378160476685, \"sigma_obs\": 160.109375, \"slope\": -0.08349984884262085, \"chain\": 3, \"draw\": 125}, {\"draws\": 725, \"mouse\": 4, \"mu_intercept_per_group\": 6.549439907073975, \"sigma_intercept_per_group\": 0.32595378160476685, \"sigma_obs\": 160.109375, \"slope\": -0.08349984884262085, \"chain\": 3, \"draw\": 125}, {\"draws\": 725, \"mouse\": 5, \"mu_intercept_per_group\": 6.313007354736328, \"sigma_intercept_per_group\": 0.32595378160476685, \"sigma_obs\": 160.109375, \"slope\": -0.08349984884262085, \"chain\": 3, \"draw\": 125}, {\"draws\": 725, \"mouse\": 6, \"mu_intercept_per_group\": 5.832117080688477, \"sigma_intercept_per_group\": 0.32595378160476685, \"sigma_obs\": 160.109375, \"slope\": -0.08349984884262085, \"chain\": 3, \"draw\": 125}, {\"draws\": 725, \"mouse\": 7, \"mu_intercept_per_group\": 5.555373668670654, \"sigma_intercept_per_group\": 0.32595378160476685, \"sigma_obs\": 160.109375, \"slope\": -0.08349984884262085, \"chain\": 3, \"draw\": 125}, {\"draws\": 726, \"mouse\": 0, \"mu_intercept_per_group\": 12.50153923034668, \"sigma_intercept_per_group\": 0.1958719789981842, \"sigma_obs\": 159.46615600585938, \"slope\": -0.056609321385622025, \"chain\": 3, \"draw\": 126}, {\"draws\": 726, \"mouse\": 1, \"mu_intercept_per_group\": 11.891666412353516, \"sigma_intercept_per_group\": 0.1958719789981842, \"sigma_obs\": 159.46615600585938, \"slope\": -0.056609321385622025, \"chain\": 3, \"draw\": 126}, {\"draws\": 726, \"mouse\": 2, \"mu_intercept_per_group\": 11.842489242553711, \"sigma_intercept_per_group\": 0.1958719789981842, \"sigma_obs\": 159.46615600585938, \"slope\": -0.056609321385622025, \"chain\": 3, \"draw\": 126}, {\"draws\": 726, \"mouse\": 3, \"mu_intercept_per_group\": 11.369599342346191, \"sigma_intercept_per_group\": 0.1958719789981842, \"sigma_obs\": 159.46615600585938, \"slope\": -0.056609321385622025, \"chain\": 3, \"draw\": 126}, {\"draws\": 726, \"mouse\": 4, \"mu_intercept_per_group\": 10.85911750793457, \"sigma_intercept_per_group\": 0.1958719789981842, \"sigma_obs\": 159.46615600585938, \"slope\": -0.056609321385622025, \"chain\": 3, \"draw\": 126}, {\"draws\": 726, \"mouse\": 5, \"mu_intercept_per_group\": 10.027853965759277, \"sigma_intercept_per_group\": 0.1958719789981842, \"sigma_obs\": 159.46615600585938, \"slope\": -0.056609321385622025, \"chain\": 3, \"draw\": 126}, {\"draws\": 726, \"mouse\": 6, \"mu_intercept_per_group\": 9.662879943847656, \"sigma_intercept_per_group\": 0.1958719789981842, \"sigma_obs\": 159.46615600585938, \"slope\": -0.056609321385622025, \"chain\": 3, \"draw\": 126}, {\"draws\": 726, \"mouse\": 7, \"mu_intercept_per_group\": 9.152652740478516, \"sigma_intercept_per_group\": 0.1958719789981842, \"sigma_obs\": 159.46615600585938, \"slope\": -0.056609321385622025, \"chain\": 3, \"draw\": 126}, {\"draws\": 727, \"mouse\": 0, \"mu_intercept_per_group\": 12.67126750946045, \"sigma_intercept_per_group\": 0.19808518886566162, \"sigma_obs\": 166.26803588867188, \"slope\": -0.053184766322374344, \"chain\": 3, \"draw\": 127}, {\"draws\": 727, \"mouse\": 1, \"mu_intercept_per_group\": 11.816771507263184, \"sigma_intercept_per_group\": 0.19808518886566162, \"sigma_obs\": 166.26803588867188, \"slope\": -0.053184766322374344, \"chain\": 3, \"draw\": 127}, {\"draws\": 727, \"mouse\": 2, \"mu_intercept_per_group\": 11.856553077697754, \"sigma_intercept_per_group\": 0.19808518886566162, \"sigma_obs\": 166.26803588867188, \"slope\": -0.053184766322374344, \"chain\": 3, \"draw\": 127}, {\"draws\": 727, \"mouse\": 3, \"mu_intercept_per_group\": 11.305840492248535, \"sigma_intercept_per_group\": 0.19808518886566162, \"sigma_obs\": 166.26803588867188, \"slope\": -0.053184766322374344, \"chain\": 3, \"draw\": 127}, {\"draws\": 727, \"mouse\": 4, \"mu_intercept_per_group\": 11.040319442749023, \"sigma_intercept_per_group\": 0.19808518886566162, \"sigma_obs\": 166.26803588867188, \"slope\": -0.053184766322374344, \"chain\": 3, \"draw\": 127}, {\"draws\": 727, \"mouse\": 5, \"mu_intercept_per_group\": 10.02702808380127, \"sigma_intercept_per_group\": 0.19808518886566162, \"sigma_obs\": 166.26803588867188, \"slope\": -0.053184766322374344, \"chain\": 3, \"draw\": 127}, {\"draws\": 727, \"mouse\": 6, \"mu_intercept_per_group\": 9.298226356506348, \"sigma_intercept_per_group\": 0.19808518886566162, \"sigma_obs\": 166.26803588867188, \"slope\": -0.053184766322374344, \"chain\": 3, \"draw\": 127}, {\"draws\": 727, \"mouse\": 7, \"mu_intercept_per_group\": 8.930584907531738, \"sigma_intercept_per_group\": 0.19808518886566162, \"sigma_obs\": 166.26803588867188, \"slope\": -0.053184766322374344, \"chain\": 3, \"draw\": 127}, {\"draws\": 728, \"mouse\": 0, \"mu_intercept_per_group\": 12.018972396850586, \"sigma_intercept_per_group\": 0.20739197731018066, \"sigma_obs\": 166.87255859375, \"slope\": -0.047316987067461014, \"chain\": 3, \"draw\": 128}, {\"draws\": 728, \"mouse\": 1, \"mu_intercept_per_group\": 11.418487548828125, \"sigma_intercept_per_group\": 0.20739197731018066, \"sigma_obs\": 166.87255859375, \"slope\": -0.047316987067461014, \"chain\": 3, \"draw\": 128}, {\"draws\": 728, \"mouse\": 2, \"mu_intercept_per_group\": 11.347502708435059, \"sigma_intercept_per_group\": 0.20739197731018066, \"sigma_obs\": 166.87255859375, \"slope\": -0.047316987067461014, \"chain\": 3, \"draw\": 128}, {\"draws\": 728, \"mouse\": 3, \"mu_intercept_per_group\": 10.921428680419922, \"sigma_intercept_per_group\": 0.20739197731018066, \"sigma_obs\": 166.87255859375, \"slope\": -0.047316987067461014, \"chain\": 3, \"draw\": 128}, {\"draws\": 728, \"mouse\": 4, \"mu_intercept_per_group\": 10.49696159362793, \"sigma_intercept_per_group\": 0.20739197731018066, \"sigma_obs\": 166.87255859375, \"slope\": -0.047316987067461014, \"chain\": 3, \"draw\": 128}, {\"draws\": 728, \"mouse\": 5, \"mu_intercept_per_group\": 9.641971588134766, \"sigma_intercept_per_group\": 0.20739197731018066, \"sigma_obs\": 166.87255859375, \"slope\": -0.047316987067461014, \"chain\": 3, \"draw\": 128}, {\"draws\": 728, \"mouse\": 6, \"mu_intercept_per_group\": 9.307409286499023, \"sigma_intercept_per_group\": 0.20739197731018066, \"sigma_obs\": 166.87255859375, \"slope\": -0.047316987067461014, \"chain\": 3, \"draw\": 128}, {\"draws\": 728, \"mouse\": 7, \"mu_intercept_per_group\": 8.774256706237793, \"sigma_intercept_per_group\": 0.20739197731018066, \"sigma_obs\": 166.87255859375, \"slope\": -0.047316987067461014, \"chain\": 3, \"draw\": 128}, {\"draws\": 729, \"mouse\": 0, \"mu_intercept_per_group\": 12.995332717895508, \"sigma_intercept_per_group\": 0.19074241816997528, \"sigma_obs\": 162.6305694580078, \"slope\": -0.04791272059082985, \"chain\": 3, \"draw\": 129}, {\"draws\": 729, \"mouse\": 1, \"mu_intercept_per_group\": 12.29616928100586, \"sigma_intercept_per_group\": 0.19074241816997528, \"sigma_obs\": 162.6305694580078, \"slope\": -0.04791272059082985, \"chain\": 3, \"draw\": 129}, {\"draws\": 729, \"mouse\": 2, \"mu_intercept_per_group\": 12.172572135925293, \"sigma_intercept_per_group\": 0.19074241816997528, \"sigma_obs\": 162.6305694580078, \"slope\": -0.04791272059082985, \"chain\": 3, \"draw\": 129}, {\"draws\": 729, \"mouse\": 3, \"mu_intercept_per_group\": 11.701844215393066, \"sigma_intercept_per_group\": 0.19074241816997528, \"sigma_obs\": 162.6305694580078, \"slope\": -0.04791272059082985, \"chain\": 3, \"draw\": 129}, {\"draws\": 729, \"mouse\": 4, \"mu_intercept_per_group\": 11.277588844299316, \"sigma_intercept_per_group\": 0.19074241816997528, \"sigma_obs\": 162.6305694580078, \"slope\": -0.04791272059082985, \"chain\": 3, \"draw\": 129}, {\"draws\": 729, \"mouse\": 5, \"mu_intercept_per_group\": 10.843403816223145, \"sigma_intercept_per_group\": 0.19074241816997528, \"sigma_obs\": 162.6305694580078, \"slope\": -0.04791272059082985, \"chain\": 3, \"draw\": 129}, {\"draws\": 729, \"mouse\": 6, \"mu_intercept_per_group\": 9.819775581359863, \"sigma_intercept_per_group\": 0.19074241816997528, \"sigma_obs\": 162.6305694580078, \"slope\": -0.04791272059082985, \"chain\": 3, \"draw\": 129}, {\"draws\": 729, \"mouse\": 7, \"mu_intercept_per_group\": 9.260869979858398, \"sigma_intercept_per_group\": 0.19074241816997528, \"sigma_obs\": 162.6305694580078, \"slope\": -0.04791272059082985, \"chain\": 3, \"draw\": 129}, {\"draws\": 730, \"mouse\": 0, \"mu_intercept_per_group\": 13.437055587768555, \"sigma_intercept_per_group\": 0.18598707020282745, \"sigma_obs\": 163.39512634277344, \"slope\": -0.04679596796631813, \"chain\": 3, \"draw\": 130}, {\"draws\": 730, \"mouse\": 1, \"mu_intercept_per_group\": 12.640295028686523, \"sigma_intercept_per_group\": 0.18598707020282745, \"sigma_obs\": 163.39512634277344, \"slope\": -0.04679596796631813, \"chain\": 3, \"draw\": 130}, {\"draws\": 730, \"mouse\": 2, \"mu_intercept_per_group\": 12.53683090209961, \"sigma_intercept_per_group\": 0.18598707020282745, \"sigma_obs\": 163.39512634277344, \"slope\": -0.04679596796631813, \"chain\": 3, \"draw\": 130}, {\"draws\": 730, \"mouse\": 3, \"mu_intercept_per_group\": 11.098411560058594, \"sigma_intercept_per_group\": 0.18598707020282745, \"sigma_obs\": 163.39512634277344, \"slope\": -0.04679596796631813, \"chain\": 3, \"draw\": 130}, {\"draws\": 730, \"mouse\": 4, \"mu_intercept_per_group\": 11.49750804901123, \"sigma_intercept_per_group\": 0.18598707020282745, \"sigma_obs\": 163.39512634277344, \"slope\": -0.04679596796631813, \"chain\": 3, \"draw\": 130}, {\"draws\": 730, \"mouse\": 5, \"mu_intercept_per_group\": 10.464823722839355, \"sigma_intercept_per_group\": 0.18598707020282745, \"sigma_obs\": 163.39512634277344, \"slope\": -0.04679596796631813, \"chain\": 3, \"draw\": 130}, {\"draws\": 730, \"mouse\": 6, \"mu_intercept_per_group\": 9.992029190063477, \"sigma_intercept_per_group\": 0.18598707020282745, \"sigma_obs\": 163.39512634277344, \"slope\": -0.04679596796631813, \"chain\": 3, \"draw\": 130}, {\"draws\": 730, \"mouse\": 7, \"mu_intercept_per_group\": 9.704736709594727, \"sigma_intercept_per_group\": 0.18598707020282745, \"sigma_obs\": 163.39512634277344, \"slope\": -0.04679596796631813, \"chain\": 3, \"draw\": 130}, {\"draws\": 731, \"mouse\": 0, \"mu_intercept_per_group\": 12.720072746276855, \"sigma_intercept_per_group\": 0.18833421170711517, \"sigma_obs\": 165.8197479248047, \"slope\": -0.0405350960791111, \"chain\": 3, \"draw\": 131}, {\"draws\": 731, \"mouse\": 1, \"mu_intercept_per_group\": 12.41745662689209, \"sigma_intercept_per_group\": 0.18833421170711517, \"sigma_obs\": 165.8197479248047, \"slope\": -0.0405350960791111, \"chain\": 3, \"draw\": 131}, {\"draws\": 731, \"mouse\": 2, \"mu_intercept_per_group\": 11.886781692504883, \"sigma_intercept_per_group\": 0.18833421170711517, \"sigma_obs\": 165.8197479248047, \"slope\": -0.0405350960791111, \"chain\": 3, \"draw\": 131}, {\"draws\": 731, \"mouse\": 3, \"mu_intercept_per_group\": 12.011150360107422, \"sigma_intercept_per_group\": 0.18833421170711517, \"sigma_obs\": 165.8197479248047, \"slope\": -0.0405350960791111, \"chain\": 3, \"draw\": 131}, {\"draws\": 731, \"mouse\": 4, \"mu_intercept_per_group\": 11.092864036560059, \"sigma_intercept_per_group\": 0.18833421170711517, \"sigma_obs\": 165.8197479248047, \"slope\": -0.0405350960791111, \"chain\": 3, \"draw\": 131}, {\"draws\": 731, \"mouse\": 5, \"mu_intercept_per_group\": 10.720244407653809, \"sigma_intercept_per_group\": 0.18833421170711517, \"sigma_obs\": 165.8197479248047, \"slope\": -0.0405350960791111, \"chain\": 3, \"draw\": 131}, {\"draws\": 731, \"mouse\": 6, \"mu_intercept_per_group\": 9.940645217895508, \"sigma_intercept_per_group\": 0.18833421170711517, \"sigma_obs\": 165.8197479248047, \"slope\": -0.0405350960791111, \"chain\": 3, \"draw\": 131}, {\"draws\": 731, \"mouse\": 7, \"mu_intercept_per_group\": 8.986881256103516, \"sigma_intercept_per_group\": 0.18833421170711517, \"sigma_obs\": 165.8197479248047, \"slope\": -0.0405350960791111, \"chain\": 3, \"draw\": 131}, {\"draws\": 732, \"mouse\": 0, \"mu_intercept_per_group\": 12.886693954467773, \"sigma_intercept_per_group\": 0.19180388748645782, \"sigma_obs\": 165.3464813232422, \"slope\": -0.0402996800839901, \"chain\": 3, \"draw\": 132}, {\"draws\": 732, \"mouse\": 1, \"mu_intercept_per_group\": 12.444831848144531, \"sigma_intercept_per_group\": 0.19180388748645782, \"sigma_obs\": 165.3464813232422, \"slope\": -0.0402996800839901, \"chain\": 3, \"draw\": 132}, {\"draws\": 732, \"mouse\": 2, \"mu_intercept_per_group\": 11.913553237915039, \"sigma_intercept_per_group\": 0.19180388748645782, \"sigma_obs\": 165.3464813232422, \"slope\": -0.0402996800839901, \"chain\": 3, \"draw\": 132}, {\"draws\": 732, \"mouse\": 3, \"mu_intercept_per_group\": 11.897159576416016, \"sigma_intercept_per_group\": 0.19180388748645782, \"sigma_obs\": 165.3464813232422, \"slope\": -0.0402996800839901, \"chain\": 3, \"draw\": 132}, {\"draws\": 732, \"mouse\": 4, \"mu_intercept_per_group\": 11.082807540893555, \"sigma_intercept_per_group\": 0.19180388748645782, \"sigma_obs\": 165.3464813232422, \"slope\": -0.0402996800839901, \"chain\": 3, \"draw\": 132}, {\"draws\": 732, \"mouse\": 5, \"mu_intercept_per_group\": 10.632864952087402, \"sigma_intercept_per_group\": 0.19180388748645782, \"sigma_obs\": 165.3464813232422, \"slope\": -0.0402996800839901, \"chain\": 3, \"draw\": 132}, {\"draws\": 732, \"mouse\": 6, \"mu_intercept_per_group\": 9.613801002502441, \"sigma_intercept_per_group\": 0.19180388748645782, \"sigma_obs\": 165.3464813232422, \"slope\": -0.0402996800839901, \"chain\": 3, \"draw\": 132}, {\"draws\": 732, \"mouse\": 7, \"mu_intercept_per_group\": 9.137874603271484, \"sigma_intercept_per_group\": 0.19180388748645782, \"sigma_obs\": 165.3464813232422, \"slope\": -0.0402996800839901, \"chain\": 3, \"draw\": 132}, {\"draws\": 733, \"mouse\": 0, \"mu_intercept_per_group\": 13.36335563659668, \"sigma_intercept_per_group\": 0.18834494054317474, \"sigma_obs\": 165.78378295898438, \"slope\": -0.04020172730088234, \"chain\": 3, \"draw\": 133}, {\"draws\": 733, \"mouse\": 1, \"mu_intercept_per_group\": 12.373543739318848, \"sigma_intercept_per_group\": 0.18834494054317474, \"sigma_obs\": 165.78378295898438, \"slope\": -0.04020172730088234, \"chain\": 3, \"draw\": 133}, {\"draws\": 733, \"mouse\": 2, \"mu_intercept_per_group\": 11.815007209777832, \"sigma_intercept_per_group\": 0.18834494054317474, \"sigma_obs\": 165.78378295898438, \"slope\": -0.04020172730088234, \"chain\": 3, \"draw\": 133}, {\"draws\": 733, \"mouse\": 3, \"mu_intercept_per_group\": 11.631389617919922, \"sigma_intercept_per_group\": 0.18834494054317474, \"sigma_obs\": 165.78378295898438, \"slope\": -0.04020172730088234, \"chain\": 3, \"draw\": 133}, {\"draws\": 733, \"mouse\": 4, \"mu_intercept_per_group\": 10.94782543182373, \"sigma_intercept_per_group\": 0.18834494054317474, \"sigma_obs\": 165.78378295898438, \"slope\": -0.04020172730088234, \"chain\": 3, \"draw\": 133}, {\"draws\": 733, \"mouse\": 5, \"mu_intercept_per_group\": 10.497276306152344, \"sigma_intercept_per_group\": 0.18834494054317474, \"sigma_obs\": 165.78378295898438, \"slope\": -0.04020172730088234, \"chain\": 3, \"draw\": 133}, {\"draws\": 733, \"mouse\": 6, \"mu_intercept_per_group\": 9.606772422790527, \"sigma_intercept_per_group\": 0.18834494054317474, \"sigma_obs\": 165.78378295898438, \"slope\": -0.04020172730088234, \"chain\": 3, \"draw\": 133}, {\"draws\": 733, \"mouse\": 7, \"mu_intercept_per_group\": 9.209131240844727, \"sigma_intercept_per_group\": 0.18834494054317474, \"sigma_obs\": 165.78378295898438, \"slope\": -0.04020172730088234, \"chain\": 3, \"draw\": 133}, {\"draws\": 734, \"mouse\": 0, \"mu_intercept_per_group\": 10.056131362915039, \"sigma_intercept_per_group\": 0.24852575361728668, \"sigma_obs\": 153.52853393554688, \"slope\": -0.08519835025072098, \"chain\": 3, \"draw\": 134}, {\"draws\": 734, \"mouse\": 1, \"mu_intercept_per_group\": 9.146105766296387, \"sigma_intercept_per_group\": 0.24852575361728668, \"sigma_obs\": 153.52853393554688, \"slope\": -0.08519835025072098, \"chain\": 3, \"draw\": 134}, {\"draws\": 734, \"mouse\": 2, \"mu_intercept_per_group\": 9.194799423217773, \"sigma_intercept_per_group\": 0.24852575361728668, \"sigma_obs\": 153.52853393554688, \"slope\": -0.08519835025072098, \"chain\": 3, \"draw\": 134}, {\"draws\": 734, \"mouse\": 3, \"mu_intercept_per_group\": 8.723642349243164, \"sigma_intercept_per_group\": 0.24852575361728668, \"sigma_obs\": 153.52853393554688, \"slope\": -0.08519835025072098, \"chain\": 3, \"draw\": 134}, {\"draws\": 734, \"mouse\": 4, \"mu_intercept_per_group\": 8.600629806518555, \"sigma_intercept_per_group\": 0.24852575361728668, \"sigma_obs\": 153.52853393554688, \"slope\": -0.08519835025072098, \"chain\": 3, \"draw\": 134}, {\"draws\": 734, \"mouse\": 5, \"mu_intercept_per_group\": 8.2618408203125, \"sigma_intercept_per_group\": 0.24852575361728668, \"sigma_obs\": 153.52853393554688, \"slope\": -0.08519835025072098, \"chain\": 3, \"draw\": 134}, {\"draws\": 734, \"mouse\": 6, \"mu_intercept_per_group\": 7.39768123626709, \"sigma_intercept_per_group\": 0.24852575361728668, \"sigma_obs\": 153.52853393554688, \"slope\": -0.08519835025072098, \"chain\": 3, \"draw\": 134}, {\"draws\": 734, \"mouse\": 7, \"mu_intercept_per_group\": 7.0284423828125, \"sigma_intercept_per_group\": 0.24852575361728668, \"sigma_obs\": 153.52853393554688, \"slope\": -0.08519835025072098, \"chain\": 3, \"draw\": 134}, {\"draws\": 735, \"mouse\": 0, \"mu_intercept_per_group\": 9.881937980651855, \"sigma_intercept_per_group\": 0.2496168315410614, \"sigma_obs\": 153.29576110839844, \"slope\": -0.08624307811260223, \"chain\": 3, \"draw\": 135}, {\"draws\": 735, \"mouse\": 1, \"mu_intercept_per_group\": 9.333061218261719, \"sigma_intercept_per_group\": 0.2496168315410614, \"sigma_obs\": 153.29576110839844, \"slope\": -0.08624307811260223, \"chain\": 3, \"draw\": 135}, {\"draws\": 735, \"mouse\": 2, \"mu_intercept_per_group\": 9.12651538848877, \"sigma_intercept_per_group\": 0.2496168315410614, \"sigma_obs\": 153.29576110839844, \"slope\": -0.08624307811260223, \"chain\": 3, \"draw\": 135}, {\"draws\": 735, \"mouse\": 3, \"mu_intercept_per_group\": 8.647741317749023, \"sigma_intercept_per_group\": 0.2496168315410614, \"sigma_obs\": 153.29576110839844, \"slope\": -0.08624307811260223, \"chain\": 3, \"draw\": 135}, {\"draws\": 735, \"mouse\": 4, \"mu_intercept_per_group\": 8.473177909851074, \"sigma_intercept_per_group\": 0.2496168315410614, \"sigma_obs\": 153.29576110839844, \"slope\": -0.08624307811260223, \"chain\": 3, \"draw\": 135}, {\"draws\": 735, \"mouse\": 5, \"mu_intercept_per_group\": 7.872128009796143, \"sigma_intercept_per_group\": 0.2496168315410614, \"sigma_obs\": 153.29576110839844, \"slope\": -0.08624307811260223, \"chain\": 3, \"draw\": 135}, {\"draws\": 735, \"mouse\": 6, \"mu_intercept_per_group\": 7.808303356170654, \"sigma_intercept_per_group\": 0.2496168315410614, \"sigma_obs\": 153.29576110839844, \"slope\": -0.08624307811260223, \"chain\": 3, \"draw\": 135}, {\"draws\": 735, \"mouse\": 7, \"mu_intercept_per_group\": 7.061133861541748, \"sigma_intercept_per_group\": 0.2496168315410614, \"sigma_obs\": 153.29576110839844, \"slope\": -0.08624307811260223, \"chain\": 3, \"draw\": 135}, {\"draws\": 736, \"mouse\": 0, \"mu_intercept_per_group\": 10.932981491088867, \"sigma_intercept_per_group\": 0.22156687080860138, \"sigma_obs\": 155.66839599609375, \"slope\": -0.060584597289562225, \"chain\": 3, \"draw\": 136}, {\"draws\": 736, \"mouse\": 1, \"mu_intercept_per_group\": 10.443153381347656, \"sigma_intercept_per_group\": 0.22156687080860138, \"sigma_obs\": 155.66839599609375, \"slope\": -0.060584597289562225, \"chain\": 3, \"draw\": 136}, {\"draws\": 736, \"mouse\": 2, \"mu_intercept_per_group\": 10.319324493408203, \"sigma_intercept_per_group\": 0.22156687080860138, \"sigma_obs\": 155.66839599609375, \"slope\": -0.060584597289562225, \"chain\": 3, \"draw\": 136}, {\"draws\": 736, \"mouse\": 3, \"mu_intercept_per_group\": 9.631119728088379, \"sigma_intercept_per_group\": 0.22156687080860138, \"sigma_obs\": 155.66839599609375, \"slope\": -0.060584597289562225, \"chain\": 3, \"draw\": 136}, {\"draws\": 736, \"mouse\": 4, \"mu_intercept_per_group\": 9.419722557067871, \"sigma_intercept_per_group\": 0.22156687080860138, \"sigma_obs\": 155.66839599609375, \"slope\": -0.060584597289562225, \"chain\": 3, \"draw\": 136}, {\"draws\": 736, \"mouse\": 5, \"mu_intercept_per_group\": 8.925204277038574, \"sigma_intercept_per_group\": 0.22156687080860138, \"sigma_obs\": 155.66839599609375, \"slope\": -0.060584597289562225, \"chain\": 3, \"draw\": 136}, {\"draws\": 736, \"mouse\": 6, \"mu_intercept_per_group\": 8.297476768493652, \"sigma_intercept_per_group\": 0.22156687080860138, \"sigma_obs\": 155.66839599609375, \"slope\": -0.060584597289562225, \"chain\": 3, \"draw\": 136}, {\"draws\": 736, \"mouse\": 7, \"mu_intercept_per_group\": 7.795246601104736, \"sigma_intercept_per_group\": 0.22156687080860138, \"sigma_obs\": 155.66839599609375, \"slope\": -0.060584597289562225, \"chain\": 3, \"draw\": 136}, {\"draws\": 737, \"mouse\": 0, \"mu_intercept_per_group\": 10.78581428527832, \"sigma_intercept_per_group\": 0.22622309625148773, \"sigma_obs\": 154.5537109375, \"slope\": -0.06337898969650269, \"chain\": 3, \"draw\": 137}, {\"draws\": 737, \"mouse\": 1, \"mu_intercept_per_group\": 10.421770095825195, \"sigma_intercept_per_group\": 0.22622309625148773, \"sigma_obs\": 154.5537109375, \"slope\": -0.06337898969650269, \"chain\": 3, \"draw\": 137}, {\"draws\": 737, \"mouse\": 2, \"mu_intercept_per_group\": 9.8960542678833, \"sigma_intercept_per_group\": 0.22622309625148773, \"sigma_obs\": 154.5537109375, \"slope\": -0.06337898969650269, \"chain\": 3, \"draw\": 137}, {\"draws\": 737, \"mouse\": 3, \"mu_intercept_per_group\": 9.531942367553711, \"sigma_intercept_per_group\": 0.22622309625148773, \"sigma_obs\": 154.5537109375, \"slope\": -0.06337898969650269, \"chain\": 3, \"draw\": 137}, {\"draws\": 737, \"mouse\": 4, \"mu_intercept_per_group\": 9.225815773010254, \"sigma_intercept_per_group\": 0.22622309625148773, \"sigma_obs\": 154.5537109375, \"slope\": -0.06337898969650269, \"chain\": 3, \"draw\": 137}, {\"draws\": 737, \"mouse\": 5, \"mu_intercept_per_group\": 8.72376537322998, \"sigma_intercept_per_group\": 0.22622309625148773, \"sigma_obs\": 154.5537109375, \"slope\": -0.06337898969650269, \"chain\": 3, \"draw\": 137}, {\"draws\": 737, \"mouse\": 6, \"mu_intercept_per_group\": 7.983673095703125, \"sigma_intercept_per_group\": 0.22622309625148773, \"sigma_obs\": 154.5537109375, \"slope\": -0.06337898969650269, \"chain\": 3, \"draw\": 137}, {\"draws\": 737, \"mouse\": 7, \"mu_intercept_per_group\": 8.00284194946289, \"sigma_intercept_per_group\": 0.22622309625148773, \"sigma_obs\": 154.5537109375, \"slope\": -0.06337898969650269, \"chain\": 3, \"draw\": 137}, {\"draws\": 738, \"mouse\": 0, \"mu_intercept_per_group\": 10.749748229980469, \"sigma_intercept_per_group\": 0.22762051224708557, \"sigma_obs\": 157.59193420410156, \"slope\": -0.07008441537618637, \"chain\": 3, \"draw\": 138}, {\"draws\": 738, \"mouse\": 1, \"mu_intercept_per_group\": 10.507018089294434, \"sigma_intercept_per_group\": 0.22762051224708557, \"sigma_obs\": 157.59193420410156, \"slope\": -0.07008441537618637, \"chain\": 3, \"draw\": 138}, {\"draws\": 738, \"mouse\": 2, \"mu_intercept_per_group\": 10.06873607635498, \"sigma_intercept_per_group\": 0.22762051224708557, \"sigma_obs\": 157.59193420410156, \"slope\": -0.07008441537618637, \"chain\": 3, \"draw\": 138}, {\"draws\": 738, \"mouse\": 3, \"mu_intercept_per_group\": 9.66126537322998, \"sigma_intercept_per_group\": 0.22762051224708557, \"sigma_obs\": 157.59193420410156, \"slope\": -0.07008441537618637, \"chain\": 3, \"draw\": 138}, {\"draws\": 738, \"mouse\": 4, \"mu_intercept_per_group\": 9.29061508178711, \"sigma_intercept_per_group\": 0.22762051224708557, \"sigma_obs\": 157.59193420410156, \"slope\": -0.07008441537618637, \"chain\": 3, \"draw\": 138}, {\"draws\": 738, \"mouse\": 5, \"mu_intercept_per_group\": 8.762348175048828, \"sigma_intercept_per_group\": 0.22762051224708557, \"sigma_obs\": 157.59193420410156, \"slope\": -0.07008441537618637, \"chain\": 3, \"draw\": 138}, {\"draws\": 738, \"mouse\": 6, \"mu_intercept_per_group\": 8.37861156463623, \"sigma_intercept_per_group\": 0.22762051224708557, \"sigma_obs\": 157.59193420410156, \"slope\": -0.07008441537618637, \"chain\": 3, \"draw\": 138}, {\"draws\": 738, \"mouse\": 7, \"mu_intercept_per_group\": 7.408453464508057, \"sigma_intercept_per_group\": 0.22762051224708557, \"sigma_obs\": 157.59193420410156, \"slope\": -0.07008441537618637, \"chain\": 3, \"draw\": 138}, {\"draws\": 739, \"mouse\": 0, \"mu_intercept_per_group\": 10.282947540283203, \"sigma_intercept_per_group\": 0.24331989884376526, \"sigma_obs\": 164.72015380859375, \"slope\": -0.06804925948381424, \"chain\": 3, \"draw\": 139}, {\"draws\": 739, \"mouse\": 1, \"mu_intercept_per_group\": 9.705615043640137, \"sigma_intercept_per_group\": 0.24331989884376526, \"sigma_obs\": 164.72015380859375, \"slope\": -0.06804925948381424, \"chain\": 3, \"draw\": 139}, {\"draws\": 739, \"mouse\": 2, \"mu_intercept_per_group\": 9.52342414855957, \"sigma_intercept_per_group\": 0.24331989884376526, \"sigma_obs\": 164.72015380859375, \"slope\": -0.06804925948381424, \"chain\": 3, \"draw\": 139}, {\"draws\": 739, \"mouse\": 3, \"mu_intercept_per_group\": 9.103585243225098, \"sigma_intercept_per_group\": 0.24331989884376526, \"sigma_obs\": 164.72015380859375, \"slope\": -0.06804925948381424, \"chain\": 3, \"draw\": 139}, {\"draws\": 739, \"mouse\": 4, \"mu_intercept_per_group\": 8.756673812866211, \"sigma_intercept_per_group\": 0.24331989884376526, \"sigma_obs\": 164.72015380859375, \"slope\": -0.06804925948381424, \"chain\": 3, \"draw\": 139}, {\"draws\": 739, \"mouse\": 5, \"mu_intercept_per_group\": 8.222900390625, \"sigma_intercept_per_group\": 0.24331989884376526, \"sigma_obs\": 164.72015380859375, \"slope\": -0.06804925948381424, \"chain\": 3, \"draw\": 139}, {\"draws\": 739, \"mouse\": 6, \"mu_intercept_per_group\": 7.7541608810424805, \"sigma_intercept_per_group\": 0.24331989884376526, \"sigma_obs\": 164.72015380859375, \"slope\": -0.06804925948381424, \"chain\": 3, \"draw\": 139}, {\"draws\": 739, \"mouse\": 7, \"mu_intercept_per_group\": 7.365998268127441, \"sigma_intercept_per_group\": 0.24331989884376526, \"sigma_obs\": 164.72015380859375, \"slope\": -0.06804925948381424, \"chain\": 3, \"draw\": 139}, {\"draws\": 740, \"mouse\": 0, \"mu_intercept_per_group\": 9.529294967651367, \"sigma_intercept_per_group\": 0.2655445635318756, \"sigma_obs\": 168.667236328125, \"slope\": -0.07677089422941208, \"chain\": 3, \"draw\": 140}, {\"draws\": 740, \"mouse\": 1, \"mu_intercept_per_group\": 9.161144256591797, \"sigma_intercept_per_group\": 0.2655445635318756, \"sigma_obs\": 168.667236328125, \"slope\": -0.07677089422941208, \"chain\": 3, \"draw\": 140}, {\"draws\": 740, \"mouse\": 2, \"mu_intercept_per_group\": 8.930413246154785, \"sigma_intercept_per_group\": 0.2655445635318756, \"sigma_obs\": 168.667236328125, \"slope\": -0.07677089422941208, \"chain\": 3, \"draw\": 140}, {\"draws\": 740, \"mouse\": 3, \"mu_intercept_per_group\": 8.451930046081543, \"sigma_intercept_per_group\": 0.2655445635318756, \"sigma_obs\": 168.667236328125, \"slope\": -0.07677089422941208, \"chain\": 3, \"draw\": 140}, {\"draws\": 740, \"mouse\": 4, \"mu_intercept_per_group\": 8.350725173950195, \"sigma_intercept_per_group\": 0.2655445635318756, \"sigma_obs\": 168.667236328125, \"slope\": -0.07677089422941208, \"chain\": 3, \"draw\": 140}, {\"draws\": 740, \"mouse\": 5, \"mu_intercept_per_group\": 7.907247066497803, \"sigma_intercept_per_group\": 0.2655445635318756, \"sigma_obs\": 168.667236328125, \"slope\": -0.07677089422941208, \"chain\": 3, \"draw\": 140}, {\"draws\": 740, \"mouse\": 6, \"mu_intercept_per_group\": 7.247810363769531, \"sigma_intercept_per_group\": 0.2655445635318756, \"sigma_obs\": 168.667236328125, \"slope\": -0.07677089422941208, \"chain\": 3, \"draw\": 140}, {\"draws\": 740, \"mouse\": 7, \"mu_intercept_per_group\": 7.001908302307129, \"sigma_intercept_per_group\": 0.2655445635318756, \"sigma_obs\": 168.667236328125, \"slope\": -0.07677089422941208, \"chain\": 3, \"draw\": 140}, {\"draws\": 741, \"mouse\": 0, \"mu_intercept_per_group\": 10.23086166381836, \"sigma_intercept_per_group\": 0.24358312785625458, \"sigma_obs\": 161.10165405273438, \"slope\": -0.06796611845493317, \"chain\": 3, \"draw\": 141}, {\"draws\": 741, \"mouse\": 1, \"mu_intercept_per_group\": 9.775779724121094, \"sigma_intercept_per_group\": 0.24358312785625458, \"sigma_obs\": 161.10165405273438, \"slope\": -0.06796611845493317, \"chain\": 3, \"draw\": 141}, {\"draws\": 741, \"mouse\": 2, \"mu_intercept_per_group\": 9.566564559936523, \"sigma_intercept_per_group\": 0.24358312785625458, \"sigma_obs\": 161.10165405273438, \"slope\": -0.06796611845493317, \"chain\": 3, \"draw\": 141}, {\"draws\": 741, \"mouse\": 3, \"mu_intercept_per_group\": 8.971124649047852, \"sigma_intercept_per_group\": 0.24358312785625458, \"sigma_obs\": 161.10165405273438, \"slope\": -0.06796611845493317, \"chain\": 3, \"draw\": 141}, {\"draws\": 741, \"mouse\": 4, \"mu_intercept_per_group\": 8.686326026916504, \"sigma_intercept_per_group\": 0.24358312785625458, \"sigma_obs\": 161.10165405273438, \"slope\": -0.06796611845493317, \"chain\": 3, \"draw\": 141}, {\"draws\": 741, \"mouse\": 5, \"mu_intercept_per_group\": 7.953216075897217, \"sigma_intercept_per_group\": 0.24358312785625458, \"sigma_obs\": 161.10165405273438, \"slope\": -0.06796611845493317, \"chain\": 3, \"draw\": 141}, {\"draws\": 741, \"mouse\": 6, \"mu_intercept_per_group\": 7.614400386810303, \"sigma_intercept_per_group\": 0.24358312785625458, \"sigma_obs\": 161.10165405273438, \"slope\": -0.06796611845493317, \"chain\": 3, \"draw\": 141}, {\"draws\": 741, \"mouse\": 7, \"mu_intercept_per_group\": 7.3246989250183105, \"sigma_intercept_per_group\": 0.24358312785625458, \"sigma_obs\": 161.10165405273438, \"slope\": -0.06796611845493317, \"chain\": 3, \"draw\": 141}, {\"draws\": 742, \"mouse\": 0, \"mu_intercept_per_group\": 10.222478866577148, \"sigma_intercept_per_group\": 0.24505355954170227, \"sigma_obs\": 161.159423828125, \"slope\": -0.06783748418092728, \"chain\": 3, \"draw\": 142}, {\"draws\": 742, \"mouse\": 1, \"mu_intercept_per_group\": 9.552958488464355, \"sigma_intercept_per_group\": 0.24505355954170227, \"sigma_obs\": 161.159423828125, \"slope\": -0.06783748418092728, \"chain\": 3, \"draw\": 142}, {\"draws\": 742, \"mouse\": 2, \"mu_intercept_per_group\": 9.651482582092285, \"sigma_intercept_per_group\": 0.24505355954170227, \"sigma_obs\": 161.159423828125, \"slope\": -0.06783748418092728, \"chain\": 3, \"draw\": 142}, {\"draws\": 742, \"mouse\": 3, \"mu_intercept_per_group\": 9.080182075500488, \"sigma_intercept_per_group\": 0.24505355954170227, \"sigma_obs\": 161.159423828125, \"slope\": -0.06783748418092728, \"chain\": 3, \"draw\": 142}, {\"draws\": 742, \"mouse\": 4, \"mu_intercept_per_group\": 8.73033332824707, \"sigma_intercept_per_group\": 0.24505355954170227, \"sigma_obs\": 161.159423828125, \"slope\": -0.06783748418092728, \"chain\": 3, \"draw\": 142}, {\"draws\": 742, \"mouse\": 5, \"mu_intercept_per_group\": 8.037149429321289, \"sigma_intercept_per_group\": 0.24505355954170227, \"sigma_obs\": 161.159423828125, \"slope\": -0.06783748418092728, \"chain\": 3, \"draw\": 142}, {\"draws\": 742, \"mouse\": 6, \"mu_intercept_per_group\": 7.702584743499756, \"sigma_intercept_per_group\": 0.24505355954170227, \"sigma_obs\": 161.159423828125, \"slope\": -0.06783748418092728, \"chain\": 3, \"draw\": 142}, {\"draws\": 742, \"mouse\": 7, \"mu_intercept_per_group\": 7.4763007164001465, \"sigma_intercept_per_group\": 0.24505355954170227, \"sigma_obs\": 161.159423828125, \"slope\": -0.06783748418092728, \"chain\": 3, \"draw\": 142}, {\"draws\": 743, \"mouse\": 0, \"mu_intercept_per_group\": 10.196353912353516, \"sigma_intercept_per_group\": 0.24453844130039215, \"sigma_obs\": 161.43832397460938, \"slope\": -0.06725417822599411, \"chain\": 3, \"draw\": 143}, {\"draws\": 743, \"mouse\": 1, \"mu_intercept_per_group\": 9.692885398864746, \"sigma_intercept_per_group\": 0.24453844130039215, \"sigma_obs\": 161.43832397460938, \"slope\": -0.06725417822599411, \"chain\": 3, \"draw\": 143}, {\"draws\": 743, \"mouse\": 2, \"mu_intercept_per_group\": 9.513096809387207, \"sigma_intercept_per_group\": 0.24453844130039215, \"sigma_obs\": 161.43832397460938, \"slope\": -0.06725417822599411, \"chain\": 3, \"draw\": 143}, {\"draws\": 743, \"mouse\": 3, \"mu_intercept_per_group\": 9.13010311126709, \"sigma_intercept_per_group\": 0.24453844130039215, \"sigma_obs\": 161.43832397460938, \"slope\": -0.06725417822599411, \"chain\": 3, \"draw\": 143}, {\"draws\": 743, \"mouse\": 4, \"mu_intercept_per_group\": 8.471399307250977, \"sigma_intercept_per_group\": 0.24453844130039215, \"sigma_obs\": 161.43832397460938, \"slope\": -0.06725417822599411, \"chain\": 3, \"draw\": 143}, {\"draws\": 743, \"mouse\": 5, \"mu_intercept_per_group\": 8.258915901184082, \"sigma_intercept_per_group\": 0.24453844130039215, \"sigma_obs\": 161.43832397460938, \"slope\": -0.06725417822599411, \"chain\": 3, \"draw\": 143}, {\"draws\": 743, \"mouse\": 6, \"mu_intercept_per_group\": 7.74001932144165, \"sigma_intercept_per_group\": 0.24453844130039215, \"sigma_obs\": 161.43832397460938, \"slope\": -0.06725417822599411, \"chain\": 3, \"draw\": 143}, {\"draws\": 743, \"mouse\": 7, \"mu_intercept_per_group\": 7.2889604568481445, \"sigma_intercept_per_group\": 0.24453844130039215, \"sigma_obs\": 161.43832397460938, \"slope\": -0.06725417822599411, \"chain\": 3, \"draw\": 143}, {\"draws\": 744, \"mouse\": 0, \"mu_intercept_per_group\": 9.993387222290039, \"sigma_intercept_per_group\": 0.24450170993804932, \"sigma_obs\": 161.72146606445312, \"slope\": -0.06717754900455475, \"chain\": 3, \"draw\": 144}, {\"draws\": 744, \"mouse\": 1, \"mu_intercept_per_group\": 9.921784400939941, \"sigma_intercept_per_group\": 0.24450170993804932, \"sigma_obs\": 161.72146606445312, \"slope\": -0.06717754900455475, \"chain\": 3, \"draw\": 144}, {\"draws\": 744, \"mouse\": 2, \"mu_intercept_per_group\": 9.63669490814209, \"sigma_intercept_per_group\": 0.24450170993804932, \"sigma_obs\": 161.72146606445312, \"slope\": -0.06717754900455475, \"chain\": 3, \"draw\": 144}, {\"draws\": 744, \"mouse\": 3, \"mu_intercept_per_group\": 8.989217758178711, \"sigma_intercept_per_group\": 0.24450170993804932, \"sigma_obs\": 161.72146606445312, \"slope\": -0.06717754900455475, \"chain\": 3, \"draw\": 144}, {\"draws\": 744, \"mouse\": 4, \"mu_intercept_per_group\": 8.25914192199707, \"sigma_intercept_per_group\": 0.24450170993804932, \"sigma_obs\": 161.72146606445312, \"slope\": -0.06717754900455475, \"chain\": 3, \"draw\": 144}, {\"draws\": 744, \"mouse\": 5, \"mu_intercept_per_group\": 8.359371185302734, \"sigma_intercept_per_group\": 0.24450170993804932, \"sigma_obs\": 161.72146606445312, \"slope\": -0.06717754900455475, \"chain\": 3, \"draw\": 144}, {\"draws\": 744, \"mouse\": 6, \"mu_intercept_per_group\": 7.698949337005615, \"sigma_intercept_per_group\": 0.24450170993804932, \"sigma_obs\": 161.72146606445312, \"slope\": -0.06717754900455475, \"chain\": 3, \"draw\": 144}, {\"draws\": 744, \"mouse\": 7, \"mu_intercept_per_group\": 7.305609703063965, \"sigma_intercept_per_group\": 0.24450170993804932, \"sigma_obs\": 161.72146606445312, \"slope\": -0.06717754900455475, \"chain\": 3, \"draw\": 144}, {\"draws\": 745, \"mouse\": 0, \"mu_intercept_per_group\": 10.049203872680664, \"sigma_intercept_per_group\": 0.2414466291666031, \"sigma_obs\": 163.1267852783203, \"slope\": -0.07042375206947327, \"chain\": 3, \"draw\": 145}, {\"draws\": 745, \"mouse\": 1, \"mu_intercept_per_group\": 9.841774940490723, \"sigma_intercept_per_group\": 0.2414466291666031, \"sigma_obs\": 163.1267852783203, \"slope\": -0.07042375206947327, \"chain\": 3, \"draw\": 145}, {\"draws\": 745, \"mouse\": 2, \"mu_intercept_per_group\": 9.728224754333496, \"sigma_intercept_per_group\": 0.2414466291666031, \"sigma_obs\": 163.1267852783203, \"slope\": -0.07042375206947327, \"chain\": 3, \"draw\": 145}, {\"draws\": 745, \"mouse\": 3, \"mu_intercept_per_group\": 8.955999374389648, \"sigma_intercept_per_group\": 0.2414466291666031, \"sigma_obs\": 163.1267852783203, \"slope\": -0.07042375206947327, \"chain\": 3, \"draw\": 145}, {\"draws\": 745, \"mouse\": 4, \"mu_intercept_per_group\": 9.10847282409668, \"sigma_intercept_per_group\": 0.2414466291666031, \"sigma_obs\": 163.1267852783203, \"slope\": -0.07042375206947327, \"chain\": 3, \"draw\": 145}, {\"draws\": 745, \"mouse\": 5, \"mu_intercept_per_group\": 8.115958213806152, \"sigma_intercept_per_group\": 0.2414466291666031, \"sigma_obs\": 163.1267852783203, \"slope\": -0.07042375206947327, \"chain\": 3, \"draw\": 145}, {\"draws\": 745, \"mouse\": 6, \"mu_intercept_per_group\": 7.7072858810424805, \"sigma_intercept_per_group\": 0.2414466291666031, \"sigma_obs\": 163.1267852783203, \"slope\": -0.07042375206947327, \"chain\": 3, \"draw\": 145}, {\"draws\": 745, \"mouse\": 7, \"mu_intercept_per_group\": 7.581063270568848, \"sigma_intercept_per_group\": 0.2414466291666031, \"sigma_obs\": 163.1267852783203, \"slope\": -0.07042375206947327, \"chain\": 3, \"draw\": 145}, {\"draws\": 746, \"mouse\": 0, \"mu_intercept_per_group\": 10.464437484741211, \"sigma_intercept_per_group\": 0.24278567731380463, \"sigma_obs\": 161.6451416015625, \"slope\": -0.06806117296218872, \"chain\": 3, \"draw\": 146}, {\"draws\": 746, \"mouse\": 1, \"mu_intercept_per_group\": 9.951813697814941, \"sigma_intercept_per_group\": 0.24278567731380463, \"sigma_obs\": 161.6451416015625, \"slope\": -0.06806117296218872, \"chain\": 3, \"draw\": 146}, {\"draws\": 746, \"mouse\": 2, \"mu_intercept_per_group\": 9.492300987243652, \"sigma_intercept_per_group\": 0.24278567731380463, \"sigma_obs\": 161.6451416015625, \"slope\": -0.06806117296218872, \"chain\": 3, \"draw\": 146}, {\"draws\": 746, \"mouse\": 3, \"mu_intercept_per_group\": 8.834802627563477, \"sigma_intercept_per_group\": 0.24278567731380463, \"sigma_obs\": 161.6451416015625, \"slope\": -0.06806117296218872, \"chain\": 3, \"draw\": 146}, {\"draws\": 746, \"mouse\": 4, \"mu_intercept_per_group\": 8.404173851013184, \"sigma_intercept_per_group\": 0.24278567731380463, \"sigma_obs\": 161.6451416015625, \"slope\": -0.06806117296218872, \"chain\": 3, \"draw\": 146}, {\"draws\": 746, \"mouse\": 5, \"mu_intercept_per_group\": 8.748008728027344, \"sigma_intercept_per_group\": 0.24278567731380463, \"sigma_obs\": 161.6451416015625, \"slope\": -0.06806117296218872, \"chain\": 3, \"draw\": 146}, {\"draws\": 746, \"mouse\": 6, \"mu_intercept_per_group\": 7.544963359832764, \"sigma_intercept_per_group\": 0.24278567731380463, \"sigma_obs\": 161.6451416015625, \"slope\": -0.06806117296218872, \"chain\": 3, \"draw\": 146}, {\"draws\": 746, \"mouse\": 7, \"mu_intercept_per_group\": 7.575748443603516, \"sigma_intercept_per_group\": 0.24278567731380463, \"sigma_obs\": 161.6451416015625, \"slope\": -0.06806117296218872, \"chain\": 3, \"draw\": 146}, {\"draws\": 747, \"mouse\": 0, \"mu_intercept_per_group\": 10.147814750671387, \"sigma_intercept_per_group\": 0.2429591566324234, \"sigma_obs\": 161.0977325439453, \"slope\": -0.0684799775481224, \"chain\": 3, \"draw\": 147}, {\"draws\": 747, \"mouse\": 1, \"mu_intercept_per_group\": 9.967001914978027, \"sigma_intercept_per_group\": 0.2429591566324234, \"sigma_obs\": 161.0977325439453, \"slope\": -0.0684799775481224, \"chain\": 3, \"draw\": 147}, {\"draws\": 747, \"mouse\": 2, \"mu_intercept_per_group\": 9.655769348144531, \"sigma_intercept_per_group\": 0.2429591566324234, \"sigma_obs\": 161.0977325439453, \"slope\": -0.0684799775481224, \"chain\": 3, \"draw\": 147}, {\"draws\": 747, \"mouse\": 3, \"mu_intercept_per_group\": 8.966939926147461, \"sigma_intercept_per_group\": 0.2429591566324234, \"sigma_obs\": 161.0977325439453, \"slope\": -0.0684799775481224, \"chain\": 3, \"draw\": 147}, {\"draws\": 747, \"mouse\": 4, \"mu_intercept_per_group\": 8.934647560119629, \"sigma_intercept_per_group\": 0.2429591566324234, \"sigma_obs\": 161.0977325439453, \"slope\": -0.0684799775481224, \"chain\": 3, \"draw\": 147}, {\"draws\": 747, \"mouse\": 5, \"mu_intercept_per_group\": 8.297595977783203, \"sigma_intercept_per_group\": 0.2429591566324234, \"sigma_obs\": 161.0977325439453, \"slope\": -0.0684799775481224, \"chain\": 3, \"draw\": 147}, {\"draws\": 747, \"mouse\": 6, \"mu_intercept_per_group\": 7.740072250366211, \"sigma_intercept_per_group\": 0.2429591566324234, \"sigma_obs\": 161.0977325439453, \"slope\": -0.0684799775481224, \"chain\": 3, \"draw\": 147}, {\"draws\": 747, \"mouse\": 7, \"mu_intercept_per_group\": 7.435002326965332, \"sigma_intercept_per_group\": 0.2429591566324234, \"sigma_obs\": 161.0977325439453, \"slope\": -0.0684799775481224, \"chain\": 3, \"draw\": 147}, {\"draws\": 748, \"mouse\": 0, \"mu_intercept_per_group\": 7.902858257293701, \"sigma_intercept_per_group\": 0.33190542459487915, \"sigma_obs\": 178.0577392578125, \"slope\": -0.0702529028058052, \"chain\": 3, \"draw\": 148}, {\"draws\": 748, \"mouse\": 1, \"mu_intercept_per_group\": 7.410987377166748, \"sigma_intercept_per_group\": 0.33190542459487915, \"sigma_obs\": 178.0577392578125, \"slope\": -0.0702529028058052, \"chain\": 3, \"draw\": 148}, {\"draws\": 748, \"mouse\": 2, \"mu_intercept_per_group\": 7.276913166046143, \"sigma_intercept_per_group\": 0.33190542459487915, \"sigma_obs\": 178.0577392578125, \"slope\": -0.0702529028058052, \"chain\": 3, \"draw\": 148}, {\"draws\": 748, \"mouse\": 3, \"mu_intercept_per_group\": 6.755171775817871, \"sigma_intercept_per_group\": 0.33190542459487915, \"sigma_obs\": 178.0577392578125, \"slope\": -0.0702529028058052, \"chain\": 3, \"draw\": 148}, {\"draws\": 748, \"mouse\": 4, \"mu_intercept_per_group\": 6.701735973358154, \"sigma_intercept_per_group\": 0.33190542459487915, \"sigma_obs\": 178.0577392578125, \"slope\": -0.0702529028058052, \"chain\": 3, \"draw\": 148}, {\"draws\": 748, \"mouse\": 5, \"mu_intercept_per_group\": 6.3692498207092285, \"sigma_intercept_per_group\": 0.33190542459487915, \"sigma_obs\": 178.0577392578125, \"slope\": -0.0702529028058052, \"chain\": 3, \"draw\": 148}, {\"draws\": 748, \"mouse\": 6, \"mu_intercept_per_group\": 5.84356164932251, \"sigma_intercept_per_group\": 0.33190542459487915, \"sigma_obs\": 178.0577392578125, \"slope\": -0.0702529028058052, \"chain\": 3, \"draw\": 148}, {\"draws\": 748, \"mouse\": 7, \"mu_intercept_per_group\": 5.689242362976074, \"sigma_intercept_per_group\": 0.33190542459487915, \"sigma_obs\": 178.0577392578125, \"slope\": -0.0702529028058052, \"chain\": 3, \"draw\": 148}, {\"draws\": 749, \"mouse\": 0, \"mu_intercept_per_group\": 7.801631450653076, \"sigma_intercept_per_group\": 0.32976722717285156, \"sigma_obs\": 177.01597595214844, \"slope\": -0.07024863362312317, \"chain\": 3, \"draw\": 149}, {\"draws\": 749, \"mouse\": 1, \"mu_intercept_per_group\": 7.680454730987549, \"sigma_intercept_per_group\": 0.32976722717285156, \"sigma_obs\": 177.01597595214844, \"slope\": -0.07024863362312317, \"chain\": 3, \"draw\": 149}, {\"draws\": 749, \"mouse\": 2, \"mu_intercept_per_group\": 7.364156723022461, \"sigma_intercept_per_group\": 0.32976722717285156, \"sigma_obs\": 177.01597595214844, \"slope\": -0.07024863362312317, \"chain\": 3, \"draw\": 149}, {\"draws\": 749, \"mouse\": 3, \"mu_intercept_per_group\": 6.943791389465332, \"sigma_intercept_per_group\": 0.32976722717285156, \"sigma_obs\": 177.01597595214844, \"slope\": -0.07024863362312317, \"chain\": 3, \"draw\": 149}, {\"draws\": 749, \"mouse\": 4, \"mu_intercept_per_group\": 6.637315273284912, \"sigma_intercept_per_group\": 0.32976722717285156, \"sigma_obs\": 177.01597595214844, \"slope\": -0.07024863362312317, \"chain\": 3, \"draw\": 149}, {\"draws\": 749, \"mouse\": 5, \"mu_intercept_per_group\": 6.256122589111328, \"sigma_intercept_per_group\": 0.32976722717285156, \"sigma_obs\": 177.01597595214844, \"slope\": -0.07024863362312317, \"chain\": 3, \"draw\": 149}, {\"draws\": 749, \"mouse\": 6, \"mu_intercept_per_group\": 5.868546962738037, \"sigma_intercept_per_group\": 0.32976722717285156, \"sigma_obs\": 177.01597595214844, \"slope\": -0.07024863362312317, \"chain\": 3, \"draw\": 149}, {\"draws\": 749, \"mouse\": 7, \"mu_intercept_per_group\": 5.592265605926514, \"sigma_intercept_per_group\": 0.32976722717285156, \"sigma_obs\": 177.01597595214844, \"slope\": -0.07024863362312317, \"chain\": 3, \"draw\": 149}, {\"draws\": 750, \"mouse\": 0, \"mu_intercept_per_group\": 7.139288902282715, \"sigma_intercept_per_group\": 0.35212603211402893, \"sigma_obs\": 167.88424682617188, \"slope\": -0.08271978795528412, \"chain\": 3, \"draw\": 150}, {\"draws\": 750, \"mouse\": 1, \"mu_intercept_per_group\": 6.93132209777832, \"sigma_intercept_per_group\": 0.35212603211402893, \"sigma_obs\": 167.88424682617188, \"slope\": -0.08271978795528412, \"chain\": 3, \"draw\": 150}, {\"draws\": 750, \"mouse\": 2, \"mu_intercept_per_group\": 6.845143795013428, \"sigma_intercept_per_group\": 0.35212603211402893, \"sigma_obs\": 167.88424682617188, \"slope\": -0.08271978795528412, \"chain\": 3, \"draw\": 150}, {\"draws\": 750, \"mouse\": 3, \"mu_intercept_per_group\": 6.480031967163086, \"sigma_intercept_per_group\": 0.35212603211402893, \"sigma_obs\": 167.88424682617188, \"slope\": -0.08271978795528412, \"chain\": 3, \"draw\": 150}, {\"draws\": 750, \"mouse\": 4, \"mu_intercept_per_group\": 6.207504749298096, \"sigma_intercept_per_group\": 0.35212603211402893, \"sigma_obs\": 167.88424682617188, \"slope\": -0.08271978795528412, \"chain\": 3, \"draw\": 150}, {\"draws\": 750, \"mouse\": 5, \"mu_intercept_per_group\": 6.05642557144165, \"sigma_intercept_per_group\": 0.35212603211402893, \"sigma_obs\": 167.88424682617188, \"slope\": -0.08271978795528412, \"chain\": 3, \"draw\": 150}, {\"draws\": 750, \"mouse\": 6, \"mu_intercept_per_group\": 5.519259929656982, \"sigma_intercept_per_group\": 0.35212603211402893, \"sigma_obs\": 167.88424682617188, \"slope\": -0.08271978795528412, \"chain\": 3, \"draw\": 150}, {\"draws\": 750, \"mouse\": 7, \"mu_intercept_per_group\": 5.1180877685546875, \"sigma_intercept_per_group\": 0.35212603211402893, \"sigma_obs\": 167.88424682617188, \"slope\": -0.08271978795528412, \"chain\": 3, \"draw\": 150}, {\"draws\": 751, \"mouse\": 0, \"mu_intercept_per_group\": 8.95447063446045, \"sigma_intercept_per_group\": 0.28910666704177856, \"sigma_obs\": 174.42098999023438, \"slope\": -0.07790906727313995, \"chain\": 3, \"draw\": 151}, {\"draws\": 751, \"mouse\": 1, \"mu_intercept_per_group\": 8.534079551696777, \"sigma_intercept_per_group\": 0.28910666704177856, \"sigma_obs\": 174.42098999023438, \"slope\": -0.07790906727313995, \"chain\": 3, \"draw\": 151}, {\"draws\": 751, \"mouse\": 2, \"mu_intercept_per_group\": 8.469487190246582, \"sigma_intercept_per_group\": 0.28910666704177856, \"sigma_obs\": 174.42098999023438, \"slope\": -0.07790906727313995, \"chain\": 3, \"draw\": 151}, {\"draws\": 751, \"mouse\": 3, \"mu_intercept_per_group\": 7.860720634460449, \"sigma_intercept_per_group\": 0.28910666704177856, \"sigma_obs\": 174.42098999023438, \"slope\": -0.07790906727313995, \"chain\": 3, \"draw\": 151}, {\"draws\": 751, \"mouse\": 4, \"mu_intercept_per_group\": 7.628402233123779, \"sigma_intercept_per_group\": 0.28910666704177856, \"sigma_obs\": 174.42098999023438, \"slope\": -0.07790906727313995, \"chain\": 3, \"draw\": 151}, {\"draws\": 751, \"mouse\": 5, \"mu_intercept_per_group\": 7.42347526550293, \"sigma_intercept_per_group\": 0.28910666704177856, \"sigma_obs\": 174.42098999023438, \"slope\": -0.07790906727313995, \"chain\": 3, \"draw\": 151}, {\"draws\": 751, \"mouse\": 6, \"mu_intercept_per_group\": 6.8398237228393555, \"sigma_intercept_per_group\": 0.28910666704177856, \"sigma_obs\": 174.42098999023438, \"slope\": -0.07790906727313995, \"chain\": 3, \"draw\": 151}, {\"draws\": 751, \"mouse\": 7, \"mu_intercept_per_group\": 6.385215759277344, \"sigma_intercept_per_group\": 0.28910666704177856, \"sigma_obs\": 174.42098999023438, \"slope\": -0.07790906727313995, \"chain\": 3, \"draw\": 151}, {\"draws\": 752, \"mouse\": 0, \"mu_intercept_per_group\": 8.696884155273438, \"sigma_intercept_per_group\": 0.296613872051239, \"sigma_obs\": 175.48379516601562, \"slope\": -0.07782009989023209, \"chain\": 3, \"draw\": 152}, {\"draws\": 752, \"mouse\": 1, \"mu_intercept_per_group\": 8.416855812072754, \"sigma_intercept_per_group\": 0.296613872051239, \"sigma_obs\": 175.48379516601562, \"slope\": -0.07782009989023209, \"chain\": 3, \"draw\": 152}, {\"draws\": 752, \"mouse\": 2, \"mu_intercept_per_group\": 7.9968438148498535, \"sigma_intercept_per_group\": 0.296613872051239, \"sigma_obs\": 175.48379516601562, \"slope\": -0.07782009989023209, \"chain\": 3, \"draw\": 152}, {\"draws\": 752, \"mouse\": 3, \"mu_intercept_per_group\": 7.833317756652832, \"sigma_intercept_per_group\": 0.296613872051239, \"sigma_obs\": 175.48379516601562, \"slope\": -0.07782009989023209, \"chain\": 3, \"draw\": 152}, {\"draws\": 752, \"mouse\": 4, \"mu_intercept_per_group\": 7.3094282150268555, \"sigma_intercept_per_group\": 0.296613872051239, \"sigma_obs\": 175.48379516601562, \"slope\": -0.07782009989023209, \"chain\": 3, \"draw\": 152}, {\"draws\": 752, \"mouse\": 5, \"mu_intercept_per_group\": 7.209747314453125, \"sigma_intercept_per_group\": 0.296613872051239, \"sigma_obs\": 175.48379516601562, \"slope\": -0.07782009989023209, \"chain\": 3, \"draw\": 152}, {\"draws\": 752, \"mouse\": 6, \"mu_intercept_per_group\": 6.644129753112793, \"sigma_intercept_per_group\": 0.296613872051239, \"sigma_obs\": 175.48379516601562, \"slope\": -0.07782009989023209, \"chain\": 3, \"draw\": 152}, {\"draws\": 752, \"mouse\": 7, \"mu_intercept_per_group\": 6.260532855987549, \"sigma_intercept_per_group\": 0.296613872051239, \"sigma_obs\": 175.48379516601562, \"slope\": -0.07782009989023209, \"chain\": 3, \"draw\": 152}, {\"draws\": 753, \"mouse\": 0, \"mu_intercept_per_group\": 10.429190635681152, \"sigma_intercept_per_group\": 0.24732372164726257, \"sigma_obs\": 176.8361053466797, \"slope\": -0.07715542614459991, \"chain\": 3, \"draw\": 153}, {\"draws\": 753, \"mouse\": 1, \"mu_intercept_per_group\": 10.045726776123047, \"sigma_intercept_per_group\": 0.24732372164726257, \"sigma_obs\": 176.8361053466797, \"slope\": -0.07715542614459991, \"chain\": 3, \"draw\": 153}, {\"draws\": 753, \"mouse\": 2, \"mu_intercept_per_group\": 9.955056190490723, \"sigma_intercept_per_group\": 0.24732372164726257, \"sigma_obs\": 176.8361053466797, \"slope\": -0.07715542614459991, \"chain\": 3, \"draw\": 153}, {\"draws\": 753, \"mouse\": 3, \"mu_intercept_per_group\": 9.282022476196289, \"sigma_intercept_per_group\": 0.24732372164726257, \"sigma_obs\": 176.8361053466797, \"slope\": -0.07715542614459991, \"chain\": 3, \"draw\": 153}, {\"draws\": 753, \"mouse\": 4, \"mu_intercept_per_group\": 8.838380813598633, \"sigma_intercept_per_group\": 0.24732372164726257, \"sigma_obs\": 176.8361053466797, \"slope\": -0.07715542614459991, \"chain\": 3, \"draw\": 153}, {\"draws\": 753, \"mouse\": 5, \"mu_intercept_per_group\": 8.502042770385742, \"sigma_intercept_per_group\": 0.24732372164726257, \"sigma_obs\": 176.8361053466797, \"slope\": -0.07715542614459991, \"chain\": 3, \"draw\": 153}, {\"draws\": 753, \"mouse\": 6, \"mu_intercept_per_group\": 8.16986083984375, \"sigma_intercept_per_group\": 0.24732372164726257, \"sigma_obs\": 176.8361053466797, \"slope\": -0.07715542614459991, \"chain\": 3, \"draw\": 153}, {\"draws\": 753, \"mouse\": 7, \"mu_intercept_per_group\": 7.784532070159912, \"sigma_intercept_per_group\": 0.24732372164726257, \"sigma_obs\": 176.8361053466797, \"slope\": -0.07715542614459991, \"chain\": 3, \"draw\": 153}, {\"draws\": 754, \"mouse\": 0, \"mu_intercept_per_group\": 10.729949951171875, \"sigma_intercept_per_group\": 0.23940381407737732, \"sigma_obs\": 176.29660034179688, \"slope\": -0.07441600412130356, \"chain\": 3, \"draw\": 154}, {\"draws\": 754, \"mouse\": 1, \"mu_intercept_per_group\": 10.265931129455566, \"sigma_intercept_per_group\": 0.23940381407737732, \"sigma_obs\": 176.29660034179688, \"slope\": -0.07441600412130356, \"chain\": 3, \"draw\": 154}, {\"draws\": 754, \"mouse\": 2, \"mu_intercept_per_group\": 10.015290260314941, \"sigma_intercept_per_group\": 0.23940381407737732, \"sigma_obs\": 176.29660034179688, \"slope\": -0.07441600412130356, \"chain\": 3, \"draw\": 154}, {\"draws\": 754, \"mouse\": 3, \"mu_intercept_per_group\": 9.748359680175781, \"sigma_intercept_per_group\": 0.23940381407737732, \"sigma_obs\": 176.29660034179688, \"slope\": -0.07441600412130356, \"chain\": 3, \"draw\": 154}, {\"draws\": 754, \"mouse\": 4, \"mu_intercept_per_group\": 9.465306282043457, \"sigma_intercept_per_group\": 0.23940381407737732, \"sigma_obs\": 176.29660034179688, \"slope\": -0.07441600412130356, \"chain\": 3, \"draw\": 154}, {\"draws\": 754, \"mouse\": 5, \"mu_intercept_per_group\": 8.631708145141602, \"sigma_intercept_per_group\": 0.23940381407737732, \"sigma_obs\": 176.29660034179688, \"slope\": -0.07441600412130356, \"chain\": 3, \"draw\": 154}, {\"draws\": 754, \"mouse\": 6, \"mu_intercept_per_group\": 7.892673492431641, \"sigma_intercept_per_group\": 0.23940381407737732, \"sigma_obs\": 176.29660034179688, \"slope\": -0.07441600412130356, \"chain\": 3, \"draw\": 154}, {\"draws\": 754, \"mouse\": 7, \"mu_intercept_per_group\": 7.631791591644287, \"sigma_intercept_per_group\": 0.23940381407737732, \"sigma_obs\": 176.29660034179688, \"slope\": -0.07441600412130356, \"chain\": 3, \"draw\": 154}, {\"draws\": 755, \"mouse\": 0, \"mu_intercept_per_group\": 10.73957347869873, \"sigma_intercept_per_group\": 0.2381337434053421, \"sigma_obs\": 176.03720092773438, \"slope\": -0.07460050284862518, \"chain\": 3, \"draw\": 155}, {\"draws\": 755, \"mouse\": 1, \"mu_intercept_per_group\": 10.341443061828613, \"sigma_intercept_per_group\": 0.2381337434053421, \"sigma_obs\": 176.03720092773438, \"slope\": -0.07460050284862518, \"chain\": 3, \"draw\": 155}, {\"draws\": 755, \"mouse\": 2, \"mu_intercept_per_group\": 9.914772033691406, \"sigma_intercept_per_group\": 0.2381337434053421, \"sigma_obs\": 176.03720092773438, \"slope\": -0.07460050284862518, \"chain\": 3, \"draw\": 155}, {\"draws\": 755, \"mouse\": 3, \"mu_intercept_per_group\": 9.7114896774292, \"sigma_intercept_per_group\": 0.2381337434053421, \"sigma_obs\": 176.03720092773438, \"slope\": -0.07460050284862518, \"chain\": 3, \"draw\": 155}, {\"draws\": 755, \"mouse\": 4, \"mu_intercept_per_group\": 9.53067398071289, \"sigma_intercept_per_group\": 0.2381337434053421, \"sigma_obs\": 176.03720092773438, \"slope\": -0.07460050284862518, \"chain\": 3, \"draw\": 155}, {\"draws\": 755, \"mouse\": 5, \"mu_intercept_per_group\": 8.669208526611328, \"sigma_intercept_per_group\": 0.2381337434053421, \"sigma_obs\": 176.03720092773438, \"slope\": -0.07460050284862518, \"chain\": 3, \"draw\": 155}, {\"draws\": 755, \"mouse\": 6, \"mu_intercept_per_group\": 7.830944061279297, \"sigma_intercept_per_group\": 0.2381337434053421, \"sigma_obs\": 176.03720092773438, \"slope\": -0.07460050284862518, \"chain\": 3, \"draw\": 155}, {\"draws\": 755, \"mouse\": 7, \"mu_intercept_per_group\": 7.653232097625732, \"sigma_intercept_per_group\": 0.2381337434053421, \"sigma_obs\": 176.03720092773438, \"slope\": -0.07460050284862518, \"chain\": 3, \"draw\": 155}, {\"draws\": 756, \"mouse\": 0, \"mu_intercept_per_group\": 10.370792388916016, \"sigma_intercept_per_group\": 0.2434636950492859, \"sigma_obs\": 175.80633544921875, \"slope\": -0.07437384873628616, \"chain\": 3, \"draw\": 156}, {\"draws\": 756, \"mouse\": 1, \"mu_intercept_per_group\": 9.996367454528809, \"sigma_intercept_per_group\": 0.2434636950492859, \"sigma_obs\": 175.80633544921875, \"slope\": -0.07437384873628616, \"chain\": 3, \"draw\": 156}, {\"draws\": 756, \"mouse\": 2, \"mu_intercept_per_group\": 10.011815071105957, \"sigma_intercept_per_group\": 0.2434636950492859, \"sigma_obs\": 175.80633544921875, \"slope\": -0.07437384873628616, \"chain\": 3, \"draw\": 156}, {\"draws\": 756, \"mouse\": 3, \"mu_intercept_per_group\": 9.180243492126465, \"sigma_intercept_per_group\": 0.2434636950492859, \"sigma_obs\": 175.80633544921875, \"slope\": -0.07437384873628616, \"chain\": 3, \"draw\": 156}, {\"draws\": 756, \"mouse\": 4, \"mu_intercept_per_group\": 8.840656280517578, \"sigma_intercept_per_group\": 0.2434636950492859, \"sigma_obs\": 175.80633544921875, \"slope\": -0.07437384873628616, \"chain\": 3, \"draw\": 156}, {\"draws\": 756, \"mouse\": 5, \"mu_intercept_per_group\": 9.068881034851074, \"sigma_intercept_per_group\": 0.2434636950492859, \"sigma_obs\": 175.80633544921875, \"slope\": -0.07437384873628616, \"chain\": 3, \"draw\": 156}, {\"draws\": 756, \"mouse\": 6, \"mu_intercept_per_group\": 7.808448791503906, \"sigma_intercept_per_group\": 0.2434636950492859, \"sigma_obs\": 175.80633544921875, \"slope\": -0.07437384873628616, \"chain\": 3, \"draw\": 156}, {\"draws\": 756, \"mouse\": 7, \"mu_intercept_per_group\": 7.909493446350098, \"sigma_intercept_per_group\": 0.2434636950492859, \"sigma_obs\": 175.80633544921875, \"slope\": -0.07437384873628616, \"chain\": 3, \"draw\": 156}, {\"draws\": 757, \"mouse\": 0, \"mu_intercept_per_group\": 10.915848731994629, \"sigma_intercept_per_group\": 0.23522241413593292, \"sigma_obs\": 176.44679260253906, \"slope\": -0.0727422907948494, \"chain\": 3, \"draw\": 157}, {\"draws\": 757, \"mouse\": 1, \"mu_intercept_per_group\": 10.473926544189453, \"sigma_intercept_per_group\": 0.23522241413593292, \"sigma_obs\": 176.44679260253906, \"slope\": -0.0727422907948494, \"chain\": 3, \"draw\": 157}, {\"draws\": 757, \"mouse\": 2, \"mu_intercept_per_group\": 10.202028274536133, \"sigma_intercept_per_group\": 0.23522241413593292, \"sigma_obs\": 176.44679260253906, \"slope\": -0.0727422907948494, \"chain\": 3, \"draw\": 157}, {\"draws\": 757, \"mouse\": 3, \"mu_intercept_per_group\": 9.747058868408203, \"sigma_intercept_per_group\": 0.23522241413593292, \"sigma_obs\": 176.44679260253906, \"slope\": -0.0727422907948494, \"chain\": 3, \"draw\": 157}, {\"draws\": 757, \"mouse\": 4, \"mu_intercept_per_group\": 9.73896598815918, \"sigma_intercept_per_group\": 0.23522241413593292, \"sigma_obs\": 176.44679260253906, \"slope\": -0.0727422907948494, \"chain\": 3, \"draw\": 157}, {\"draws\": 757, \"mouse\": 5, \"mu_intercept_per_group\": 8.41452693939209, \"sigma_intercept_per_group\": 0.23522241413593292, \"sigma_obs\": 176.44679260253906, \"slope\": -0.0727422907948494, \"chain\": 3, \"draw\": 157}, {\"draws\": 757, \"mouse\": 6, \"mu_intercept_per_group\": 8.59951400756836, \"sigma_intercept_per_group\": 0.23522241413593292, \"sigma_obs\": 176.44679260253906, \"slope\": -0.0727422907948494, \"chain\": 3, \"draw\": 157}, {\"draws\": 757, \"mouse\": 7, \"mu_intercept_per_group\": 7.705958366394043, \"sigma_intercept_per_group\": 0.23522241413593292, \"sigma_obs\": 176.44679260253906, \"slope\": -0.0727422907948494, \"chain\": 3, \"draw\": 157}, {\"draws\": 758, \"mouse\": 0, \"mu_intercept_per_group\": 10.762299537658691, \"sigma_intercept_per_group\": 0.2380019724369049, \"sigma_obs\": 176.9068603515625, \"slope\": -0.07355130463838577, \"chain\": 3, \"draw\": 158}, {\"draws\": 758, \"mouse\": 1, \"mu_intercept_per_group\": 10.511747360229492, \"sigma_intercept_per_group\": 0.2380019724369049, \"sigma_obs\": 176.9068603515625, \"slope\": -0.07355130463838577, \"chain\": 3, \"draw\": 158}, {\"draws\": 758, \"mouse\": 2, \"mu_intercept_per_group\": 10.123562812805176, \"sigma_intercept_per_group\": 0.2380019724369049, \"sigma_obs\": 176.9068603515625, \"slope\": -0.07355130463838577, \"chain\": 3, \"draw\": 158}, {\"draws\": 758, \"mouse\": 3, \"mu_intercept_per_group\": 9.535950660705566, \"sigma_intercept_per_group\": 0.2380019724369049, \"sigma_obs\": 176.9068603515625, \"slope\": -0.07355130463838577, \"chain\": 3, \"draw\": 158}, {\"draws\": 758, \"mouse\": 4, \"mu_intercept_per_group\": 8.992022514343262, \"sigma_intercept_per_group\": 0.2380019724369049, \"sigma_obs\": 176.9068603515625, \"slope\": -0.07355130463838577, \"chain\": 3, \"draw\": 158}, {\"draws\": 758, \"mouse\": 5, \"mu_intercept_per_group\": 9.275135040283203, \"sigma_intercept_per_group\": 0.2380019724369049, \"sigma_obs\": 176.9068603515625, \"slope\": -0.07355130463838577, \"chain\": 3, \"draw\": 158}, {\"draws\": 758, \"mouse\": 6, \"mu_intercept_per_group\": 8.139825820922852, \"sigma_intercept_per_group\": 0.2380019724369049, \"sigma_obs\": 176.9068603515625, \"slope\": -0.07355130463838577, \"chain\": 3, \"draw\": 158}, {\"draws\": 758, \"mouse\": 7, \"mu_intercept_per_group\": 7.993486404418945, \"sigma_intercept_per_group\": 0.2380019724369049, \"sigma_obs\": 176.9068603515625, \"slope\": -0.07355130463838577, \"chain\": 3, \"draw\": 158}, {\"draws\": 759, \"mouse\": 0, \"mu_intercept_per_group\": 12.657690048217773, \"sigma_intercept_per_group\": 0.19180896878242493, \"sigma_obs\": 158.80734252929688, \"slope\": -0.0478978268802166, \"chain\": 3, \"draw\": 159}, {\"draws\": 759, \"mouse\": 1, \"mu_intercept_per_group\": 12.089020729064941, \"sigma_intercept_per_group\": 0.19180896878242493, \"sigma_obs\": 158.80734252929688, \"slope\": -0.0478978268802166, \"chain\": 3, \"draw\": 159}, {\"draws\": 759, \"mouse\": 2, \"mu_intercept_per_group\": 12.07634449005127, \"sigma_intercept_per_group\": 0.19180896878242493, \"sigma_obs\": 158.80734252929688, \"slope\": -0.0478978268802166, \"chain\": 3, \"draw\": 159}, {\"draws\": 759, \"mouse\": 3, \"mu_intercept_per_group\": 11.097119331359863, \"sigma_intercept_per_group\": 0.19180896878242493, \"sigma_obs\": 158.80734252929688, \"slope\": -0.0478978268802166, \"chain\": 3, \"draw\": 159}, {\"draws\": 759, \"mouse\": 4, \"mu_intercept_per_group\": 11.00284481048584, \"sigma_intercept_per_group\": 0.19180896878242493, \"sigma_obs\": 158.80734252929688, \"slope\": -0.0478978268802166, \"chain\": 3, \"draw\": 159}, {\"draws\": 759, \"mouse\": 5, \"mu_intercept_per_group\": 10.229061126708984, \"sigma_intercept_per_group\": 0.19180896878242493, \"sigma_obs\": 158.80734252929688, \"slope\": -0.0478978268802166, \"chain\": 3, \"draw\": 159}, {\"draws\": 759, \"mouse\": 6, \"mu_intercept_per_group\": 9.18822956085205, \"sigma_intercept_per_group\": 0.19180896878242493, \"sigma_obs\": 158.80734252929688, \"slope\": -0.0478978268802166, \"chain\": 3, \"draw\": 159}, {\"draws\": 759, \"mouse\": 7, \"mu_intercept_per_group\": 8.932744026184082, \"sigma_intercept_per_group\": 0.19180896878242493, \"sigma_obs\": 158.80734252929688, \"slope\": -0.0478978268802166, \"chain\": 3, \"draw\": 159}, {\"draws\": 760, \"mouse\": 0, \"mu_intercept_per_group\": 11.600404739379883, \"sigma_intercept_per_group\": 0.21699045598506927, \"sigma_obs\": 166.65301513671875, \"slope\": -0.05284504592418671, \"chain\": 3, \"draw\": 160}, {\"draws\": 760, \"mouse\": 1, \"mu_intercept_per_group\": 11.032018661499023, \"sigma_intercept_per_group\": 0.21699045598506927, \"sigma_obs\": 166.65301513671875, \"slope\": -0.05284504592418671, \"chain\": 3, \"draw\": 160}, {\"draws\": 760, \"mouse\": 2, \"mu_intercept_per_group\": 10.831950187683105, \"sigma_intercept_per_group\": 0.21699045598506927, \"sigma_obs\": 166.65301513671875, \"slope\": -0.05284504592418671, \"chain\": 3, \"draw\": 160}, {\"draws\": 760, \"mouse\": 3, \"mu_intercept_per_group\": 10.130634307861328, \"sigma_intercept_per_group\": 0.21699045598506927, \"sigma_obs\": 166.65301513671875, \"slope\": -0.05284504592418671, \"chain\": 3, \"draw\": 160}, {\"draws\": 760, \"mouse\": 4, \"mu_intercept_per_group\": 9.747709274291992, \"sigma_intercept_per_group\": 0.21699045598506927, \"sigma_obs\": 166.65301513671875, \"slope\": -0.05284504592418671, \"chain\": 3, \"draw\": 160}, {\"draws\": 760, \"mouse\": 5, \"mu_intercept_per_group\": 9.399882316589355, \"sigma_intercept_per_group\": 0.21699045598506927, \"sigma_obs\": 166.65301513671875, \"slope\": -0.05284504592418671, \"chain\": 3, \"draw\": 160}, {\"draws\": 760, \"mouse\": 6, \"mu_intercept_per_group\": 8.400920867919922, \"sigma_intercept_per_group\": 0.21699045598506927, \"sigma_obs\": 166.65301513671875, \"slope\": -0.05284504592418671, \"chain\": 3, \"draw\": 160}, {\"draws\": 760, \"mouse\": 7, \"mu_intercept_per_group\": 8.215264320373535, \"sigma_intercept_per_group\": 0.21699045598506927, \"sigma_obs\": 166.65301513671875, \"slope\": -0.05284504592418671, \"chain\": 3, \"draw\": 160}, {\"draws\": 761, \"mouse\": 0, \"mu_intercept_per_group\": 11.270872116088867, \"sigma_intercept_per_group\": 0.21801599860191345, \"sigma_obs\": 165.4142303466797, \"slope\": -0.05187979340553284, \"chain\": 3, \"draw\": 161}, {\"draws\": 761, \"mouse\": 1, \"mu_intercept_per_group\": 10.982641220092773, \"sigma_intercept_per_group\": 0.21801599860191345, \"sigma_obs\": 165.4142303466797, \"slope\": -0.05187979340553284, \"chain\": 3, \"draw\": 161}, {\"draws\": 761, \"mouse\": 2, \"mu_intercept_per_group\": 10.57148265838623, \"sigma_intercept_per_group\": 0.21801599860191345, \"sigma_obs\": 165.4142303466797, \"slope\": -0.05187979340553284, \"chain\": 3, \"draw\": 161}, {\"draws\": 761, \"mouse\": 3, \"mu_intercept_per_group\": 10.06497573852539, \"sigma_intercept_per_group\": 0.21801599860191345, \"sigma_obs\": 165.4142303466797, \"slope\": -0.05187979340553284, \"chain\": 3, \"draw\": 161}, {\"draws\": 761, \"mouse\": 4, \"mu_intercept_per_group\": 9.985152244567871, \"sigma_intercept_per_group\": 0.21801599860191345, \"sigma_obs\": 165.4142303466797, \"slope\": -0.05187979340553284, \"chain\": 3, \"draw\": 161}, {\"draws\": 761, \"mouse\": 5, \"mu_intercept_per_group\": 9.280248641967773, \"sigma_intercept_per_group\": 0.21801599860191345, \"sigma_obs\": 165.4142303466797, \"slope\": -0.05187979340553284, \"chain\": 3, \"draw\": 161}, {\"draws\": 761, \"mouse\": 6, \"mu_intercept_per_group\": 8.557171821594238, \"sigma_intercept_per_group\": 0.21801599860191345, \"sigma_obs\": 165.4142303466797, \"slope\": -0.05187979340553284, \"chain\": 3, \"draw\": 161}, {\"draws\": 761, \"mouse\": 7, \"mu_intercept_per_group\": 8.102675437927246, \"sigma_intercept_per_group\": 0.21801599860191345, \"sigma_obs\": 165.4142303466797, \"slope\": -0.05187979340553284, \"chain\": 3, \"draw\": 161}, {\"draws\": 762, \"mouse\": 0, \"mu_intercept_per_group\": 11.402796745300293, \"sigma_intercept_per_group\": 0.21611206233501434, \"sigma_obs\": 163.44601440429688, \"slope\": -0.05600818991661072, \"chain\": 3, \"draw\": 162}, {\"draws\": 762, \"mouse\": 1, \"mu_intercept_per_group\": 11.256052017211914, \"sigma_intercept_per_group\": 0.21611206233501434, \"sigma_obs\": 163.44601440429688, \"slope\": -0.05600818991661072, \"chain\": 3, \"draw\": 162}, {\"draws\": 762, \"mouse\": 2, \"mu_intercept_per_group\": 10.648415565490723, \"sigma_intercept_per_group\": 0.21611206233501434, \"sigma_obs\": 163.44601440429688, \"slope\": -0.05600818991661072, \"chain\": 3, \"draw\": 162}, {\"draws\": 762, \"mouse\": 3, \"mu_intercept_per_group\": 10.112022399902344, \"sigma_intercept_per_group\": 0.21611206233501434, \"sigma_obs\": 163.44601440429688, \"slope\": -0.05600818991661072, \"chain\": 3, \"draw\": 162}, {\"draws\": 762, \"mouse\": 4, \"mu_intercept_per_group\": 9.53541374206543, \"sigma_intercept_per_group\": 0.21611206233501434, \"sigma_obs\": 163.44601440429688, \"slope\": -0.05600818991661072, \"chain\": 3, \"draw\": 162}, {\"draws\": 762, \"mouse\": 5, \"mu_intercept_per_group\": 9.200285911560059, \"sigma_intercept_per_group\": 0.21611206233501434, \"sigma_obs\": 163.44601440429688, \"slope\": -0.05600818991661072, \"chain\": 3, \"draw\": 162}, {\"draws\": 762, \"mouse\": 6, \"mu_intercept_per_group\": 8.82563591003418, \"sigma_intercept_per_group\": 0.21611206233501434, \"sigma_obs\": 163.44601440429688, \"slope\": -0.05600818991661072, \"chain\": 3, \"draw\": 162}, {\"draws\": 762, \"mouse\": 7, \"mu_intercept_per_group\": 8.31286334991455, \"sigma_intercept_per_group\": 0.21611206233501434, \"sigma_obs\": 163.44601440429688, \"slope\": -0.05600818991661072, \"chain\": 3, \"draw\": 162}, {\"draws\": 763, \"mouse\": 0, \"mu_intercept_per_group\": 11.571456909179688, \"sigma_intercept_per_group\": 0.21250608563423157, \"sigma_obs\": 160.40786743164062, \"slope\": -0.05926164239645004, \"chain\": 3, \"draw\": 163}, {\"draws\": 763, \"mouse\": 1, \"mu_intercept_per_group\": 11.31467342376709, \"sigma_intercept_per_group\": 0.21250608563423157, \"sigma_obs\": 160.40786743164062, \"slope\": -0.05926164239645004, \"chain\": 3, \"draw\": 163}, {\"draws\": 763, \"mouse\": 2, \"mu_intercept_per_group\": 10.731243133544922, \"sigma_intercept_per_group\": 0.21250608563423157, \"sigma_obs\": 160.40786743164062, \"slope\": -0.05926164239645004, \"chain\": 3, \"draw\": 163}, {\"draws\": 763, \"mouse\": 3, \"mu_intercept_per_group\": 10.582756042480469, \"sigma_intercept_per_group\": 0.21250608563423157, \"sigma_obs\": 160.40786743164062, \"slope\": -0.05926164239645004, \"chain\": 3, \"draw\": 163}, {\"draws\": 763, \"mouse\": 4, \"mu_intercept_per_group\": 9.896758079528809, \"sigma_intercept_per_group\": 0.21250608563423157, \"sigma_obs\": 160.40786743164062, \"slope\": -0.05926164239645004, \"chain\": 3, \"draw\": 163}, {\"draws\": 763, \"mouse\": 5, \"mu_intercept_per_group\": 9.24056339263916, \"sigma_intercept_per_group\": 0.21250608563423157, \"sigma_obs\": 160.40786743164062, \"slope\": -0.05926164239645004, \"chain\": 3, \"draw\": 163}, {\"draws\": 763, \"mouse\": 6, \"mu_intercept_per_group\": 8.618664741516113, \"sigma_intercept_per_group\": 0.21250608563423157, \"sigma_obs\": 160.40786743164062, \"slope\": -0.05926164239645004, \"chain\": 3, \"draw\": 163}, {\"draws\": 763, \"mouse\": 7, \"mu_intercept_per_group\": 8.255875587463379, \"sigma_intercept_per_group\": 0.21250608563423157, \"sigma_obs\": 160.40786743164062, \"slope\": -0.05926164239645004, \"chain\": 3, \"draw\": 163}, {\"draws\": 764, \"mouse\": 0, \"mu_intercept_per_group\": 11.715466499328613, \"sigma_intercept_per_group\": 0.2111777663230896, \"sigma_obs\": 161.11355590820312, \"slope\": -0.06108834594488144, \"chain\": 3, \"draw\": 164}, {\"draws\": 764, \"mouse\": 1, \"mu_intercept_per_group\": 11.16947078704834, \"sigma_intercept_per_group\": 0.2111777663230896, \"sigma_obs\": 161.11355590820312, \"slope\": -0.06108834594488144, \"chain\": 3, \"draw\": 164}, {\"draws\": 764, \"mouse\": 2, \"mu_intercept_per_group\": 11.139195442199707, \"sigma_intercept_per_group\": 0.2111777663230896, \"sigma_obs\": 161.11355590820312, \"slope\": -0.06108834594488144, \"chain\": 3, \"draw\": 164}, {\"draws\": 764, \"mouse\": 3, \"mu_intercept_per_group\": 10.041115760803223, \"sigma_intercept_per_group\": 0.2111777663230896, \"sigma_obs\": 161.11355590820312, \"slope\": -0.06108834594488144, \"chain\": 3, \"draw\": 164}, {\"draws\": 764, \"mouse\": 4, \"mu_intercept_per_group\": 10.024396896362305, \"sigma_intercept_per_group\": 0.2111777663230896, \"sigma_obs\": 161.11355590820312, \"slope\": -0.06108834594488144, \"chain\": 3, \"draw\": 164}, {\"draws\": 764, \"mouse\": 5, \"mu_intercept_per_group\": 9.684070587158203, \"sigma_intercept_per_group\": 0.2111777663230896, \"sigma_obs\": 161.11355590820312, \"slope\": -0.06108834594488144, \"chain\": 3, \"draw\": 164}, {\"draws\": 764, \"mouse\": 6, \"mu_intercept_per_group\": 8.955487251281738, \"sigma_intercept_per_group\": 0.2111777663230896, \"sigma_obs\": 161.11355590820312, \"slope\": -0.06108834594488144, \"chain\": 3, \"draw\": 164}, {\"draws\": 764, \"mouse\": 7, \"mu_intercept_per_group\": 8.513140678405762, \"sigma_intercept_per_group\": 0.2111777663230896, \"sigma_obs\": 161.11355590820312, \"slope\": -0.06108834594488144, \"chain\": 3, \"draw\": 164}, {\"draws\": 765, \"mouse\": 0, \"mu_intercept_per_group\": 11.81451416015625, \"sigma_intercept_per_group\": 0.20854833722114563, \"sigma_obs\": 161.3738250732422, \"slope\": -0.06152849644422531, \"chain\": 3, \"draw\": 165}, {\"draws\": 765, \"mouse\": 1, \"mu_intercept_per_group\": 11.646134376525879, \"sigma_intercept_per_group\": 0.20854833722114563, \"sigma_obs\": 161.3738250732422, \"slope\": -0.06152849644422531, \"chain\": 3, \"draw\": 165}, {\"draws\": 765, \"mouse\": 2, \"mu_intercept_per_group\": 10.786036491394043, \"sigma_intercept_per_group\": 0.20854833722114563, \"sigma_obs\": 161.3738250732422, \"slope\": -0.06152849644422531, \"chain\": 3, \"draw\": 165}, {\"draws\": 765, \"mouse\": 3, \"mu_intercept_per_group\": 10.383417129516602, \"sigma_intercept_per_group\": 0.20854833722114563, \"sigma_obs\": 161.3738250732422, \"slope\": -0.06152849644422531, \"chain\": 3, \"draw\": 165}, {\"draws\": 765, \"mouse\": 4, \"mu_intercept_per_group\": 10.361141204833984, \"sigma_intercept_per_group\": 0.20854833722114563, \"sigma_obs\": 161.3738250732422, \"slope\": -0.06152849644422531, \"chain\": 3, \"draw\": 165}, {\"draws\": 765, \"mouse\": 5, \"mu_intercept_per_group\": 9.519373893737793, \"sigma_intercept_per_group\": 0.20854833722114563, \"sigma_obs\": 161.3738250732422, \"slope\": -0.06152849644422531, \"chain\": 3, \"draw\": 165}, {\"draws\": 765, \"mouse\": 6, \"mu_intercept_per_group\": 8.79110336303711, \"sigma_intercept_per_group\": 0.20854833722114563, \"sigma_obs\": 161.3738250732422, \"slope\": -0.06152849644422531, \"chain\": 3, \"draw\": 165}, {\"draws\": 765, \"mouse\": 7, \"mu_intercept_per_group\": 8.826194763183594, \"sigma_intercept_per_group\": 0.20854833722114563, \"sigma_obs\": 161.3738250732422, \"slope\": -0.06152849644422531, \"chain\": 3, \"draw\": 165}, {\"draws\": 766, \"mouse\": 0, \"mu_intercept_per_group\": 11.873067855834961, \"sigma_intercept_per_group\": 0.20455791056156158, \"sigma_obs\": 155.52230834960938, \"slope\": -0.06916404515504837, \"chain\": 3, \"draw\": 166}, {\"draws\": 766, \"mouse\": 1, \"mu_intercept_per_group\": 11.691819190979004, \"sigma_intercept_per_group\": 0.20455791056156158, \"sigma_obs\": 155.52230834960938, \"slope\": -0.06916404515504837, \"chain\": 3, \"draw\": 166}, {\"draws\": 766, \"mouse\": 2, \"mu_intercept_per_group\": 10.664663314819336, \"sigma_intercept_per_group\": 0.20455791056156158, \"sigma_obs\": 155.52230834960938, \"slope\": -0.06916404515504837, \"chain\": 3, \"draw\": 166}, {\"draws\": 766, \"mouse\": 3, \"mu_intercept_per_group\": 10.571410179138184, \"sigma_intercept_per_group\": 0.20455791056156158, \"sigma_obs\": 155.52230834960938, \"slope\": -0.06916404515504837, \"chain\": 3, \"draw\": 166}, {\"draws\": 766, \"mouse\": 4, \"mu_intercept_per_group\": 10.469170570373535, \"sigma_intercept_per_group\": 0.20455791056156158, \"sigma_obs\": 155.52230834960938, \"slope\": -0.06916404515504837, \"chain\": 3, \"draw\": 166}, {\"draws\": 766, \"mouse\": 5, \"mu_intercept_per_group\": 9.941133499145508, \"sigma_intercept_per_group\": 0.20455791056156158, \"sigma_obs\": 155.52230834960938, \"slope\": -0.06916404515504837, \"chain\": 3, \"draw\": 166}, {\"draws\": 766, \"mouse\": 6, \"mu_intercept_per_group\": 9.187856674194336, \"sigma_intercept_per_group\": 0.20455791056156158, \"sigma_obs\": 155.52230834960938, \"slope\": -0.06916404515504837, \"chain\": 3, \"draw\": 166}, {\"draws\": 766, \"mouse\": 7, \"mu_intercept_per_group\": 8.369572639465332, \"sigma_intercept_per_group\": 0.20455791056156158, \"sigma_obs\": 155.52230834960938, \"slope\": -0.06916404515504837, \"chain\": 3, \"draw\": 166}, {\"draws\": 767, \"mouse\": 0, \"mu_intercept_per_group\": 12.340476989746094, \"sigma_intercept_per_group\": 0.2022404670715332, \"sigma_obs\": 155.24778747558594, \"slope\": -0.07026156783103943, \"chain\": 3, \"draw\": 167}, {\"draws\": 767, \"mouse\": 1, \"mu_intercept_per_group\": 11.532817840576172, \"sigma_intercept_per_group\": 0.2022404670715332, \"sigma_obs\": 155.24778747558594, \"slope\": -0.07026156783103943, \"chain\": 3, \"draw\": 167}, {\"draws\": 767, \"mouse\": 2, \"mu_intercept_per_group\": 11.556739807128906, \"sigma_intercept_per_group\": 0.2022404670715332, \"sigma_obs\": 155.24778747558594, \"slope\": -0.07026156783103943, \"chain\": 3, \"draw\": 167}, {\"draws\": 767, \"mouse\": 3, \"mu_intercept_per_group\": 10.381568908691406, \"sigma_intercept_per_group\": 0.2022404670715332, \"sigma_obs\": 155.24778747558594, \"slope\": -0.07026156783103943, \"chain\": 3, \"draw\": 167}, {\"draws\": 767, \"mouse\": 4, \"mu_intercept_per_group\": 10.401261329650879, \"sigma_intercept_per_group\": 0.2022404670715332, \"sigma_obs\": 155.24778747558594, \"slope\": -0.07026156783103943, \"chain\": 3, \"draw\": 167}, {\"draws\": 767, \"mouse\": 5, \"mu_intercept_per_group\": 9.684311866760254, \"sigma_intercept_per_group\": 0.2022404670715332, \"sigma_obs\": 155.24778747558594, \"slope\": -0.07026156783103943, \"chain\": 3, \"draw\": 167}, {\"draws\": 767, \"mouse\": 6, \"mu_intercept_per_group\": 9.281103134155273, \"sigma_intercept_per_group\": 0.2022404670715332, \"sigma_obs\": 155.24778747558594, \"slope\": -0.07026156783103943, \"chain\": 3, \"draw\": 167}, {\"draws\": 767, \"mouse\": 7, \"mu_intercept_per_group\": 8.939600944519043, \"sigma_intercept_per_group\": 0.2022404670715332, \"sigma_obs\": 155.24778747558594, \"slope\": -0.07026156783103943, \"chain\": 3, \"draw\": 167}, {\"draws\": 768, \"mouse\": 0, \"mu_intercept_per_group\": 12.07421588897705, \"sigma_intercept_per_group\": 0.20299223065376282, \"sigma_obs\": 155.3294677734375, \"slope\": -0.07097478210926056, \"chain\": 3, \"draw\": 168}, {\"draws\": 768, \"mouse\": 1, \"mu_intercept_per_group\": 11.590912818908691, \"sigma_intercept_per_group\": 0.20299223065376282, \"sigma_obs\": 155.3294677734375, \"slope\": -0.07097478210926056, \"chain\": 3, \"draw\": 168}, {\"draws\": 768, \"mouse\": 2, \"mu_intercept_per_group\": 11.201417922973633, \"sigma_intercept_per_group\": 0.20299223065376282, \"sigma_obs\": 155.3294677734375, \"slope\": -0.07097478210926056, \"chain\": 3, \"draw\": 168}, {\"draws\": 768, \"mouse\": 3, \"mu_intercept_per_group\": 10.2747163772583, \"sigma_intercept_per_group\": 0.20299223065376282, \"sigma_obs\": 155.3294677734375, \"slope\": -0.07097478210926056, \"chain\": 3, \"draw\": 168}, {\"draws\": 768, \"mouse\": 4, \"mu_intercept_per_group\": 10.529412269592285, \"sigma_intercept_per_group\": 0.20299223065376282, \"sigma_obs\": 155.3294677734375, \"slope\": -0.07097478210926056, \"chain\": 3, \"draw\": 168}, {\"draws\": 768, \"mouse\": 5, \"mu_intercept_per_group\": 9.749241828918457, \"sigma_intercept_per_group\": 0.20299223065376282, \"sigma_obs\": 155.3294677734375, \"slope\": -0.07097478210926056, \"chain\": 3, \"draw\": 168}, {\"draws\": 768, \"mouse\": 6, \"mu_intercept_per_group\": 9.149262428283691, \"sigma_intercept_per_group\": 0.20299223065376282, \"sigma_obs\": 155.3294677734375, \"slope\": -0.07097478210926056, \"chain\": 3, \"draw\": 168}, {\"draws\": 768, \"mouse\": 7, \"mu_intercept_per_group\": 8.869793891906738, \"sigma_intercept_per_group\": 0.20299223065376282, \"sigma_obs\": 155.3294677734375, \"slope\": -0.07097478210926056, \"chain\": 3, \"draw\": 168}, {\"draws\": 769, \"mouse\": 0, \"mu_intercept_per_group\": 12.769002914428711, \"sigma_intercept_per_group\": 0.19269198179244995, \"sigma_obs\": 157.77525329589844, \"slope\": -0.055016208440065384, \"chain\": 3, \"draw\": 169}, {\"draws\": 769, \"mouse\": 1, \"mu_intercept_per_group\": 12.011289596557617, \"sigma_intercept_per_group\": 0.19269198179244995, \"sigma_obs\": 157.77525329589844, \"slope\": -0.055016208440065384, \"chain\": 3, \"draw\": 169}, {\"draws\": 769, \"mouse\": 2, \"mu_intercept_per_group\": 11.94405746459961, \"sigma_intercept_per_group\": 0.19269198179244995, \"sigma_obs\": 157.77525329589844, \"slope\": -0.055016208440065384, \"chain\": 3, \"draw\": 169}, {\"draws\": 769, \"mouse\": 3, \"mu_intercept_per_group\": 10.948301315307617, \"sigma_intercept_per_group\": 0.19269198179244995, \"sigma_obs\": 157.77525329589844, \"slope\": -0.055016208440065384, \"chain\": 3, \"draw\": 169}, {\"draws\": 769, \"mouse\": 4, \"mu_intercept_per_group\": 11.280792236328125, \"sigma_intercept_per_group\": 0.19269198179244995, \"sigma_obs\": 157.77525329589844, \"slope\": -0.055016208440065384, \"chain\": 3, \"draw\": 169}, {\"draws\": 769, \"mouse\": 5, \"mu_intercept_per_group\": 10.460577011108398, \"sigma_intercept_per_group\": 0.19269198179244995, \"sigma_obs\": 157.77525329589844, \"slope\": -0.055016208440065384, \"chain\": 3, \"draw\": 169}, {\"draws\": 769, \"mouse\": 6, \"mu_intercept_per_group\": 9.479144096374512, \"sigma_intercept_per_group\": 0.19269198179244995, \"sigma_obs\": 157.77525329589844, \"slope\": -0.055016208440065384, \"chain\": 3, \"draw\": 169}, {\"draws\": 769, \"mouse\": 7, \"mu_intercept_per_group\": 8.963424682617188, \"sigma_intercept_per_group\": 0.19269198179244995, \"sigma_obs\": 157.77525329589844, \"slope\": -0.055016208440065384, \"chain\": 3, \"draw\": 169}, {\"draws\": 770, \"mouse\": 0, \"mu_intercept_per_group\": 12.456975936889648, \"sigma_intercept_per_group\": 0.19588609039783478, \"sigma_obs\": 155.5713348388672, \"slope\": -0.08269758522510529, \"chain\": 3, \"draw\": 170}, {\"draws\": 770, \"mouse\": 1, \"mu_intercept_per_group\": 12.030630111694336, \"sigma_intercept_per_group\": 0.19588609039783478, \"sigma_obs\": 155.5713348388672, \"slope\": -0.08269758522510529, \"chain\": 3, \"draw\": 170}, {\"draws\": 770, \"mouse\": 2, \"mu_intercept_per_group\": 11.96314525604248, \"sigma_intercept_per_group\": 0.19588609039783478, \"sigma_obs\": 155.5713348388672, \"slope\": -0.08269758522510529, \"chain\": 3, \"draw\": 170}, {\"draws\": 770, \"mouse\": 3, \"mu_intercept_per_group\": 11.422475814819336, \"sigma_intercept_per_group\": 0.19588609039783478, \"sigma_obs\": 155.5713348388672, \"slope\": -0.08269758522510529, \"chain\": 3, \"draw\": 170}, {\"draws\": 770, \"mouse\": 4, \"mu_intercept_per_group\": 10.56315803527832, \"sigma_intercept_per_group\": 0.19588609039783478, \"sigma_obs\": 155.5713348388672, \"slope\": -0.08269758522510529, \"chain\": 3, \"draw\": 170}, {\"draws\": 770, \"mouse\": 5, \"mu_intercept_per_group\": 9.976505279541016, \"sigma_intercept_per_group\": 0.19588609039783478, \"sigma_obs\": 155.5713348388672, \"slope\": -0.08269758522510529, \"chain\": 3, \"draw\": 170}, {\"draws\": 770, \"mouse\": 6, \"mu_intercept_per_group\": 9.333247184753418, \"sigma_intercept_per_group\": 0.19588609039783478, \"sigma_obs\": 155.5713348388672, \"slope\": -0.08269758522510529, \"chain\": 3, \"draw\": 170}, {\"draws\": 770, \"mouse\": 7, \"mu_intercept_per_group\": 8.829742431640625, \"sigma_intercept_per_group\": 0.19588609039783478, \"sigma_obs\": 155.5713348388672, \"slope\": -0.08269758522510529, \"chain\": 3, \"draw\": 170}, {\"draws\": 771, \"mouse\": 0, \"mu_intercept_per_group\": 12.146601676940918, \"sigma_intercept_per_group\": 0.19952720403671265, \"sigma_obs\": 151.01824951171875, \"slope\": -0.0774756669998169, \"chain\": 3, \"draw\": 171}, {\"draws\": 771, \"mouse\": 1, \"mu_intercept_per_group\": 11.675453186035156, \"sigma_intercept_per_group\": 0.19952720403671265, \"sigma_obs\": 151.01824951171875, \"slope\": -0.0774756669998169, \"chain\": 3, \"draw\": 171}, {\"draws\": 771, \"mouse\": 2, \"mu_intercept_per_group\": 11.575342178344727, \"sigma_intercept_per_group\": 0.19952720403671265, \"sigma_obs\": 151.01824951171875, \"slope\": -0.0774756669998169, \"chain\": 3, \"draw\": 171}, {\"draws\": 771, \"mouse\": 3, \"mu_intercept_per_group\": 10.979840278625488, \"sigma_intercept_per_group\": 0.19952720403671265, \"sigma_obs\": 151.01824951171875, \"slope\": -0.0774756669998169, \"chain\": 3, \"draw\": 171}, {\"draws\": 771, \"mouse\": 4, \"mu_intercept_per_group\": 10.070964813232422, \"sigma_intercept_per_group\": 0.19952720403671265, \"sigma_obs\": 151.01824951171875, \"slope\": -0.0774756669998169, \"chain\": 3, \"draw\": 171}, {\"draws\": 771, \"mouse\": 5, \"mu_intercept_per_group\": 9.677971839904785, \"sigma_intercept_per_group\": 0.19952720403671265, \"sigma_obs\": 151.01824951171875, \"slope\": -0.0774756669998169, \"chain\": 3, \"draw\": 171}, {\"draws\": 771, \"mouse\": 6, \"mu_intercept_per_group\": 8.787348747253418, \"sigma_intercept_per_group\": 0.19952720403671265, \"sigma_obs\": 151.01824951171875, \"slope\": -0.0774756669998169, \"chain\": 3, \"draw\": 171}, {\"draws\": 771, \"mouse\": 7, \"mu_intercept_per_group\": 8.954888343811035, \"sigma_intercept_per_group\": 0.19952720403671265, \"sigma_obs\": 151.01824951171875, \"slope\": -0.0774756669998169, \"chain\": 3, \"draw\": 171}, {\"draws\": 772, \"mouse\": 0, \"mu_intercept_per_group\": 12.166513442993164, \"sigma_intercept_per_group\": 0.20111002027988434, \"sigma_obs\": 149.8680419921875, \"slope\": -0.07780707627534866, \"chain\": 3, \"draw\": 172}, {\"draws\": 772, \"mouse\": 1, \"mu_intercept_per_group\": 11.706625938415527, \"sigma_intercept_per_group\": 0.20111002027988434, \"sigma_obs\": 149.8680419921875, \"slope\": -0.07780707627534866, \"chain\": 3, \"draw\": 172}, {\"draws\": 772, \"mouse\": 2, \"mu_intercept_per_group\": 11.105216979980469, \"sigma_intercept_per_group\": 0.20111002027988434, \"sigma_obs\": 149.8680419921875, \"slope\": -0.07780707627534866, \"chain\": 3, \"draw\": 172}, {\"draws\": 772, \"mouse\": 3, \"mu_intercept_per_group\": 10.431343078613281, \"sigma_intercept_per_group\": 0.20111002027988434, \"sigma_obs\": 149.8680419921875, \"slope\": -0.07780707627534866, \"chain\": 3, \"draw\": 172}, {\"draws\": 772, \"mouse\": 4, \"mu_intercept_per_group\": 10.67699146270752, \"sigma_intercept_per_group\": 0.20111002027988434, \"sigma_obs\": 149.8680419921875, \"slope\": -0.07780707627534866, \"chain\": 3, \"draw\": 172}, {\"draws\": 772, \"mouse\": 5, \"mu_intercept_per_group\": 9.946747779846191, \"sigma_intercept_per_group\": 0.20111002027988434, \"sigma_obs\": 149.8680419921875, \"slope\": -0.07780707627534866, \"chain\": 3, \"draw\": 172}, {\"draws\": 772, \"mouse\": 6, \"mu_intercept_per_group\": 9.629112243652344, \"sigma_intercept_per_group\": 0.20111002027988434, \"sigma_obs\": 149.8680419921875, \"slope\": -0.07780707627534866, \"chain\": 3, \"draw\": 172}, {\"draws\": 772, \"mouse\": 7, \"mu_intercept_per_group\": 8.923524856567383, \"sigma_intercept_per_group\": 0.20111002027988434, \"sigma_obs\": 149.8680419921875, \"slope\": -0.07780707627534866, \"chain\": 3, \"draw\": 172}, {\"draws\": 773, \"mouse\": 0, \"mu_intercept_per_group\": 12.211318016052246, \"sigma_intercept_per_group\": 0.19917094707489014, \"sigma_obs\": 147.33433532714844, \"slope\": -0.0677962452173233, \"chain\": 3, \"draw\": 173}, {\"draws\": 773, \"mouse\": 1, \"mu_intercept_per_group\": 11.7933349609375, \"sigma_intercept_per_group\": 0.19917094707489014, \"sigma_obs\": 147.33433532714844, \"slope\": -0.0677962452173233, \"chain\": 3, \"draw\": 173}, {\"draws\": 773, \"mouse\": 2, \"mu_intercept_per_group\": 11.259264945983887, \"sigma_intercept_per_group\": 0.19917094707489014, \"sigma_obs\": 147.33433532714844, \"slope\": -0.0677962452173233, \"chain\": 3, \"draw\": 173}, {\"draws\": 773, \"mouse\": 3, \"mu_intercept_per_group\": 10.596977233886719, \"sigma_intercept_per_group\": 0.19917094707489014, \"sigma_obs\": 147.33433532714844, \"slope\": -0.0677962452173233, \"chain\": 3, \"draw\": 173}, {\"draws\": 773, \"mouse\": 4, \"mu_intercept_per_group\": 10.647040367126465, \"sigma_intercept_per_group\": 0.19917094707489014, \"sigma_obs\": 147.33433532714844, \"slope\": -0.0677962452173233, \"chain\": 3, \"draw\": 173}, {\"draws\": 773, \"mouse\": 5, \"mu_intercept_per_group\": 9.916994094848633, \"sigma_intercept_per_group\": 0.19917094707489014, \"sigma_obs\": 147.33433532714844, \"slope\": -0.0677962452173233, \"chain\": 3, \"draw\": 173}, {\"draws\": 773, \"mouse\": 6, \"mu_intercept_per_group\": 8.677689552307129, \"sigma_intercept_per_group\": 0.19917094707489014, \"sigma_obs\": 147.33433532714844, \"slope\": -0.0677962452173233, \"chain\": 3, \"draw\": 173}, {\"draws\": 773, \"mouse\": 7, \"mu_intercept_per_group\": 8.523141860961914, \"sigma_intercept_per_group\": 0.19917094707489014, \"sigma_obs\": 147.33433532714844, \"slope\": -0.0677962452173233, \"chain\": 3, \"draw\": 173}, {\"draws\": 774, \"mouse\": 0, \"mu_intercept_per_group\": 12.107095718383789, \"sigma_intercept_per_group\": 0.19927553832530975, \"sigma_obs\": 147.73350524902344, \"slope\": -0.06901177018880844, \"chain\": 3, \"draw\": 174}, {\"draws\": 774, \"mouse\": 1, \"mu_intercept_per_group\": 11.111706733703613, \"sigma_intercept_per_group\": 0.19927553832530975, \"sigma_obs\": 147.73350524902344, \"slope\": -0.06901177018880844, \"chain\": 3, \"draw\": 174}, {\"draws\": 774, \"mouse\": 2, \"mu_intercept_per_group\": 11.348793029785156, \"sigma_intercept_per_group\": 0.19927553832530975, \"sigma_obs\": 147.73350524902344, \"slope\": -0.06901177018880844, \"chain\": 3, \"draw\": 174}, {\"draws\": 774, \"mouse\": 3, \"mu_intercept_per_group\": 11.009777069091797, \"sigma_intercept_per_group\": 0.19927553832530975, \"sigma_obs\": 147.73350524902344, \"slope\": -0.06901177018880844, \"chain\": 3, \"draw\": 174}, {\"draws\": 774, \"mouse\": 4, \"mu_intercept_per_group\": 10.38424015045166, \"sigma_intercept_per_group\": 0.19927553832530975, \"sigma_obs\": 147.73350524902344, \"slope\": -0.06901177018880844, \"chain\": 3, \"draw\": 174}, {\"draws\": 774, \"mouse\": 5, \"mu_intercept_per_group\": 9.909147262573242, \"sigma_intercept_per_group\": 0.19927553832530975, \"sigma_obs\": 147.73350524902344, \"slope\": -0.06901177018880844, \"chain\": 3, \"draw\": 174}, {\"draws\": 774, \"mouse\": 6, \"mu_intercept_per_group\": 9.268518447875977, \"sigma_intercept_per_group\": 0.19927553832530975, \"sigma_obs\": 147.73350524902344, \"slope\": -0.06901177018880844, \"chain\": 3, \"draw\": 174}, {\"draws\": 774, \"mouse\": 7, \"mu_intercept_per_group\": 8.99924087524414, \"sigma_intercept_per_group\": 0.19927553832530975, \"sigma_obs\": 147.73350524902344, \"slope\": -0.06901177018880844, \"chain\": 3, \"draw\": 174}, {\"draws\": 775, \"mouse\": 0, \"mu_intercept_per_group\": 11.87932300567627, \"sigma_intercept_per_group\": 0.197565495967865, \"sigma_obs\": 147.41156005859375, \"slope\": -0.070706807076931, \"chain\": 3, \"draw\": 175}, {\"draws\": 775, \"mouse\": 1, \"mu_intercept_per_group\": 11.614605903625488, \"sigma_intercept_per_group\": 0.197565495967865, \"sigma_obs\": 147.41156005859375, \"slope\": -0.070706807076931, \"chain\": 3, \"draw\": 175}, {\"draws\": 775, \"mouse\": 2, \"mu_intercept_per_group\": 11.290952682495117, \"sigma_intercept_per_group\": 0.197565495967865, \"sigma_obs\": 147.41156005859375, \"slope\": -0.070706807076931, \"chain\": 3, \"draw\": 175}, {\"draws\": 775, \"mouse\": 3, \"mu_intercept_per_group\": 10.656957626342773, \"sigma_intercept_per_group\": 0.197565495967865, \"sigma_obs\": 147.41156005859375, \"slope\": -0.070706807076931, \"chain\": 3, \"draw\": 175}, {\"draws\": 775, \"mouse\": 4, \"mu_intercept_per_group\": 10.219718933105469, \"sigma_intercept_per_group\": 0.197565495967865, \"sigma_obs\": 147.41156005859375, \"slope\": -0.070706807076931, \"chain\": 3, \"draw\": 175}, {\"draws\": 775, \"mouse\": 5, \"mu_intercept_per_group\": 9.80676555633545, \"sigma_intercept_per_group\": 0.197565495967865, \"sigma_obs\": 147.41156005859375, \"slope\": -0.070706807076931, \"chain\": 3, \"draw\": 175}, {\"draws\": 775, \"mouse\": 6, \"mu_intercept_per_group\": 9.314509391784668, \"sigma_intercept_per_group\": 0.197565495967865, \"sigma_obs\": 147.41156005859375, \"slope\": -0.070706807076931, \"chain\": 3, \"draw\": 175}, {\"draws\": 775, \"mouse\": 7, \"mu_intercept_per_group\": 9.053914070129395, \"sigma_intercept_per_group\": 0.197565495967865, \"sigma_obs\": 147.41156005859375, \"slope\": -0.070706807076931, \"chain\": 3, \"draw\": 175}, {\"draws\": 776, \"mouse\": 0, \"mu_intercept_per_group\": 11.922754287719727, \"sigma_intercept_per_group\": 0.20008298754692078, \"sigma_obs\": 147.95492553710938, \"slope\": -0.070560522377491, \"chain\": 3, \"draw\": 176}, {\"draws\": 776, \"mouse\": 1, \"mu_intercept_per_group\": 11.752396583557129, \"sigma_intercept_per_group\": 0.20008298754692078, \"sigma_obs\": 147.95492553710938, \"slope\": -0.070560522377491, \"chain\": 3, \"draw\": 176}, {\"draws\": 776, \"mouse\": 2, \"mu_intercept_per_group\": 11.161404609680176, \"sigma_intercept_per_group\": 0.20008298754692078, \"sigma_obs\": 147.95492553710938, \"slope\": -0.070560522377491, \"chain\": 3, \"draw\": 176}, {\"draws\": 776, \"mouse\": 3, \"mu_intercept_per_group\": 10.627239227294922, \"sigma_intercept_per_group\": 0.20008298754692078, \"sigma_obs\": 147.95492553710938, \"slope\": -0.070560522377491, \"chain\": 3, \"draw\": 176}, {\"draws\": 776, \"mouse\": 4, \"mu_intercept_per_group\": 10.198945999145508, \"sigma_intercept_per_group\": 0.20008298754692078, \"sigma_obs\": 147.95492553710938, \"slope\": -0.070560522377491, \"chain\": 3, \"draw\": 176}, {\"draws\": 776, \"mouse\": 5, \"mu_intercept_per_group\": 9.795965194702148, \"sigma_intercept_per_group\": 0.20008298754692078, \"sigma_obs\": 147.95492553710938, \"slope\": -0.070560522377491, \"chain\": 3, \"draw\": 176}, {\"draws\": 776, \"mouse\": 6, \"mu_intercept_per_group\": 9.163239479064941, \"sigma_intercept_per_group\": 0.20008298754692078, \"sigma_obs\": 147.95492553710938, \"slope\": -0.070560522377491, \"chain\": 3, \"draw\": 176}, {\"draws\": 776, \"mouse\": 7, \"mu_intercept_per_group\": 9.11458969116211, \"sigma_intercept_per_group\": 0.20008298754692078, \"sigma_obs\": 147.95492553710938, \"slope\": -0.070560522377491, \"chain\": 3, \"draw\": 176}, {\"draws\": 777, \"mouse\": 0, \"mu_intercept_per_group\": 12.00605583190918, \"sigma_intercept_per_group\": 0.20538628101348877, \"sigma_obs\": 157.92654418945312, \"slope\": -0.06590162962675095, \"chain\": 3, \"draw\": 177}, {\"draws\": 777, \"mouse\": 1, \"mu_intercept_per_group\": 11.250916481018066, \"sigma_intercept_per_group\": 0.20538628101348877, \"sigma_obs\": 157.92654418945312, \"slope\": -0.06590162962675095, \"chain\": 3, \"draw\": 177}, {\"draws\": 777, \"mouse\": 2, \"mu_intercept_per_group\": 11.091480255126953, \"sigma_intercept_per_group\": 0.20538628101348877, \"sigma_obs\": 157.92654418945312, \"slope\": -0.06590162962675095, \"chain\": 3, \"draw\": 177}, {\"draws\": 777, \"mouse\": 3, \"mu_intercept_per_group\": 10.16357135772705, \"sigma_intercept_per_group\": 0.20538628101348877, \"sigma_obs\": 157.92654418945312, \"slope\": -0.06590162962675095, \"chain\": 3, \"draw\": 177}, {\"draws\": 777, \"mouse\": 4, \"mu_intercept_per_group\": 10.146231651306152, \"sigma_intercept_per_group\": 0.20538628101348877, \"sigma_obs\": 157.92654418945312, \"slope\": -0.06590162962675095, \"chain\": 3, \"draw\": 177}, {\"draws\": 777, \"mouse\": 5, \"mu_intercept_per_group\": 9.711807250976562, \"sigma_intercept_per_group\": 0.20538628101348877, \"sigma_obs\": 157.92654418945312, \"slope\": -0.06590162962675095, \"chain\": 3, \"draw\": 177}, {\"draws\": 777, \"mouse\": 6, \"mu_intercept_per_group\": 9.163249969482422, \"sigma_intercept_per_group\": 0.20538628101348877, \"sigma_obs\": 157.92654418945312, \"slope\": -0.06590162962675095, \"chain\": 3, \"draw\": 177}, {\"draws\": 777, \"mouse\": 7, \"mu_intercept_per_group\": 8.484573364257812, \"sigma_intercept_per_group\": 0.20538628101348877, \"sigma_obs\": 157.92654418945312, \"slope\": -0.06590162962675095, \"chain\": 3, \"draw\": 177}, {\"draws\": 778, \"mouse\": 0, \"mu_intercept_per_group\": 12.728737831115723, \"sigma_intercept_per_group\": 0.18873590230941772, \"sigma_obs\": 149.1088104248047, \"slope\": -0.06572698056697845, \"chain\": 3, \"draw\": 178}, {\"draws\": 778, \"mouse\": 1, \"mu_intercept_per_group\": 12.253805160522461, \"sigma_intercept_per_group\": 0.18873590230941772, \"sigma_obs\": 149.1088104248047, \"slope\": -0.06572698056697845, \"chain\": 3, \"draw\": 178}, {\"draws\": 778, \"mouse\": 2, \"mu_intercept_per_group\": 11.957311630249023, \"sigma_intercept_per_group\": 0.18873590230941772, \"sigma_obs\": 149.1088104248047, \"slope\": -0.06572698056697845, \"chain\": 3, \"draw\": 178}, {\"draws\": 778, \"mouse\": 3, \"mu_intercept_per_group\": 11.571531295776367, \"sigma_intercept_per_group\": 0.18873590230941772, \"sigma_obs\": 149.1088104248047, \"slope\": -0.06572698056697845, \"chain\": 3, \"draw\": 178}, {\"draws\": 778, \"mouse\": 4, \"mu_intercept_per_group\": 10.891606330871582, \"sigma_intercept_per_group\": 0.18873590230941772, \"sigma_obs\": 149.1088104248047, \"slope\": -0.06572698056697845, \"chain\": 3, \"draw\": 178}, {\"draws\": 778, \"mouse\": 5, \"mu_intercept_per_group\": 9.858242988586426, \"sigma_intercept_per_group\": 0.18873590230941772, \"sigma_obs\": 149.1088104248047, \"slope\": -0.06572698056697845, \"chain\": 3, \"draw\": 178}, {\"draws\": 778, \"mouse\": 6, \"mu_intercept_per_group\": 9.667549133300781, \"sigma_intercept_per_group\": 0.18873590230941772, \"sigma_obs\": 149.1088104248047, \"slope\": -0.06572698056697845, \"chain\": 3, \"draw\": 178}, {\"draws\": 778, \"mouse\": 7, \"mu_intercept_per_group\": 8.987088203430176, \"sigma_intercept_per_group\": 0.18873590230941772, \"sigma_obs\": 149.1088104248047, \"slope\": -0.06572698056697845, \"chain\": 3, \"draw\": 178}, {\"draws\": 779, \"mouse\": 0, \"mu_intercept_per_group\": 13.99666690826416, \"sigma_intercept_per_group\": 0.18421603739261627, \"sigma_obs\": 169.74136352539062, \"slope\": -0.08701842278242111, \"chain\": 3, \"draw\": 179}, {\"draws\": 779, \"mouse\": 1, \"mu_intercept_per_group\": 13.434558868408203, \"sigma_intercept_per_group\": 0.18421603739261627, \"sigma_obs\": 169.74136352539062, \"slope\": -0.08701842278242111, \"chain\": 3, \"draw\": 179}, {\"draws\": 779, \"mouse\": 2, \"mu_intercept_per_group\": 13.015089988708496, \"sigma_intercept_per_group\": 0.18421603739261627, \"sigma_obs\": 169.74136352539062, \"slope\": -0.08701842278242111, \"chain\": 3, \"draw\": 179}, {\"draws\": 779, \"mouse\": 3, \"mu_intercept_per_group\": 12.11876392364502, \"sigma_intercept_per_group\": 0.18421603739261627, \"sigma_obs\": 169.74136352539062, \"slope\": -0.08701842278242111, \"chain\": 3, \"draw\": 179}, {\"draws\": 779, \"mouse\": 4, \"mu_intercept_per_group\": 12.376805305480957, \"sigma_intercept_per_group\": 0.18421603739261627, \"sigma_obs\": 169.74136352539062, \"slope\": -0.08701842278242111, \"chain\": 3, \"draw\": 179}, {\"draws\": 779, \"mouse\": 5, \"mu_intercept_per_group\": 11.004284858703613, \"sigma_intercept_per_group\": 0.18421603739261627, \"sigma_obs\": 169.74136352539062, \"slope\": -0.08701842278242111, \"chain\": 3, \"draw\": 179}, {\"draws\": 779, \"mouse\": 6, \"mu_intercept_per_group\": 10.5905122756958, \"sigma_intercept_per_group\": 0.18421603739261627, \"sigma_obs\": 169.74136352539062, \"slope\": -0.08701842278242111, \"chain\": 3, \"draw\": 179}, {\"draws\": 779, \"mouse\": 7, \"mu_intercept_per_group\": 10.251273155212402, \"sigma_intercept_per_group\": 0.18421603739261627, \"sigma_obs\": 169.74136352539062, \"slope\": -0.08701842278242111, \"chain\": 3, \"draw\": 179}, {\"draws\": 780, \"mouse\": 0, \"mu_intercept_per_group\": 13.898451805114746, \"sigma_intercept_per_group\": 0.18510976433753967, \"sigma_obs\": 170.70492553710938, \"slope\": -0.08627275377511978, \"chain\": 3, \"draw\": 180}, {\"draws\": 780, \"mouse\": 1, \"mu_intercept_per_group\": 13.453012466430664, \"sigma_intercept_per_group\": 0.18510976433753967, \"sigma_obs\": 170.70492553710938, \"slope\": -0.08627275377511978, \"chain\": 3, \"draw\": 180}, {\"draws\": 780, \"mouse\": 2, \"mu_intercept_per_group\": 12.942962646484375, \"sigma_intercept_per_group\": 0.18510976433753967, \"sigma_obs\": 170.70492553710938, \"slope\": -0.08627275377511978, \"chain\": 3, \"draw\": 180}, {\"draws\": 780, \"mouse\": 3, \"mu_intercept_per_group\": 12.092893600463867, \"sigma_intercept_per_group\": 0.18510976433753967, \"sigma_obs\": 170.70492553710938, \"slope\": -0.08627275377511978, \"chain\": 3, \"draw\": 180}, {\"draws\": 780, \"mouse\": 4, \"mu_intercept_per_group\": 11.890989303588867, \"sigma_intercept_per_group\": 0.18510976433753967, \"sigma_obs\": 170.70492553710938, \"slope\": -0.08627275377511978, \"chain\": 3, \"draw\": 180}, {\"draws\": 780, \"mouse\": 5, \"mu_intercept_per_group\": 11.353862762451172, \"sigma_intercept_per_group\": 0.18510976433753967, \"sigma_obs\": 170.70492553710938, \"slope\": -0.08627275377511978, \"chain\": 3, \"draw\": 180}, {\"draws\": 780, \"mouse\": 6, \"mu_intercept_per_group\": 10.820816040039062, \"sigma_intercept_per_group\": 0.18510976433753967, \"sigma_obs\": 170.70492553710938, \"slope\": -0.08627275377511978, \"chain\": 3, \"draw\": 180}, {\"draws\": 780, \"mouse\": 7, \"mu_intercept_per_group\": 10.297664642333984, \"sigma_intercept_per_group\": 0.18510976433753967, \"sigma_obs\": 170.70492553710938, \"slope\": -0.08627275377511978, \"chain\": 3, \"draw\": 180}, {\"draws\": 781, \"mouse\": 0, \"mu_intercept_per_group\": 14.103483200073242, \"sigma_intercept_per_group\": 0.1827012300491333, \"sigma_obs\": 170.98638916015625, \"slope\": -0.08648695051670074, \"chain\": 3, \"draw\": 181}, {\"draws\": 781, \"mouse\": 1, \"mu_intercept_per_group\": 13.71688175201416, \"sigma_intercept_per_group\": 0.1827012300491333, \"sigma_obs\": 170.98638916015625, \"slope\": -0.08648695051670074, \"chain\": 3, \"draw\": 181}, {\"draws\": 781, \"mouse\": 2, \"mu_intercept_per_group\": 13.158134460449219, \"sigma_intercept_per_group\": 0.1827012300491333, \"sigma_obs\": 170.98638916015625, \"slope\": -0.08648695051670074, \"chain\": 3, \"draw\": 181}, {\"draws\": 781, \"mouse\": 3, \"mu_intercept_per_group\": 12.350931167602539, \"sigma_intercept_per_group\": 0.1827012300491333, \"sigma_obs\": 170.98638916015625, \"slope\": -0.08648695051670074, \"chain\": 3, \"draw\": 181}, {\"draws\": 781, \"mouse\": 4, \"mu_intercept_per_group\": 12.139426231384277, \"sigma_intercept_per_group\": 0.1827012300491333, \"sigma_obs\": 170.98638916015625, \"slope\": -0.08648695051670074, \"chain\": 3, \"draw\": 181}, {\"draws\": 781, \"mouse\": 5, \"mu_intercept_per_group\": 11.507896423339844, \"sigma_intercept_per_group\": 0.1827012300491333, \"sigma_obs\": 170.98638916015625, \"slope\": -0.08648695051670074, \"chain\": 3, \"draw\": 181}, {\"draws\": 781, \"mouse\": 6, \"mu_intercept_per_group\": 10.287477493286133, \"sigma_intercept_per_group\": 0.1827012300491333, \"sigma_obs\": 170.98638916015625, \"slope\": -0.08648695051670074, \"chain\": 3, \"draw\": 181}, {\"draws\": 781, \"mouse\": 7, \"mu_intercept_per_group\": 10.07107925415039, \"sigma_intercept_per_group\": 0.1827012300491333, \"sigma_obs\": 170.98638916015625, \"slope\": -0.08648695051670074, \"chain\": 3, \"draw\": 181}, {\"draws\": 782, \"mouse\": 0, \"mu_intercept_per_group\": 14.502510070800781, \"sigma_intercept_per_group\": 0.1702527403831482, \"sigma_obs\": 161.27920532226562, \"slope\": -0.0707826167345047, \"chain\": 3, \"draw\": 182}, {\"draws\": 782, \"mouse\": 1, \"mu_intercept_per_group\": 13.82107162475586, \"sigma_intercept_per_group\": 0.1702527403831482, \"sigma_obs\": 161.27920532226562, \"slope\": -0.0707826167345047, \"chain\": 3, \"draw\": 182}, {\"draws\": 782, \"mouse\": 2, \"mu_intercept_per_group\": 13.553266525268555, \"sigma_intercept_per_group\": 0.1702527403831482, \"sigma_obs\": 161.27920532226562, \"slope\": -0.0707826167345047, \"chain\": 3, \"draw\": 182}, {\"draws\": 782, \"mouse\": 3, \"mu_intercept_per_group\": 12.916163444519043, \"sigma_intercept_per_group\": 0.1702527403831482, \"sigma_obs\": 161.27920532226562, \"slope\": -0.0707826167345047, \"chain\": 3, \"draw\": 182}, {\"draws\": 782, \"mouse\": 4, \"mu_intercept_per_group\": 12.629972457885742, \"sigma_intercept_per_group\": 0.1702527403831482, \"sigma_obs\": 161.27920532226562, \"slope\": -0.0707826167345047, \"chain\": 3, \"draw\": 182}, {\"draws\": 782, \"mouse\": 5, \"mu_intercept_per_group\": 11.97089672088623, \"sigma_intercept_per_group\": 0.1702527403831482, \"sigma_obs\": 161.27920532226562, \"slope\": -0.0707826167345047, \"chain\": 3, \"draw\": 182}, {\"draws\": 782, \"mouse\": 6, \"mu_intercept_per_group\": 10.695028305053711, \"sigma_intercept_per_group\": 0.1702527403831482, \"sigma_obs\": 161.27920532226562, \"slope\": -0.0707826167345047, \"chain\": 3, \"draw\": 182}, {\"draws\": 782, \"mouse\": 7, \"mu_intercept_per_group\": 10.134557723999023, \"sigma_intercept_per_group\": 0.1702527403831482, \"sigma_obs\": 161.27920532226562, \"slope\": -0.0707826167345047, \"chain\": 3, \"draw\": 182}, {\"draws\": 783, \"mouse\": 0, \"mu_intercept_per_group\": 14.626103401184082, \"sigma_intercept_per_group\": 0.16751056909561157, \"sigma_obs\": 159.22946166992188, \"slope\": -0.06621871888637543, \"chain\": 3, \"draw\": 183}, {\"draws\": 783, \"mouse\": 1, \"mu_intercept_per_group\": 14.25621509552002, \"sigma_intercept_per_group\": 0.16751056909561157, \"sigma_obs\": 159.22946166992188, \"slope\": -0.06621871888637543, \"chain\": 3, \"draw\": 183}, {\"draws\": 783, \"mouse\": 2, \"mu_intercept_per_group\": 13.801427841186523, \"sigma_intercept_per_group\": 0.16751056909561157, \"sigma_obs\": 159.22946166992188, \"slope\": -0.06621871888637543, \"chain\": 3, \"draw\": 183}, {\"draws\": 783, \"mouse\": 3, \"mu_intercept_per_group\": 12.370251655578613, \"sigma_intercept_per_group\": 0.16751056909561157, \"sigma_obs\": 159.22946166992188, \"slope\": -0.06621871888637543, \"chain\": 3, \"draw\": 183}, {\"draws\": 783, \"mouse\": 4, \"mu_intercept_per_group\": 12.540060043334961, \"sigma_intercept_per_group\": 0.16751056909561157, \"sigma_obs\": 159.22946166992188, \"slope\": -0.06621871888637543, \"chain\": 3, \"draw\": 183}, {\"draws\": 783, \"mouse\": 5, \"mu_intercept_per_group\": 11.733025550842285, \"sigma_intercept_per_group\": 0.16751056909561157, \"sigma_obs\": 159.22946166992188, \"slope\": -0.06621871888637543, \"chain\": 3, \"draw\": 183}, {\"draws\": 783, \"mouse\": 6, \"mu_intercept_per_group\": 11.41783332824707, \"sigma_intercept_per_group\": 0.16751056909561157, \"sigma_obs\": 159.22946166992188, \"slope\": -0.06621871888637543, \"chain\": 3, \"draw\": 183}, {\"draws\": 783, \"mouse\": 7, \"mu_intercept_per_group\": 10.882160186767578, \"sigma_intercept_per_group\": 0.16751056909561157, \"sigma_obs\": 159.22946166992188, \"slope\": -0.06621871888637543, \"chain\": 3, \"draw\": 183}, {\"draws\": 784, \"mouse\": 0, \"mu_intercept_per_group\": 13.06056022644043, \"sigma_intercept_per_group\": 0.1890881061553955, \"sigma_obs\": 156.543701171875, \"slope\": -0.07640249282121658, \"chain\": 3, \"draw\": 184}, {\"draws\": 784, \"mouse\": 1, \"mu_intercept_per_group\": 12.445810317993164, \"sigma_intercept_per_group\": 0.1890881061553955, \"sigma_obs\": 156.543701171875, \"slope\": -0.07640249282121658, \"chain\": 3, \"draw\": 184}, {\"draws\": 784, \"mouse\": 2, \"mu_intercept_per_group\": 12.200968742370605, \"sigma_intercept_per_group\": 0.1890881061553955, \"sigma_obs\": 156.543701171875, \"slope\": -0.07640249282121658, \"chain\": 3, \"draw\": 184}, {\"draws\": 784, \"mouse\": 3, \"mu_intercept_per_group\": 11.098692893981934, \"sigma_intercept_per_group\": 0.1890881061553955, \"sigma_obs\": 156.543701171875, \"slope\": -0.07640249282121658, \"chain\": 3, \"draw\": 184}, {\"draws\": 784, \"mouse\": 4, \"mu_intercept_per_group\": 11.01091194152832, \"sigma_intercept_per_group\": 0.1890881061553955, \"sigma_obs\": 156.543701171875, \"slope\": -0.07640249282121658, \"chain\": 3, \"draw\": 184}, {\"draws\": 784, \"mouse\": 5, \"mu_intercept_per_group\": 10.35018253326416, \"sigma_intercept_per_group\": 0.1890881061553955, \"sigma_obs\": 156.543701171875, \"slope\": -0.07640249282121658, \"chain\": 3, \"draw\": 184}, {\"draws\": 784, \"mouse\": 6, \"mu_intercept_per_group\": 9.940608024597168, \"sigma_intercept_per_group\": 0.1890881061553955, \"sigma_obs\": 156.543701171875, \"slope\": -0.07640249282121658, \"chain\": 3, \"draw\": 184}, {\"draws\": 784, \"mouse\": 7, \"mu_intercept_per_group\": 9.819738388061523, \"sigma_intercept_per_group\": 0.1890881061553955, \"sigma_obs\": 156.543701171875, \"slope\": -0.07640249282121658, \"chain\": 3, \"draw\": 184}, {\"draws\": 785, \"mouse\": 0, \"mu_intercept_per_group\": 12.596001625061035, \"sigma_intercept_per_group\": 0.1957402527332306, \"sigma_obs\": 158.63462829589844, \"slope\": -0.06313572078943253, \"chain\": 3, \"draw\": 185}, {\"draws\": 785, \"mouse\": 1, \"mu_intercept_per_group\": 11.85953426361084, \"sigma_intercept_per_group\": 0.1957402527332306, \"sigma_obs\": 158.63462829589844, \"slope\": -0.06313572078943253, \"chain\": 3, \"draw\": 185}, {\"draws\": 785, \"mouse\": 2, \"mu_intercept_per_group\": 11.617588996887207, \"sigma_intercept_per_group\": 0.1957402527332306, \"sigma_obs\": 158.63462829589844, \"slope\": -0.06313572078943253, \"chain\": 3, \"draw\": 185}, {\"draws\": 785, \"mouse\": 3, \"mu_intercept_per_group\": 11.314460754394531, \"sigma_intercept_per_group\": 0.1957402527332306, \"sigma_obs\": 158.63462829589844, \"slope\": -0.06313572078943253, \"chain\": 3, \"draw\": 185}, {\"draws\": 785, \"mouse\": 4, \"mu_intercept_per_group\": 10.872377395629883, \"sigma_intercept_per_group\": 0.1957402527332306, \"sigma_obs\": 158.63462829589844, \"slope\": -0.06313572078943253, \"chain\": 3, \"draw\": 185}, {\"draws\": 785, \"mouse\": 5, \"mu_intercept_per_group\": 9.783961296081543, \"sigma_intercept_per_group\": 0.1957402527332306, \"sigma_obs\": 158.63462829589844, \"slope\": -0.06313572078943253, \"chain\": 3, \"draw\": 185}, {\"draws\": 785, \"mouse\": 6, \"mu_intercept_per_group\": 9.495681762695312, \"sigma_intercept_per_group\": 0.1957402527332306, \"sigma_obs\": 158.63462829589844, \"slope\": -0.06313572078943253, \"chain\": 3, \"draw\": 185}, {\"draws\": 785, \"mouse\": 7, \"mu_intercept_per_group\": 9.44607162475586, \"sigma_intercept_per_group\": 0.1957402527332306, \"sigma_obs\": 158.63462829589844, \"slope\": -0.06313572078943253, \"chain\": 3, \"draw\": 185}, {\"draws\": 786, \"mouse\": 0, \"mu_intercept_per_group\": 12.718660354614258, \"sigma_intercept_per_group\": 0.1957569718360901, \"sigma_obs\": 160.12417602539062, \"slope\": -0.0634714812040329, \"chain\": 3, \"draw\": 186}, {\"draws\": 786, \"mouse\": 1, \"mu_intercept_per_group\": 12.201940536499023, \"sigma_intercept_per_group\": 0.1957569718360901, \"sigma_obs\": 160.12417602539062, \"slope\": -0.0634714812040329, \"chain\": 3, \"draw\": 186}, {\"draws\": 786, \"mouse\": 2, \"mu_intercept_per_group\": 11.966007232666016, \"sigma_intercept_per_group\": 0.1957569718360901, \"sigma_obs\": 160.12417602539062, \"slope\": -0.0634714812040329, \"chain\": 3, \"draw\": 186}, {\"draws\": 786, \"mouse\": 3, \"mu_intercept_per_group\": 10.785585403442383, \"sigma_intercept_per_group\": 0.1957569718360901, \"sigma_obs\": 160.12417602539062, \"slope\": -0.0634714812040329, \"chain\": 3, \"draw\": 186}, {\"draws\": 786, \"mouse\": 4, \"mu_intercept_per_group\": 10.680954933166504, \"sigma_intercept_per_group\": 0.1957569718360901, \"sigma_obs\": 160.12417602539062, \"slope\": -0.0634714812040329, \"chain\": 3, \"draw\": 186}, {\"draws\": 786, \"mouse\": 5, \"mu_intercept_per_group\": 9.569643020629883, \"sigma_intercept_per_group\": 0.1957569718360901, \"sigma_obs\": 160.12417602539062, \"slope\": -0.0634714812040329, \"chain\": 3, \"draw\": 186}, {\"draws\": 786, \"mouse\": 6, \"mu_intercept_per_group\": 9.840314865112305, \"sigma_intercept_per_group\": 0.1957569718360901, \"sigma_obs\": 160.12417602539062, \"slope\": -0.0634714812040329, \"chain\": 3, \"draw\": 186}, {\"draws\": 786, \"mouse\": 7, \"mu_intercept_per_group\": 9.1331148147583, \"sigma_intercept_per_group\": 0.1957569718360901, \"sigma_obs\": 160.12417602539062, \"slope\": -0.0634714812040329, \"chain\": 3, \"draw\": 186}, {\"draws\": 787, \"mouse\": 0, \"mu_intercept_per_group\": 11.809525489807129, \"sigma_intercept_per_group\": 0.20481880009174347, \"sigma_obs\": 158.89089965820312, \"slope\": -0.06662449985742569, \"chain\": 3, \"draw\": 187}, {\"draws\": 787, \"mouse\": 1, \"mu_intercept_per_group\": 11.584819793701172, \"sigma_intercept_per_group\": 0.20481880009174347, \"sigma_obs\": 158.89089965820312, \"slope\": -0.06662449985742569, \"chain\": 3, \"draw\": 187}, {\"draws\": 787, \"mouse\": 2, \"mu_intercept_per_group\": 11.100998878479004, \"sigma_intercept_per_group\": 0.20481880009174347, \"sigma_obs\": 158.89089965820312, \"slope\": -0.06662449985742569, \"chain\": 3, \"draw\": 187}, {\"draws\": 787, \"mouse\": 3, \"mu_intercept_per_group\": 10.94271183013916, \"sigma_intercept_per_group\": 0.20481880009174347, \"sigma_obs\": 158.89089965820312, \"slope\": -0.06662449985742569, \"chain\": 3, \"draw\": 187}, {\"draws\": 787, \"mouse\": 4, \"mu_intercept_per_group\": 10.512534141540527, \"sigma_intercept_per_group\": 0.20481880009174347, \"sigma_obs\": 158.89089965820312, \"slope\": -0.06662449985742569, \"chain\": 3, \"draw\": 187}, {\"draws\": 787, \"mouse\": 5, \"mu_intercept_per_group\": 10.315774917602539, \"sigma_intercept_per_group\": 0.20481880009174347, \"sigma_obs\": 158.89089965820312, \"slope\": -0.06662449985742569, \"chain\": 3, \"draw\": 187}, {\"draws\": 787, \"mouse\": 6, \"mu_intercept_per_group\": 8.945398330688477, \"sigma_intercept_per_group\": 0.20481880009174347, \"sigma_obs\": 158.89089965820312, \"slope\": -0.06662449985742569, \"chain\": 3, \"draw\": 187}, {\"draws\": 787, \"mouse\": 7, \"mu_intercept_per_group\": 8.224472045898438, \"sigma_intercept_per_group\": 0.20481880009174347, \"sigma_obs\": 158.89089965820312, \"slope\": -0.06662449985742569, \"chain\": 3, \"draw\": 187}, {\"draws\": 788, \"mouse\": 0, \"mu_intercept_per_group\": 12.422297477722168, \"sigma_intercept_per_group\": 0.19953814148902893, \"sigma_obs\": 157.86676025390625, \"slope\": -0.06458193808794022, \"chain\": 3, \"draw\": 188}, {\"draws\": 788, \"mouse\": 1, \"mu_intercept_per_group\": 11.754326820373535, \"sigma_intercept_per_group\": 0.19953814148902893, \"sigma_obs\": 157.86676025390625, \"slope\": -0.06458193808794022, \"chain\": 3, \"draw\": 188}, {\"draws\": 788, \"mouse\": 2, \"mu_intercept_per_group\": 11.589799880981445, \"sigma_intercept_per_group\": 0.19953814148902893, \"sigma_obs\": 157.86676025390625, \"slope\": -0.06458193808794022, \"chain\": 3, \"draw\": 188}, {\"draws\": 788, \"mouse\": 3, \"mu_intercept_per_group\": 10.493807792663574, \"sigma_intercept_per_group\": 0.19953814148902893, \"sigma_obs\": 157.86676025390625, \"slope\": -0.06458193808794022, \"chain\": 3, \"draw\": 188}, {\"draws\": 788, \"mouse\": 4, \"mu_intercept_per_group\": 10.387492179870605, \"sigma_intercept_per_group\": 0.19953814148902893, \"sigma_obs\": 157.86676025390625, \"slope\": -0.06458193808794022, \"chain\": 3, \"draw\": 188}, {\"draws\": 788, \"mouse\": 5, \"mu_intercept_per_group\": 9.305474281311035, \"sigma_intercept_per_group\": 0.19953814148902893, \"sigma_obs\": 157.86676025390625, \"slope\": -0.06458193808794022, \"chain\": 3, \"draw\": 188}, {\"draws\": 788, \"mouse\": 6, \"mu_intercept_per_group\": 9.314534187316895, \"sigma_intercept_per_group\": 0.19953814148902893, \"sigma_obs\": 157.86676025390625, \"slope\": -0.06458193808794022, \"chain\": 3, \"draw\": 188}, {\"draws\": 788, \"mouse\": 7, \"mu_intercept_per_group\": 8.930122375488281, \"sigma_intercept_per_group\": 0.19953814148902893, \"sigma_obs\": 157.86676025390625, \"slope\": -0.06458193808794022, \"chain\": 3, \"draw\": 188}, {\"draws\": 789, \"mouse\": 0, \"mu_intercept_per_group\": 11.598896980285645, \"sigma_intercept_per_group\": 0.21536412835121155, \"sigma_obs\": 164.75369262695312, \"slope\": -0.0817842036485672, \"chain\": 3, \"draw\": 189}, {\"draws\": 789, \"mouse\": 1, \"mu_intercept_per_group\": 11.160624504089355, \"sigma_intercept_per_group\": 0.21536412835121155, \"sigma_obs\": 164.75369262695312, \"slope\": -0.0817842036485672, \"chain\": 3, \"draw\": 189}, {\"draws\": 789, \"mouse\": 2, \"mu_intercept_per_group\": 10.744789123535156, \"sigma_intercept_per_group\": 0.21536412835121155, \"sigma_obs\": 164.75369262695312, \"slope\": -0.0817842036485672, \"chain\": 3, \"draw\": 189}, {\"draws\": 789, \"mouse\": 3, \"mu_intercept_per_group\": 10.469903945922852, \"sigma_intercept_per_group\": 0.21536412835121155, \"sigma_obs\": 164.75369262695312, \"slope\": -0.0817842036485672, \"chain\": 3, \"draw\": 189}, {\"draws\": 789, \"mouse\": 4, \"mu_intercept_per_group\": 10.311260223388672, \"sigma_intercept_per_group\": 0.21536412835121155, \"sigma_obs\": 164.75369262695312, \"slope\": -0.0817842036485672, \"chain\": 3, \"draw\": 189}, {\"draws\": 789, \"mouse\": 5, \"mu_intercept_per_group\": 9.363936424255371, \"sigma_intercept_per_group\": 0.21536412835121155, \"sigma_obs\": 164.75369262695312, \"slope\": -0.0817842036485672, \"chain\": 3, \"draw\": 189}, {\"draws\": 789, \"mouse\": 6, \"mu_intercept_per_group\": 9.16152286529541, \"sigma_intercept_per_group\": 0.21536412835121155, \"sigma_obs\": 164.75369262695312, \"slope\": -0.0817842036485672, \"chain\": 3, \"draw\": 189}, {\"draws\": 789, \"mouse\": 7, \"mu_intercept_per_group\": 8.62782096862793, \"sigma_intercept_per_group\": 0.21536412835121155, \"sigma_obs\": 164.75369262695312, \"slope\": -0.0817842036485672, \"chain\": 3, \"draw\": 189}, {\"draws\": 790, \"mouse\": 0, \"mu_intercept_per_group\": 10.86587142944336, \"sigma_intercept_per_group\": 0.23355171084403992, \"sigma_obs\": 165.1996612548828, \"slope\": -0.0883173942565918, \"chain\": 3, \"draw\": 190}, {\"draws\": 790, \"mouse\": 1, \"mu_intercept_per_group\": 10.432299613952637, \"sigma_intercept_per_group\": 0.23355171084403992, \"sigma_obs\": 165.1996612548828, \"slope\": -0.0883173942565918, \"chain\": 3, \"draw\": 190}, {\"draws\": 790, \"mouse\": 2, \"mu_intercept_per_group\": 10.342677116394043, \"sigma_intercept_per_group\": 0.23355171084403992, \"sigma_obs\": 165.1996612548828, \"slope\": -0.0883173942565918, \"chain\": 3, \"draw\": 190}, {\"draws\": 790, \"mouse\": 3, \"mu_intercept_per_group\": 9.217738151550293, \"sigma_intercept_per_group\": 0.23355171084403992, \"sigma_obs\": 165.1996612548828, \"slope\": -0.0883173942565918, \"chain\": 3, \"draw\": 190}, {\"draws\": 790, \"mouse\": 4, \"mu_intercept_per_group\": 9.447562217712402, \"sigma_intercept_per_group\": 0.23355171084403992, \"sigma_obs\": 165.1996612548828, \"slope\": -0.0883173942565918, \"chain\": 3, \"draw\": 190}, {\"draws\": 790, \"mouse\": 5, \"mu_intercept_per_group\": 8.57290267944336, \"sigma_intercept_per_group\": 0.23355171084403992, \"sigma_obs\": 165.1996612548828, \"slope\": -0.0883173942565918, \"chain\": 3, \"draw\": 190}, {\"draws\": 790, \"mouse\": 6, \"mu_intercept_per_group\": 8.599268913269043, \"sigma_intercept_per_group\": 0.23355171084403992, \"sigma_obs\": 165.1996612548828, \"slope\": -0.0883173942565918, \"chain\": 3, \"draw\": 190}, {\"draws\": 790, \"mouse\": 7, \"mu_intercept_per_group\": 7.581075668334961, \"sigma_intercept_per_group\": 0.23355171084403992, \"sigma_obs\": 165.1996612548828, \"slope\": -0.0883173942565918, \"chain\": 3, \"draw\": 190}, {\"draws\": 791, \"mouse\": 0, \"mu_intercept_per_group\": 11.043574333190918, \"sigma_intercept_per_group\": 0.2303226739168167, \"sigma_obs\": 164.83558654785156, \"slope\": -0.08752425760030746, \"chain\": 3, \"draw\": 191}, {\"draws\": 791, \"mouse\": 1, \"mu_intercept_per_group\": 10.403690338134766, \"sigma_intercept_per_group\": 0.2303226739168167, \"sigma_obs\": 164.83558654785156, \"slope\": -0.08752425760030746, \"chain\": 3, \"draw\": 191}, {\"draws\": 791, \"mouse\": 2, \"mu_intercept_per_group\": 10.290645599365234, \"sigma_intercept_per_group\": 0.2303226739168167, \"sigma_obs\": 164.83558654785156, \"slope\": -0.08752425760030746, \"chain\": 3, \"draw\": 191}, {\"draws\": 791, \"mouse\": 3, \"mu_intercept_per_group\": 9.412010192871094, \"sigma_intercept_per_group\": 0.2303226739168167, \"sigma_obs\": 164.83558654785156, \"slope\": -0.08752425760030746, \"chain\": 3, \"draw\": 191}, {\"draws\": 791, \"mouse\": 4, \"mu_intercept_per_group\": 9.441898345947266, \"sigma_intercept_per_group\": 0.2303226739168167, \"sigma_obs\": 164.83558654785156, \"slope\": -0.08752425760030746, \"chain\": 3, \"draw\": 191}, {\"draws\": 791, \"mouse\": 5, \"mu_intercept_per_group\": 8.868480682373047, \"sigma_intercept_per_group\": 0.2303226739168167, \"sigma_obs\": 164.83558654785156, \"slope\": -0.08752425760030746, \"chain\": 3, \"draw\": 191}, {\"draws\": 791, \"mouse\": 6, \"mu_intercept_per_group\": 8.402600288391113, \"sigma_intercept_per_group\": 0.2303226739168167, \"sigma_obs\": 164.83558654785156, \"slope\": -0.08752425760030746, \"chain\": 3, \"draw\": 191}, {\"draws\": 791, \"mouse\": 7, \"mu_intercept_per_group\": 7.72254753112793, \"sigma_intercept_per_group\": 0.2303226739168167, \"sigma_obs\": 164.83558654785156, \"slope\": -0.08752425760030746, \"chain\": 3, \"draw\": 191}, {\"draws\": 792, \"mouse\": 0, \"mu_intercept_per_group\": 10.887977600097656, \"sigma_intercept_per_group\": 0.23241952061653137, \"sigma_obs\": 164.63394165039062, \"slope\": -0.0876179039478302, \"chain\": 3, \"draw\": 192}, {\"draws\": 792, \"mouse\": 1, \"mu_intercept_per_group\": 10.099590301513672, \"sigma_intercept_per_group\": 0.23241952061653137, \"sigma_obs\": 164.63394165039062, \"slope\": -0.0876179039478302, \"chain\": 3, \"draw\": 192}, {\"draws\": 792, \"mouse\": 2, \"mu_intercept_per_group\": 10.4866304397583, \"sigma_intercept_per_group\": 0.23241952061653137, \"sigma_obs\": 164.63394165039062, \"slope\": -0.0876179039478302, \"chain\": 3, \"draw\": 192}, {\"draws\": 792, \"mouse\": 3, \"mu_intercept_per_group\": 9.310357093811035, \"sigma_intercept_per_group\": 0.23241952061653137, \"sigma_obs\": 164.63394165039062, \"slope\": -0.0876179039478302, \"chain\": 3, \"draw\": 192}, {\"draws\": 792, \"mouse\": 4, \"mu_intercept_per_group\": 9.445374488830566, \"sigma_intercept_per_group\": 0.23241952061653137, \"sigma_obs\": 164.63394165039062, \"slope\": -0.0876179039478302, \"chain\": 3, \"draw\": 192}, {\"draws\": 792, \"mouse\": 5, \"mu_intercept_per_group\": 8.559183120727539, \"sigma_intercept_per_group\": 0.23241952061653137, \"sigma_obs\": 164.63394165039062, \"slope\": -0.0876179039478302, \"chain\": 3, \"draw\": 192}, {\"draws\": 792, \"mouse\": 6, \"mu_intercept_per_group\": 8.386777877807617, \"sigma_intercept_per_group\": 0.23241952061653137, \"sigma_obs\": 164.63394165039062, \"slope\": -0.0876179039478302, \"chain\": 3, \"draw\": 192}, {\"draws\": 792, \"mouse\": 7, \"mu_intercept_per_group\": 7.578215599060059, \"sigma_intercept_per_group\": 0.23241952061653137, \"sigma_obs\": 164.63394165039062, \"slope\": -0.0876179039478302, \"chain\": 3, \"draw\": 192}, {\"draws\": 793, \"mouse\": 0, \"mu_intercept_per_group\": 10.963240623474121, \"sigma_intercept_per_group\": 0.23507630825042725, \"sigma_obs\": 164.94912719726562, \"slope\": -0.08777852356433868, \"chain\": 3, \"draw\": 193}, {\"draws\": 793, \"mouse\": 1, \"mu_intercept_per_group\": 10.401483535766602, \"sigma_intercept_per_group\": 0.23507630825042725, \"sigma_obs\": 164.94912719726562, \"slope\": -0.08777852356433868, \"chain\": 3, \"draw\": 193}, {\"draws\": 793, \"mouse\": 2, \"mu_intercept_per_group\": 10.293546676635742, \"sigma_intercept_per_group\": 0.23507630825042725, \"sigma_obs\": 164.94912719726562, \"slope\": -0.08777852356433868, \"chain\": 3, \"draw\": 193}, {\"draws\": 793, \"mouse\": 3, \"mu_intercept_per_group\": 9.325892448425293, \"sigma_intercept_per_group\": 0.23507630825042725, \"sigma_obs\": 164.94912719726562, \"slope\": -0.08777852356433868, \"chain\": 3, \"draw\": 193}, {\"draws\": 793, \"mouse\": 4, \"mu_intercept_per_group\": 9.382390975952148, \"sigma_intercept_per_group\": 0.23507630825042725, \"sigma_obs\": 164.94912719726562, \"slope\": -0.08777852356433868, \"chain\": 3, \"draw\": 193}, {\"draws\": 793, \"mouse\": 5, \"mu_intercept_per_group\": 8.614899635314941, \"sigma_intercept_per_group\": 0.23507630825042725, \"sigma_obs\": 164.94912719726562, \"slope\": -0.08777852356433868, \"chain\": 3, \"draw\": 193}, {\"draws\": 793, \"mouse\": 6, \"mu_intercept_per_group\": 8.464072227478027, \"sigma_intercept_per_group\": 0.23507630825042725, \"sigma_obs\": 164.94912719726562, \"slope\": -0.08777852356433868, \"chain\": 3, \"draw\": 193}, {\"draws\": 793, \"mouse\": 7, \"mu_intercept_per_group\": 7.588108062744141, \"sigma_intercept_per_group\": 0.23507630825042725, \"sigma_obs\": 164.94912719726562, \"slope\": -0.08777852356433868, \"chain\": 3, \"draw\": 193}, {\"draws\": 794, \"mouse\": 0, \"mu_intercept_per_group\": 10.900333404541016, \"sigma_intercept_per_group\": 0.22328129410743713, \"sigma_obs\": 151.646484375, \"slope\": -0.09036821871995926, \"chain\": 3, \"draw\": 194}, {\"draws\": 794, \"mouse\": 1, \"mu_intercept_per_group\": 10.454730033874512, \"sigma_intercept_per_group\": 0.22328129410743713, \"sigma_obs\": 151.646484375, \"slope\": -0.09036821871995926, \"chain\": 3, \"draw\": 194}, {\"draws\": 794, \"mouse\": 2, \"mu_intercept_per_group\": 9.916970252990723, \"sigma_intercept_per_group\": 0.22328129410743713, \"sigma_obs\": 151.646484375, \"slope\": -0.09036821871995926, \"chain\": 3, \"draw\": 194}, {\"draws\": 794, \"mouse\": 3, \"mu_intercept_per_group\": 9.830240249633789, \"sigma_intercept_per_group\": 0.22328129410743713, \"sigma_obs\": 151.646484375, \"slope\": -0.09036821871995926, \"chain\": 3, \"draw\": 194}, {\"draws\": 794, \"mouse\": 4, \"mu_intercept_per_group\": 9.289810180664062, \"sigma_intercept_per_group\": 0.22328129410743713, \"sigma_obs\": 151.646484375, \"slope\": -0.09036821871995926, \"chain\": 3, \"draw\": 194}, {\"draws\": 794, \"mouse\": 5, \"mu_intercept_per_group\": 8.764251708984375, \"sigma_intercept_per_group\": 0.22328129410743713, \"sigma_obs\": 151.646484375, \"slope\": -0.09036821871995926, \"chain\": 3, \"draw\": 194}, {\"draws\": 794, \"mouse\": 6, \"mu_intercept_per_group\": 8.5060453414917, \"sigma_intercept_per_group\": 0.22328129410743713, \"sigma_obs\": 151.646484375, \"slope\": -0.09036821871995926, \"chain\": 3, \"draw\": 194}, {\"draws\": 794, \"mouse\": 7, \"mu_intercept_per_group\": 7.5997514724731445, \"sigma_intercept_per_group\": 0.22328129410743713, \"sigma_obs\": 151.646484375, \"slope\": -0.09036821871995926, \"chain\": 3, \"draw\": 194}, {\"draws\": 795, \"mouse\": 0, \"mu_intercept_per_group\": 10.542780876159668, \"sigma_intercept_per_group\": 0.23383519053459167, \"sigma_obs\": 162.35418701171875, \"slope\": -0.0827443078160286, \"chain\": 3, \"draw\": 195}, {\"draws\": 795, \"mouse\": 1, \"mu_intercept_per_group\": 10.253045082092285, \"sigma_intercept_per_group\": 0.23383519053459167, \"sigma_obs\": 162.35418701171875, \"slope\": -0.0827443078160286, \"chain\": 3, \"draw\": 195}, {\"draws\": 795, \"mouse\": 2, \"mu_intercept_per_group\": 10.045275688171387, \"sigma_intercept_per_group\": 0.23383519053459167, \"sigma_obs\": 162.35418701171875, \"slope\": -0.0827443078160286, \"chain\": 3, \"draw\": 195}, {\"draws\": 795, \"mouse\": 3, \"mu_intercept_per_group\": 9.24405288696289, \"sigma_intercept_per_group\": 0.23383519053459167, \"sigma_obs\": 162.35418701171875, \"slope\": -0.0827443078160286, \"chain\": 3, \"draw\": 195}, {\"draws\": 795, \"mouse\": 4, \"mu_intercept_per_group\": 9.143983840942383, \"sigma_intercept_per_group\": 0.23383519053459167, \"sigma_obs\": 162.35418701171875, \"slope\": -0.0827443078160286, \"chain\": 3, \"draw\": 195}, {\"draws\": 795, \"mouse\": 5, \"mu_intercept_per_group\": 8.51268482208252, \"sigma_intercept_per_group\": 0.23383519053459167, \"sigma_obs\": 162.35418701171875, \"slope\": -0.0827443078160286, \"chain\": 3, \"draw\": 195}, {\"draws\": 795, \"mouse\": 6, \"mu_intercept_per_group\": 8.170395851135254, \"sigma_intercept_per_group\": 0.23383519053459167, \"sigma_obs\": 162.35418701171875, \"slope\": -0.0827443078160286, \"chain\": 3, \"draw\": 195}, {\"draws\": 795, \"mouse\": 7, \"mu_intercept_per_group\": 7.812601089477539, \"sigma_intercept_per_group\": 0.23383519053459167, \"sigma_obs\": 162.35418701171875, \"slope\": -0.0827443078160286, \"chain\": 3, \"draw\": 195}, {\"draws\": 796, \"mouse\": 0, \"mu_intercept_per_group\": 7.314107418060303, \"sigma_intercept_per_group\": 0.34177854657173157, \"sigma_obs\": 164.07696533203125, \"slope\": -0.06025856360793114, \"chain\": 3, \"draw\": 196}, {\"draws\": 796, \"mouse\": 1, \"mu_intercept_per_group\": 6.979272365570068, \"sigma_intercept_per_group\": 0.34177854657173157, \"sigma_obs\": 164.07696533203125, \"slope\": -0.06025856360793114, \"chain\": 3, \"draw\": 196}, {\"draws\": 796, \"mouse\": 2, \"mu_intercept_per_group\": 6.8012213706970215, \"sigma_intercept_per_group\": 0.34177854657173157, \"sigma_obs\": 164.07696533203125, \"slope\": -0.06025856360793114, \"chain\": 3, \"draw\": 196}, {\"draws\": 796, \"mouse\": 3, \"mu_intercept_per_group\": 6.467513561248779, \"sigma_intercept_per_group\": 0.34177854657173157, \"sigma_obs\": 164.07696533203125, \"slope\": -0.06025856360793114, \"chain\": 3, \"draw\": 196}, {\"draws\": 796, \"mouse\": 4, \"mu_intercept_per_group\": 6.396047115325928, \"sigma_intercept_per_group\": 0.34177854657173157, \"sigma_obs\": 164.07696533203125, \"slope\": -0.06025856360793114, \"chain\": 3, \"draw\": 196}, {\"draws\": 796, \"mouse\": 5, \"mu_intercept_per_group\": 6.0365214347839355, \"sigma_intercept_per_group\": 0.34177854657173157, \"sigma_obs\": 164.07696533203125, \"slope\": -0.06025856360793114, \"chain\": 3, \"draw\": 196}, {\"draws\": 796, \"mouse\": 6, \"mu_intercept_per_group\": 5.463860511779785, \"sigma_intercept_per_group\": 0.34177854657173157, \"sigma_obs\": 164.07696533203125, \"slope\": -0.06025856360793114, \"chain\": 3, \"draw\": 196}, {\"draws\": 796, \"mouse\": 7, \"mu_intercept_per_group\": 5.04931640625, \"sigma_intercept_per_group\": 0.34177854657173157, \"sigma_obs\": 164.07696533203125, \"slope\": -0.06025856360793114, \"chain\": 3, \"draw\": 196}, {\"draws\": 797, \"mouse\": 0, \"mu_intercept_per_group\": 7.275882244110107, \"sigma_intercept_per_group\": 0.3400193452835083, \"sigma_obs\": 164.009765625, \"slope\": -0.060813914984464645, \"chain\": 3, \"draw\": 197}, {\"draws\": 797, \"mouse\": 1, \"mu_intercept_per_group\": 7.20744514465332, \"sigma_intercept_per_group\": 0.3400193452835083, \"sigma_obs\": 164.009765625, \"slope\": -0.060813914984464645, \"chain\": 3, \"draw\": 197}, {\"draws\": 797, \"mouse\": 2, \"mu_intercept_per_group\": 6.797229766845703, \"sigma_intercept_per_group\": 0.3400193452835083, \"sigma_obs\": 164.009765625, \"slope\": -0.060813914984464645, \"chain\": 3, \"draw\": 197}, {\"draws\": 797, \"mouse\": 3, \"mu_intercept_per_group\": 6.467225551605225, \"sigma_intercept_per_group\": 0.3400193452835083, \"sigma_obs\": 164.009765625, \"slope\": -0.060813914984464645, \"chain\": 3, \"draw\": 197}, {\"draws\": 797, \"mouse\": 4, \"mu_intercept_per_group\": 6.4180755615234375, \"sigma_intercept_per_group\": 0.3400193452835083, \"sigma_obs\": 164.009765625, \"slope\": -0.060813914984464645, \"chain\": 3, \"draw\": 197}, {\"draws\": 797, \"mouse\": 5, \"mu_intercept_per_group\": 5.983630180358887, \"sigma_intercept_per_group\": 0.3400193452835083, \"sigma_obs\": 164.009765625, \"slope\": -0.060813914984464645, \"chain\": 3, \"draw\": 197}, {\"draws\": 797, \"mouse\": 6, \"mu_intercept_per_group\": 5.4197845458984375, \"sigma_intercept_per_group\": 0.3400193452835083, \"sigma_obs\": 164.009765625, \"slope\": -0.060813914984464645, \"chain\": 3, \"draw\": 197}, {\"draws\": 797, \"mouse\": 7, \"mu_intercept_per_group\": 5.030885219573975, \"sigma_intercept_per_group\": 0.3400193452835083, \"sigma_obs\": 164.009765625, \"slope\": -0.060813914984464645, \"chain\": 3, \"draw\": 197}, {\"draws\": 798, \"mouse\": 0, \"mu_intercept_per_group\": 6.354033946990967, \"sigma_intercept_per_group\": 0.3906073570251465, \"sigma_obs\": 159.022705078125, \"slope\": -0.06666383147239685, \"chain\": 3, \"draw\": 198}, {\"draws\": 798, \"mouse\": 1, \"mu_intercept_per_group\": 6.270650386810303, \"sigma_intercept_per_group\": 0.3906073570251465, \"sigma_obs\": 159.022705078125, \"slope\": -0.06666383147239685, \"chain\": 3, \"draw\": 198}, {\"draws\": 798, \"mouse\": 2, \"mu_intercept_per_group\": 5.907196998596191, \"sigma_intercept_per_group\": 0.3906073570251465, \"sigma_obs\": 159.022705078125, \"slope\": -0.06666383147239685, \"chain\": 3, \"draw\": 198}, {\"draws\": 798, \"mouse\": 3, \"mu_intercept_per_group\": 5.592130661010742, \"sigma_intercept_per_group\": 0.3906073570251465, \"sigma_obs\": 159.022705078125, \"slope\": -0.06666383147239685, \"chain\": 3, \"draw\": 198}, {\"draws\": 798, \"mouse\": 4, \"mu_intercept_per_group\": 5.341757774353027, \"sigma_intercept_per_group\": 0.3906073570251465, \"sigma_obs\": 159.022705078125, \"slope\": -0.06666383147239685, \"chain\": 3, \"draw\": 198}, {\"draws\": 798, \"mouse\": 5, \"mu_intercept_per_group\": 5.18872594833374, \"sigma_intercept_per_group\": 0.3906073570251465, \"sigma_obs\": 159.022705078125, \"slope\": -0.06666383147239685, \"chain\": 3, \"draw\": 198}, {\"draws\": 798, \"mouse\": 6, \"mu_intercept_per_group\": 4.832635402679443, \"sigma_intercept_per_group\": 0.3906073570251465, \"sigma_obs\": 159.022705078125, \"slope\": -0.06666383147239685, \"chain\": 3, \"draw\": 198}, {\"draws\": 798, \"mouse\": 7, \"mu_intercept_per_group\": 4.285597324371338, \"sigma_intercept_per_group\": 0.3906073570251465, \"sigma_obs\": 159.022705078125, \"slope\": -0.06666383147239685, \"chain\": 3, \"draw\": 198}, {\"draws\": 799, \"mouse\": 0, \"mu_intercept_per_group\": 6.318623065948486, \"sigma_intercept_per_group\": 0.38642197847366333, \"sigma_obs\": 157.72372436523438, \"slope\": -0.06525484472513199, \"chain\": 3, \"draw\": 199}, {\"draws\": 799, \"mouse\": 1, \"mu_intercept_per_group\": 6.076009750366211, \"sigma_intercept_per_group\": 0.38642197847366333, \"sigma_obs\": 157.72372436523438, \"slope\": -0.06525484472513199, \"chain\": 3, \"draw\": 199}, {\"draws\": 799, \"mouse\": 2, \"mu_intercept_per_group\": 5.996989727020264, \"sigma_intercept_per_group\": 0.38642197847366333, \"sigma_obs\": 157.72372436523438, \"slope\": -0.06525484472513199, \"chain\": 3, \"draw\": 199}, {\"draws\": 799, \"mouse\": 3, \"mu_intercept_per_group\": 5.647278785705566, \"sigma_intercept_per_group\": 0.38642197847366333, \"sigma_obs\": 157.72372436523438, \"slope\": -0.06525484472513199, \"chain\": 3, \"draw\": 199}, {\"draws\": 799, \"mouse\": 4, \"mu_intercept_per_group\": 5.5670647621154785, \"sigma_intercept_per_group\": 0.38642197847366333, \"sigma_obs\": 157.72372436523438, \"slope\": -0.06525484472513199, \"chain\": 3, \"draw\": 199}, {\"draws\": 799, \"mouse\": 5, \"mu_intercept_per_group\": 5.142434597015381, \"sigma_intercept_per_group\": 0.38642197847366333, \"sigma_obs\": 157.72372436523438, \"slope\": -0.06525484472513199, \"chain\": 3, \"draw\": 199}, {\"draws\": 799, \"mouse\": 6, \"mu_intercept_per_group\": 4.923486709594727, \"sigma_intercept_per_group\": 0.38642197847366333, \"sigma_obs\": 157.72372436523438, \"slope\": -0.06525484472513199, \"chain\": 3, \"draw\": 199}, {\"draws\": 799, \"mouse\": 7, \"mu_intercept_per_group\": 4.726696968078613, \"sigma_intercept_per_group\": 0.38642197847366333, \"sigma_obs\": 157.72372436523438, \"slope\": -0.06525484472513199, \"chain\": 3, \"draw\": 199}]}}, {\"mode\": \"vega-lite\"});\n</script>",
      "text/plain": "alt.LayerChart(...)"
     },
     "execution_count": 3,
     "metadata": {},
     "output_type": "execute_result"
    }
   ],
   "source": [
    "window = BayesRegression(df=df, y='isi', treatment='stim_strength', group='mouse', detail='i_trial')\n",
    "window.fit(add_group_slope=False, dist_y='gamma')\n",
    "window.chart"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 4,
   "outputs": [
    {
     "ename": "AttributeError",
     "evalue": "'BayesRegression' object has no attribute 'explore_model_kinds'",
     "output_type": "error",
     "traceback": [
      "\u001B[0;31m---------------------------------------------------------------------------\u001B[0m",
      "\u001B[0;31mAttributeError\u001B[0m                            Traceback (most recent call last)",
      "\u001B[0;32m<ipython-input-4-7df91f859f51>\u001B[0m in \u001B[0;36m<module>\u001B[0;34m\u001B[0m\n\u001B[0;32m----> 1\u001B[0;31m \u001B[0mwindow\u001B[0m\u001B[0;34m.\u001B[0m\u001B[0mexplore_model_kinds\u001B[0m\u001B[0;34m(\u001B[0m\u001B[0;34m)\u001B[0m\u001B[0;34m\u001B[0m\u001B[0;34m\u001B[0m\u001B[0m\n\u001B[0m",
      "\u001B[0;31mAttributeError\u001B[0m: 'BayesRegression' object has no attribute 'explore_model_kinds'"
     ]
    }
   ],
   "source": [
    "window.explore_model_kinds()"
   ],
   "metadata": {
    "collapsed": false,
    "pycharm": {
     "name": "#%%\n"
    }
   }
  },
  {
   "cell_type": "code",
   "execution_count": null,
   "outputs": [],
   "source": [
    "## Power"
   ],
   "metadata": {
    "collapsed": false,
    "pycharm": {
     "name": "#%%\n"
    }
   }
  },
  {
   "cell_type": "markdown",
   "metadata": {},
   "source": [
    "## Power"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": null,
   "metadata": {},
   "outputs": [],
   "source": [
    "df = []\n",
    "for slope in np.linspace(4, 400, 4):\n",
    "    df1 = generate_fake_lfp(mouse_response_slope=slope)[0]\n",
    "    df1['stim_strength'] = slope\n",
    "    df.append(df1)\n",
    "df = pd.concat(df)\n",
    "\n",
    "BayesWindow(df=df, y='Power', treatment='stim_strength', group='mouse', detail='i_trial').data_box_detail()\n"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": null,
   "metadata": {
    "pycharm": {
     "name": "#%%\n"
    }
   },
   "outputs": [],
   "source": [
    "window = BayesRegression(df=df, y='Power', treatment='stim_strength', group='mouse', detail='i_trial')\n",
    "window.fit(add_group_slope=False, dist_y='gamma')\n",
    "window.chart"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": null,
   "outputs": [],
   "source": [
    "window = BayesRegression(df=df, y='Power', treatment='stim_strength', condition='mouse', detail='i_trial')\n",
    "window.fit(add_condition_slope=True, center_intercept=True, dist_y='gamma')\n",
    "window.chart\n",
    "\n"
   ],
   "metadata": {
    "collapsed": false,
    "pycharm": {
     "name": "#%%\n"
    }
   }
  },
  {
   "cell_type": "code",
   "execution_count": null,
   "outputs": [],
   "source": [
    "window.explore_model_kinds()"
   ],
   "metadata": {
    "collapsed": false,
    "pycharm": {
     "name": "#%%\n"
    }
   }
  },
  {
   "cell_type": "code",
   "execution_count": null,
   "outputs": [],
   "source": [
    "window.explore_models()"
   ],
   "metadata": {
    "collapsed": false,
    "pycharm": {
     "name": "#%%\n"
    }
   }
  },
  {
   "cell_type": "code",
   "execution_count": null,
   "outputs": [],
   "source": [
    "window.explore_models()"
   ],
   "metadata": {
    "collapsed": false,
    "pycharm": {
     "name": "#%%\n"
    }
   }
  },
  {
   "cell_type": "code",
   "execution_count": null,
   "outputs": [],
   "source": [
    "window.explore_models()\n"
   ],
   "metadata": {
    "collapsed": false,
    "pycharm": {
     "name": "#%%\n"
    }
   }
  }
 ],
 "metadata": {
  "celltoolbar": "Slideshow",
  "hide_code_all_hidden": true,
  "kernelspec": {
   "display_name": "Python 3",
   "language": "python",
   "name": "python3"
  },
  "language_info": {
   "codemirror_mode": {
    "name": "ipython",
    "version": 3
   },
   "file_extension": ".py",
   "mimetype": "text/x-python",
   "name": "python",
   "nbconvert_exporter": "python",
   "pygments_lexer": "ipython3",
   "version": "3.8.5"
  }
 },
 "nbformat": 4,
 "nbformat_minor": 1
}